@@ -1,12 +1,11 @@
-#!/usr/bin/env php
 <?php
 //
 // Created on: <26-Jun-2007 15:00:00 dl>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -45,12 +44,9 @@ global $script;
 /*!
  includes
 */
-require 'autoload.php';
+require_once 'autoload.php';
 
-//include_once( 'kernel/classes/ezscript.php' );
 require_once( 'kernel/common/i18n.php' );
-//include_once( 'kernel/classes/ezpackage.php' );
-
 
 /**************************************************************
 * 'cli->output' wrappers                                      *
@@ -172,16 +168,31 @@ function checkDir( $dirName )
         if( strpos( $action, 'n' ) === 0 )
             showError( "Unable to continue. Aborting..." );
 
-        if( !eZDir::mkdir( $dirName, eZDir::directoryPermission(), true ) )
+        if( !eZDir::mkdir( $dirName, false, true ) )
             showError( "Unable to create dir '$dirName'. Aborting..." );
     }
 
     return true;
 }
 
-function installScriptDir( $packageRepository )
+function installScriptDir( $packageRepository, $packageName )
 {
-    return ( eZPackage::repositoryPath() . "/$packageRepository/ezwebin_site" );
+    return ( eZPackage::repositoryPath() . "/$packageRepository/$packageName" );
+}
+
+function defaultVendor()
+{
+    // $vendor is taken from 'ezwebin_site' package.
+    $vendor = 'eZ systems';
+    return $vendor;
+}
+
+function repositoryByVendor( $vendor )
+{
+    // it's copy/paste from eZPackage
+    $trans = eZCharTransform::instance();
+    $repository = $trans->transformByGroup( $vendor, 'urlalias' );
+    return $repository;
 }
 
 /*!
@@ -270,8 +281,6 @@ function downloadPackages( $packageList, $packageURL, $packageDir, $packageRepos
     {
         // TODO: using 'eZStepSiteTypes' is hack.
         //       need to exclude 'downloadFile' from that class.
-        //include_once( 'kernel/setup/steps/ezstep_site_types.php' );
-
         $tpl = false;
         $http = false;
         $ini = false;
@@ -282,9 +291,10 @@ function downloadPackages( $packageList, $packageURL, $packageDir, $packageRepos
         foreach( $downloadPackageList as $packageName )
         {
             showMessage( "$packageName" );
+
             $archiveName = $downloader->downloadFile( "$packageURL/$packageName.ezpkg", $packageDir );
             if ( $archiveName === false )
-                showError( "Error while downloading: " . $downloader->ErrorMsg );
+                showError( "download error - " . $downloader->ErrorMsg );
         }
     }
 
@@ -295,8 +305,8 @@ function downloadPackages( $packageList, $packageURL, $packageDir, $packageRepos
     foreach( $packageList as $packageName )
     {
         showMessage( "$packageName" );
-        $package = eZPackage::import( "$packageDir/$packageName.ezpkg", $packageName, false, $packageRepository );
 
+        $package = eZPackage::import( "$packageDir/$packageName.ezpkg", $packageName, false, $packageRepository );
         if( !is_object( $package ) )
             showError( "Faild to import '$packageName' package: err = $package" );
     }
@@ -313,6 +323,11 @@ function installPackages( $packageList, $params = array() )
 
     showMessage2( "Installing..." );
 
+    // copy/paste from eZPackage
+    if ( !isset( $params['path'] ) )
+        $params['path'] = false;
+
+    // process packages
     $action = false;
     while( ( list( , $packageName ) = each( $packageList ) ) && $action != EZ_INSTALL_PACKAGE_EXTRA_ACTION_QUIT )
     {
@@ -320,20 +335,19 @@ function installPackages( $packageList, $params = array() )
 
         $cli->output( $cli->stylize( 'emphasize', "Installing package '$packageName'" ), true );
 
-        //$params['install_type'] = 'install';
-
         $package = eZPackage::fetch( $packageName );
         if ( !is_object( $package ) )
         {
             showError( "can't fetch package '$packageName'. Aborting..." );
         }
 
-        // skip installing 'site packages'
-        $packageType = $package->attribute( 'type' );
-
-        if ( $packageType == 'site' )
+        // skip package which can not be installed(e.g. which can be imported only, like 'design' and 'site' types)
+        if ( $package->attribute( 'install_type' ) != 'install' )
+        {
             continue;
+        }
 
+        $packageType = $package->attribute( 'type' );
         $packageItems = $package->installItemsList();
 
         while( ( list( , $item ) = each( $packageItems ) ) && $action != EZ_INSTALL_PACKAGE_EXTRA_ACTION_QUIT
@@ -403,32 +417,30 @@ function siteAccessMap( $siteAccessNameArray )
 
 function checkSiteaccess( $siteAccess, $bailOutOnError = false )
 {
-    //include_once( 'lib/ezutils/classes/ezextension.php' );
     $extensionBaseDir = eZExtension::baseDirectory();
     $extensionNameArray = eZExtension::activeExtensions();
-    $siteAccessPath = '/settings/siteaccess/';
+    $siteAccessSettingsDir = '/settings/siteaccess/';
     $siteAccessExists = false;
 
-    $path = 'settings/siteaccess/' . $siteAccess;
-
-    $pathMap = false;
-
-    if( file_exists( $path ) )
+    if( file_exists( 'settings/siteaccess/' . $siteAccess ) )
     {
-        $pathMap = array( $siteAccess => $path );
+        $siteAccessExists = true;
     }
     else
     {
         // Not found, check if it exists in extensions
         foreach( $extensionNameArray as $extensionName )
         {
-            $extensionSiteaccessPath = $extensionBaseDir . '/' . $extensionName . $siteAccessPath . $siteAccess;
+            $extensionSiteaccessPath = $extensionBaseDir . '/' . $extensionName . $siteAccessSettingsDir . $siteAccess;
             if( file_exists( $extensionSiteaccessPath ) )
-                $pathMap = array( $siteAccess => $extensionSiteaccessPath );
+            {
+                $siteAccessExists = true;
+                break;
+            }
         }
     }
 
-    if( !$pathMap && $bailOutOnError )
+    if( !$siteAccessExists && $bailOutOnError )
     {
         showError( "Siteaccess '" . $siteAccess . "' does not exist. Exiting..." );
     }
