@@ -4,9 +4,9 @@
 // Created on: <26-Jun-2007 15:00:00 dl>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -42,8 +42,6 @@
  includes
 */
 include_once( 'bin/php/ezwebincommon.php' );
-//include_once( 'kernel/classes/ezcontentlanguage.php' );
-
 require 'autoload.php';
 
 // script initializing
@@ -105,7 +103,7 @@ $script->initialize();
 $packageRepository = $scriptOptions['repository'];
 if ( !$packageRepository )
 {
-    $packageRepository = "ez_systems";
+    $packageRepository = repositoryByVendor( defaultVendor() );
 }
 
 
@@ -225,7 +223,7 @@ if( downloadPackages( $packageList, $packageURL, $packageDir, $packageRepository
                          'primary_language' => $primaryLanguage->attribute( 'locale' ),
                          'host' => $siteINI->variable( 'SiteSettings', 'SiteURL' ) );
 
-        $user =& eZUser::currentUser();
+        $user = eZUser::currentUser();
 
         $installParameters = array( 'site_access_map' => array( '*' => $userSiteaccess ),
                                     'top_nodes_map' => array( '*' => 2 ),
@@ -263,8 +261,6 @@ if( downloadPackages( $packageList, $packageURL, $packageDir, $packageRepository
             // BC for eZWebin < 1.3
             //
 
-            //include_once( 'kernel/classes/ezsiteinstaller.php' );
-
             $siteInstaller = new eZSiteInstaller();
 
             $params['locales'] = $params['all_language_codes'];
