@@ -6,9 +6,9 @@
 // Created on: <03-Apr-2003 16:05:43 sp>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -27,14 +27,11 @@
 //
 //
 
-/*! \file updateniceurls.php
+/*! \file
 */
 
 set_time_limit ( 0 );
 
-//include_once( 'lib/ezutils/classes/ezcli.php' );
-//include_once( 'kernel/classes/ezscript.php' );
-
 require 'autoload.php';
 $cli = eZCLI::instance();
 $script = eZScript::instance( array( 'description' => ( "eZ Publish url-alias imported and updater.\n\n" .
@@ -49,7 +46,7 @@ $script = eZScript::instance( array( 'description' => ( "eZ Publish url-alias im
 
 $script->startup();
 
-$options = $script->getOptions( "[db-user:][db-password:][db-database:][db-type:|db-driver:][sql]" .
+$options = $script->getOptions( "[db-host:][db-user:][db-password:][db-database:][db-type:|db-driver:][sql]" .
                                 "[no-import]" .
                                 "[import][import-nodes][import-aliases][import-redirections][import-wildcards]" .
                                 "[no-update-nodes][update-nodes]" .
@@ -90,7 +87,7 @@ $dbHost = isset( $options['db-host'] ) && $options['db-host'] ? $options['db-hos
 $dbName = $options['db-database'] ? $options['db-database'] : false;
 $dbImpl = $options['db-driver'] ? $options['db-driver'] : false;
 $showSQL = $options['sql'] ? true : false;
-$siteAccess = $options['siteaccess'] ? $options['siteaccess'] : false;;
+$siteAccess = $options['siteaccess'] ? $options['siteaccess'] : false;
 if ( $siteAccess )
 {
     changeSiteAccessSetting( $siteAccess );
@@ -112,10 +109,6 @@ function changeSiteAccessSetting( $siteAccess )
     }
 }
 
-//include_once( 'lib/ezdb/classes/ezdb.php' );
-//include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
-//include_once( 'kernel/classes/ezurlwildcard.php' );
-
 $db = eZDb::instance();
 
 if ( $dbHost or $dbName or $dbUser or $dbImpl )
@@ -138,11 +131,9 @@ if ( $dbHost or $dbName or $dbUser or $dbImpl )
 
 $db->setIsSQLOutputEnabled( $showSQL );
 
-//include_once( 'kernel/classes/ezcontentlanguage.php' );
 eZContentLanguage::setCronjobMode( true );
 
 $fetchLimit = 200;
-$cli->notice( "Using fetch limit: $fetchLimit" );
 if ( $options['fetch-limit'] !== null )
 {
     $fetchLimit = $options['fetch-limit'];
@@ -151,6 +142,7 @@ if ( $options['fetch-limit'] !== null )
         $script->shutdown( 1, "The --fetch-limit must be 1 or higher, tried with $fetchLimit" );
     }
 }
+
 $percentLength = 6;
 $timeLength = 12;
 $columnWidth = 72;
@@ -345,6 +337,10 @@ function logError( $msg )
 
 function logStore( $res, $func, $args )
 {
+    global $options;
+    if ( !isset( $options['debug'] ) )
+        return;
+
     $logFile = fopen( 'urlalias_store.log', "a" );
     if ( $logFile )
     {
@@ -403,7 +399,7 @@ function fetchHistoricWildcardCount()
 {
     $db = eZDB::instance();
     $sql = 'SELECT count(*) AS count FROM ezurlalias
-            WHERE is_imported = 0 AND is_wildcard = 1';
+            WHERE is_imported = 0 AND is_wildcard != 0';
     $rows = $db->arrayQuery( $sql );
     return $rows[0]['count'];
 }
@@ -434,7 +430,7 @@ function fetchHistoricWildcardChunk( $offset, $fetchLimit )
 {
     $db = eZDB::instance();
     $sql = 'SELECT id, is_wildcard, is_internal, source_url, destination_url
-            FROM ezurlalias WHERE is_imported = 0 AND is_wildcard = 1';
+            FROM ezurlalias WHERE is_imported = 0 AND is_wildcard != 0';
     $rows = $db->arrayQuery( $sql,
                              array( 'offset' => $offset,
                                     'limit' => $fetchLimit ) );
@@ -531,7 +527,7 @@ function createURLListCondition( $rows, $sqlField = 'id', $fieldKey = 'id' )
     {
         if ( $cond != "" )
              $cond .= " OR ";
-        $cond .= "{$sqlField} IN (" . join( ",", $singleIDs ) . ")";
+        $cond .= eZDB::instance()->generateSQLINStatement( $singleIDs, $sqlField );
     }
     return $cond;
 }
@@ -642,6 +638,10 @@ function backupTables( $stage )
     }
 }
 
+
+$cli->notice( "Note: any errors encountered will be logged to urlalias_error.log" );
+$cli->notice( "Using fetch limit: $fetchLimit" );
+
 resetErrorLog();
 resetStorageLog();
 
@@ -735,10 +735,13 @@ if ( $urlCount > 0 )
                 $linkID = false;
                 $source = eZURLAliasML::sanitizeURL( $source, true );
                 $destination = $row['destination_url'];
+                $aliasRedirects = true;
+
                 list( $action, $alwaysAvailable ) = decodeAction( $destination );
                 list( $actionType, $actionValue ) = explode( ":", $action, 2 );
                 $aliases = eZURLAliasML::fetchByAction( $actionType, $actionValue );
-                if ( $aliases )
+
+                if ( $aliases && $actionType == 'eznode' )
                 {
                     // This is a user-entered URL so lets make it an alias of the found dupe.
                     $linkID = (int)$aliases[0]->attribute( 'id' );
@@ -761,6 +764,15 @@ if ( $urlCount > 0 )
                     }
                     $linkID = false;
                 }
+                else if ( $actionType == 'module' )
+                {
+                    $linkID = true;
+
+                    // Links that pointed to modules in the old system does not
+                    // redirect. Make sure they won't redirect in the new system either.
+                    $aliasRedirects = false;
+                }
+
                 $aliases = eZURLAliasML::fetchByPath( $source );
                 if ( $aliases )
                 {
@@ -776,14 +788,14 @@ if ( $urlCount > 0 )
                 }
                 $res = eZURLAliasML::storePath( $source, $action,
                                                 false, $linkID, $alwaysAvailable, false,
-                                                false );
+                                                false, false, true, $aliasRedirects );
                 if ( !$res || $res['status'] !== true )
                 {
-                    logStoreError( $res, "eZURLAliasML::storePath", array( $source, $action, false, $linkID, $alwaysAvailable, false, false ) );
+                    logStoreError( $res, "eZURLAliasML::storePath", array( $source, $action, false, $linkID, $alwaysAvailable, false, false, false, true, $aliasRedirects ) );
                     list( $column, $counter ) = displayProgress( 'E', $urlImportStartTime, $counter, $urlCount, $column );
                     continue;
                 }
-                logStore( $res, "eZURLAliasML::storePath", array( $source, $action, false, $linkID, $alwaysAvailable, false, false ) );
+                logStore( $res, "eZURLAliasML::storePath", array( $source, $action, false, $linkID, $alwaysAvailable, false, false, false, true, $aliasRedirects ) );
                 $result = '.';
                 verifyData( $result, $source, $row['id'] );
                 list( $column, $counter ) = displayProgress( $result, $urlImportStartTime, $counter, $urlCount, $column );
@@ -883,11 +895,11 @@ if ( $urlCount > 0 )
                                                 true, true );
                 if ( !$res || $res['status'] !== true )
                 {
-                    logStoreError( $res, "eZURLAliasML::storePath", array( $source, $action, false, $linkID, $alwaysAvailable, false, false ) );
+                    logStoreError( $res, "eZURLAliasML::storePath", array( $source, $action, false, $linkID, $alwaysAvailable, false, true, true ) );
                     list( $column, $counter ) = displayProgress( 'E', $urlImportStartTime, $counter, $urlCount, $column );
                     continue;
                 }
-                logStore( $res, "eZURLAliasML::storePath", array( $source, $action, false, $linkID, $alwaysAvailable, false, false ) );
+                logStore( $res, "eZURLAliasML::storePath", array( $source, $action, false, $linkID, $alwaysAvailable, false, true, true ) );
                 $result = '.';
                 verifyData( $result, $source, $row['id'] );
                 list( $column, $counter ) = displayProgress( $result, $urlImportStartTime, $counter, $urlCount, $column );
@@ -1047,7 +1059,6 @@ if ( $urlCount > 0 )
     if ( $importOldAliasWildcard )
     {
         $cli->output( "Removing old wildcard caches" );
-        //include_once( 'kernel/classes/ezcache.php' );
         eZCache::clearByID( 'urlalias' );
     }
 
@@ -1087,7 +1098,7 @@ if ( $updateNodeAlias )
             foreach ( array_keys( $nodeList ) as $key )
             {
                 $node = $nodeList[ $key ];
-                $hasChanged = $node->updateSubTreePath( false );
+                $hasChanged = $node->updateSubTreePath();
                 if ( $hasChanged )
                 {
                     ++$changedNodes;
