@@ -1,8 +1,9 @@
 <?php
 //
-// SOFTWARE NAME: eZ publish
-// SOFTWARE RELEASE: 3.9.x
-// COPYRIGHT NOTICE: Copyright (C) 1999-2006 eZ systems AS
+// SOFTWARE NAME: eZ Publish
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -20,20 +21,15 @@
 //   MA 02110-1301, USA.
 //
 //
-//
 
 class ezodfInfo
 {
     static function info()
     {
-        return array( 'Name' => "eZ OpenOffice.org extension",
-                      'Version' => "2.0.1",
-                      'Copyright' => "Copyright (C) 1999-2006 eZ systems AS",
-                      'License' => "GNU General Public License v2.0",
-                      'Includes the following third-party software' => array( 'Name' => 'PhpConcept Library - Zip Module',
-                                                                              'Version' => '2.4',
-                                                                              'License' => 'GNU/LGPL - Vincent Blavet - November 2004',
-                                                                              'For more information' => 'http://www.phpconcept.net' )
+        return array( 'Name' => 'eZ OpenOffice.org extension',
+                      'Version' => '2.3.1',
+                      'Copyright' => 'Copyright (C) 1999-' . date( 'Y' ) . ' eZ Systems AS',
+                      'License' => 'GNU General Public License v2.0',
                       );
     }
 }
