@@ -5,9 +5,9 @@
 // Created on: <16-Apr-2002 11:08:14 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -40,12 +40,6 @@ Bugs/missing/deprecated features:
 
 */
 
-//include_once( 'kernel/classes/ezdatatype.php' );
-//include_once( 'kernel/classes/ezcontentobject.php' );
-//include_once( 'lib/ezutils/classes/ezintegervalidator.php' );
-//include_once( 'lib/ezutils/classes/ezinputvalidator.php' );
-//include_once( 'lib/ezi18n/classes/eztranslatormanager.php' );
-
 class eZObjectRelationListType extends eZDataType
 {
     const DATA_TYPE_STRING = "ezobjectrelationlist";
@@ -135,6 +129,8 @@ class eZObjectRelationListType extends eZDataType
                 }
             }
         }
+
+        $contentObjectAttribute->setContent( $content );
         return $status;
     }
 
@@ -214,9 +210,9 @@ class eZObjectRelationListType extends eZDataType
                 }
                 ++$priority;
                 $content['relation_list'][] = $this->appendObject( $objectID, $priority, $contentObjectAttribute );
-                $contentObjectAttribute->setContent( $content );
-                $contentObjectAttribute->store();
             }
+
+            $contentObjectAttribute->setContent( $content );
             return true;
         }
 
@@ -335,7 +331,6 @@ class eZObjectRelationListType extends eZDataType
         $nodeassignment = $newObjectInstance->createNodeAssignment( $defaultPlacementNode, true );
         $nodeassignment->store();
         $newObjectInstance->sync();
-        //include_once( "lib/ezutils/classes/ezoperationhandler.php" );
         $operationResult = eZOperationHandler::execute( 'content', 'publish', array( 'object_id' => $newObjectInstance->attribute( 'id' ), 'version' => 1 ) );
         // so it updates the attributes
         $newObjectInstance->rename( $name );
@@ -343,8 +338,6 @@ class eZObjectRelationListType extends eZDataType
         return $newObjectInstance->attribute( 'id' );
     }
 
-    /*!
-    */
     function storeObjectAttribute( $attribute )
     {
         $content = $attribute->content();
@@ -360,7 +353,6 @@ class eZObjectRelationListType extends eZDataType
             }
             unset( $content['new_object'] );
             $attribute->setContent( $content );
-            $attribute->store();
         }
 
         $contentClassAttributeID = $attribute->ContentClassAttributeID;
@@ -399,7 +391,7 @@ class eZObjectRelationListType extends eZDataType
 
             eZContentObject::fetch( $contentObjectID )->addContentObjectRelation( $subObjectID, $contentObjectVersion, $contentClassAttributeID, eZContentObject::RELATION_ATTRIBUTE );
 
-            if ( $relationItem['is_modified'] )
+            if ( $relationItem['is_modified'] && isset( $content['temp'][$subObjectID]['object' ] ) )
             {
                 // handling sub-objects
                 $object = $content['temp'][$subObjectID]['object'];
@@ -425,9 +417,6 @@ class eZObjectRelationListType extends eZDataType
         return eZObjectRelationListType::storeObjectAttributeContent( $attribute, $content );
     }
 
-    /*!
-     \reimp
-    */
     function onPublish( $contentObjectAttribute, $contentObject, $publishedNodes )
     {
         $content = $contentObjectAttribute->content();
@@ -471,8 +460,8 @@ class eZObjectRelationListType extends eZDataType
                         $nodeAssignment = eZNodeAssignment::create( array( 'contentobject_id' => $object->attribute( 'id' ),
                                                                            'contentobject_version' => $object->attribute( 'current_version' ),
                                                                            'parent_node' => $relationItem['parent_node_id'],
-                                                                           'sort_field' => 2,
-                                                                           'sort_order' => 0,
+                                                                           'sort_field' => eZContentObjectTreeNode::SORT_FIELD_PUBLISHED,
+                                                                           'sort_order' => eZContentObjectTreeNode::SORT_ORDER_DESC,
                                                                            'is_main' => 1 ) );
                         $nodeAssignment->store();
                     }
@@ -488,8 +477,8 @@ class eZObjectRelationListType extends eZDataType
                         $nodeAssignment = eZNodeAssignment::create( array( 'contentobject_id' => $object->attribute( 'id' ),
                                                                            'contentobject_version' => $object->attribute( 'current_version' ),
                                                                            'parent_node' => $contentObject->attribute( 'main_node_id' ),
-                                                                           'sort_field' => 2,
-                                                                           'sort_order' => 0,
+                                                                           'sort_field' => eZContentObjectTreeNode::SORT_FIELD_PUBLISHED,
+                                                                           'sort_order' => eZContentObjectTreeNode::SORT_ORDER_DESC,
                                                                            'is_main' => 1 ) );
                         $nodeAssignment->store();
                     }
@@ -581,24 +570,15 @@ class eZObjectRelationListType extends eZDataType
         }
     }
 
-    /*!
-     \reimp
-    */
     function validateClassAttributeHTTPInput( $http, $base, $classAttribute )
     {
         return eZInputValidator::STATE_ACCEPTED;
     }
 
-    /*!
-     \reimp
-    */
     function fixupClassAttributeHTTPInput( $http, $base, $classAttribute )
     {
     }
 
-    /*!
-     \reimp
-    */
     function fetchClassAttributeHTTPInput( $http, $base, $classAttribute )
     {
         $content = $classAttribute->content();
@@ -637,9 +617,6 @@ class eZObjectRelationListType extends eZDataType
         return true;
     }
 
-    /*!
-     \reimp
-    */
     function initializeClassAttribute( $classAttribute )
     {
         $xmlText = $classAttribute->attribute( 'data_text5' );
@@ -650,9 +627,6 @@ class eZObjectRelationListType extends eZDataType
         }
     }
 
-    /*!
-     \reimp
-    */
     function preStoreClassAttribute( $classAttribute, $version )
     {
         $content = $classAttribute->content();
@@ -681,13 +655,13 @@ class eZObjectRelationListType extends eZDataType
         return false;
     }
 
-    function storeClassDOMDocument( $doc, $classAttribute )
+    static function storeClassDOMDocument( $doc, $classAttribute )
     {
         $docText = eZObjectRelationListType::domString( $doc );
         $classAttribute->setAttribute( 'data_text5', $docText );
     }
 
-    function storeObjectDOMDocument( $doc, $objectAttribute )
+    static function storeObjectDOMDocument( $doc, $objectAttribute )
     {
         $docText = eZObjectRelationListType::domString( $doc );
         $objectAttribute->setAttribute( 'data_text', $docText );
@@ -705,7 +679,6 @@ class eZObjectRelationListType extends eZDataType
         $xmlCharset = $ini->variable( 'RegionalSettings', 'ContentXMLCharset' );
         if ( $xmlCharset == 'enabled' )
         {
-            //include_once( 'lib/ezi18n/classes/eztextcodec.php' );
             $charset = eZTextCodec::internalCharset();
         }
         else if ( $xmlCharset == 'disabled' )
@@ -714,14 +687,13 @@ class eZObjectRelationListType extends eZDataType
             $charset = $xmlCharset;
         if ( $charset !== true )
         {
-            //include_once( 'lib/ezi18n/classes/ezcharsetinfo.php' );
             $charset = eZCharsetInfo::realCharsetCode( $charset );
         }
         $domString = $domDocument->saveXML();
         return $domString;
     }
 
-    function createClassDOMDocument( $content )
+    static function createClassDOMDocument( $content )
     {
         $doc = new DOMDocument( '1.0', 'utf-8' );
         $root = $doc->createElement( 'related-objects' );
@@ -754,7 +726,7 @@ class eZObjectRelationListType extends eZDataType
         return $doc;
     }
 
-    function createObjectDOMDocument( $content )
+    static function createObjectDOMDocument( $content )
     {
         $doc = new DOMDocument( '1.0', 'utf-8' );
         $root = $doc->createElement( 'related-objects' );
@@ -797,9 +769,6 @@ class eZObjectRelationListType extends eZDataType
                       'contentobject-remote-id' => 'contentobject_remote_id' );
     }
 
-    /*!
-     \reimp
-    */
     function deleteStoredObjectAttribute( $objectAttribute, $version = null )
     {
         $content = $objectAttribute->content();
@@ -816,9 +785,6 @@ class eZObjectRelationListType extends eZDataType
         }
     }
 
-    /*!
-     \reimp
-    */
     function customObjectAttributeHTTPAction( $http, $action, $contentObjectAttribute, $parameters )
     {
         $contentobjectID = false;
@@ -996,7 +962,6 @@ class eZObjectRelationListType extends eZDataType
                 $classConstraintList = array();
             }
 
-            //include_once( 'kernel/classes/ezcontentbrowse.php' );
             $browseParameters = array( 'action_name' => 'AddRelatedObject_' . $contentObjectAttribute->attribute( 'id' ),
                                        'type' =>  $browseType,
                                        'browse_custom_action' => array( 'name' => 'CustomActionButton[' . $contentObjectAttribute->attribute( 'id' ) . '_set_object_relation_list]',
@@ -1071,9 +1036,6 @@ class eZObjectRelationListType extends eZDataType
         }
     }
 
-    /*!
-     \reimp
-    */
     function handleCustomObjectHTTPActions( $http, $attributeDataBaseName,
                                             $customActionAttributeArray, $customActionParameters )
     {
@@ -1081,21 +1043,24 @@ class eZObjectRelationListType extends eZDataType
         $content = $contentObjectAttribute->content();
         foreach( $content['relation_list'] as $relationItem )
         {
-            $subObjectID = $relationItem['contentobject_id'];
-            $subObjectVersion = $relationItem['contentobject_version'];
-
-            $attributeBase = $attributeDataBaseName . '_ezorl_edit_object_' . $subObjectID;
-            if ( eZContentObject::recursionProtect( $subObjectID ) )
+            if ( $relationItem['is_modified'] )
             {
-                if ( isset ( $conent['temp'] ) )
-                    $object = $content['temp'][$subObjectID]['object'];
-                else
-                    $object = eZContentObject::fetch( $subObjectID );
-                if ( $object )
-                    $object->handleAllCustomHTTPActions( $attributeBase,
-                                                         $customActionAttributeArray,
-                                                         $customActionParameters,
-                                                         $subObjectVersion );
+                $subObjectID = $relationItem['contentobject_id'];
+                $subObjectVersion = $relationItem['contentobject_version'];
+
+                $attributeBase = $attributeDataBaseName . '_ezorl_edit_object_' . $subObjectID;
+                if ( eZContentObject::recursionProtect( $subObjectID ) )
+                {
+                    if ( isset ( $content['temp'] ) )
+                        $object = $content['temp'][$subObjectID]['object'];
+                    else
+                        $object = eZContentObject::fetch( $subObjectID );
+                    if ( $object )
+                        $object->handleAllCustomHTTPActions( $attributeBase,
+                                                             $customActionAttributeArray,
+                                                             $customActionParameters,
+                                                             $subObjectVersion );
+                }
             }
         }
     }
@@ -1338,9 +1303,6 @@ class eZObjectRelationListType extends eZDataType
         return $content;
     }
 
-    /*!
-     \reimp
-    */
     function classAttributeContent( $classAttribute )
     {
         $xmlText = $classAttribute->attribute( 'data_text5' );
@@ -1436,9 +1398,6 @@ class eZObjectRelationListType extends eZDataType
         return $content;
     }
 
-    /*!
-     \reimp
-    */
     function customClassAttributeHTTPAction( $http, $action, $classAttribute )
     {
         switch ( $action )
@@ -1446,7 +1405,6 @@ class eZObjectRelationListType extends eZDataType
             case 'browse_for_placement':
             {
                 $module = $classAttribute->currentModule();
-                //include_once( 'kernel/classes/ezcontentbrowse.php' );
                 $customActionName = 'CustomActionButton[' . $classAttribute->attribute( 'id' ) . '_browsed_for_placement]';
                 eZContentBrowse::browse( array( 'action_name' => 'SelectObjectRelationListNode',
                                                 'content' => array( 'contentclass_id' => $classAttribute->attribute( 'contentclass_id' ),
@@ -1461,7 +1419,6 @@ class eZObjectRelationListType extends eZDataType
             } break;
             case 'browsed_for_placement':
             {
-                //include_once( 'kernel/classes/ezcontentbrowse.php' );
                 $nodeSelection = eZContentBrowse::result( 'SelectObjectRelationListNode' );
                 if ( $nodeSelection and count( $nodeSelection ) > 0 )
                 {
@@ -1513,7 +1470,8 @@ class eZObjectRelationListType extends eZDataType
                 }
             }
 
-            $metaDataArray = array_merge( $metaDataArray, eZContentObjectAttribute::metaDataArray( $attributes ) );
+            $attributeMetaDataArray = eZContentObjectAttribute::metaDataArray( $attributes );
+            $metaDataArray = array_merge( $metaDataArray, $attributeMetaDataArray );
         }
 
         return $metaDataArray;
@@ -1563,9 +1521,6 @@ class eZObjectRelationListType extends eZDataType
         return count( $content['relation_list'] ) > 0;
     }
 
-    /*!
-     \reimp
-    */
     function isIndexable()
     {
         return true;
@@ -1591,9 +1546,6 @@ class eZObjectRelationListType extends eZDataType
         }
     }
 
-    /*!
-     \reimp
-    */
     function serializeContentClassAttribute( $classAttribute, $attributeNode, $attributeParametersNode )
     {
         $dom = $attributeParametersNode->ownerDocument;
@@ -1604,16 +1556,12 @@ class eZObjectRelationListType extends eZDataType
             $defaultPlacementNode->setAttribute( 'node-id', $content['default_placement']['node_id'] );
             $attributeParametersNode->appendChild( $defaultPlacementNode );
         }
-        if ( is_numeric( $content['type'] ) )
-        {
-            $typeNode = $dom->createElement( 'type', $content['type'] );
-            $attributeParametersNode->appendChild( $typeNode );
-        }
-        else
-        {
-            $typeNode = $dom->createElement( 'type', '0' );
-            $attributeParametersNode->appendChild( $typeNode );
-        }
+
+        $type = is_numeric( $content['type'] ) ? $content['type'] : '0';
+        $typeNode = $dom->createElement( 'type' );
+        $typeNode->appendChild( $dom->createTextNode( $type ) );
+        $attributeParametersNode->appendChild( $typeNode );
+
         $classConstraintsNode = $dom->createElement( 'class-constraints' );
         $attributeParametersNode->appendChild( $classConstraintsNode );
         foreach ( $content['class_constraint_list'] as $classConstraint )
@@ -1623,11 +1571,22 @@ class eZObjectRelationListType extends eZDataType
             $classConstraintNode->setAttribute( 'class-identifier', $classConstraintIdentifier );
             $classConstraintsNode->appendChild( $classConstraintNode );
         }
+
+        if ( isset( $content['selection_type'] ) && is_numeric( $content['selection_type'] ) )
+        {
+            $selectionTypeNode = $dom->createElement( 'selection-type' );
+            $selectionTypeNode->appendChild( $dom->createTextNode( $content['selection_type'] ) );
+            $attributeParametersNode->appendChild( $selectionTypeNode );
+        }
+
+        if ( isset( $content['object_class'] ) && is_numeric( $content['object_class'] ) )
+        {
+            $objectClassNode = $dom->createElement( 'object-class' );
+            $objectClassNode->appendChild( $dom->createTextNode( $content['object_class'] ) );
+            $attributeParametersNode->appendChild( $objectClassNode );
+        }
     }
 
-    /*!
-     \reimp
-    */
     function unserializeContentClassAttribute( $classAttribute, $attributeNode, $attributeParametersNode )
     {
         $content = $classAttribute->content();
@@ -1648,6 +1607,19 @@ class eZObjectRelationListType extends eZDataType
             $content['class_constraint_list'][] = $classIdentifier;
         }
 
+        $objectClassNode = $attributeParametersNode->getElementsByTagName( 'object-class' )->item( 0 );
+        if ( $objectClassNode )
+        {
+            $content['object_class'] = $objectClassNode->textContent;
+        }
+
+        $selectionTypeNode = $attributeParametersNode->getElementsByTagName( 'selection-type' )->item( 0 );
+        if ( $selectionTypeNode )
+        {
+            $content['selection_type'] = $selectionTypeNode->textContent;
+        }
+
+        $classAttribute->setContent( $content );
         $this->storeClassAttributeContent( $classAttribute, $content );
     }
 
@@ -1662,20 +1634,26 @@ class eZObjectRelationListType extends eZDataType
         </relation-list>
      To do this we fetch content XML and strip all the relation attributes except of "priority" from there,
      and add "contentobject-remote-id" attribute.
-     \reimp
     */
     function serializeContentObjectAttribute( $package, $objectAttribute )
     {
         $node = $this->createContentObjectAttributeDOMNode( $objectAttribute );
 
-        $dom = new DOMDocument( '1.0', 'utf-8' );
         eZDebug::writeDebug( $objectAttribute->attribute( 'data_text' ), 'xml string from data_text field' );
-        $success = $dom->loadXML( $objectAttribute->attribute( 'data_text' ) );
+        if ( $objectAttribute->attribute( 'data_text' ) === null )
+        {
+            $content = array( 'relation_list' => array() );
+            $dom = eZObjectRelationListType::createObjectDOMDocument( $content );
+        }
+        else
+        {
+            $dom = new DOMDocument( '1.0', 'utf-8' );
+            $success = $dom->loadXML( $objectAttribute->attribute( 'data_text' ) );
+        }
         $rootNode = $dom->documentElement;
         $relationList = $rootNode->getElementsByTagName( 'relation-list' )->item( 0 );
         if ( $relationList )
         {
-            require_once( 'kernel/classes/ezcontentobject.php' );
             $relationItems = $relationList->getElementsByTagName( 'relation-item' );
             for ( $i = 0; $i < $relationItems->length; $i++ )
             {
@@ -1715,13 +1693,10 @@ class eZObjectRelationListType extends eZDataType
         return $node;
     }
 
-    /*!
-     \reimp
-    */
     function unserializeContentObjectAttribute( $package, $objectAttribute, $attributeNode )
     {
-        $rootNode = $attributeNode->getElementsByTagName( 'ezobjectrelationlist' )->item( 0 );
-        $xmlString = $rootNode ? $rootNode->textContent : '';
+        $rootNode = $attributeNode->getElementsByTagName( 'related-objects' )->item( 0 );
+        $xmlString = $rootNode ? $rootNode->ownerDocument->saveXML( $rootNode ) : '';
         $objectAttribute->setAttribute( 'data_text', $xmlString );
     }
 
@@ -1735,10 +1710,10 @@ class eZObjectRelationListType extends eZDataType
         if ( !$relationList )
             return false;
 
-        require_once( 'kernel/classes/ezcontentobject.php' );
         $relationItems = $relationList->getElementsByTagName( 'relation-item' );
-        foreach ( $relationItems as $i => $relationItem )
+        for ( $i = $relationItems->length - 1; $i >= 0; $i-- )
         {
+            $relationItem = $relationItems->item( $i );
             $relatedObjectRemoteID = $relationItem->getAttribute( 'contentobject-remote-id' );
             $object = eZContentObject::fetchByRemoteID( $relatedObjectRemoteID );
 
@@ -1746,16 +1721,16 @@ class eZObjectRelationListType extends eZDataType
             {
                 eZDebug::writeWarning( "Object with remote id '$relatedObjectRemoteID' not found: removing the link.",
                                        'eZObjectRelationListType::unserializeContentObjectAttribute()' );
-                unset( $relationItems[$i] );
+                $relationItem->parentNode->removeChild( $relationItem );
                 continue;
             }
 
-            $relationItems[$i]->setAttribute( 'contentobject-id',        $object->attribute( 'id' ) );
-            $relationItems[$i]->setAttribute( 'contentobject-version',   $object->attribute( 'current_version' ) );
-            $relationItems[$i]->setAttribute( 'node-id',                 $object->attribute( 'main_node_id' ) );
-            $relationItems[$i]->setAttribute( 'parent-node-id',          $object->attribute( 'main_parent_node_id' ) );
-            $relationItems[$i]->setAttribute( 'contentclass-id',         $object->attribute( 'contentclass_id' ) );
-            $relationItems[$i]->setAttribute( 'contentclass-identifier', $object->attribute( 'class_identifier' ) );
+            $relationItem->setAttribute( 'contentobject-id',        $object->attribute( 'id' ) );
+            $relationItem->setAttribute( 'contentobject-version',   $object->attribute( 'current_version' ) );
+            $relationItem->setAttribute( 'node-id',                 $object->attribute( 'main_node_id' ) );
+            $relationItem->setAttribute( 'parent-node-id',          $object->attribute( 'main_parent_node_id' ) );
+            $relationItem->setAttribute( 'contentclass-id',         $object->attribute( 'contentclass_id' ) );
+            $relationItem->setAttribute( 'contentclass-identifier', $object->attribute( 'class_identifier' ) );
         }
 
         $newXmlString = $doc->saveXML( $rootNode );
@@ -1796,6 +1771,11 @@ class eZObjectRelationListType extends eZDataType
         return $return;
     }
 
+    function supportsBatchInitializeObjectAttribute()
+    {
+        return true;
+    }
+
     /// \privatesection
 }
 
