@@ -5,9 +5,9 @@
 // Created on: <27-Mar-2006 15:28:39 ks>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -27,8 +27,6 @@
 //
 
 // if ( !class_exists( 'eZXMLInputParser' ) )
-    //include_once( 'kernel/classes/datatypes/ezxmltext/ezxmlinputparser.php' );
-
 class eZSimplifiedXMLInputParser extends eZXMLInputParser
 {
     public $InputTags = array(
@@ -42,6 +40,12 @@ class eZSimplifiedXMLInputParser extends eZXMLInputParser
         'br'      => array( 'name' => 'br',
                             'noChildren' => true ),
         'a'       => array( 'name' => 'link' ),
+        'h1'     => array( 'nameHandler' => 'tagNameHeader' ),
+        'h2'     => array( 'nameHandler' => 'tagNameHeader' ),
+        'h3'     => array( 'nameHandler' => 'tagNameHeader' ),
+        'h4'     => array( 'nameHandler' => 'tagNameHeader' ),
+        'h5'     => array( 'nameHandler' => 'tagNameHeader' ),
+        'h6'     => array( 'nameHandler' => 'tagNameHeader' ),
         );
 
     public $OutputTags = array(
@@ -128,6 +132,45 @@ class eZSimplifiedXMLInputParser extends eZXMLInputParser
         $this->eZXMLInputParser( $validateErrorLevel, $detectErrorLevel, $parseLineBreaks, $removeDefaultAttrs );
     }
 
+    /*
+        Tag Name handlers (init handlers)
+    */
+    function tagNameHeader( $tagName, &$attributes )
+    {
+        switch ( $tagName )
+        {
+            case 'h1':
+            {
+                $attributes['level'] = '1';
+            } break;
+            case 'h2':
+            {
+                $attributes['level'] = '2';
+            } break;
+            case 'h3':
+            {
+                $attributes['level'] = '3';
+            } break;
+            case 'h4':
+            {
+                $attributes['level'] = '4';
+            } break;
+            case 'h5':
+            {
+                $attributes['level'] = '5';
+            } break;
+            case 'h6':
+            {
+                $attributes['level'] = '6';
+            } break;
+            default :
+            {
+                return '';
+            } break;
+        }
+        return 'header';
+    }
+
     /*
         Parsing Handlers (called at pass 1)
     */
@@ -422,7 +465,8 @@ class eZSimplifiedXMLInputParser extends eZXMLInputParser
                 if ( $this->StrictHeaders &&
                      $level - $sectionLevel > 1 )
                 {
-                    $this->handleError( eZXMLInputParser::ERROR_SCHEMA, ezi18n( 'kernel/classes/datatypes/ezxmltext', "Incorrect headers nesting" ) );
+                    $this->handleError( eZXMLInputParser::ERROR_SCHEMA,
+                                        ezi18n( 'kernel/classes/datatypes/ezxmltext', "Incorrect headers nesting" ) );
                 }
 
                 $newParent = $parent;
@@ -682,7 +726,7 @@ class eZSimplifiedXMLInputParser extends eZXMLInputParser
 
         if ( $href )
         {
-            if ( ereg( "^ezobject://[0-9]+(#.*)?$", $href ) )
+            if ( preg_match( "@^ezobject://[0-9]+(#.*)?$@", $href ) )
             {
                 $url = strtok( $href, '#' );
                 $anchorName = strtok( '#' );
@@ -694,20 +738,20 @@ class eZSimplifiedXMLInputParser extends eZXMLInputParser
                     $this->linkedObjectIDArray[] = $objectID;
                 }
             }
-            elseif ( ereg( "^eznode://.+(#.*)?$" , $href ) )
+            elseif ( preg_match( "@^eznode://.+(#.*)?$@" , $href ) )
             {
                 $objectID = null;
                 $url = strtok( $href, '#' );
                 $anchorName = strtok( '#' );
                 $nodePath = substr( strchr( $url, "/" ), 2 );
-                if ( ereg( "^[0-9]+$", $nodePath ) )
+                if ( preg_match( "@^[0-9]+$@", $nodePath ) )
                 {
                     $nodeID = $nodePath;
                     $node = eZContentObjectTreeNode::fetch( $nodeID, false, false );
                     if ( !$node )
                     {
-                        $this->handleError( eZXMLInputParser::ERROR_DATA, "Node '%1' does not exist.",
-                                            array( $nodeID ) );
+                        $this->handleError( eZXMLInputParser::ERROR_DATA,
+                                            ezi18n( 'kernel/classes/datatypes/ezxmltext', "Node '%1' does not exist.", '', array( $nodeID ) ) );
                     }
                     else
                     {
@@ -719,8 +763,8 @@ class eZSimplifiedXMLInputParser extends eZXMLInputParser
                     $node = eZContentObjectTreeNode::fetchByURLPath( $nodePath, false );
                     if ( !$node )
                     {
-                        $this->handleError( eZXMLInputParser::ERROR_DATA, "Node '%1' does not exist.",
-                                            array( $nodePath ) );
+                        $this->handleError( eZXMLInputParser::ERROR_DATA,
+                                            ezi18n( 'kernel/classes/datatypes/ezxmltext', "Node '%1' does not exist.", '', array( $nodePath ) ) );
                     }
                     else
                     {
@@ -736,7 +780,7 @@ class eZSimplifiedXMLInputParser extends eZXMLInputParser
                     $this->linkedObjectIDArray[] = $objectID;
                 }
             }
-            elseif ( ereg( "^#.*$" , $href ) )
+            elseif ( preg_match( "@^#.*$@" , $href ) )
             {
                 $anchorName = substr( $href, 1 );
             }
@@ -757,20 +801,19 @@ class eZSimplifiedXMLInputParser extends eZXMLInputParser
                     // Protection from XSS attack
                     if ( preg_match( "/^(java|vb)script:.*/i" , $url ) )
                     {
-                        $this->handleError( eZXMLInputParser::ERROR_DATA, "Using scripts in links is not allowed, link '%1' has been removed",
-                                            array( $url ) );
+                        $this->handleError( eZXMLInputParser::ERROR_DATA,
+                                            ezi18n( 'kernel/classes/datatypes/ezxmltext', "Using scripts in links is not allowed, link '%1' has been removed", '', array( $url ) ) );
 
                         $element->removeAttribute( 'href' );
                         return $ret;
 
                     }
                     // Check mail address validity
-                    //include_once( 'lib/ezutils/classes/ezmail.php' );
                     if ( preg_match( "/^mailto:(.*)/i" , $url, $mailAddr ) &&
                          !eZMail::validate( $mailAddr[1] ) )
                     {
-                        $this->handleError( eZXMLInputParser::ERROR_DATA, "Invalid e-mail address: '%1'",
-                                            array( $mailAddr[1] ) );
+                        $this->handleError( eZXMLInputParser::ERROR_DATA,
+                                            ezi18n( 'kernel/classes/datatypes/ezxmltext', "Invalid e-mail address: '%1'", '' , array( $mailAddr[1] ) ) );
 
                         $element->removeAttribute( 'href' );
                         return $ret;
@@ -822,15 +865,15 @@ class eZSimplifiedXMLInputParser extends eZXMLInputParser
 
         if ( $href != null )
         {
-            if ( ereg( "^ezobject://[0-9]+$" , $href ) )
+            if ( preg_match( "@^ezobject://[0-9]+$@" , $href ) )
             {
                 $objectID = substr( strrchr( $href, "/" ), 1 );
 
                 // protection from self-embedding
                 if ( $objectID == $this->contentObjectID )
                 {
-                    $this->handleError( eZXMLInputParser::ERROR_DATA, 'Object %1 can not be embeded to itself.',
-                                        array( $objectID ) );
+                    $this->handleError( eZXMLInputParser::ERROR_DATA,
+                                        ezi18n( 'kernel/classes/datatypes/ezxmltext', 'Object %1 can not be embeded to itself.', '', array( $objectID ) ) );
 
                     $element->removeAttribute( 'href' );
                     return $ret;
@@ -843,18 +886,18 @@ class eZSimplifiedXMLInputParser extends eZXMLInputParser
                     $this->relatedObjectIDArray[] = $objectID;
                 }
             }
-            elseif ( ereg( "^eznode://.+$" , $href ) )
+            elseif ( preg_match( "@^eznode://.+$@" , $href ) )
             {
                 $nodePath = substr( strchr( $href, "/" ), 2 );
 
-                if ( ereg( "^[0-9]+$", $nodePath ) )
+                if ( preg_match( "@^[0-9]+$@", $nodePath ) )
                 {
                     $nodeID = $nodePath;
                     $node = eZContentObjectTreeNode::fetch( $nodeID, false, false );
                     if ( !$node )
                     {
-                        $this->handleError( eZXMLInputParser::ERROR_DATA, "Node '%1' does not exist.",
-                                            array( $nodeID ) );
+                        $this->handleError( eZXMLInputParser::ERROR_DATA,
+                                            ezi18n( 'kernel/classes/datatypes/ezxmltext', "Node '%1' does not exist.", '', array( $nodeID ) ) );
 
                         $element->removeAttribute( 'href' );
                         return $ret;
@@ -865,8 +908,8 @@ class eZSimplifiedXMLInputParser extends eZXMLInputParser
                     $node = eZContentObjectTreeNode::fetchByURLPath( $nodePath, false );
                     if ( !$node )
                     {
-                        $this->handleError( eZXMLInputParser::ERROR_DATA, 'Node \'%1\' does not exist.',
-                                            array( $nodePath ) );
+                        $this->handleError( eZXMLInputParser::ERROR_DATA,
+                                            ezi18n( 'kernel/classes/datatypes/ezxmltext', 'Node \'%1\' does not exist.', '', array( $nodePath ) ) );
 
                         $element->removeAttribute( 'href' );
                         return $ret;
@@ -881,8 +924,8 @@ class eZSimplifiedXMLInputParser extends eZXMLInputParser
                 // protection from self-embedding
                 if ( $objectID == $this->contentObjectID )
                 {
-                    $this->handleError( eZXMLInputParser::ERROR_DATA, 'Object %1 can not be embeded to itself.',
-                                        array( $objectID ) );
+                    $this->handleError( eZXMLInputParser::ERROR_DATA,
+                                        ezi18n( 'kernel/classes/datatypes/ezxmltext', 'Object %1 can not be embeded to itself.', '', array( $objectID ) ) );
 
                     $element->removeAttribute( 'href' );
                     return $ret;
