@@ -5,9 +5,9 @@
 // Created on: <04-Jul-2002 15:28:58 bf>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -34,15 +34,6 @@
   \sa eZProductCollection
 */
 
-//include_once( "kernel/classes/ezpersistentobject.php" );
-//include_once( "kernel/classes/ezproductcollection.php" );
-//include_once( "kernel/classes/ezproductcollectionitem.php" );
-//include_once( "kernel/classes/datatypes/ezuser/ezuser.php" );
-//include_once( "kernel/classes/ezuserdiscountrule.php" );
-//include_once( "kernel/classes/ezcontentobjecttreenode.php" );
-//include_once( "kernel/classes/ezshippingmanager.php" );
-//include_once( "kernel/classes/ezorder.php" );
-
 class eZBasket extends eZPersistentObject
 {
     /*!
@@ -50,8 +41,6 @@ class eZBasket extends eZPersistentObject
     */
     const ITEM_LIMIT = 3000;
 
-    /*!
-    */
     function eZBasket( $row )
     {
         $this->eZPersistentObject( $row );
@@ -124,7 +113,7 @@ class eZBasket extends eZPersistentObject
                 $count = $productItem->attribute( 'item_count' );
                 $discountPercent = $productItem->attribute( 'discount' );
                 $nodeID = $contentObject->attribute( 'main_node_id' );
-                $objectName = $contentObject->attribute( 'name' );
+                $objectName = $contentObject->name( false, $contentObject->currentLanguage() );
 
                 $isVATIncluded = $productItem->attribute( 'is_vat_inc' );
                 $price = $productItem->attribute( 'price' );
@@ -363,7 +352,6 @@ class eZBasket extends eZPersistentObject
         $user = eZUser::currentUser();
         $userID = $user->attribute( 'contentobject_id' );
 
-        //include_once( 'kernel/classes/ezorderstatus.php' );
         $time = time();
         $order = new eZOrder( array( 'productcollection_id' => $productCollectionID,
                                      'user_id' => $userID,
@@ -395,8 +383,6 @@ class eZBasket extends eZPersistentObject
         $productCollection = $this->attribute( 'productcollection' );
         if ( $productCollection )
         {
-            //include_once( 'kernel/shop/classes/ezshopfunctions.php' );
-
             $currencyCode = '';
             $items = $this->items();
 
@@ -560,7 +546,6 @@ WHERE ezbasket.session_id = ezsession.session_key AND
             $product = $productCollectionItemList[0]->attribute( 'contentobject' );
             if ( is_object( $product ) )
             {
-                //include_once( 'kernel/shop/classes/ezshopfunctions.php' );
                 $type = eZShopFunctions::productTypeByObject( $product );
             }
         }
@@ -570,9 +555,6 @@ WHERE ezbasket.session_id = ezsession.session_key AND
 
     function canAddProduct( $contentObject )
     {
-        //include_once( 'kernel/shop/classes/ezshopfunctions.php' );
-        //include_once( 'kernel/shop/errors.php' );
-
         $error = eZError::SHOP_OK;
 
         $productType = eZShopFunctions::productTypeByObject( $contentObject );
