@@ -5,9 +5,9 @@
 // Created on: <09-Oct-2003 15:24:36 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezcache.php
+/*! \file
 */
 
 /*!
@@ -38,8 +38,6 @@
 
 */
 
-//include_once( 'lib/ezfile/classes/ezfilehandler.php' );
-//include_once( 'lib/ezfile/classes/ezdir.php' );
 require_once( 'kernel/common/i18n.php' );
 
 class eZCache
@@ -61,6 +59,7 @@ class eZCache
         if ( !isset( $cacheList ) )
         {
             $ini = eZINI::instance();
+            $textToImageIni = eZINI::instance( 'texttoimage.ini' );
             $cacheList = array( array( 'name' => ezi18n( 'kernel/cache', 'Content view cache' ),
                                        'id' => 'content',
                                        'tag' => array( 'content' ),
@@ -94,12 +93,14 @@ class eZCache
                                 array( 'name' => ezi18n( 'kernel/cache', 'Class identifier cache' ),
                                        'id' => 'classid',
                                        'tag' => array( 'content' ),
+                                       'expiry-key' => 'class-identifier-cache',
                                        'enabled' => true,
                                        'path' => false,
                                        'function' => array( 'eZCache', 'clearClassID' ) ),
                                 array( 'name' => ezi18n( 'kernel/cache', 'Sort key cache' ),
                                        'id' => 'sortkey',
                                        'tag' => array( 'content' ),
+                                       'expiry-key' => 'sort-key-cache',
                                        'enabled' => true,
                                        'path' => false,
                                        'function' => array( 'eZCache', 'clearSortKey' ) ),
@@ -136,6 +137,13 @@ class eZCache
                                        'tag' => array( 'template' ),
                                        'enabled' => true,
                                        'path' => 'override' ),
+                                array( 'name' => ezi18n( 'kernel/cache', 'Text to image cache' ),
+                                       'id' => 'texttoimage',
+                                       'tag' => array( 'template' ),
+                                       'enabled' => $textToImageIni->variable( 'ImageSettings', 'UseCache' ) == 'enabled',
+                                       'path' => $textToImageIni->variable( 'PathSettings', 'CacheDir' ),
+                                       'function' => array( 'eZCache', 'clearTextToImageCache' ),
+                                       'purge-function' => array( 'eZCache', 'purgeTextToImageCache' ) ),
                                 array( 'name' => ezi18n( 'kernel/cache', 'RSS cache' ),
                                        'id' => 'rss_cache',
                                        'tag' => array( 'content' ),
@@ -154,6 +162,13 @@ class eZCache
                                        'path' => false,
                                        'enabled' => true,
                                        'function' => 'eZCacheClearContentTreeMenu' ),
+                                array( 'name' => ezi18n( 'kernel/cache', 'State limitations cache' ),
+                                       'id' => 'state_limitations',
+                                       'tag' => array( 'content' ),
+                                       'expiry-key' => 'state-limitations',
+                                       'enabled' => true,
+                                       'path' => false,
+                                       'function' => array( 'eZCache', 'clearStateLimitations' ) ),
                                 );
         }
         return $cacheList;
@@ -388,7 +403,6 @@ class eZCache
 
             if ( $isContentRelated )
             {
-                require_once( 'kernel/classes/ezclusterfilehandler.php' );
                 $fileHandler = eZClusterFileHandler::instance( $cachePath );
                 if ( $purge )
                     $fileHandler->purge( $reporter, $iterationSleep, $iterationMax, $expiry );
@@ -399,7 +413,7 @@ class eZCache
 
             if ( is_file( $cachePath ) )
             {
-                $handler =& eZFileHandler::instance( false );
+                $handler = eZFileHandler::instance( false );
                 $handler->unlink( $cachePath );
             }
             else
@@ -461,9 +475,6 @@ class eZCache
     {
         $cachePath = eZSys::cacheDirectory();
 
-        // VS-DBFILE
-
-        require_once( 'kernel/classes/ezclusterfilehandler.php' );
         $fileHandler = eZClusterFileHandler::instance();
         $fileHandler->fileDelete( $cachePath, 'classidentifiers_' );
         $fileHandler->fileDelete( $cachePath, 'classattributeidentifiers_' );
@@ -478,9 +489,6 @@ class eZCache
     {
         $cachePath = eZSys::cacheDirectory();
 
-        // VS-DBFILE
-
-        require_once( 'kernel/classes/ezclusterfilehandler.php' );
         $fileHandler = eZClusterFileHandler::instance();
         $fileHandler->fileDelete( $cachePath, 'sortkey_' );
     }
@@ -532,9 +540,44 @@ class eZCache
      \static
      Clear global ini cache
     */
-    static function clearGlobalINICache()
+    static function clearGlobalINICache( $cacheItem )
     {
-        eZDir::recursiveDelete( 'var/cache/ini' );
+        eZDir::recursiveDelete( $cacheItem['path'] );
+    }
+
+    /*!
+     \private
+     \static
+     Clear texttoimage cache
+    */
+    static function clearTextToImageCache( $cacheItem )
+    {
+        $fileHandler = eZClusterFileHandler::instance( $cacheItem['path'] );
+        $fileHandler->delete();
+    }
+
+    /*!
+     \private
+     \static
+     Purge texttoimage cache
+    */
+    static function purgeTextToImageCache( $cacheItem )
+    {
+        $fileHandler = eZClusterFileHandler::instance( $cacheItem['path'] );
+        $fileHandler->purge();
+    }
+
+    /*!
+     \private
+     \static
+     Clears all state limitation cache files.
+    */
+    static function clearStateLimitations( $cacheItem )
+    {
+        $cachePath = eZSys::cacheDirectory();
+
+        $fileHandler = eZClusterFileHandler::instance();
+        $fileHandler->fileDelete( $cachePath, 'statelimitations_' );
     }
 }
 
@@ -565,7 +608,7 @@ function eZCacheClearClassID( $cacheItem )
 */
 function eZCacheClearGlobalINI( $cacheItem )
 {
-    eZCache::clearGlobalINICache();
+    eZCache::clearGlobalINICache( $cacheItem );
 }
 
 
