@@ -5,9 +5,9 @@
 // Created on: <22-Jan-2003 16:24:33 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezcollaborationitemhandler.php
+/*! \file
 */
 
 /*!
@@ -35,9 +35,6 @@
 
 */
 
-//include_once( 'lib/ezutils/classes/ezini.php' );
-//include_once( "lib/ezfile/classes/ezdir.php" );
-
 class eZCollaborationItemHandler
 {
     /*
@@ -121,8 +118,6 @@ class eZCollaborationItemHandler
         return $this->NotificationCollectionHandling;
     }
 
-    /*!
-    */
     function notificationParticipantTemplate( $participantRole )
     {
         return 'participant.tpl';
@@ -137,7 +132,6 @@ class eZCollaborationItemHandler
     */
     static function handleCollaborationEvent( $event, $item, &$parameters )
     {
-        //include_once( 'kernel/classes/ezcollaborationitemparticipantlink.php' );
         $participantList = eZCollaborationItemParticipantLink::fetchParticipantList( array( 'item_id' => $item->attribute( 'id' ),
                                                                                              'participant_type' => eZCollaborationItemParticipantLink::TYPE_USER,
                                                                                              'as_object' => false ) );
@@ -176,7 +170,6 @@ class eZCollaborationItemHandler
         $db->begin();
         if ( $collectionHandling == self::NOTIFICATION_COLLECTION_ONE_FOR_ALL )
         {
-            //include_once( 'kernel/classes/notification/eznotificationcollection.php' );
             require_once( 'kernel/common/template.php' );
             $tpl = templateInit();
             $tpl->resetVariables();
@@ -191,6 +184,8 @@ class eZCollaborationItemHandler
                 $parameters['reply_to'] = $tpl->variable( 'reply_to' );
             if ( $tpl->hasVariable( 'from' ) )
                 $parameters['from'] = $tpl->variable( 'from' );
+            if ( $tpl->hasVariable( 'content_type' ) )
+                $parameters['content_type'] = $tpl->variable( 'content_type' );
 
             $collection = eZNotificationCollection::create( $event->attribute( 'id' ),
                                                             eZCollaborationNotificationHandler::NOTIFICATION_HANDLER_ID,
@@ -231,7 +226,6 @@ class eZCollaborationItemHandler
 
                 $itemInfo = $itemHandler->attribute( 'info' );
                 $typeIdentifier = $itemInfo['type-identifier'];
-                //include_once( 'kernel/classes/notification/eznotificationcollection.php' );
                 $tpl->setVariable( 'collaboration_item', $item );
                 $tpl->setVariable( 'collaboration_participant_role', $participantRole );
                 $result = $tpl->fetch( 'design:notification/handler/ezcollaboration/view/' . $typeIdentifier . '/' . $templateName );
@@ -244,6 +238,8 @@ class eZCollaborationItemHandler
                     $parameters['reply_to'] = $tpl->variable( 'reply_to' );
                 if ( $tpl->hasVariable( 'from' ) )
                     $parameters['from'] = $tpl->variable( 'from' );
+                if ( $tpl->hasVariable( 'content_type' ) )
+                    $parameters['content_type'] = $tpl->variable( 'content_type' );
 
                 $collection = eZNotificationCollection::create( $event->attribute( 'id' ),
                                                                 eZCollaborationNotificationHandler::NOTIFICATION_HANDLER_ID,
@@ -274,7 +270,7 @@ class eZCollaborationItemHandler
     /*!
      \return true if the attribute \a $attribute exists in the content data.
     */
-    function hasContentAttribute( &$collaborationItem, $attribute )
+    function hasContentAttribute( $collaborationItem, $attribute )
     {
         $content = $collaborationItem->content();
         if ( is_array( $content ) )
@@ -287,7 +283,7 @@ class eZCollaborationItemHandler
     /*!
      \return the attribute \a $attribute if it exists in the content data or \c null.
     */
-    function contentAttribute( &$collaborationItem, $attribute )
+    function contentAttribute( $collaborationItem, $attribute )
     {
         $content = $collaborationItem->content();
         if ( is_array( $content ) )
@@ -328,7 +324,7 @@ class eZCollaborationItemHandler
     /*!
      \return the title of the collaboration item.
     */
-    function title( &$collaborationItem )
+    function title( $collaborationItem )
     {
         return $this->Info['type-name'];
     }
@@ -338,7 +334,7 @@ class eZCollaborationItemHandler
      \note The handler can either determine this by passing \a $useMessages to the constructor
            or by reimplementing this function to do it per item.
     */
-    function useMessages( &$collaborationItem )
+    function useMessages( $collaborationItem )
     {
         return $this->Info['use-messages'];
     }
@@ -348,7 +344,7 @@ class eZCollaborationItemHandler
      \note The default implementation returns 0, if you want real counts
            the handler must reimplement this function.
     */
-    function messageCount( &$collaborationItem )
+    function messageCount( $collaborationItem )
     {
         return 0;
     }
@@ -358,7 +354,7 @@ class eZCollaborationItemHandler
      \note The default implementation returns 0, if you want real counts
            the handler must reimplement this function.
     */
-    function unreadMessageCount( &$collaborationItem )
+    function unreadMessageCount( $collaborationItem )
     {
         return 0;
     }
@@ -377,7 +373,7 @@ class eZCollaborationItemHandler
      Reimplementing this function can be used to cleanup external tables
      or other resources.
     */
-    function removeItem( &$collaborationItem )
+    function removeItem( $collaborationItem )
     {
     }
 
@@ -432,7 +428,7 @@ class eZCollaborationItemHandler
      \note The default does nothing, the function must be reimplemented in real handlers.
      \sa isCustomAction
     */
-    function handleCustomAction( &$module, &$collaborationItem )
+    function handleCustomAction( $module, $collaborationItem )
     {
     }
 
@@ -549,7 +545,7 @@ class eZCollaborationItemHandler
                 {
                     $foundHandler = true;
                     $handlerInstance = new $handlerClass();
-                    $objectCache[$handler] =& $handlerInstance;
+                    $objectCache[$handler] = $handlerInstance;
                     $handlerClasses = $handlerInstance->classes();
                     foreach ( $handlerClasses as $handlerClass )
                     {
@@ -585,7 +581,7 @@ class eZCollaborationItemHandler
         {
             $handlerInstance = eZCollaborationItemHandler::instantiate( $handler, $repositories );
             if ( $handlerInstance !== null )
-                $list[] =& $handlerInstance;
+                $list[] = $handlerInstance;
         }
         return $list;
     }
