@@ -5,9 +5,9 @@
 // Created on: <23-Sep-2004 12:52:38 jb>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezcontentcachemanager.php
+/*! \file
 */
 
 /*!
@@ -42,8 +42,6 @@
   \sa eZContentCache
 */
 
-//include_once( 'kernel/classes/ezcontentobject.php' );
-//include_once( 'lib/ezutils/classes/ezini.php' );
 require_once( 'access.php' );
 
 class eZContentCacheManager
@@ -66,12 +64,9 @@ class eZContentCacheManager
     */
     static function appendParentNodeIDs( $object, $versionNum, &$nodeIDList )
     {
-        foreach ( $object->parentNodes( $versionNum ) as $parentNode )
+        foreach ( $object->parentNodeIDArray() as $parentNodeID )
         {
-            if ( is_object ( $parentNode ) )
-            {
-                $nodeIDList[] = $parentNode->attribute( 'node_id' );
-            }
+            $nodeIDList[] = $parentNodeID;
         }
     }
 
@@ -206,15 +201,17 @@ class eZContentCacheManager
      \param $versionNum The version of the object to use or \c true for current version
      \param[out] $nodeIDList Array with node IDs
     */
-    static function appendKeywordNodeIDs( $object, $versionNum, &$nodeIDList )
+    static function appendKeywordNodeIDs( $object, $versionNum, &$nodeIDList, $limit = null )
     {
+        if ( $limit === 0 )
+            return;
         if ( $versionNum === true )
             $versionNum = false;
         $keywordArray = array();
         $attributes = $object->contentObjectAttributes( true, $versionNum );
         foreach ( array_keys( $attributes ) as $key )  // Looking for ezkeyword attributes
         {
-            if ( get_class( $attributes[$key] ) == 'ezcontentobjectattribute' and
+            if ( $attributes[$key] instanceof eZContentObjectAttribute and
                  $attributes[$key]->attribute( 'data_type_string' ) == 'ezkeyword' )  // Found one
             {
                 $keywordObject = $attributes[$key]->content();
@@ -231,10 +228,13 @@ class eZContentCacheManager
         // Find all nodes that have the given keywords
         if ( count( $keywordArray ) > 0 )
         {
-            $keywordString = implode( "', '", $keywordArray );
-            //include_once( 'lib/ezdb/classes/ezdb.php' );
             $db = eZDB::instance();
-            $keywordString = "'".$db->escapeString( $keyword )."'";
+            foreach( $keywordArray as $k => $keyword )
+            {
+                $keywordArray[$k] = "'" . $db->escapeString( $keyword ) . "'";
+            }
+            $keywordString = implode( ', ', $keywordArray );
+            $params = $limit ? array( 'offset' => 0, 'limit'  => $limit ) : array();
             $rows = $db->arrayQuery( "SELECT DISTINCT ezcontentobject_tree.node_id
                                        FROM
                                          ezcontentobject_tree,
@@ -245,7 +245,8 @@ class eZContentCacheManager
                                          ezcontentobject_tree.contentobject_id = ezcontentobject_attribute.contentobject_id AND
                                          ezcontentobject_attribute.id = ezkeyword_attribute_link.objectattribute_id AND
                                          ezkeyword_attribute_link.keyword_id = ezkeyword.id AND
-                                         ezkeyword.keyword IN ( $keywordString )" );
+                                         ezkeyword.keyword IN ( $keywordString )",
+                                        $params );
 
             foreach ( $rows as $row )
             {
@@ -293,11 +294,13 @@ class eZContentCacheManager
         $ini = eZINI::instance( 'viewcache.ini' );
         $info = false;
 
-        if ( $ignoreINISettings || $ini->variable( 'ViewCacheSettings', 'SmartCacheClear' ) == 'enabled' )
+        if ( $ignoreINISettings || $ini->variable( 'ViewCacheSettings', 'SmartCacheClear' ) !== 'disabled' )
         {
             if ( $ini->hasGroup( $classID ) )
             {
                 $info = array();
+                $info['clear_cache_exclusive'] = $ini->variable( 'ViewCacheSettings', 'SmartCacheClear' ) === 'exclusive';
+
                 if ( $ini->hasVariable( $classID, 'DependentClassIdentifier' ) )
                     $info['dependent_class_identifier'] = $ini->variable( $classID, 'DependentClassIdentifier' );
 
@@ -395,6 +398,29 @@ class eZContentCacheManager
         return $info;
     }
 
+    /*
+     Can be used to debug the \a $handledObjectList parameter of nodeListForObject()
+    */
+    static function writeDebugBits( $handledObjectList, $highestBit )
+    {
+        $bitPadLength = (int)( pow( $highestBit, 0.5 ) + 1 );
+        //$bitPadLength = strlen( decbin( $highestBit ) );
+
+        $objectIDList = array_keys( $handledObjectList );
+        $maxObjectID = max( $objectIDList );
+        $padLength = strlen( $maxObjectID ) + 2;
+
+        $msg = '';
+        foreach ( $handledObjectList as $objectID => $clearCacheType )
+        {
+            $bitString = decbin( $clearCacheType );
+            $msg .= str_pad( $objectID, $padLength, ' ', STR_PAD_RIGHT ) . str_pad( $bitString, $bitPadLength, '0', STR_PAD_LEFT );
+            $msg .= "\r\n";
+        }
+
+        eZDebug::writeDebug( $msg, 'eZContentCacheManager::writeDebugBits()' );
+    }
+
     /*!
      \static
      Use \a $clearCacheType to include different kind of nodes( parent, relating, etc ).
@@ -412,23 +438,49 @@ class eZContentCacheManager
                             - self::CLEAR_ALL_CACHE - Enables all of the above
                             - self::CLEAR_NO_CACHE - Do not clear cache for current object.
      \param[out] $nodeList An array with node IDs that are affected by the current object change.
+     \param[out] $handledObjectList An associative array with object IDs and the cache types that were handled for these objects already.
+                                    Used to avoid infinite recursion.
 
      \note This function is recursive.
     */
-    static function nodeListForObject( $contentObject, $versionNum, $clearCacheType, &$nodeList )
+    static function nodeListForObject( $contentObject, $versionNum, $clearCacheType, &$nodeList, &$handledObjectList )
     {
+        $contentObjectID = $contentObject->attribute( 'id' );
+
+        if ( isset( $handledObjectList[$contentObjectID] ) )
+        {
+            $handledObjectList[$contentObjectID] |= $clearCacheType;
+        }
+        else
+        {
+            $handledObjectList[$contentObjectID] = $clearCacheType;
+        }
+        //self::writeDebugBits( $handledObjectList, self::CLEAR_SIBLINGS_CACHE );
+
         $assignedNodes = $contentObject->assignedNodes();
 
         // determine if $contentObject has dependent objects for which cache should be cleared too.
         $objectClassIdentifier = $contentObject->attribute( 'class_identifier' );
         $dependentClassInfo = eZContentCacheManager::dependencyInfo( $objectClassIdentifier );
 
-        //Check if clear_cache_type on class type is none before we begin
         if ( $dependentClassInfo['clear_cache_type'] === self::CLEAR_NO_CACHE )
         {
+            // BC: Allow smart cache clear setting to specify no caching setting
+            $clearCacheType = self::CLEAR_NO_CACHE;
+        }
+        else if ( $dependentClassInfo['clear_cache_exclusive'] === true )
+        {
+            // use class specific smart cache rules exclusivly
             $clearCacheType = $dependentClassInfo['clear_cache_type'];
         }
 
+        if ( $clearCacheType === self::CLEAR_NO_CACHE )
+        {
+            // when recursing we will never have to handle this object again for other cache types
+            // because types of caches to clear will always be set to none
+            $handledObjectList[$contentObjectID] = self::CLEAR_ALL_CACHE;
+        }
+
         if ( $clearCacheType & self::CLEAR_NODE_CACHE )
         {
             eZContentCacheManager::appendNodeIDs( $assignedNodes, $nodeList );
@@ -446,7 +498,12 @@ class eZContentCacheManager
 
         if ( $clearCacheType & self::CLEAR_KEYWORD_CACHE )
         {
-            eZContentCacheManager::appendKeywordNodeIDs( $contentObject, $versionNum, $nodeList );
+            $keywordClearLimit = null;
+            $viewcacheini = eZINI::instance( 'viewcache.ini' );
+            if ( is_numeric( $viewcacheini->variable( 'ViewCacheSettings', 'KeywordNodesCacheClearLimit' ) ) )
+                $keywordClearLimit = (int) $viewcacheini->variable( 'ViewCacheSettings', 'KeywordNodesCacheClearLimit' );
+
+            eZContentCacheManager::appendKeywordNodeIDs( $contentObject, $versionNum, $nodeList, $keywordClearLimit );
         }
 
         if ( $clearCacheType & self::CLEAR_SIBLINGS_CACHE )
@@ -456,7 +513,11 @@ class eZContentCacheManager
 
         if ( $dependentClassInfo['clear_cache_type'] & self::CLEAR_SIBLINGS_CACHE )
         {
-            eZContentCacheManager::appendSiblingsNodeIDs( $assignedNodes, $nodeList );
+            if ( !( $clearCacheType & self::CLEAR_SIBLINGS_CACHE ) )
+            {
+                eZContentCacheManager::appendSiblingsNodeIDs( $assignedNodes, $nodeList );
+                $handledObjectList[$contentObjectID] |= self::CLEAR_SIBLINGS_CACHE;
+            }
 
             // drop 'siblings' bit and process parent nodes.
             // since 'sibling' mode is affected to the current object
@@ -467,9 +528,18 @@ class eZContentCacheManager
         {
             foreach( $dependentClassInfo['additional_objects'] as $objectID )
             {
+                // skip if cache type is already handled for this object
+                if ( isset( $handledObjectList[$objectID] ) && $handledObjectList[$objectID] & self::CLEAR_NODE_CACHE )
+                {
+                    continue;
+                }
+
                 $object = eZContentObject::fetch( $objectID );
                 if ( $object )
-                    eZContentCacheManager::nodeListForObject( $object, true, self::CLEAR_NODE_CACHE, $nodeList );
+                {
+                    //eZDebug::writeDebug( 'adding additional object ' . $objectID, 'eZContentCacheManager::nodeListForObject() for object ' . $contentObjectID );
+                    eZContentCacheManager::nodeListForObject( $object, true, self::CLEAR_NODE_CACHE, $nodeList, $handledObjectList );
+                }
             }
         }
 
@@ -486,17 +556,8 @@ class eZContentCacheManager
             {
                 $step = 0;
 
-                // getting class identifier and node ID for each node in the $nodePath.
-                $nodeInfoList = eZContentObjectTreeNode::fetchClassIdentifierListByPathString( $nodePath, false );
-
-                if ( $maxParents > 0 )
-                {
-                    // need to reverse $nodeInfoList if $maxParents is used.
-                    // if offset is zero then we will loop through all elements in $nodeInfoList. So,
-                    // array_reverse is not needed.
-
-                    $nodeInfoList = array_reverse( $nodeInfoList );
-                }
+                // getting class identifier and node ID for each node in the $nodePath, up to $maxParents
+                $nodeInfoList = eZContentObjectTreeNode::fetchClassIdentifierListByPathString( $nodePath, false, $maxParents );
 
                 // for each node in $nodeInfoList determine if this node belongs to $dependentClassIdentifiers. If
                 // so then clear cache for this node.
@@ -505,32 +566,43 @@ class eZContentCacheManager
                     if ( in_array( $item['class_identifier'], $dependentClassIdentifiers ) )
                     {
                         $object = eZContentObject::fetchByNodeID( $item['node_id'] );
+                        if ( !$object instanceof eZContentObject )
+                        {
+                            continue;
+                        }
+                        $objectID = $object->attribute( 'id' );
+
+                        if ( isset( $handledObjectList[$objectID] ) )
+                        {
+                            // remove cache types that were already handled
+                            $smartClearType &= ~$handledObjectList[$objectID];
+
+                            // if there are no cache types remaining, then skip
+                            if ( $smartClearType == self::CLEAR_NO_CACHE )
+                            {
+                                continue;
+                            }
+                        }
 
                         if ( count( $dependentClassInfo['object_filter'] ) > 0 )
                         {
-                            foreach ( $dependentClassInfo['object_filter'] as $objectIDFilter )
+                            if ( in_array( $objectID, $dependentClassInfo['object_filter'] ) )
                             {
-                                if ( $objectIDFilter == $object->attribute( 'id' ) )
-                                {
-                                    eZContentCacheManager::nodeListForObject( $object, true, $smartClearType, $nodeList );
-                                    break;
-                                }
+                                //eZDebug::writeDebug( 'adding parent ' . $objectID, 'eZContentCacheManager::nodeListForObject() for object ' . $contentObjectID );
+                                eZContentCacheManager::nodeListForObject( $object, true, $smartClearType, $nodeList, $handledObjectList );
                             }
                         }
                         else
                         {
-                            eZContentCacheManager::nodeListForObject( $object, true, $smartClearType, $nodeList );
+                            //eZDebug::writeDebug( 'adding parent ' . $objectID, 'eZContentCacheManager::nodeListForObject() for object ' . $contentObjectID );
+                            eZContentCacheManager::nodeListForObject( $object, true, $smartClearType, $nodeList, $handledObjectList );
                         }
                     }
-
-                    // if we reached $maxParents then break
-                    if ( ++$step == $maxParents )
-                    {
-                        break;
-                    }
                 }
             }
         }
+
+        //self::writeDebugBits( $handledObjectList, self::CLEAR_SIBLINGS_CACHE );
     }
 
     /*!
@@ -557,7 +629,7 @@ class eZContentCacheManager
             return false;
         }
 
-        eZContentCacheManager::nodeListForObject( $object, $versionNum, self::CLEAR_DEFAULT, $nodeList );
+        eZContentCacheManager::nodeListForObject( $object, $versionNum, self::CLEAR_DEFAULT, $nodeList, $handledObjectList );
 
         return $nodeList;
     }
@@ -584,32 +656,42 @@ class eZContentCacheManager
     */
     static function clearObjectViewCache( $objectID, $versionNum = true, $additionalNodeList = false )
     {
+        eZDebug::accumulatorStart( 'node_cleanup_list', '', 'Node cleanup list' );
+
         $nodeList = eZContentCacheManager::nodeList( $objectID, $versionNum );
 
         if ( $nodeList === false and !is_array( $additionalNodeList ) )
             return false;
 
+        if ( $nodeList === false )
+        {
+            $nodeList = array();
+        }
+
         if ( is_array( $additionalNodeList ) )
         {
             array_splice( $nodeList, count( $nodeList ), 0, $additionalNodeList );
         }
 
+        if ( count( $nodeList ) == 0 )
+        {
+            return false;
+        }
+
         $nodeList = array_unique( $nodeList );
 
+        eZDebug::accumulatorStop( 'node_cleanup_list' );
+
         eZDebugSetting::writeDebug( 'kernel-content-edit', count( $nodeList ), "count in nodeList" );
 
         $ini = eZINI::instance();
         if ( $ini->variable( 'ContentSettings', 'StaticCache' ) == 'enabled' )
         {
-            //include_once( 'kernel/classes/ezstaticcache.php' );
-            //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
             $staticCache = new eZStaticCache();
             $staticCache->generateAlwaysUpdatedCache();
             $staticCache->generateNodeListCache( $nodeList );
         }
 
-        //include_once( 'kernel/classes/ezcontentcache.php' );
-
         eZDebug::accumulatorStart( 'node_cleanup', '', 'Node cleanup' );
 
         eZContentObject::expireComplexViewModeCache();
@@ -667,7 +749,6 @@ class eZContentCacheManager
         if ( $object )
             $nodeList = $object->assignedNodes();
 
-        //include_once( 'kernel/classes/ezsubtreecache.php' );
         eZSubtreeCache::cleanup( $nodeList );
     }
 
@@ -685,7 +766,6 @@ class eZContentCacheManager
         $object = eZContentObject::fetch( $objectID );
         $user = eZUser::currentUser();
 
-        //include_once( 'kernel/classes/eznodeviewfunctions.php' );
         eZDebug::accumulatorStart( 'generate_cache', '', 'Generating view cache' );
         if ( $ini->variable( 'ContentSettings', 'PreViewCache' ) == 'enabled' )
         {
@@ -699,95 +779,96 @@ class eZContentCacheManager
                                      'month' => false,
                                      'day' => false,
                                      'namefilter' => false );
-
-            foreach ( $preCacheSiteaccessArray as $changeToSiteAccess )
+            if ( is_array( $preCacheSiteaccessArray ) && count( $preCacheSiteaccessArray ) > 0 )
             {
-                $GLOBALS['eZCurrentAccess']['name'] = $changeToSiteAccess;
-
-                if ( $GLOBALS['eZCurrentAccess']['type'] == EZ_ACCESS_TYPE_URI )
+                foreach ( $preCacheSiteaccessArray as $changeToSiteAccess )
                 {
-                    eZSys::clearAccessPath();
-                    eZSys::addAccessPath( $changeToSiteAccess );
-                }
-
-                require_once( 'kernel/common/template.php' );
-                $tpl = templateInit();
-                $res = eZTemplateDesignResource::instance();
-
-                // Get the sitedesign and cached view preferences for this siteaccess
-                $siteini = eZINI::instance( 'site.ini', 'settings', null, null, false );
-                $siteini->prependOverrideDir( "siteaccess/$changeToSiteAccess", false, 'siteaccess' );
-                $siteini->loadCache();
-                $designSetting = $siteini->variable( "DesignSettings", "SiteDesign" );
-                $cachedViewPreferences = $siteini->variable( 'ContentSettings', 'CachedViewPreferences' );
-                $res->setDesignSetting( $designSetting, 'site' );
-
-                $res->setOverrideAccess( $changeToSiteAccess );
-
-                $language = false; // Needs to be specified if you want to generate the cache for a specific language
-                $viewMode = 'full';
-
-                $assignedNodes = $object->assignedNodes();
-                foreach ( $assignedNodes as $node )
-                {
-                    // We want to generate the cache for the specified user
-                    $previewCacheUsers = $ini->variable( 'ContentSettings', 'PreviewCacheUsers' );
-                    foreach ( $previewCacheUsers as $previewCacheUserID )
+                    $GLOBALS['eZCurrentAccess']['name'] = $changeToSiteAccess;
+    
+                    if ( $GLOBALS['eZCurrentAccess']['type'] == EZ_ACCESS_TYPE_URI )
                     {
-                        // If the text is 'anon' we need to fetch the Anonymous user ID.
-                        if ( $previewCacheUserID === 'anonymous' )
+                        eZSys::clearAccessPath();
+                        eZSys::addAccessPath( $changeToSiteAccess );
+                    }
+    
+                    require_once( 'kernel/common/template.php' );
+                    $tpl = templateInit();
+                    $res = eZTemplateDesignResource::instance();
+    
+                    // Get the sitedesign and cached view preferences for this siteaccess
+                    $siteini = eZINI::instance( 'site.ini', 'settings', null, null, false );
+                    $siteini->prependOverrideDir( "siteaccess/$changeToSiteAccess", false, 'siteaccess' );
+                    $siteini->loadCache();
+                    $designSetting = $siteini->variable( "DesignSettings", "SiteDesign" );
+                    $cachedViewPreferences = $siteini->variable( 'ContentSettings', 'CachedViewPreferences' );
+                    $res->setDesignSetting( $designSetting, 'site' );
+    
+                    $res->setOverrideAccess( $changeToSiteAccess );
+    
+                    $language = false; // Needs to be specified if you want to generate the cache for a specific language
+                    $viewMode = 'full';
+    
+                    $assignedNodes = $object->assignedNodes();
+                    foreach ( $assignedNodes as $node )
+                    {
+                        // We want to generate the cache for the specified user
+                        $previewCacheUsers = $ini->variable( 'ContentSettings', 'PreviewCacheUsers' );
+                        foreach ( $previewCacheUsers as $previewCacheUserID )
                         {
-                            $previewCacheUserID = $siteini->variable( "UserSettings", "AnonymousUserID" );
-                            $previewCacheUser = eZUser::fetch( $previewCacheUserID  );
-                        }
-                        else if ( $previewCacheUserID === 'current' )
-                        {
-                            $previewCacheUser = $user;
-                        }
-                        else
-                        {
-                            $previewCacheUser = eZUser::fetch( $previewCacheUserID  );
-                        }
-                        if ( !$previewCacheUser )
-                            continue;
-
-                        // Before we generate the view cache we must change the currently logged in user to $previewCacheUser
-                        // If not the templates might read in wrong personalized data (preferences etc.)
-                        $previewCacheUser->setCurrentlyLoggedInUser( $previewCacheUser, $previewCacheUser->attribute( 'contentobject_id' ) );
-
-                        // Cache the current node
-                        $cacheFileArray = eZNodeviewfunctions::generateViewCacheFile( $previewCacheUser, $node->attribute( 'node_id' ), 0, false, $language, $viewMode, $viewParameters, $cachedViewPreferences );
-                        $tmpRes = eZNodeviewfunctions::generateNodeView( $tpl, $node, $node->attribute( 'object' ), $language, $viewMode, 0, $cacheFileArray['cache_dir'], $cacheFileArray['cache_path'], true, $viewParameters );
-
-                        // Cache the parent node
-                        $parentNode = $node->attribute( 'parent' );
-                        $objectID = $parentNode->attribute( 'contentobject_id' );
-                        // if parent objectID is null or is 0 we should not create cache.
-                        if ( $objectID )
-                        {
-                            $cacheFileArray = eZNodeviewfunctions::generateViewCacheFile( $previewCacheUser, $parentNode->attribute( 'node_id' ), 0, false, $language, $viewMode, $viewParameters, $cachedViewPreferences );
-                            $tmpRes = eZNodeviewfunctions::generateNodeView( $tpl, $parentNode, $parentNode->attribute( 'object' ), $language, $viewMode, 0, $cacheFileArray['cache_dir'], $cacheFileArray['cache_path'], true, $viewParameters );
+                            // If the text is 'anon' we need to fetch the Anonymous user ID.
+                            if ( $previewCacheUserID === 'anonymous' )
+                            {
+                                $previewCacheUserID = $siteini->variable( "UserSettings", "AnonymousUserID" );
+                                $previewCacheUser = eZUser::fetch( $previewCacheUserID  );
+                            }
+                            else if ( $previewCacheUserID === 'current' )
+                            {
+                                $previewCacheUser = $user;
+                            }
+                            else
+                            {
+                                $previewCacheUser = eZUser::fetch( $previewCacheUserID  );
+                            }
+                            if ( !$previewCacheUser )
+                                continue;
+    
+                            // Before we generate the view cache we must change the currently logged in user to $previewCacheUser
+                            // If not the templates might read in wrong personalized data (preferences etc.)
+                            $previewCacheUser->setCurrentlyLoggedInUser( $previewCacheUser, $previewCacheUser->attribute( 'contentobject_id' ) );
+    
+                            // Cache the current node
+                            $cacheFileArray = eZNodeviewfunctions::generateViewCacheFile( $previewCacheUser, $node->attribute( 'node_id' ), 0, false, $language, $viewMode, $viewParameters, $cachedViewPreferences );
+                            $tmpRes = eZNodeviewfunctions::generateNodeView( $tpl, $node, $node->attribute( 'object' ), $language, $viewMode, 0, $cacheFileArray['cache_dir'], $cacheFileArray['cache_path'], true, $viewParameters );
+    
+                            // Cache the parent node
+                            $parentNode = $node->attribute( 'parent' );
+                            $objectID = $parentNode->attribute( 'contentobject_id' );
+                            // if parent objectID is null or is 0 we should not create cache.
+                            if ( $objectID )
+                            {
+                                $cacheFileArray = eZNodeviewfunctions::generateViewCacheFile( $previewCacheUser, $parentNode->attribute( 'node_id' ), 0, false, $language, $viewMode, $viewParameters, $cachedViewPreferences );
+                                $tmpRes = eZNodeviewfunctions::generateNodeView( $tpl, $parentNode, $parentNode->attribute( 'object' ), $language, $viewMode, 0, $cacheFileArray['cache_dir'], $cacheFileArray['cache_path'], true, $viewParameters );
+                            }
                         }
                     }
                 }
-            }
-            // Restore the old user as the current one
-            $user->setCurrentlyLoggedInUser( $user, $user->attribute( 'contentobject_id' ) );
-
-            $GLOBALS['eZCurrentAccess']['name'] = $currentSiteAccess;
-            $res->setDesignSetting( $currentSiteAccess, 'site' );
-            $res->setOverrideAccess( false );
-            if ( $GLOBALS['eZCurrentAccess']['type'] == EZ_ACCESS_TYPE_URI )
-            {
-                eZSys::clearAccessPath();
-                eZSys::addAccessPath( $currentSiteAccess );
+                // Restore the old user as the current one
+                $user->setCurrentlyLoggedInUser( $user, $user->attribute( 'contentobject_id' ) );
+    
+                $GLOBALS['eZCurrentAccess']['name'] = $currentSiteAccess;
+                $res->setDesignSetting( $currentSiteAccess, 'site' );
+                $res->setOverrideAccess( false );
+    
+                if ( $GLOBALS['eZCurrentAccess']['type'] == EZ_ACCESS_TYPE_URI )
+                {
+                    eZSys::clearAccessPath();
+                    eZSys::addAccessPath( $currentSiteAccess );
+                }
             }
         }
 
         if ( $ini->variable( 'ContentSettings', 'StaticCache' ) == 'enabled' )
         {
-            //include_once( 'kernel/classes/ezstaticcache.php' );
-
             $nodes = array();
             $ini = eZINI::instance();
             $staticCache = new eZStaticCache();
@@ -799,7 +880,7 @@ class eZContentCacheManager
                 $useURLAlias = $ini->variable( 'URLTranslator', 'Translation' ) == 'enabled';
             }
 
-            eZContentCacheManager::nodeListForObject( $object, true, self::CLEAR_DEFAULT, $nodes );
+            eZContentCacheManager::nodeListForObject( $object, true, self::CLEAR_DEFAULT, $nodes, $handledObjectList );
 
             // If no nodes returns it means that ClearCacheMethod = self::CLEAR_NO_CACHE
             if ( count( $nodes ) )
@@ -808,11 +889,11 @@ class eZContentCacheManager
                 {
                     if ( $useURLAlias )
                     {
-                        $aNode = eZContentObjectTreeNode::fetch( $nodeID, false, false );
-                        if ( !isset( $aNode ) )
+                        $oNode = eZContentObjectTreeNode::fetch( $nodeID, false, true );
+                        if ( !isset( $oNode ) )
                             continue;
 
-                        $urlAlias = $aNode['path_identification_string'];
+                        $urlAlias = $oNode->urlAlias();
                         if ( $pathPrefix != '' )
                         {
                             $tempAlias = substr( $pathPrefix, strlen( $pathPrefix ) -1 ) == '/'
@@ -838,7 +919,7 @@ class eZContentCacheManager
      \static
      Clears content cache if needed by \a $sectionID
     */
-    function clearContentCacheIfNeededBySectionID( $sectionID )
+    static function clearContentCacheIfNeededBySectionID( $sectionID )
     {
         // fetch all objects of this section
         $objectList = eZContentObject::fetchList( false, array( 'section_id' => "$sectionID" ) );
@@ -863,7 +944,6 @@ class eZContentCacheManager
         eZContentCacheManager::clearTemplateBlockCacheIfNeeded( $objectID );
 
         // Clear cached path strings of content SSL zones.
-        //include_once( 'kernel/classes/ezsslzone.php' );
         eZSSLZone::clearCacheIfNeeded();
 
         eZDebug::accumulatorStop( 'check_cache' );
@@ -883,7 +963,6 @@ class eZContentCacheManager
         eZContentCacheManager::clearTemplateBlockCache( $objectID );
 
         // Clear cached path strings of content SSL zones.
-        //include_once( 'kernel/classes/ezsslzone.php' );
         eZSSLZone::clearCache();
 
         eZDebug::accumulatorStop( 'check_cache' );
@@ -916,7 +995,6 @@ class eZContentCacheManager
             // subtree template block caches
             if ( $templateCacheEnabled )
             {
-                //include_once( 'kernel/classes/ezsubtreecache.php' );
                 eZSubtreeCache::cleanupAll();
             }
         }
