@@ -3,9 +3,9 @@
 // Created on: <02-Dec-2002 13:15:49 bf>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -34,9 +34,6 @@
 
 */
 
-//include_once( 'kernel/classes/ezinformationcollectionattribute.php' );
-//include_once( 'lib/ezutils/classes/ezsys.php' );
-
 class eZInformationCollection extends eZPersistentObject
 {
     function eZInformationCollection( $row )
@@ -112,7 +109,7 @@ class eZInformationCollection extends eZPersistentObject
 
      Remove infomation collection from specified contentobject_id
 
-     \param contentobject id
+     \param delID contentobject id
      \note Transaction unsafe. If you call several transaction unsafe methods you must enclose
      the calls within a db transaction; thus within db->begin and db->commit.
     */
@@ -301,7 +298,7 @@ class eZInformationCollection extends eZPersistentObject
         return $userData;
     }
 
-    function sendOutEmail( $contentObject )
+    static function sendOutEmail( $contentObject )
     {
         if ( !$contentObject )
             return false;
@@ -334,7 +331,7 @@ class eZInformationCollection extends eZPersistentObject
         return $sendEmail;
     }
 
-    function displayHandling( $contentObject )
+    static function displayHandling( $contentObject )
     {
         if ( !$contentObject )
             return false;
@@ -370,7 +367,7 @@ class eZInformationCollection extends eZPersistentObject
         return $display;
     }
 
-    function redirectURL( $contentObject )
+    static function redirectURL( $contentObject )
     {
         if ( !$contentObject )
             return false;
@@ -430,7 +427,7 @@ class eZInformationCollection extends eZPersistentObject
                                                 $asObject );
     }
 
-    function fetchCountForAttribute( $objectAttributeID, $value )
+    static function fetchCountForAttribute( $objectAttributeID, $value )
     {
         $db = eZDB::instance();
         // Do a count on the value of collected integer info. Useful for e.g. polls
@@ -450,7 +447,7 @@ class eZInformationCollection extends eZPersistentObject
         return $resArray[0]['count'];
     }
 
-    function fetchCollectionCountForObject( $objectID )
+    static function fetchCollectionCountForObject( $objectID )
     {
         if( !is_numeric( $objectID ) )
         {
@@ -590,7 +587,7 @@ class eZInformationCollection extends eZPersistentObject
         return $resultSet[0]['count'];
     }
 
-    function fetchCountList( $objectAttributeID )
+    static function fetchCountList( $objectAttributeID )
     {
         $db = eZDB::instance();
         // Do a count on the value of collected integer info. Useful for e.g. polls
@@ -679,7 +676,7 @@ class eZInformationCollection extends eZPersistentObject
     /*!
      Same as generateUserIdentifier but returns the user identifier for the current user.
     */
-    function currentUserIdentifier()
+    static function currentUserIdentifier()
     {
         $user = null;
         return eZInformationCollection::generateUserIdentifier( $user );
@@ -692,7 +689,7 @@ class eZInformationCollection extends eZPersistentObject
      The user identifier is either calculated from the unique user ID
      or the IP address when the user is anonymous.
     */
-    function generateUserIdentifier( &$user )
+    static function generateUserIdentifier( &$user )
     {
         if ( !$user )
         {
@@ -715,7 +712,7 @@ class eZInformationCollection extends eZPersistentObject
     /*!
      Creates a new eZInformationCollection instance.
     */
-    function create( $contentObjectID, $userIdentifier, $creatorID = false )
+    static function create( $contentObjectID, $userIdentifier, $creatorID = false )
     {
         $timestamp = time();
 
