@@ -5,9 +5,9 @@
 // Created on: <31-Jul-2002 14:00:03 bf>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -34,22 +34,12 @@
   \sa eZProductCollection eZBasket
 */
 
-//include_once( "kernel/classes/ezpersistentobject.php" );
-//include_once( "kernel/classes/ezproductcollection.php" );
-//include_once( "kernel/classes/ezproductcollectionitem.php" );
-//include_once( "kernel/classes/datatypes/ezuser/ezuser.php" );
-//include_once( "kernel/classes/ezuserdiscountrule.php" );
-//include_once( "kernel/classes/ezcontentobjecttreenode.php" );
-//include_once( "kernel/classes/ezorderitem.php" );
-
 class eZOrder extends eZPersistentObject
 {
     const SHOW_NORMAL = 0;
     const SHOW_ARCHIVED = 1;
     const SHOW_ALL = 2;
 
-    /*!
-    */
     function eZOrder( $row )
     {
         $this->eZPersistentObject( $row );
@@ -789,8 +779,6 @@ class eZOrder extends eZPersistentObject
     */
     static function discount( $userID, $object )
     {
-        //include_once( 'kernel/classes/ezdiscount.php' );
-
         $user = eZUser::fetch( $userID );
         $bestMatch = eZDiscount::discountPersent( $user, array( 'contentclass_id' => $object->attribute( 'contentclass_id'),
                                                                 'contentobject_id' => $object->attribute( 'id' ),
@@ -1038,7 +1026,6 @@ class eZOrder extends eZPersistentObject
     function accountInformation()
     {
         // Fetch the shop account handler
-        //include_once( 'kernel/classes/ezshopaccounthandler.php' );
         $accountHandler = eZShopAccountHandler::instance();
         return $accountHandler->accountInformation( $this );
     }
@@ -1051,7 +1038,6 @@ class eZOrder extends eZPersistentObject
     function accountName()
     {
         // Fetch the shop account handler
-        //include_once( 'kernel/classes/ezshopaccounthandler.php' );
         $accountHandler = eZShopAccountHandler::instance();
 
         return $accountHandler->accountName( $this );
@@ -1064,7 +1050,6 @@ class eZOrder extends eZPersistentObject
     function accountEmail()
     {
         // Fetch the shop account handler
-        //include_once( 'kernel/classes/ezshopaccounthandler.php' );
         $accountHandler = eZShopAccountHandler::instance();
 
         return $accountHandler->email( $this );
@@ -1163,7 +1148,6 @@ class eZOrder extends eZPersistentObject
         if ( $accessWord == 'yes' )
         {
             // We have full access so we return all of them
-            //include_once( 'kernel/classes/ezorderstatus.php' );
             $statusList = eZOrderStatus::fetchOrderedList( true, false );
             return $statusList;
         }
@@ -1196,7 +1180,6 @@ class eZOrder extends eZPersistentObject
                     else
                     {
                         // We have full access for the current status so we return all of them
-                        //include_once( 'kernel/classes/ezorderstatus.php' );
                         $statusList = eZOrderStatus::fetchOrderedList( true, false );
                         return $statusList;
                     }
@@ -1205,7 +1188,6 @@ class eZOrder extends eZPersistentObject
             if ( count( $accessList ) > 0 )
             {
                 $accessList = array_unique( array_merge( $accessList, array( $currentStatusID ) ) );
-                //include_once( 'kernel/classes/ezorderstatus.php' );
                 $statuses = eZOrderStatus::fetchOrderedList( true, false );
                 foreach ( $statuses as $status )
                 {
@@ -1235,7 +1217,6 @@ class eZOrder extends eZPersistentObject
         if ( $userID === false )
             $userID = eZUser::currentUserID();
 
-        //include_once( 'kernel/classes/ezorderstatushistory.php' );
         $history = eZOrderStatusHistory::create( $this->OrderNr, $statusID, $userID, $time );
         $history->store();
 
@@ -1257,7 +1238,6 @@ class eZOrder extends eZPersistentObject
     */
     function createStatusHistory()
     {
-        //include_once( 'kernel/classes/ezorderstatushistory.php' );
         $history = eZOrderStatusHistory::create( $this->OrderNr, // Note: Use the order nr, not id
                                                  $this->StatusID,
                                                  $this->StatusModifierID,
@@ -1296,10 +1276,9 @@ class eZOrder extends eZPersistentObject
     {
         if ( $this->Status === null )
         {
-            //include_once( 'kernel/classes/ezorderstatus.php' );
             $this->Status = eZOrderStatus::fetchByStatus( $this->StatusID );
         }
-        return $this->Status->attribute( 'name' );;
+        return $this->Status->attribute( 'name' );
     }
 
     /*!
@@ -1311,7 +1290,6 @@ class eZOrder extends eZPersistentObject
     {
         if ( $this->Status === null )
         {
-            //include_once( 'kernel/classes/ezorderstatus.php' );
             $this->Status = eZOrderStatus::fetchByStatus( $this->StatusID );
         }
         return $this->Status;
@@ -1378,7 +1356,6 @@ class eZOrder extends eZPersistentObject
         if ( count( $rows ) > 0 )
         {
             // Who deletes which order in shop should be logged.
-            //include_once( "kernel/classes/ezaudit.php" );
             eZAudit::writeAudit( 'order-delete', array( 'Order ID' => $orderID,
                                                         'Comment' => 'Removed the order and its related data from the database: eZOrder::cleanupOrder()' ) );
 
@@ -1443,10 +1420,8 @@ class eZOrder extends eZPersistentObject
             eZProductCollection::cleanupList( $productCollectionIDList );
         }
         // Who deletes which order in shop should be logged.
-        //include_once( "kernel/classes/ezaudit.php" );
         eZAudit::writeAudit( 'order-delete', array( 'Comment' => 'Removed all orders from the database: eZOrder::cleanup()' ) );
 
-        //include_once( 'kernel/classes/ezorderitem.php' );
         eZOrderItem::cleanup();
         $db->query( "DELETE FROM ezorder_status_history" );
         $db->query( "DELETE FROM ezorder" );
@@ -1583,7 +1558,7 @@ class eZOrder extends eZPersistentObject
         }
         else
         {
-            if ( $collection instanceof eZProductCollection )
+            if ( ( $collection instanceof eZProductCollection ) === false )
             {
                 $collection = eZProductCollection::fetch( $this->attribute( 'productcollection_id' ) );
             }
