@@ -3,9 +3,9 @@
 // Created on: <02-Oct-2006 13:37:23 dl>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -24,8 +24,6 @@
 //
 //
 
-//include_once( 'kernel/classes/ezcontentlanguage.php' );
-
 class eZSerializedObjectNameList
 {
     const ALWAYS_AVAILABLE_STR = 'always-available';
@@ -308,6 +306,16 @@ class eZSerializedObjectNameList
         return $this->NameList;
     }
 
+    /*!
+     Same as 'nameList()' but without 'always-available' entry.
+     */
+    function cleanNameList()
+    {
+        $nameList = $this->nameList();
+        unset( $nameList[eZSerializedObjectNameList::ALWAYS_AVAILABLE_STR] );
+        return $nameList;
+    }
+
     function nameListCount()
     {
         return count( $this->nameList );
@@ -332,8 +340,6 @@ class eZSerializedObjectNameList
         }
     }
 
-    /*!
-    */
     function defaultLanguageLocale()
     {
         $languageLocale = false;
@@ -345,8 +351,6 @@ class eZSerializedObjectNameList
         return $languageLocale;
     }
 
-    /*!
-    */
     function defaultLanguage()
     {
         if ( !is_object( $this->DefaultLanguage ) )
@@ -359,7 +363,7 @@ class eZSerializedObjectNameList
 
     function setDefaultLanguage( $language )
     {
-        $this->DefualtLanguage = $language;
+        $this->DefaultLanguage = $language;
     }
 
     function setDefaultLanguageByLocale( $languageLocale, $createIfNotExist = true )
