@@ -5,9 +5,9 @@
 // Created on: <12-Dec-2005 12:00:06 vs>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezshippingmanager.php
+/*! \file
 */
 
 /*!
@@ -196,7 +196,7 @@ class eZShippingManager
              false if a handler specified but could not be loaded,
              handler object if handler specified and found.
      */
-    function loadBasketInfoHandler()
+    static function loadBasketInfoHandler()
     {
         $shopINI = eZINI::instance( 'shop.ini' );
 
@@ -294,7 +294,7 @@ class eZShippingManager
      - total_shipping_ex_vat     - contains the sum of all prices (float) ex vat.
      - total_shipping_inc_vat    - contains the sum of all prices (float) inc vat.
      */
-    function vatPriceInfo( $shippingInfo )
+    static function vatPriceInfo( $shippingInfo )
     {
         $totalShippingExVat = 0;
         $totalShippingIncVat = 0;
@@ -437,7 +437,7 @@ class eZShippingManager
                                                                    'total_price_vat' => 26.18 ) ) );
      \endcode
     */
-    function updatePriceInfo( $productCollectionID, &$basketInfo )
+    static function updatePriceInfo( $productCollectionID, &$basketInfo )
     {
         $returnValue = false;
         if ( is_object( $handler = eZShippingManager::loadBasketInfoHandler() ) )
