@@ -3,9 +3,9 @@
 // Created on: <01-Jun-2007 15:00:00 dl>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -24,7 +24,7 @@
 //
 //
 
-/*! \file ezsiteinstaller.php
+/*! \file
 */
 
 /*!
@@ -38,10 +38,6 @@
 
 */
 
-//include_once( 'kernel/classes/ezcontentobjectattribute.php' );
-//include_once( 'kernel/classes/ezcontentclassattribute.php' );
-//include_once( 'kernel/classes/ezrole.php' );
-
 class eZSiteInstaller
 {
     const ERR_OK = 0;
@@ -332,8 +328,6 @@ class eZSiteInstaller
     */
     function classByIdentifier( $params )
     {
-        //include_once( 'kernel/classes/ezcontentclass.php' );
-
         $classIdentifier = $params['identifier'];
 
         $contentClass = eZContentClass::fetchByIdentifier( $classIdentifier );
@@ -361,8 +355,6 @@ class eZSiteInstaller
     */
     function removeClassAttribute( $params )
     {
-        //include_once( 'kernel/classes/ezcontentclassattribute.php' );
-
         $contentClassID = $params['class_id'];
         $classAttributeIdentifier = $params['attribute_identifier'];
 
@@ -424,12 +416,10 @@ class eZSiteInstaller
     */
     function addClassAttributes( $params )
     {
-        //include_once( 'kernel/classes/ezcontentclassattribute.php' );
-
         $classInfo = $params['class'];
         $attributesInfo = $params['attributes'];
 
-        $classID = isset( $classInfo['id'] ) ? $classInfo['id'] : false;;
+        $classID = isset( $classInfo['id'] ) ? $classInfo['id'] : false;
         if( $classID )
         {
             $class = eZContentClass::fetch( $classID );
@@ -614,8 +604,6 @@ class eZSiteInstaller
     */
     function createContentObject( $params )
     {
-        //include_once( 'kernel/classes/ezcontentfunctions.php' );
-
         $objectID = false;
 
         $classIdentifier = $params['class_identifier'];
@@ -647,7 +635,6 @@ class eZSiteInstaller
     */
     function renameContentObject( $params )
     {
-        //include_once( 'kernel/classes/ezcontentobject.php' );
         $contentObjectID = $params['contentobject_id'];
         $newName = $params['name'];
         $object = eZContentObject::fetch( $contentObjectID );
@@ -930,8 +917,6 @@ class eZSiteInstaller
     */
     function nodePathStringByURL( $params )
     {
-        //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
-
         $pathString = '';
 
         $node = $this->nodeByUrl( $params );
@@ -951,8 +936,6 @@ class eZSiteInstaller
     */
     function nodeByUrl( $params )
     {
-        //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
-
         $path_identification_string = $params['location'];
 
         $node = eZContentObjectTreeNode::fetchByURLPath( $path_identification_string );
@@ -1076,7 +1059,6 @@ class eZSiteInstaller
         }
 
         // clear cache.
-        //include_once( 'kernel/classes/ezcontentcachemanager.php' );
         eZContentCacheManager::clearContentCacheIfNeeded( $objectID );
 
         $selectedObject = $selectedNode->object();
@@ -1185,8 +1167,6 @@ class eZSiteInstaller
     */
     function assignUserToRole( $params )
     {
-        //include_once( 'kernel/classes/ezrole.php' );
-
         $location = $params['location'];
         $roleName = $params['role_name'];
 
@@ -1212,8 +1192,6 @@ class eZSiteInstaller
     */
     function addPoliciesForRole( $params )
     {
-        //include_once( 'kernel/classes/ezrole.php' );
-
         $roleName = $params['role_name'];
         $policiesDefinition = $params['policies'];
         $createRoleIfNotExists = isset( $params['create_role'] ) ? $params['create_role'] : true;
@@ -1261,8 +1239,6 @@ class eZSiteInstaller
     */
     function removePoliciesForRole( $params )
     {
-        //include_once( 'kernel/classes/ezrole.php' );
-
         $roleName = $params['role_name'];
         $policiesDefinition = $params['policies'];
         $removeRoleIfEmpty = isset( $params['remove_role'] ) ? $params['remove_role'] : true;
@@ -1301,8 +1277,6 @@ class eZSiteInstaller
     */
     function sectionIDbyName( $params )
     {
-        //include_once( 'kernel/classes/ezsection.php' );
-
         $sectionID = false;
         $sectionName = $params['section_name'];
 
@@ -1328,8 +1302,6 @@ class eZSiteInstaller
     */
     function createContentSection( $params )
     {
-        //include_once( 'kernel/classes/ezsection.php' );
-
         $section = false;
 
         $sectionName = $params['name'];
@@ -1377,8 +1349,6 @@ class eZSiteInstaller
     */
     function setRSSExport( $params )
     {
-        //include_once( 'kernel/classes/ezrssexport.php' );
-        //include_once( 'kernel/classes/ezrssexportitem.php' );
         require_once( 'kernel/common/i18n.php' );
 
         // Create default rssExport object to use
@@ -1468,10 +1438,12 @@ class eZSiteInstaller
     /*!
      Create siteaccess urls for additional user siteacceses using info about access type(host, post, uri)
      Params:
-        'siteaccess_list'   - list of siteaccess names to build urls;
-        'access_type'       - access type: port, hostname, url;
-        'port'              - optional, port number to start with. used if 'access_type' is 'port';
-        'exclude_port_list' - optional, ports to skip. used if 'access_type' is 'port';
+        'siteaccess_list'         - list of siteaccess names to build urls;
+        'access_type'             - access type: port, hostname, url;
+        'port'                    - optional, port number to start with. used if 'access_type' is 'port';
+        'exclude_port_list'       - optional, ports to skip. used if 'access_type' is 'port';
+        'host'                    - host name
+        'host_prepend_siteaccess' - optional, boolean which instructs to prepend the site access name or not to the value of 'host', by default true
     */
     function createSiteaccessUrls( $params )
     {
@@ -1514,7 +1486,7 @@ class eZSiteInstaller
             case 'host':
             case 'hostname':
                 {
-                    $hostMatchMapItems = array();
+                    $prependSiteAccess = isset( $params['host_prepend_siteaccess'] ) && is_bool( $params['host_prepend_siteaccess'] ) ? $params['host_prepend_siteaccess'] : true;
 
                     // grep domain
                     if( preg_match( "#^[a-zA-Z0-9]+://(.*)$#", $host, $matches ) )
@@ -1522,12 +1494,21 @@ class eZSiteInstaller
 
                     foreach( $siteaccessList as $siteaccess )
                     {
-                        // replace undescores with dashes( '_' -> '-' );
-                        $hostPrefix = preg_replace( '/(_)/', '-', $siteaccess);
+                        if ( $prependSiteAccess )
+                        {
+                            // replace undescores with dashes( '_' -> '-' );
+                            $hostPrefix = preg_replace( '/(_)/', '-', $siteaccess);
 
-                        // create url and host
-                        $urlList[$siteaccess]['url'] = $hostPrefix . '.' . $host . $indexFile;
-                        $urlList[$siteaccess]['host'] = $hostPrefix . '.' . $host;
+                            // create url and host
+                            $urlList[$siteaccess]['url'] = $hostPrefix . '.' . $host . $indexFile;
+                            $urlList[$siteaccess]['host'] = $hostPrefix . '.' . $host;
+                        }
+                        else
+                        {
+                            // create url and host
+                            $urlList[$siteaccess]['url'] = $host . $indexFile;
+                            $urlList[$siteaccess]['host'] = $host;
+                        }
                     }
                 }
                 break;
@@ -1733,11 +1714,11 @@ class eZSiteInstaller
     }
 
     // store data to use in your steps.
-    var $Settings;
+    public $Settings;
     // define an order of functions to execute.
-    var $Steps;
+    public $Steps;
     // hold an error code of last executed step.
-    var $LastErrorCode;
+    public $LastErrorCode;
 }
 
 ?>
