@@ -5,9 +5,9 @@
 // Created on: <12-Jan-2005 10:29:21 dr>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezstaticcache.php
+/*! \file
 */
 
 /*!
@@ -47,11 +47,10 @@
 
 */
 
-//include_once( 'lib/ezutils/classes/ezini.php' );
-//include_once( 'kernel/classes/ezurlaliasml.php' );
-
 class eZStaticCache
 {
+    const USER_AGENT = 'eZ Publish static cache generator';
+
     /*!
      Initialises the static cache object with settings from staticcache.ini.
     */
@@ -113,7 +112,7 @@ class eZStaticCache
     */
     function alwaysUpdateURLArray()
     {
-        return $this->AlwaysUpdateArray;
+        return $this->AlwaysUpdate;
     }
 
     /*!
@@ -288,12 +287,14 @@ class eZStaticCache
             if ( $url == $cacheURL )
             {
                 $doCacheURL = true;
+                break;
             }
             else if ( strpos( $cacheURL, '*') !== false )
             {
                 if ( strpos( $url, str_replace( '*', '', $cacheURL ) ) === 0 )
                 {
                     $doCacheURL = true;
+                    break;
                 }
             }
         }
@@ -333,14 +334,11 @@ class eZStaticCache
         {
             $dirs = array ('');
         }
+        $http = eZHTTPTool::instance();
 
         foreach ( $dirs as $dir )
         {
             $cacheFiles = array();
-            if ( !is_dir( $staticStorageDir . $dir ) )
-            {
-                eZDir::mkdir( $staticStorageDir . $dir, 0777, true );
-            }
 
             $cacheFiles[] = $this->buildCacheFilename( $staticStorageDir, $dir . $url );
             foreach ( $alternativeStaticLocations as $location )
@@ -364,7 +362,7 @@ class eZStaticCache
                         /* Generate content, if required */
                         if ( $content === false )
                         {
-                            $content = @file_get_contents( $fileName );
+                            $content = $http->getDataByURL( $fileName, false, eZStaticCache::USER_AGENT );
                         }
                         if ( $content === false )
                         {
@@ -405,7 +403,7 @@ class eZStaticCache
         $dir = dirname( $file );
         if ( !is_dir( $dir ) )
         {
-            eZDir::mkdir( $dir, 0777, true );
+            eZDir::mkdir( $dir, false, true );
         }
 
         $oldumask = umask( 0 );
@@ -421,8 +419,10 @@ class eZStaticCache
         {
             fwrite( $fp, $content . '<!-- Generated: '. date( 'Y-m-d H:i:s' ). " -->\n\n" );
             fclose( $fp );
-            //include_once( 'lib/ezfile/classes/ezfile.php' );
             eZFile::rename( $tmpFileName, $file );
+
+            $perm = eZINI::instance()->variable( 'FileSettings', 'StorageFilePermissions' );
+            chmod( $file, octdec( $perm ) );
         }
 
         umask( $oldumask );
@@ -435,14 +435,7 @@ class eZStaticCache
     */
     function removeURL( $url )
     {
-        if ( $url == "/" )
-        {
-            $dir = $this->StaticStorageDir . $url;
-        }
-        else
-        {
-            $dir = $this->StaticStorageDir . $url . "/";
-        }
+        $dir = eZDir::path( array( $this->StaticStorageDir, $url ) );
 
         @unlink( $dir . "/index.html" );
         @rmdir( $dir );
@@ -479,10 +472,11 @@ class eZStaticCache
 
         if ( $clearByCronjob )
         {
-            //include_once( "lib/ezdb/classes/ezdb.php" );
             $db = eZDB::instance();
         }
 
+        $http = eZHTTPTool::instance();
+
         foreach ( $GLOBALS['eZStaticCache-ActionList'] as $action )
         {
             list( $action, $parameters ) = $action;
@@ -504,7 +498,7 @@ class eZStaticCache
                     {
                         if ( !isset( $fileContentCache[$source] ) )
                         {
-                            $fileContentCache[$source] = @file_get_contents( $source );
+                            $fileContentCache[$source] = $http->getDataByURL( $source, false, eZStaticCache::USER_AGENT );
                         }
                         if ( $fileContentCache[$source] === false )
                         {
@@ -531,6 +525,8 @@ class eZStaticCache
     public $MaxCacheDepth;
     /// Array of URLs to cache.
     public $CachedURLArray;
+    /// An array with URLs that is to always be updated.
+    public $AlwaysUpdate;
 }
 
 ?>
