@@ -5,9 +5,9 @@
 // Created on: <24-Jan-2007 16:36:24 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezurlalias.php
+/*! \file
 */
 
 /*!
@@ -75,10 +75,6 @@
 
 */
 
-//include_once( "kernel/classes/ezpersistentobject.php" );
-//include_once( "kernel/classes/ezcontentlanguage.php" );
-//include_once( 'lib/ezi18n/classes/ezchartransform.php' );
-
 class eZURLAliasML extends eZPersistentObject
 {
     // Return values from storePath()
@@ -91,7 +87,7 @@ class eZURLAliasML extends eZPersistentObject
     /*!
      Optionally computed path string for this element, used for caching purposes.
      */
-    var $Path;
+    public $Path;
     private static $charset = null;
 
     /*!
@@ -108,9 +104,6 @@ class eZURLAliasML extends eZPersistentObject
         }
     }
 
-    /*!
-     \reimp
-    */
     static public function definition()
     {
         return array( "fields" => array( "id" => array( 'name' => 'ID',
@@ -152,7 +145,11 @@ class eZURLAliasML extends eZPersistentObject
                                          "is_original" => array( 'name' => 'IsOriginal',
                                                                  'datatype' => 'integer',
                                                                  'default' => 0,
-                                                                 'required' => true ) ),
+                                                                 'required' => true ),
+                                         "alias_redirects" => array( 'name' => 'AliasRedirects',
+                                                                     'datatype' => 'integer',
+                                                                     'default' => 1,
+                                                                     'required' => true ) ),
                       "keys" => array( "parent", "text_md5" ),
                       "function_attributes" => array( "children" => "getChildren",
                                                       "path" => "getPath" ),
@@ -170,7 +167,7 @@ class eZURLAliasML extends eZPersistentObject
         {
             self::$charset = eZTextCodec::internalCharset();
         }
-        
+
         //First try to use mbstring
         if ( extension_loaded( 'mbstring' ) )
         {
@@ -235,18 +232,9 @@ class eZURLAliasML extends eZPersistentObject
     */
     function store( $fieldFilters = null )
     {
-        $locked = false;
         if ( $this->ID === null )
         {
-            $locked = true;
-            $db = eZDB::instance();
-            $db->lock( "ezurlalias_ml" );
-            $query = "SELECT max( id ) + 1 AS id FROM ezurlalias_ml";
-            $rows = $db->arrayQuery( $query );
-            $id = (int)$rows[0]['id'];
-            if ( $id == 0 )
-                $id = 1;
-            $this->ID = $id;
+            $this->ID = self::getNewID();
         }
         if ( $this->Link === null )
         {
@@ -270,10 +258,6 @@ class eZURLAliasML extends eZPersistentObject
         }
 
         eZPersistentObject::store( $fieldFilters );
-        if ( $locked )
-        {
-            $db->unlock();
-        }
     }
 
     /*!
@@ -299,7 +283,7 @@ class eZURLAliasML extends eZPersistentObject
      \param $textMD5  MD5 of the lowercase version of the text, see eZURLAliasML::strtolower().
      \param $language The language entry to remove, can be a string with the locale or a language object (eZContentLanguage).
      */
-    function removeSingleEntry( $parentID, $textMD5, $language )
+    public static function removeSingleEntry( $parentID, $textMD5, $language )
     {
         $parentID = (int)$parentID;
         if ( !is_object( $language ) )
@@ -352,11 +336,14 @@ class eZURLAliasML extends eZPersistentObject
 
     /*!
      Calculates the full path for the current item and returns it.
+     
+     \param $locale The locale for which a path should be calculated.
+     \param $incomingLanguageList Array of locale codes representing the prioritized site language list.
 
      \note If you know the action values of the path use fetchPathByActionList() instead, it is more optimized.
      \note The calculated path is cached in $Path.
      */
-    function getPath()
+    function getPath( $locale = null, $incomingLanguageList = null )
     {
         if ( $this->Path !== null )
             return $this->Path;
@@ -368,12 +355,32 @@ class eZURLAliasML extends eZPersistentObject
         while ( $id != 0 )
         {
             $query = "SELECT parent, lang_mask, text FROM ezurlalias_ml WHERE id={$id}";
+            if ( $locale !== null && is_string( $locale ) )
+            {
+                // We also want to consider the prioritized language list for the
+                // destination siteaccess, so that untranslated objects, are not
+                // disregarded from the URL.
+                if ( $incomingLanguageList !== null )
+                {
+                    eZContentLanguage::setPrioritizedLanguages( $incomingLanguageList );
+                }
+
+                $langMask = trim( eZContentLanguage::languagesSQLFilter( 'ezurlalias_ml', 'lang_mask' ) );
+                $query .= " AND ({$langMask})";
+            }
             $rows = $db->arrayQuery( $query );
+
             if ( count( $rows ) == 0 )
             {
                 break;
             }
             $result = eZURLAliasML::choosePrioritizedRow( $rows );
+
+            if ( $incomingLanguageList !== null )
+            {
+                eZContentLanguage::clearPrioritizedLanguages();
+            }
+
             if ( !$result )
             {
                 $result = $rows[0];
@@ -401,10 +408,11 @@ class eZURLAliasML extends eZPersistentObject
      \param $cleanupElements If true each element in the path will be cleaned up according to the current URL transformation rules.
      \param $autoAdjustName If true it will adjust the name until it is unique in the path. Used together with $linkID.
      \param $reportErrors If true it will report found errors using eZDebug, if \c false errors are only return in 'status'.
+     \param $aliasRedirects If true and an alias is being stored it will redirect (using HTTP 301) to it's destination.
      */
     static function storePath( $path, $action,
                         $languageName = false, $linkID = false, $alwaysAvailable = false, $rootID = false,
-                        $cleanupElements = true, $autoAdjustName = false, $reportErrors = true )
+                        $cleanupElements = true, $autoAdjustName = false, $reportErrors = true, $aliasRedirects = true )
     {
         $path = eZURLAliasML::cleanURL( $path );
         if ( $languageName === false )
@@ -427,7 +435,7 @@ class eZURLAliasML extends eZPersistentObject
             $languageMask |= 1;
 
         $path = eZURLAliasML::cleanURL( $path );
-        $elements = split( "/", $path );
+        $elements = explode( '/', $path );
 
         $db = eZDB::instance();
         $parentID = 0;
@@ -545,7 +553,7 @@ class eZURLAliasML extends eZPersistentObject
                     if ( $reportErrors )
                         eZDebug::writeError( "Tried to store path '{$path}' but the path already exists (ID: {$curID}) but with action '{$curAction}', the new action was '{$action}'" );
                     return array( 'status' => self::LINK_ALREADY_TAKEN,
-                                  'path'    => null,
+                                  'path'    => $path,
                                   'element' => null );
                 }
                 // Need to adjust name, re-iterate
@@ -557,7 +565,7 @@ class eZURLAliasML extends eZPersistentObject
             if ( $newElementID === null )
             {
                 $query = "SELECT * FROM ezurlalias_ml\n" .
-                         "WHERE parent = $parentID AND action = '{$actionStr}'";
+                         "WHERE parent = $parentID AND action = '{$actionStr}' AND is_original = 1 AND is_alias = 0";
                 $rows = $db->arrayQuery( $query );
                 if ( count( $rows ) > 0 )
                 {
@@ -568,6 +576,26 @@ class eZURLAliasML extends eZPersistentObject
             // Create or update the element
             if ( $curElementID !== null )
             {
+                // Check if an already existing entry at the same level exists, with a different id
+                // if so the id must be updated.
+                $query = "SELECT * FROM ezurlalias_ml\n" .
+                         "WHERE parent = $parentID AND action = '{$actionStr}' AND is_original = 1 AND is_alias = 0";
+                $rows = $db->arrayQuery( $query );
+                if ( count( $rows ) > 0 )
+                {
+                    $existingEntryId = (int)$rows[0]['id'];
+
+                    if ( $existingEntryId != $curElementID )
+                    {
+                        // move history entry to the same id
+                        $query = "UPDATE ezurlalias_ml SET id = {$existingEntryId} " .
+                                 "WHERE parent = $parentID AND text_md5 = {$textMD5}";
+                        $res = $db->query( $query );
+                        if ( !$res ) return eZURLAliasML::dbError( $db );
+                        $curElementID = $existingEntryId;
+                    }
+                }
+
                 $bitOr = $db->bitOr( $db->bitAnd( 'lang_mask', ~1 ), $languageMask );
                 // Note: The `text` field is updated too, this ensures case-changes are stored.
                 $query = "UPDATE ezurlalias_ml SET link = id, lang_mask = {$bitOr}, text = '{$textEsc}', action = '{$actionStr}', action_type = '{$actionTypeStr}', is_alias = 0, is_original = 1\n" .
@@ -590,35 +618,60 @@ class eZURLAliasML extends eZPersistentObject
             }
             $createdPath[] = $newText;
 
-            // Remove the language ID from other elements which have the same action
-            $bitDel = $db->bitAnd( 'lang_mask', ~$languageID );
-            $query = "UPDATE ezurlalias_ml SET lang_mask = {$bitDel}\n" .
-                     "WHERE action = '{$actionStr}' AND (parent != $parentID OR text_md5 != {$textMD5})";
-            $res = $db->query( $query );
-            if ( !$res ) return eZURLAliasML::dbError( $db );
+            // OMS-urlalias-fix: We want to retain the lang_mask of url entries, but mark others as history elements is_original = 0
+            // Furthermore this change is not performed on custom alias entries.
+            $bitAnd = $db->bitAnd( 'lang_mask', $languageID );
 
-            // Look for other nodes with the same action and no languages
-            // if found make then link to the new entry
-            $bitAnd = $db->bitAnd( 'lang_mask', ~1 );
+            // First we look at the entries to mark as history entries, if an entry comprise more languages, it must not be set as history element.
             $query = "SELECT * FROM ezurlalias_ml\n" .
-                     "WHERE action = '{$actionStr}' AND {$bitAnd} = 0 AND (parent != $parentID OR text_md5 != {$textMD5})";
+                     "WHERE action = '{$actionStr}' AND (${bitAnd} > 0) AND is_original = 1 AND is_alias = 0 AND (parent != $parentID OR text_md5 != {$textMD5})";
+            $toBeUpdated = $db->arrayQuery( $query );
+
+            // 0. Check if the entry to be updated represents multiple languages:
+            // IF YES:
+            //  1. "Downgrade" existing entry, by removing the active translation's language id from the language_mask.
+            // IF NO:
+            //  1. Mark entry as a history entry
+
+            if ( count( $toBeUpdated ) > 0 )
+            {
+                $languageMask = $toBeUpdated[0]['lang_mask'];
+                if ( ( $languageMask & ~( $languageID | 1 ) ) != 0 )
+                {
+                    // "Composite entry", downgrade current entry
+                    $currentEntry = new eZURLAliasML( $toBeUpdated[0] );
+                    $currentEntry->LangMask = (int)$currentEntry->LangMask & ~$languageID;
+                    $currentEntry->store();
+                }
+                else
+                {
+                    // Mark as history element.
+                    $query = "UPDATE ezurlalias_ml SET is_original = 0\n" .
+                             "WHERE action = '{$actionStr}' AND (${bitAnd} > 0) AND is_original = 1 AND is_alias = 0 AND (parent != $parentID OR text_md5 != {$textMD5})";
+                    $res = $db->query( $query );
+                    if ( !$res ) return eZURLAliasML::dbError( $db );
+                }
+            }
+
+            // OMS-urlalias-fix: instead entries without language we look at history elements with same action (and language)
+            // Look for other nodes with the same action and language
+            // if found make then link to the new entry
+            $bitAnd = $db->bitAnd( 'lang_mask', $languageID );
+            $query = "SELECT * FROM ezurlalias_ml\n" .
+                     "WHERE action = '{$actionStr}' AND (${bitAnd} > 0) AND is_original = 0 AND (parent != $parentID OR text_md5 != {$textMD5})";
             $rows = $db->arrayQuery( $query );
             foreach ( $rows as $row )
             {
                 $idtmp = (int)$row['id'];
                 if ( $idtmp == $newElementID )
                 {
-                    $db->lock( "ezurlalias_ml" );
-                    $query = "SELECT max( id ) + 1 AS id FROM ezurlalias_ml";
-                    $rowstmp = $db->arrayQuery( $query );
-                    $idtmp = (int)$rowstmp[0]['id'];
-                    if ( $idtmp == 0 )
-                        $idtmp = 1;
-                    $db->unlock();
+                    $idtmp = self::getNewID();
                 }
                 $parentIDTmp = (int)$row['parent'];
                 $textMD5Tmp = eZURLALiasML::md5( $db, $row['text'] );
-                $res = $db->query( "UPDATE ezurlalias_ml SET id = {$idtmp}, link = {$newElementID}, lang_mask = 1, is_alias = 0, is_original = 0\n" .
+
+                // OMS-urlalias-fix: We do not touch the lang_mask here
+                $res = $db->query( "UPDATE ezurlalias_ml SET id = {$idtmp}, link = {$newElementID}, is_alias = 0, is_original = 0\n" .
                                    "WHERE parent = {$parentIDTmp} AND text_md5 = {$textMD5Tmp}" );
                 if ( !$res ) return eZURLAliasML::dbError( $db );
             }
@@ -627,8 +680,11 @@ class eZURLAliasML extends eZPersistentObject
 
             // Look for other nodes which is a link for the current action
             // if found make then link to the new entry
+            // OMS-urlalias-fix: We only want to update the links of entries within the same language.
+            // Also, only to be applied on normal entries, not custom aliases
+            $bitAnd = $db->bitAnd( 'lang_mask', $languageID );
             $query = "UPDATE ezurlalias_ml SET link = {$newElementID}, is_alias = 0, is_original = 0\n" .
-                     "WHERE action = '{$actionStr}' AND is_original = 0 AND (parent != $parentID OR text_md5 != {$textMD5})";
+                     "WHERE action = '{$actionStr}' AND is_original = 0 AND is_alias = 0 AND (${bitAnd} > 0) AND (parent != $parentID OR text_md5 != {$textMD5})";
             $res = $db->query( $query );
             if ( !$res ) return eZURLAliasML::dbError( $db );
 
@@ -651,14 +707,17 @@ class eZURLAliasML extends eZPersistentObject
 
             // TODO: Handle all conflict cases, for now only the `Delete old, reparent` action is done
 
+            // OMS-urlalias-fix: We are only updating child nodes within the same language,
+            // and only for real system-generated url aliases. Custom aliases are left alone.
+            $bitAnd = $db->bitAnd( 'lang_mask', $languageID );
             $query = "SELECT id FROM ezurlalias_ml\n" .
-                     "WHERE action = '{$actionStr}' AND (parent != $parentID OR text_md5 != {$textMD5})";
+                     "WHERE action = '{$actionStr}' AND is_alias = 0 AND (parent != $parentID OR text_md5 != {$textMD5})";
             $rows = $db->arrayQuery( $query );
             foreach ( $rows as $row )
             {
                 $oldParentID = (int)$row['id'];
                 $query = "UPDATE ezurlalias_ml SET parent = {$newElementID}\n" .
-                         "WHERE parent = {$oldParentID}";
+                         "WHERE parent = {$oldParentID} AND (${bitAnd} > 0)";
                 $res = $db->query( $query );
                 if ( !$res ) return eZURLAliasML::dbError( $db );
             }
@@ -751,7 +810,7 @@ class eZURLAliasML extends eZPersistentObject
                     if ( $reportErrors )
                         eZDebug::writeError( "Tried to store path '{$path}' but the path already exists (ID: {$curID}) but with action '{$curAction}', the new action was '{$action}'" );
                     return array( 'status' => self::LINK_ALREADY_TAKEN,
-                                  'path'    => null,
+                                  'path'    => $path,
                                   'element' => null );
                 }
                 // Need to adjust name, re-iterate
@@ -782,6 +841,7 @@ class eZURLAliasML extends eZPersistentObject
                                                     'action' => $action,
                                                     'is_alias' => 1 ) );
             }
+            $element->AliasRedirects = $aliasRedirects ? 1 : 0;
             $element->store();
             $createdPath[]  = $topElement;
             $createdElement = $element;
@@ -860,15 +920,23 @@ class eZURLAliasML extends eZPersistentObject
         $db = eZDB::instance();
         $actionStr = $db->escapeString( $action );
         $langMask = '';
-        if ( $maskLanguages )
+        if ( is_bool( $maskLanguages ) && $maskLanguages )
         {
             $langMask = "(" . trim( eZContentLanguage::languagesSQLFilter( 'ezurlalias_ml', 'lang_mask' ) ) . ") AND ";
         }
+        else if ( is_string( $maskLanguages ) )
+        {
+            // maskByLocale can support array input, here we only want one item.
+            $mask = eZContentLanguage::maskByLocale( $maskLanguages );
+            $langFilter = $db->bitAnd( 'lang_mask', $mask );
+            $langMask = "({$langFilter} > 0) AND";
+        }
         $query = "SELECT * FROM ezurlalias_ml WHERE $langMask action = '$actionStr'";
         if ( !$includeRedirections )
         {
             $query .= " AND is_original = 1 AND is_alias = 0";
         }
+
         $rows = $db->arrayQuery( $query );
         if ( count( $rows ) == 0 )
             return array();
@@ -982,11 +1050,11 @@ class eZURLAliasML extends eZPersistentObject
      \note This function is faster than getPath() since it can fetch all elements in one SQL.
      \note If the fetched elements does not point to each other (parent/id) then null is returned.
      */
-    static public function fetchPathByActionList( $actionName, $actionValues )
+    static public function fetchPathByActionList( $actionName, $actionValues, $locale = null )
     {
-        if ( count( $actionValues ) == 0 )
+        if ( !is_array( $actionValues ) || count( $actionValues ) == 0 )
         {
-            eZDebug::writeError( "Action value array must not be empty" );
+            eZDebug::writeError( "Action values array must not be empty", __METHOD__ );
             return null;
         }
         $db = eZDB::instance();
@@ -1008,7 +1076,16 @@ class eZURLAliasML extends eZPersistentObject
             $actionMap[$action][] = $row;
         }
 
-        $prioritizedLanguages = eZContentLanguage::prioritizedLanguages();
+        if ( $locale !== null && is_string( $locale ) && !empty( $locale ) )
+        {
+            $selectedLanguage = eZContentLanguage::fetchByLocale( $locale );
+            $prioritizedLanguages = $selectedLanguage !== false ? array( $selectedLanguage ): eZContentLanguage::prioritizedLanguages();
+        }
+        else
+        {
+            $prioritizedLanguages = eZContentLanguage::prioritizedLanguages();
+        }
+
         $path = array();
         $lastID = false;
         foreach ( $actionValues as $actionValue )
@@ -1127,7 +1204,7 @@ class eZURLAliasML extends eZPersistentObject
         if ( $uriString == '' && $glob !== false )
             $elements = array();
         else
-            $elements = split( "/", $uriString );
+            $elements = explode( '/', $uriString );
         $len      = count( $elements );
         $i = 0;
         $selects = array();
@@ -1372,12 +1449,16 @@ class eZURLAliasML extends eZPersistentObject
         $originalURIString = $uriString;
 
         $ini = eZIni::instance();
-        if ( $ini->hasVariable( 'SiteAccessSettings', 'PathPrefix' ) &&
-             $ini->variable( 'SiteAccessSettings', 'PathPrefix' ) != '' )
+
+        $prefixAdded = false;
+        $prefix = $ini->hasVariable( 'SiteAccessSettings', 'PathPrefix' ) &&
+                      $ini->variable( 'SiteAccessSettings', 'PathPrefix' ) != '' ? eZURLAliasML::cleanURL( $ini->variable( 'SiteAccessSettings', 'PathPrefix' ) ) : false;
+
+        if ( $prefix )
         {
-            $prefix = $ini->variable( 'SiteAccessSettings', 'PathPrefix' );
+            $escapedPrefix = preg_quote( $prefix, '#' );
             // Only prepend the path prefix if it's not already the first element of the url.
-            if ( !preg_match( "#^$prefix(/.*)?$#", $uriString )  )
+            if ( !preg_match( "#^$escapedPrefix(/.*)?$#i", $uriString )  )
             {
                 $exclude = $ini->hasVariable( 'SiteAccessSettings', 'PathPrefixExclude' )
                            ? $ini->variable( 'SiteAccessSettings', 'PathPrefixExclude' )
@@ -1385,7 +1466,8 @@ class eZURLAliasML extends eZPersistentObject
                 $breakInternalURI = false;
                 foreach ( $exclude as $item )
                 {
-                    if ( preg_match( "#^$item(/.*)?$#", $uriString )  )
+                    $escapedItem = preg_quote( $item, '#' );
+                    if ( preg_match( "#^$escapedItem(/.*)?$#i", $uriString )  )
                     {
                         $breakInternalURI = true;
                         break;
@@ -1393,12 +1475,15 @@ class eZURLAliasML extends eZPersistentObject
                 }
 
                 if ( !$breakInternalURI )
-                    $internalURIString = eZURLAliasML::cleanURL( eZURLAliasML::cleanURL( $prefix ) . '/' . $uriString );
+                {
+                    $internalURIString = $prefix . '/' . $uriString;
+                    $prefixAdded = true;
+                }
             }
         }
 
         $db = eZDB::instance();
-        $elements = split( "/", $internalURIString );
+        $elements = explode( '/', $internalURIString );
         $len      = count( $elements );
         if ( $reverse )
         {
@@ -1412,14 +1497,19 @@ class eZURLAliasML extends eZPersistentObject
         foreach ( $elements as $element )
         {
             $table = "e" . $i;
+
+            $selectString = "{$table}.id AS {$table}_id, ";
+            $selectString .= "{$table}.link AS {$table}_link, ";
+            $selectString .= "{$table}.text AS {$table}_text, ";
+            $selectString .= "{$table}.text_md5 AS {$table}_text_md5, ";
+            $selectString .= "{$table}.is_alias AS {$table}_is_alias, ";
+
             if ( $i == $len - 1 )
-            {
-                $selects[] = "{$table}.id AS {$table}_id, {$table}.link AS {$table}_link, {$table}.text AS {$table}_text, {$table}.text_md5 AS {$table}_text_md5, {$table}.action AS {$table}_action, {$table}.is_alias AS {$table}_is_alias";
-            }
-            else
-            {
-                $selects[] = "{$table}.id AS {$table}_id, {$table}.link AS {$table}_link, {$table}.text AS {$table}_text, {$table}.text_md5 AS {$table}_text_md5, {$table}.is_alias AS {$table}_is_alias";
-            }
+                $selectString .= "{$table}.action AS {$table}_action, ";
+
+            $selectString .= "{$table}.alias_redirects AS {$table}_alias_redirects";
+            $selects[] = $selectString;
+
             $tables[]  = "ezurlalias_ml " . $table;
             $langMask = trim( eZContentLanguage::languagesSQLFilter( $table, 'lang_mask' ) );
             if ( $i == 0 )
@@ -1433,8 +1523,8 @@ class eZURLAliasML extends eZPersistentObject
             $prevTable = $table;
             ++$i;
         }
-        $query = "SELECT " . join( ", ", $selects ) . "\nFROM " . join( ", ", $tables ) . "\nWHERE " . join( "\nAND ", $conds );
 
+        $query = "SELECT " . join( ", ", $selects ) . "\nFROM " . join( ", ", $tables ) . "\nWHERE " . join( "\nAND ", $conds );
         $return = false;
         $urlAliasArray = $db->arrayQuery( $query, array( 'limit' => 1 ) );
         if ( count( $urlAliasArray ) > 0 )
@@ -1447,6 +1537,7 @@ class eZURLAliasML extends eZPersistentObject
             $action = false;
             $verifiedPath = array();
             $doRedirect = false;
+
             for ( $i = 0; $i < $len; ++$i )
             {
                 $table = "e" . $i;
@@ -1454,6 +1545,7 @@ class eZURLAliasML extends eZPersistentObject
                 $link = $pathRow[$table . "_link"];
                 $text = $pathRow[$table . "_text"];
                 $isAlias = $pathRow[$table . '_is_alias'];
+                $aliasRedirects = $pathRow[$table . '_alias_redirects'];
                 $verifiedPath[] = $text;
                 if ( $i == $len - 1 )
                 {
@@ -1465,16 +1557,35 @@ class eZURLAliasML extends eZPersistentObject
                 }
                 else if ( $isAlias && $action !== false )
                 {
-                    // If the entry is an alias and we have an action we redirect to the original
-                    // url of that action.
-                    $redirectAction = $action;
-                    $doRedirect = true;
+                    if ( $aliasRedirects )
+                    {
+                        // If the entry is an alias and we have an action we redirect to the original
+                        // url of that action.
+                        $redirectAction = $action;
+                        $doRedirect = true;
+                    }
                 }
                 $lastID = $link;
             }
-            if ( strcmp( join( "/", $verifiedPath ), $internalURIString ) != 0 ) // Check for case difference
-                $doRedirect = true;
-            if ( preg_match( "#^module:(.+)$#", $action, $matches ) )
+
+            if ( !$doRedirect )
+            {
+                $verifiedPathString = implode( '/', $verifiedPath );
+                // Check for case difference
+                if ( $prefixAdded )
+                {
+                    if ( strcmp( $originalURIString, substr( $verifiedPathString, strlen( $prefix ) + 1 ) ) != 0 )
+                    {
+                        $doRedirect = true;
+                    }
+                }
+                else if ( strcmp( $verifiedPathString, $internalURIString ) != 0 )
+                {
+                    $doRedirect = true;
+                }
+            }
+
+            if ( preg_match( "#^module:(.+)$#", $action, $matches ) and $doRedirect )
             {
                 $uriString = 'error/301';
                 $return = $matches[1];
@@ -1506,6 +1617,7 @@ class eZURLAliasML extends eZPersistentObject
                     $pathData = array();
                     // Figure out the correct path by iterating down the parents until we have all
                     // elements figured out.
+
                     while ( $id != 0 )
                     {
                         $query = "SELECT parent, lang_mask, text FROM ezurlalias_ml WHERE id={$id}";
@@ -1525,6 +1637,15 @@ class eZURLAliasML extends eZPersistentObject
                     $uriString = 'error/301';
                     $return = join( "/", $pathData );
                 }
+
+                // Remove prefix of redirect uri if needed
+                if ( $prefix && is_string( $return ) )
+                {
+                    if ( strncasecmp( $return, $prefix . '/', strlen( $prefix ) + 1 ) == 0 )
+                    {
+                        $return = substr( $return, strlen( $prefix ) + 1 );
+                    }
+                }
             }
             else
             {
@@ -1613,6 +1734,33 @@ class eZURLAliasML extends eZPersistentObject
         return false;
     }
 
+    /*!
+     \static
+     Checks if url translation should be used on the current url.
+
+     \param $uri The current eZUri object
+     */
+    static public function urlTranslationEnabledByUri( eZURI $uri )
+    {
+        if ( $uri->isEmpty() )
+            return false;
+
+        $ini = eZINI::instance();
+        if ( $ini->variable( 'URLTranslator', 'Translation' ) === 'enabled' )
+        {
+            if ( $ini->variable( 'URLTranslator', 'TranslatableSystemUrls' ) === 'disabled' )
+            {
+                $moduleName = $uri->element( 0 );
+                $moduleINI  = eZINI::instance( 'module.ini' );
+                $moduleList = $moduleINI->variable( 'ModuleSettings', 'ModuleList' );
+                if ( in_array( $moduleName, $moduleList, true ) )
+                  return false;
+            }
+            return true;
+        }
+        return false;
+    }
+
     /*!
      \static
      Checks if the text entry $text is unique on the current level in the URL path.
@@ -1684,6 +1832,11 @@ class eZURLAliasML extends eZPersistentObject
      */
     static public function setLangMaskAlwaysAvailable( $langID, $actionName, $actionValue )
     {
+        if ( !$actionName )
+        {
+            eZDebug::writeError( "ActionName value must not be empty", __METHOD__ );
+            return null;
+        }
         $db = eZDB::instance();
         if ( is_array( $actionName ) )
         {
@@ -1710,7 +1863,7 @@ class eZURLAliasML extends eZPersistentObject
             $db->query( $query );
 
             // Clear the 0 bit for all other languages
-            $bitOp = $db->bitOr( 'lang_mask', -2 );
+            $bitOp = $db->bitAnd( 'lang_mask', ~1 );
             $langWhere = ' AND ' . $db->bitAnd( 'lang_mask' , (int)$langID ) . ' = 0';
 
             $query = "UPDATE ezurlalias_ml SET lang_mask = $bitOp WHERE $actionSql $langWhere";
@@ -1718,7 +1871,7 @@ class eZURLAliasML extends eZPersistentObject
         }
         else
         {
-            $bitOp = $db->bitAnd( 'lang_mask', -2 );
+            $bitOp = $db->bitAnd( 'lang_mask', ~1 );
             $query = "UPDATE ezurlalias_ml SET lang_mask = $bitOp WHERE $actionSql";
             $db->query( $query );
         }
@@ -2008,7 +2161,6 @@ class eZURLAliasML extends eZPersistentObject
     */
     static public function convertToAlias( $urlElement, $defaultValue = false )
     {
-        //include_once( 'lib/ezi18n/classes/ezchartransform.php' );
         $trans = eZCharTransform::instance();
 
         $ini = eZINI::instance();
@@ -2049,7 +2201,6 @@ class eZURLAliasML extends eZPersistentObject
     */
     static public function convertToAliasCompat( $urlElement, $defaultValue = false )
     {
-        //include_once( 'lib/ezi18n/classes/ezchartransform.php' );
         $trans = eZCharTransform::instance();
 
         $urlElement = $trans->transformByGroup( $urlElement, "urlalias_compat" );
@@ -2122,6 +2273,21 @@ class eZURLAliasML extends eZPersistentObject
         return $db->md5( "'" . $text . "'" );
     }
 
+    static function getNewID()
+    {
+        $db = eZDB::instance();
+        if ( $db->supportsDefaultValuesInsertion() )
+        {
+            $db->query( 'INSERT INTO ezurlalias_ml_incr DEFAULT VALUES' );
+        }
+        else
+        {
+            // can not use VALUES(DEFAULT), because of http://bugs.mysql.com/bug.php?id=42270
+            $db->query( 'INSERT INTO ezurlalias_ml_incr(id) VALUES(NULL)' );
+        }
+
+        return $db->lastSerialID( 'ezurlalias_ml_incr', 'id' );
+    }
 }
 
 ?>
