@@ -5,9 +5,9 @@
 // Created on: <16-Apr-2002 11:08:14 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -32,11 +32,6 @@
 
 */
 
-//include_once( "lib/ezdb/classes/ezdb.php" );
-//include_once( "kernel/classes/ezpersistentobject.php" );
-//include_once( "kernel/classes/ezworkflowevent.php" );
-//include_once( 'kernel/classes/ezworkflowgrouplink.php' );
-
 class eZWorkflow extends eZPersistentObject
 {
     const STATUS_NONE = 0;
@@ -72,11 +67,13 @@ class eZWorkflow extends eZPersistentObject
                                          "workflow_type_string" => array( 'name' => "WorkflowTypeString",
                                                                           'datatype' => 'string',
                                                                           'default' => '',
-                                                                          'required' => true ),
+                                                                          'required' => true,
+                                                                          'max_length' => 50 ),
                                          "name" => array( 'name' => "Name",
                                                           'datatype' => 'string',
                                                           'default' => '',
-                                                          'required' => true ),
+                                                          'required' => true,
+                                                          'max_length' => 255 ),
                                          "creator_id" => array( 'name' => "CreatorID",
                                                                 'datatype' => 'integer',
                                                                 'default' => 0,
@@ -138,10 +135,8 @@ class eZWorkflow extends eZPersistentObject
         return new eZWorkflow( $row );
     }
 
-    function setIsEnabled( $enabled, $id = false, $version = 0 )
+    static function setIsEnabled( $enabled, $id, $version = 0 )
     {
-        if ( $id === false )
-            $id = $this->attribute( "id" );
         eZPersistentObject::updateObjectList( array(
                                                   "definition" => eZWorkflow::definition(),
                                                   "update_fields" => array( "is_enabled" => ( $enabled ? 1 : 0 ) ),
@@ -155,11 +150,11 @@ class eZWorkflow extends eZPersistentObject
      \note Transaction unsafe. If you call several transaction unsafe methods you must enclose
      the calls within a db transaction; thus within db->begin and db->commit.
      */
-    function removeWorkflow( $id, $version )
+    static function removeWorkflow( $id, $version )
     {
         eZPersistentObject::removeObject( eZWorkflow::definition(),
-                                          array("id" => $id,
-                                                "version" => $version ) );
+                                          array( "id" => $id,
+                                                 "version" => $version ) );
     }
 
     /*!
@@ -194,7 +189,7 @@ class eZWorkflow extends eZPersistentObject
      \note Transaction unsafe. If you call several transaction unsafe methods you must enclose
      the calls within a db transaction; thus within db->begin and db->commit.
     */
-    function removeTemporary()
+    static function removeTemporary()
     {
         $version = 1;
         $temporaryWorkflows = eZWorkflow::fetchList( $version, null, true );
@@ -242,7 +237,7 @@ class eZWorkflow extends eZPersistentObject
         }
     }
 
-    function adjustEventPlacements( $events )
+    static function adjustEventPlacements( $events )
     {
         if ( !is_array( $events ) )
             return;
@@ -339,9 +334,9 @@ class eZWorkflow extends eZPersistentObject
       \static
       Fetch workflows based on module, function and connection type
 
-      \param module name
-      \param function name
-      \param connect type
+      \param $moduleName module name
+      \param $functionName function name
+      \param $connectType connection type
 
       \returns array of allowed workflows limited by trigger
     */
@@ -366,9 +361,9 @@ class eZWorkflow extends eZPersistentObject
     /*!
       Check if a trigger specified trigger is allowed to use with this workflow
 
-      \param module name
-      \param function name
-      \param connect type
+      \param $moduleName module name
+      \param $functionName function name
+      \param $connectType connection type
 
       \return true if allowed, false if not.
     */
@@ -432,22 +427,28 @@ class eZWorkflow extends eZPersistentObject
         return null;
     }
 
-    function fetchEvents( $id = false, $asObject = true, $version = 0 )
+    function fetchEvents( $asObject = true, $version = false )
     {
-        if ( $id === false )
+        if ( $version === false )
         {
-            $id = $this->ID;
             $version = $this->Version;
         }
-        return eZWorkflowEvent::fetchFilteredList( array( "workflow_id" => $id,
-                                                          "version" => $version ) );
+        return eZWorkflowEvent::fetchFilteredList( array( "workflow_id" => $this->ID,
+                                                          "version" => $version ),
+                                                   $asObject );
     }
 
-    function fetchEventCount( $id = false, $version = 0 )
+    static function fetchEventsByWorkflowID( $id, $asObject = true, $version = 0 )
     {
-        if ( $id === false )
+        return eZWorkflowEvent::fetchFilteredList( array( "workflow_id" => $id,
+                                                          "version" => $version ),
+                                                   $asObject );
+    }
+
+    function fetchEventCount( $version = false )
+    {
+        if ( $version === false )
         {
-            $id = $this->ID;
             $version = $this->Version;
         }
         $list = eZPersistentObject::fetchObjectList( eZWorkflowEvent::definition(),
@@ -463,11 +464,25 @@ class eZWorkflow extends eZPersistentObject
         return $list[0]["count"];
     }
 
+    static function fetchEventCountByWorkflowID( $id, $version = 0 )
+    {
+        $list = eZPersistentObject::fetchObjectList( eZWorkflowEvent::definition(),
+                                                     array(),
+                                                     array( 'version' => $version,
+                                                            'workflow_id' => $id ),
+                                                     false,
+                                                     null,
+                                                     false,
+                                                     false,
+                                                     array( array( 'operation' => 'count( id )',
+                                                                   'name' => 'count' ) ) );
+        return $list[0]["count"];
+    }
+
     function creator()
     {
         if ( isset( $this->CreatorID ) and $this->CreatorID )
         {
-            //include_once( "kernel/classes/datatypes/ezuser/ezuser.php" );
             return eZUser::fetch( $this->CreatorID );
         }
 
@@ -478,7 +493,6 @@ class eZWorkflow extends eZPersistentObject
     {
         if ( isset( $this->ModifierID ) and $this->ModifierID )
         {
-            //include_once( "kernel/classes/datatypes/ezuser/ezuser.php" );
             return eZUser::fetch( $this->ModifierID );
         }
 
@@ -515,7 +529,6 @@ class eZWorkflow extends eZPersistentObject
 
     function workflowType()
     {
-        //include_once( "kernel/classes/ezworkflowtype.php" );
         return eZWorkflowType::createType( $this->WorkflowTypeString );
     }
 
@@ -525,29 +538,25 @@ class eZWorkflow extends eZPersistentObject
      */
     function cleanupWorkFlowProcess()
     {
-        if ( isset( $this ) )
+        $db = eZDB::instance();
+        $workflowID = $this->attribute( 'id' );
+        $event_list = $this->fetchEvents();
+        if ( $event_list != null )
         {
-            $db = eZDB::instance();
-            $workflowID = $this->attribute( 'id' );
-            $event_list = $this->fetchEvents();
-            if ( $event_list != null )
+            $existEventIDArray = array();
+            foreach ( $event_list as $event )
             {
-                $existEventIDArray = array();
-                foreach ( $event_list as $event )
-                {
-                    $eventID = $event->attribute( 'id' );
-                    $existEventIDArray[] = $eventID;
-                }
-                $existEventIDString = implode( ',', $existEventIDArray );
-                $db->query( "DELETE FROM ezworkflow_process
-                                   WHERE workflow_id=$workflowID
-                                     AND event_id not in ( $existEventIDString )" );
-            }
-            else
-            {
-                $db->query( "DELETE FROM ezworkflow_process
-                                   WHERE workflow_id=$workflowID");
+                $eventID = $event->attribute( 'id' );
+                $existEventIDArray[] = $eventID;
             }
+            $existEventIDString = implode( ',', $existEventIDArray );
+            $db->query( "DELETE FROM ezworkflow_process
+                               WHERE workflow_id=$workflowID
+                                 AND event_id not in ( $existEventIDString )" );
+        }
+        else
+        {
+            $db->query( "DELETE FROM ezworkflow_process WHERE workflow_id=$workflowID" );
         }
     }
 
