@@ -5,9 +5,9 @@
 // Created on: <16-Apr-2002 11:08:14 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -32,10 +32,6 @@
 
 */
 
-//include_once( 'lib/ezdb/classes/ezdb.php' );
-//include_once( 'kernel/classes/ezpersistentobject.php' );
-//include_once( 'kernel/classes/ezworkflowevent.php' );
-
 class eZWorkflowProcess extends eZPersistentObject
 {
     function eZWorkflowProcess( $row )
@@ -250,7 +246,7 @@ class eZWorkflowProcess extends eZPersistentObject
                     else if ( time() < $activationDate )
                     {
                         eZDebugSetting::writeDebug( 'workflow-process', "Date failed, not running events" );
-                        $eventType =& $workflowEvent->eventType();
+                        $eventType = $workflowEvent->eventType();
                         $eventLog[] = array( "status" => $currentEventStatus,
                                              "status_text" => eZWorkflowType::statusName( $currentEventStatus ),
                                              "information" => $eventType->attribute( "information" ),
@@ -455,10 +451,12 @@ class eZWorkflowProcess extends eZPersistentObject
                                                 $asObject );
     }
 
-    static function fetchList( $conds = null, $asObject = true )
+    static function fetchList( $conds = null, $asObject = true, $offset = false, $limit = false )
     {
+        $limitation = array( 'offset' => $offset,
+                             'length' => $limit );
         return eZPersistentObject::fetchObjectList( eZWorkflowProcess::definition(),
-                                                    null, $conds, null, null,
+                                                    null, $conds, null, $limitation,
                                                     $asObject );
     }
 
@@ -470,13 +468,21 @@ class eZWorkflowProcess extends eZPersistentObject
             foreach ( $keys as $key )
             {
                 $value = $parameters[$key];
+                if ( is_array( $value ) )
+                {
+                    $value = serialize( $value );
+                }
                 $string .= $key . $value;
             }
         }else
         {
             foreach ( array_keys( $parameters ) as $key )
             {
-                $value =& $parameters[$key];
+                $value = $parameters[$key];
+                if ( is_array( $value ) )
+                {
+                    $value = serialize( $value );
+                }
                 $string .= $key . $value;
             }
         }
@@ -562,7 +568,6 @@ class eZWorkflowProcess extends eZPersistentObject
     {
         if ( isset( $this->UserID ) and $this->UserID )
         {
-            //include_once( 'kernel/classes/datatypes/ezuser/ezuser.php' );
             return eZUser::instance( $this->UserID );
         }
         return null;
@@ -572,7 +577,6 @@ class eZWorkflowProcess extends eZPersistentObject
     {
         if ( isset( $this->ContentID ) and $this->ContentID )
         {
-            //include_once( 'kernel/classes/ezcontentobject.php' );
             return eZContentObject::fetch( $this->ContentID );
         }
         return null;
@@ -582,7 +586,6 @@ class eZWorkflowProcess extends eZPersistentObject
     {
         if ( isset( $this->NodeID ) and $this->NodeID )
         {
-            //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
             return eZContentObjectTreeNode::fetch( $this->NodeID );
         }
         return null;
@@ -592,7 +595,6 @@ class eZWorkflowProcess extends eZPersistentObject
     {
         if ( isset( $this->WorkflowID ) and $this->WorkflowID )
         {
-            //include_once( 'kernel/classes/ezworkflow.php' );
             return eZWorkflow::fetch( $this->WorkflowID );
         }
         return null;
@@ -602,7 +604,6 @@ class eZWorkflowProcess extends eZPersistentObject
     {
         if ( isset( $this->EventID ) and $this->EventID )
         {
-            //include_once( 'kernel/classes/ezworkflowevent.php' );
             return eZWorkflowEvent::fetch( $this->EventID );
         }
         return null;
@@ -612,7 +613,6 @@ class eZWorkflowProcess extends eZPersistentObject
     {
         if ( isset( $this->LastEventID ) and $this->LastEventID )
         {
-            //include_once( 'kernel/classes/ezworkflowevent.php' );
             return eZWorkflowEvent::fetch( $this->LastEventID );
         }
         return null;
@@ -643,6 +643,8 @@ class eZWorkflowProcess extends eZPersistentObject
             $cleanupList = $workflowParameters['cleanup_list'];
             foreach ( $cleanupList as $workflowEventID )
             {
+                $workflowEvent = eZWorkflowEvent::fetch( $workflowEventID );
+                $workflowType = $workflowEvent->eventType();
                 $workflowType->cleanup( $this, eZWorkflowEvent::fetch( $workflowEventID ) );
             }
         }
