@@ -5,9 +5,9 @@
 // Created on: <14-May-2003 16:20:24 sp>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezsubtreenotificationrule.php
+/*! \file
 */
 
 /*!
@@ -34,8 +34,6 @@
   \brief The class eZSubtreeNotificationRule does
 
 */
-//include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
-
 class eZSubtreeNotificationRule extends eZPersistentObject
 {
     /*!
@@ -151,21 +149,91 @@ class eZSubtreeNotificationRule extends eZPersistentObject
         $db = eZDB::instance();
         $concatString = $db->concatString(  array( 'user_tree.path_string', "'%'" ) );
 
-        $sql = 'SELECT DISTINCT policy.id AS policy_id, subtree_rule.user_id,
+        // Select affected users
+        $sql = 'SELECT DISTINCT subtree_rule.user_id,
+                                user_node.node_id
+                FROM ezsubtree_notification_rule subtree_rule,
+                     ezcontentobject_tree user_node
+                WHERE subtree_rule.node_id IN ( ' . $db->implodeWithTypeCast( ', ', $nodeIDList, 'int' ) . ' ) AND
+                      user_node.contentobject_id = subtree_rule.user_id';
+        $userPart = $db->arrayQuery( $sql );
+
+        // Remove duplicates
+        $userNodeIDList = array();
+        foreach ( $userPart as $row )
+            $userNodeIDList[] = $row['node_id'];
+        $userNodeIDList = array_unique( $userNodeIDList );
+
+        if ( count( $userNodeIDList ) == 0 )
+        {
+            $retValue = array();
+            return $retValue;
+        }
+
+        // Select affected nodes
+        $sql = 'SELECT DISTINCT user_node.node_id,
+                                user_node.path_string,
+                                user_tree.contentobject_id
+                FROM ezcontentobject_tree user_node,
+                     ezcontentobject_tree user_tree
+                WHERE user_node.node_id IN ( ' . $db->implodeWithTypeCast( ', ', $userNodeIDList, 'int' ) . ' ) AND
+                      user_node.path_string like ' . $concatString;
+        $nodePart = $db->arrayQuery( $sql );
+
+        // Remove duplicates
+        $objectIDList = array();
+        foreach ( $nodePart as $row )
+            if ( $row['contentobject_id'] != '0' )
+                $objectIDList[] = $row['contentobject_id'];
+        $objectIDList = array_unique( $objectIDList );
+
+        if ( count( $objectIDList ) == 0 )
+        {
+            $retValue = array();
+            return $retValue;
+        }
+
+        // Select affected roles and policies
+        $sql = 'SELECT DISTINCT user_role.contentobject_id,
+                                policy.id AS policy_id,
                                 user_role.limit_identifier AS limitation,
                                 user_role.limit_value AS value
-                  FROM ezuser_role user_role,
-                       ezsubtree_notification_rule subtree_rule,
-                       ezcontentobject_tree user_tree,
-                       ezcontentobject_tree user_node,
-                       ezpolicy policy
-                  WHERE subtree_rule.node_id IN ( ' . $db->implodeWithTypeCast( ', ', $nodeIDList, 'int' ) . ' ) AND
-                        user_node.contentobject_id=subtree_rule.user_id AND
-                        user_node.path_string like ' . $concatString . " AND
-                        user_role.contentobject_id=user_tree.contentobject_id AND
-                        ( user_role.role_id=policy.role_id AND ( policy.module_name='*' OR ( policy.module_name='content' AND ( policy.function_name='*' OR policy.function_name='read' ) ) ) )";
+                FROM ezuser_role user_role,
+                     ezpolicy policy
+                WHERE user_role.contentobject_id IN ( ' . $db->implodeWithTypeCast( ', ', $objectIDList, 'int' ) . " ) AND
+                      ( user_role.role_id=policy.role_id AND
+                        ( policy.module_name='*' OR
+                          ( policy.module_name='content' AND
+                            ( policy.function_name='*' OR
+                              policy.function_name='read'
+                            )
+                          )
+                        )
+                      )";
+        $rolePart = $db->arrayQuery( $sql );
 
-        $resultArray = $db->arrayQuery( $sql );
+        // Build resultArray. Make sure there are no duplicates.
+        $resultArray = array();
+        foreach ( $userPart as $up )
+        {
+            foreach ( $nodePart as $np )
+            {
+                if ( $up['node_id'] == $np['node_id'] )
+                {
+                    foreach ( $rolePart as $rp )
+                    {
+                        if ( $np['contentobject_id'] == $rp['contentobject_id'] )
+                        {
+                            $key = $rp['policy_id'] . $up['user_id'] . $rp['limitation'] . $rp['value'];
+                            $resultArray[$key] = array( 'policy_id' => $rp['policy_id'],
+                                                        'user_id' => $up['user_id'],
+                                                        'limitation' => $rp['limitation'],
+                                                        'value' => $rp['value'] );
+                        }
+                    }
+                }
+            }
+        }
 
         $policyIDArray = array();
         $limitedPolicyIDArray = array();
@@ -190,7 +258,6 @@ class eZSubtreeNotificationRule extends eZPersistentObject
             }
         }
 
-        //include_once( 'kernel/classes/ezpolicy.php' );
         $acceptedUserArray = array();
         foreach( array_keys( $policyIDArray ) as $policyID )
         {
@@ -208,7 +275,7 @@ class eZSubtreeNotificationRule extends eZPersistentObject
             }
 
             $userArray = eZSubtreeNotificationRule::checkObjectAccess( $contentObject, $policyID, $policyIDArray[$policyID] );
-            $acceptedUserArray = array_unique( array_merge( $acceptedUserArray, $userArray ) );
+            $acceptedUserArray = array_merge( $acceptedUserArray, $userArray );
 
             foreach ( $userArray as $userID )
             {
@@ -228,16 +295,17 @@ class eZSubtreeNotificationRule extends eZPersistentObject
                                                                        array( $policyEntry['user_id'] ),
                                                                        array( $policyEntry['limitation'] => $policyEntry['value'] ) );
 
-            $acceptedUserArray = array_unique( array_merge( $acceptedUserArray, $userArray ) );
+            $acceptedUserArray = array_merge( $acceptedUserArray, $userArray );
             foreach ( $userArray as $userID )
             {
                 $userIDArray[(string)$userID] = false;
             }
         }
+        $acceptedUserArray = array_unique( $acceptedUserArray );
 
         foreach( array_keys( $acceptedUserArray ) as $key )
         {
-            if ( !is_int( $acceptedUserArray[$key] ) || $acceptedUserArray[$key] == 0 )
+            if ( !is_int( $acceptedUserArray[$key] ) or $acceptedUserArray[$key] == 0 )
             {
                 unset( $acceptedUserArray[$key] );
             }
