@@ -5,9 +5,9 @@
 // Created on: <15-Aug-2003 15:15:15 bh>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -33,13 +33,6 @@
 
 */
 
-//include_once( 'lib/ezwebdav/classes/ezwebdavserver.php' );
-//include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
-//include_once( "kernel/classes/datatypes/ezbinaryfile/ezbinaryfile.php" );
-//include_once( "lib/ezutils/classes/ezmimetype.php" );
-//include_once( 'lib/ezfile/classes/ezdir.php' );
-//include_once( "kernel/classes/ezurlaliasml.php" );
-//include_once( 'kernel/classes/datatypes/ezuser/ezuser.php' );
 require_once( 'access.php' );
 
 class eZWebDAVContentServer extends eZWebDAVServer
@@ -61,7 +54,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
     }
 
     /*!
-     \reimp
      Makes sure $this->User is reinitialized with the current user,
      then calls the $super->processClientRequest().
     */
@@ -76,7 +68,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
     */
 
     /*!
-      \reimp
       Fetch the file from eZCluster if needed before send.
     */
     function outputSendDataToClient( $output, $headers_only = false )
@@ -84,7 +75,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
         if ( $output["file"] )
         {
             $realPath = $output["file"];
-            require_once( 'kernel/classes/ezclusterfilehandler.php' );
             $file = eZClusterFileHandler::instance( $realPath );
             $file->fetch();
         }
@@ -95,7 +85,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
     }
 
     /*!
-      \reimp
       Restricts the allowed methods to only the subset that this server supports.
     */
     function options( $target )
@@ -109,7 +98,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
     }
 
     /*!
-      \reimp
       Produces the collection content. Builds either the virtual start folder
       with the virtual content folder in it (and additional files). OR: if
       we're browsing within the content folder: it gets the content of the
@@ -202,7 +190,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
     }
 
     /*!
-     \reimp
      Tries to figure out the filepath of the object being shown,
      if not we will pass the virtual url as the filepath.
     */
@@ -308,7 +295,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
 
         $object = $node->attribute( 'object' );
 
-        //include_once( 'kernel/classes/ezcontentupload.php' );
         $upload = new eZContentUpload();
         $info = $upload->objectFileInfo( $object );
         if ( $info )
@@ -328,7 +314,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
     }
 
     /*!
-     \reimp
      Tries to create/update an object at location \a $target with the file \a $tempFile.
     */
     function put( $target, $tempFile )
@@ -427,8 +412,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
         $defaultObjectType = $webdavINI->variable( 'PutSettings', 'DefaultClass' );
 
         $existingNode = $this->fetchNodeByTranslation( $nodePath );
-        //include_once( 'kernel/classes/ezcontentupload.php' );
-
         $upload = new eZContentUpload();
         if ( !$upload->handleLocalFile( $result, $tempFile, $parentNodeID, $existingNode ) )
         {
@@ -452,7 +435,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
     }
 
     /*!
-      \reimp
       Tries to create a collection at \a $target. In our case this is a content-class
       of a given type (most likely a folder).
     */
@@ -549,7 +531,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
     }
 
     /*!
-      \reimp
       Removes the object from the node tree and leaves it in the trash.
     */
     function delete( $target )
@@ -643,7 +624,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
     }
 
     /*!
-      \reimp
       Moves the object \a $source to destination \a $destination.
     */
     function move( $source, $destination )
@@ -815,7 +795,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
         }
         else
         {
-            //include_once( 'kernel/classes/ezcontentobjecttreenodeoperations.php' );
             if( !eZContentObjectTreeNodeOperations::move( $sourceNode->attribute( 'node_id' ), $destinationNode->attribute( 'node_id' ) ) )
             {
                 $this->appendLogEntry( "Unable to move the node '$sourceSite':'$nodePath' to '$destinationSite':'$destinationNodePath'", 'CS:moveContent' );
@@ -870,8 +849,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
 
         if ( $accessWord == 'limited' )
         {
-            //include_once( 'lib/ezutils/classes/ezsys.php' );
-
             $hasAccess = false;
             $policyChecked = false;
             foreach ( array_keys( $result['policies'] ) as $key )
@@ -950,7 +927,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
     }
 
     /*!
-      \reimp
       Removes the www-dir and indexfile from the URL.
     */
     function processURL( $url )
@@ -973,9 +949,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
         return $url;
     }
 
-    /*!
-     \reimp
-    */
     function headers()
     {
         header( "WebDAV-Powered-By: eZ Publish" );
@@ -1251,18 +1224,18 @@ class eZWebDAVContentServer extends eZWebDAVServer
     */
     function fetchVirtualSiteContent( $site, $depth, $properties )
     {
-        $this->appendLogEntry( "Script URL.." . $_SERVER["SCRIPT_URL"], 'CS:fetchVirtualSiteContent' );
+        $this->appendLogEntry( "Script URL.." . eZSys::instance()->RequestURI, 'CS:fetchVirtualSiteContent' );
         // Location of the info file.
         $infoFile = $_SERVER['DOCUMENT_ROOT'] . '/' . eZWebDAVContentServer::virtualInfoFileName();
 
         // Always add the current collection
         $contentEntry = array();
-        $contentEntry["name"]     = $_SERVER["SCRIPT_URL"];
+        $contentEntry["name"]     = eZSys::instance()->RequestURI;
         $contentEntry["size"]     = 0;
         $contentEntry["mimetype"] = 'httpd/unix-directory';
         $contentEntry["ctime"]    = filectime( 'settings/siteaccess/' . $site );
         $contentEntry["mtime"]    = filemtime( 'settings/siteaccess/' . $site );
-        $contentEntry["href"]     = $_SERVER["SCRIPT_URL"];
+        $contentEntry["href"]     = eZSys::instance()->RequestURI;
         $entries[] = $contentEntry;
 
         $defctime = $contentEntry['ctime'];
@@ -1270,7 +1243,7 @@ class eZWebDAVContentServer extends eZWebDAVServer
 
         if ( $depth > 0 )
         {
-            $scriptURL = $_SERVER["SCRIPT_URL"];
+            $scriptURL = eZSys::instance()->RequestURI;
             if ( $scriptURL{strlen($scriptURL) - 1} != "/" )
                 $scriptURL .= "/";
 
@@ -1328,7 +1301,7 @@ class eZWebDAVContentServer extends eZWebDAVServer
 
         // Set up attributes for the virtual site-list folder:
         $contentEntry["name"]     = '/';
-        $contentEntry["href"]     = $_SERVER['SCRIPT_URL'];
+        $contentEntry["href"]     = eZSys::instance()->RequestURI;
         $contentEntry["size"]     = 0;
         $contentEntry["mimetype"] = 'httpd/unix-directory';
         $contentEntry["ctime"]    = filectime( 'var' );
@@ -1345,19 +1318,19 @@ class eZWebDAVContentServer extends eZWebDAVServer
             foreach ( $sites as $site )
             {
                 // Set up attributes for the virtual site-list folder:
-                $contentEntry["name"]     = $_SERVER['SCRIPT_URL'] . $site;
+                $contentEntry["name"]     = eZSys::instance()->RequestURI . $site;
                 $contentEntry["size"]     = 0;
                 $contentEntry["mimetype"] = 'httpd/unix-directory';
                 $contentEntry["ctime"]    = filectime( 'settings/siteaccess/' . $site );
                 $contentEntry["mtime"]    = filemtime( 'settings/siteaccess/' . $site );
 
-                if ( $_SERVER["SCRIPT_URL"] == '/' )
+                if ( eZSys::instance()->RequestURI == '/' )
                 {
                     $contentEntry["href"] = $contentEntry["name"];
                 }
                 else
                 {
-                    $contentEntry["href"] = $_SERVER["SCRIPT_URL"] . $contentEntry["name"];
+                    $contentEntry["href"] = eZSys::instance()->RequestURI . $contentEntry["name"];
                 }
 
                 $entries[] = $contentEntry;
@@ -1393,7 +1366,7 @@ class eZWebDAVContentServer extends eZWebDAVServer
         // Always include the information about the current level node
         $thisNodeInfo = array();
         $thisNodeInfo = $this->fetchNodeInfo( $node );
-        $thisNodeInfo["href"] = $_SERVER['SCRIPT_URL'];
+        $thisNodeInfo["href"] = eZSys::instance()->RequestURI;
         $entries[] = $thisNodeInfo;
 
         // Return the content of the target.
@@ -1444,7 +1417,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
         $entry["ctime"] = $object->attribute( 'published' );
         $entry["mtime"] = $object->attribute( 'modified' );
 
-        //include_once( 'kernel/classes/ezcontentupload.php' );
         $upload = new eZContentUpload();
         $info = $upload->objectFileInfo( $object );
         $suffix = '';
@@ -1510,45 +1482,33 @@ class eZWebDAVContentServer extends eZWebDAVServer
             }
         }
 
-        $scriptURL = $_SERVER["SCRIPT_URL"];
+        $scriptURL = eZSys::instance()->RequestURI;
         if ( strlen( $scriptURL ) > 0 and $scriptURL[ strlen( $scriptURL ) - 1 ] != "/" )
             $scriptURL .= "/";
 
         $trimmedScriptURL = trim( $scriptURL, '/' );
         $scriptURLParts = explode( '/', $trimmedScriptURL );
 
-        $urlPartCount = count( $scriptURLParts );
+        $siteAccess = $scriptURLParts[0];
+        $virtualFolder = $scriptURLParts[1];
 
-        if ( $urlPartCount >= 2 )
-        {
-            // one of the virtual folders
-            // or inside one of the virtual folders
-            $siteAccess = $scriptURLParts[0];
-            $virtualFolder = $scriptURLParts[1];
-
-            // only when the virtual folder is Content we need to add its path to the start URL
-            // the paths of other top level folders (like Media) are included in URL aliases of their descending nodes
-            if ( $virtualFolder == VIRTUAL_CONTENT_FOLDER_NAME )
-            {
-                $startURL = '/' . $siteAccess . '/' . $virtualFolder . '/';
-            }
-            else
-            {
-                $startURL = '/' . $siteAccess . '/';
-            }
-        }
-        else
-        {
-            // site access level
-            $startURL = $scriptURL;
-        }
+        $startURL = '/' . $siteAccess . '/' . $virtualFolder . '/';
 
         // Set the href attribute (note that it doesn't just equal the name).
         if ( !isset( $entry['href'] ) )
         {
             if ( strlen( $suffix ) > 0 )
-                    $suffix = '.' . $suffix;
-            $entry["href"] = $startURL . $node->urlAlias() . $suffix;
+                $suffix = '.' . $suffix;
+
+            $alias = $node->urlAlias();
+            if ( $virtualFolder == eZWebDAVContentServer::virtualMediaFolderName() )
+            {
+                // remove the real media node url alias, the virtual media folder is already in $startURL
+                $aliasParts = explode( '/', $alias );
+                array_shift( $aliasParts );
+                $alias = implode( '/', $aliasParts );
+            }
+            $entry["href"] = $startURL . $alias . $suffix;
         }
         // Return array of attributes/properties (name, size, mime, times, etc.).
         return $entry;
@@ -1584,7 +1544,6 @@ class eZWebDAVContentServer extends eZWebDAVServer
             $contentObjectAttributes[0]->store();
             $db->commit();
 
-            //include_once( 'lib/ezutils/classes/ezoperationhandler.php' );
             $operationResult = eZOperationHandler::execute( 'content', 'publish', array( 'object_id' => $contentObjectID,
                                                                                          'version' => 1 ) );
             return eZWebDAVServer::OK_CREATED;
