@@ -5,9 +5,9 @@
 // Created on: <14-Jul-2004 14:18:58 dl>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezcontentstructuretreeoperator.php
+/*! \file
 */
 
 /*!
@@ -34,9 +34,6 @@
   \brief
 */
 
-require_once( 'kernel/classes/ezcontentlanguage.php' );
-//include_once( 'kernel/classes/ezcontentclassnamelist.php' );
-
 class eZContentStructureTreeOperator
 {
     function eZContentStructureTreeOperator( $name = 'content_structure_tree' )
@@ -80,9 +77,6 @@ class eZContentStructureTreeOperator
                                                'default' => 0 ) );
     }
 
-    /*!
-     \reimp
-    */
     function modify( $tpl, $operatorName, $operatorParameters, $rootNamespace, $currentNamespace, &$operatorValue, $namedParameters )
     {
         $sortArray = false;
@@ -134,8 +128,9 @@ class eZContentStructureTreeOperator
         $sortingInfo = eZContentObjectTreeNode::createSortingSQLStrings( $params['SortBy'] );
 
         // node params
-        $notEqParentString = eZContentObjectTreeNode::createNotEqParentSQLString( $nodeID, 1, false );
-        $pathStringCond    = eZContentObjectTreeNode::createPathConditionSQLString( $params['NodePath'], $params['NodeDepth'], 1, false );
+        $notEqParentString = '';
+        $pathStringCond    = '';
+        eZContentObjectTreeNode::createPathConditionAndNotEqParentSQLStrings( $pathStringCond, $notEqParentString, $nodeID, 1, false );
 
         // class filter
         $classCondition = eZContentObjectTreeNode::createClassFilteringSQLString( $params['ClassFilterType'], $params['ClassFilterArray'] );
@@ -352,9 +347,9 @@ class eZContentStructureTreeOperator
             --$depthLeft;
             if ( $depthLeft != 0 )
             {
-                $children = $contentTree['children'];
+                $children =& $contentTree['children'];
 
-                foreach( $children as $child )
+                foreach( $children as &$child )
                 {
                     $currentDepth = $depthLeft;
 
