@@ -5,9 +5,9 @@
 // Created on: <06-Oct-2002 16:19:31 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezcontentfunctioncollection.php
+/*! \file
 */
 
 /*!
@@ -35,8 +35,6 @@
 
 */
 
-//include_once( 'kernel/error/errors.php' );
-
 class eZContentFunctionCollection
 {
     /*!
@@ -46,10 +44,17 @@ class eZContentFunctionCollection
     {
     }
 
-    function fetchContentObject( $objectID )
+    static public function fetchContentObject( $objectID, $remoteID = false )
     {
-        //include_once( 'kernel/classes/ezcontentobject.php' );
-        $contentObject = eZContentObject::fetch( $objectID );
+        if ( $objectID ===false && $remoteID !== false )
+        {
+            $contentObject = eZContentObject::fetchByRemoteID( $remoteID );
+        }
+        else
+        {
+            $contentObject = eZContentObject::fetch( $objectID );
+        }
+        
         if ( $contentObject === null )
         {
             $result = array( 'error' => array( 'error_type' => 'kernel',
@@ -63,9 +68,8 @@ class eZContentFunctionCollection
         return $result;
     }
 
-    function fetchContentVersion( $objectID, $versionID )
+    static public function fetchContentVersion( $objectID, $versionID )
     {
-        //include_once( 'kernel/classes/ezcontentobjectversion.php' );
         $contentVersion = eZContentObjectVersion::fetchVersion( $versionID, $objectID );
         if ( !$contentVersion )
         {
@@ -80,19 +84,25 @@ class eZContentFunctionCollection
         return $result;
     }
 
-    function fetchContentNode( $nodeID, $nodePath )
+    static public function fetchContentNode( $nodeID, $nodePath, $languageCode, $remoteID = false )
     {
-        //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
         $contentNode = null;
         if ( $nodeID )
         {
-            $contentNode = eZContentObjectTreeNode::fetch( $nodeID );
+            if ( !isset( $languageCode ) )
+                $languageCode = false;
+
+            $contentNode = eZContentObjectTreeNode::fetch( $nodeID, $languageCode );
         }
         else if ( $nodePath )
         {
             $nodeID = eZURLAliasML::fetchNodeIDByPath( $nodePath );
             $contentNode = eZContentObjectTreeNode::fetch( $nodeID );
         }
+        else if ( $remoteID )
+        {
+            $contentNode = eZContentObjectTreeNode::fetchByRemoteID( $remoteID );
+        }
         if ( $contentNode === null )
         {
             $retVal = array( 'error' => array( 'error_type' => 'kernel',
@@ -106,10 +116,8 @@ class eZContentFunctionCollection
         return $retVal;
     }
 
-    function fetchNonTranslationList( $objectID, $version )
+    static public function fetchNonTranslationList( $objectID, $version )
     {
-        //include_once( 'kernel/classes/ezcontentobject.php' );
-        //include_once( 'kernel/classes/ezcontentobjectversion.php' );
         $version = eZContentObjectVersion::fetchVersion( $version, $objectID );
         if ( !$version )
             return array( 'error' => array( 'error_type' => 'kernel',
@@ -122,9 +130,8 @@ class eZContentFunctionCollection
         return array( 'result' => $nonTranslationList );
     }
 
-    function fetchTranslationList()
+    static public function fetchTranslationList()
     {
-        //include_once( 'kernel/classes/ezcontentobject.php' );
         $translationList = eZContentObject::translationList();
         if ( $translationList === null )
         {
@@ -139,9 +146,8 @@ class eZContentFunctionCollection
         return $result;
     }
 
-    function fetchPrioritizedLanguages()
+    static public function fetchPrioritizedLanguages()
     {
-        //include_once( 'kernel/classes/ezcontentlanguage.php' );
         $languages = eZContentLanguage::prioritizedLanguages();
         if ( $languages === null )
         {
@@ -156,9 +162,8 @@ class eZContentFunctionCollection
         return $result;
     }
 
-    function fetchPrioritizedLanguageCodes()
+    static public function fetchPrioritizedLanguageCodes()
     {
-        //include_once( 'kernel/classes/ezcontentlanguage.php' );
         $languageCodes = eZContentLanguage::prioritizedLanguageCodes();
         if ( $languageCodes === null )
         {
@@ -173,9 +178,8 @@ class eZContentFunctionCollection
         return $result;
     }
 
-    function fetchLocaleList( $withVariations )
+    static public function fetchLocaleList( $withVariations )
     {
-        //include_once( 'lib/ezlocale/classes/ezlocale.php' );
         $localeList = eZLocale::localeList( true, $withVariations );
         if ( $localeList === null )
         {
@@ -190,9 +194,8 @@ class eZContentFunctionCollection
         return $result;
     }
 
-    function fetchLocale( $localeCode )
+    static public function fetchLocale( $localeCode )
     {
-        //include_once( 'lib/ezlocale/classes/ezlocale.php' );
         // Fetch locale list
         $localeList = eZLocale::localeList( false, true );
         $localeObj = eZLocale::instance( $localeCode );
@@ -210,9 +213,8 @@ class eZContentFunctionCollection
         return $result;
     }
 
-    function fetchObject( $objectID )
+    static public function fetchObject( $objectID )
     {
-        //include_once( 'kernel/classes/ezcontentobject.php' );
         $object = eZContentObject::fetch( $objectID );
         if ( $object === null )
         {
@@ -227,9 +229,8 @@ class eZContentFunctionCollection
         return $result;
     }
 
-    function fetchClass( $classID )
+    static public function fetchClass( $classID )
     {
-        //include_once( 'kernel/classes/ezcontentclass.php' );
         if ( !is_numeric( $classID ) )
             $object = eZContentClass::fetchByIdentifier( $classID );
         else
@@ -247,9 +248,8 @@ class eZContentFunctionCollection
         return $result;
     }
 
-    function fetchClassAttributeList( $classID, $versionID )
+    static public function fetchClassAttributeList( $classID, $versionID )
     {
-        //include_once( 'kernel/classes/ezcontentclass.php' );
         $objectList = eZContentClass::fetch( $classID )->fetchAttributes( false, true, $versionID );
         if ( $objectList === null )
         {
@@ -264,9 +264,8 @@ class eZContentFunctionCollection
         return $result;
     }
 
-    function fetchClassAttribute( $attributeID, $versionID )
+    static public function fetchClassAttribute( $attributeID, $versionID )
     {
-        //include_once( 'kernel/classes/ezcontentclass.php' );
         $attribute = eZContentClassAttribute::fetch( $attributeID, true, $versionID );
         if ( $attribute === null )
         {
@@ -281,11 +280,10 @@ class eZContentFunctionCollection
         return $result;
     }
 
-    function calendar( $parentNodeID, $offset, $limit, $depth, $depthOperator,
+    static public function calendar( $parentNodeID, $offset, $limit, $depth, $depthOperator,
                                $classID, $attribute_filter, $extended_attribute_filter, $class_filter_type, $class_filter_array,
                                $groupBy, $mainNodeOnly, $ignoreVisibility, $limitation )
     {
-        //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
         $treeParameters = array( 'Offset' => $offset,
                                  'Limit' => $limit,
                                  'Limitation' => $limitation,
@@ -330,11 +328,10 @@ class eZContentFunctionCollection
         return $result;
     }
 
-    function fetchObjectTree( $parentNodeID, $sortBy, $onlyTranslated, $language, $offset, $limit, $depth, $depthOperator,
+    static public function fetchObjectTree( $parentNodeID, $sortBy, $onlyTranslated, $language, $offset, $limit, $depth, $depthOperator,
                               $classID, $attribute_filter, $extended_attribute_filter, $class_filter_type, $class_filter_array,
-                              $groupBy, $mainNodeOnly, $ignoreVisibility, $limitation, $asObject, $objectNameFilter, $loadDataMap = true )
+                              $groupBy, $mainNodeOnly, $ignoreVisibility, $limitation, $asObject, $objectNameFilter, $loadDataMap = null )
     {
-        //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
         $treeParameters = array( 'Offset' => $offset,
                                  'OnlyTranslated' => $onlyTranslated,
                                  'Language' => $language,
@@ -361,6 +358,8 @@ class eZContentFunctionCollection
             $treeParameters['AsObject'] = $asObject;
         if ( $loadDataMap )
             $treeParameters['LoadDataMap'] = true;
+        else if ( $loadDataMap === null )
+            $treeParameters['LoadDataMap'] = 15;
         if ( $depth !== false )
         {
             $treeParameters['Depth'] = $depth;
@@ -378,19 +377,17 @@ class eZContentFunctionCollection
         {
             return array( 'error' => array( 'error_type' => 'kernel',
                                             'error_code' => eZError::KERNEL_NOT_FOUND ) );
-        } 
+        }
         else
         {
             return array( 'result' => $children );
         }
     }
 
-    function fetchObjectTreeCount( $parentNodeID, $onlyTranslated, $language, $class_filter_type, $class_filter_array,
+    static public function fetchObjectTreeCount( $parentNodeID, $onlyTranslated, $language, $class_filter_type, $class_filter_array,
                                    $attributeFilter, $depth, $depthOperator,
                                    $ignoreVisibility, $limitation, $mainNodeOnly, $extendedAttributeFilter, $objectNameFilter )
     {
-        //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
-
         $childrenCount = null;
 
         if ( is_numeric( $parentNodeID ) or is_array( $parentNodeID ) )
@@ -422,10 +419,9 @@ class eZContentFunctionCollection
         return $result;
     }
 
-    function fetchContentSearch( $searchText, $subTreeArray, $offset, $limit, $searchTimestamp, $publishDate, $sectionID,
+    static public function fetchContentSearch( $searchText, $subTreeArray, $offset, $limit, $searchTimestamp, $publishDate, $sectionID,
                                  $classID, $classAttributeID, $ignoreVisibility, $limitation, $sortArray )
     {
-        //include_once( "kernel/classes/ezsearch.php" );
         $searchArray = eZSearch::buildSearchArray();
         $parameters = array();
         if ( $classID !== false )
@@ -453,24 +449,22 @@ class eZContentFunctionCollection
         return array( 'result' => $searchResult );
     }
 
-    function fetchTrashObjectCount( $objectNameFilter )
+    static public function fetchTrashObjectCount( $objectNameFilter, $attributeFilter = false )
     {
-        //include_once( 'kernel/classes/ezcontentobjecttrashnode.php' );
+        $params = array();
         if ( $objectNameFilter !== false )
         {
-            $params = array();
             $params['ObjectNameFilter'] = $objectNameFilter;
         }
-        else
-            $params = false;
+
+        $params[ 'AttributeFilter' ] = $attributeFilter;
 
         $trashCount = eZContentObjectTrashNode::trashListCount( $params );
         return array( 'result' => $trashCount );
     }
 
-    function fetchTrashObjectList( $offset, $limit, $objectNameFilter )
+    static public function fetchTrashObjectList( $offset, $limit, $objectNameFilter, $attributeFilter = false, $sortBy = false, $asObject = true )
     {
-        //include_once( 'kernel/classes/ezcontentobjecttrashnode.php' );
         $params = array();
         if ( $objectNameFilter !== false )
         {
@@ -478,12 +472,15 @@ class eZContentFunctionCollection
         }
         $params[ 'Limit' ] = $limit;
         $params[ 'Offset' ] = $offset;
+        $params[ 'AttributeFilter' ] = $attributeFilter;
+        $params[ 'SortBy' ] = $sortBy;
+        $params[ 'AsObject' ] = $asObject;
 
         $trashNodesList = eZContentObjectTrashNode::trashList( $params, false );
         return array( 'result' => $trashNodesList );
     }
 
-    function fetchDraftVersionList( $offset, $limit )
+    static public function fetchDraftVersionList( $offset, $limit )
     {
         $userID = eZUser::currentUserID();
         $draftVersionList =  eZPersistentObject::fetchObjectList( eZContentObjectVersion::definition(),
@@ -496,7 +493,7 @@ class eZContentFunctionCollection
         return array( 'result' => $draftVersionList );
     }
 
-    function fetchDraftVersionCount()
+    static public function fetchDraftVersionCount()
     {
         $userID = eZUser::currentUserID();
         $draftVersionList = eZPersistentObject::fetchObjectList( eZContentObjectVersion::definition(),
@@ -512,7 +509,7 @@ class eZContentFunctionCollection
         return array( 'result' => $draftVersionList[0]['count'] );
     }
 
-    function fetchPendingList( $offset, $limit )
+    static public function fetchPendingList( $offset, $limit )
     {
         $userID = eZUser::currentUserID();
         $pendingList =  eZPersistentObject::fetchObjectList( eZContentObjectVersion::definition(),
@@ -524,7 +521,7 @@ class eZContentFunctionCollection
 
     }
 
-    function fetchPendingCount()
+    static public function fetchPendingCount()
     {
         $userID = eZUser::currentUserID();
         $pendingList = eZPersistentObject::fetchObjectList( eZContentObjectVersion::definition(),
@@ -541,19 +538,19 @@ class eZContentFunctionCollection
     }
 
 
-    function fetchVersionList( $contentObject, $offset, $limit )
+    static public function fetchVersionList( $contentObject, $offset, $limit, $sorts = null )
     {
         if ( !is_object( $contentObject ) )
             return array( 'result' => null );
         $versionList =  eZPersistentObject::fetchObjectList( eZContentObjectVersion::definition(),
                                                               null, array(  'contentobject_id' => $contentObject->attribute("id") ),
-                                                                   null, array( 'length' => $limit, 'offset' => $offset ),
+                                                                   $sorts, array( 'length' => $limit, 'offset' => $offset ),
                                                                    true );
         return array( 'result' => $versionList );
 
     }
 
-    function fetchVersionCount( $contentObject )
+    static public function fetchVersionCount( $contentObject )
     {
         if ( !is_object( $contentObject ) )
             return array( 'result' => 0 );
@@ -569,7 +566,7 @@ class eZContentFunctionCollection
         return array( 'result' => $versionList[0]['count'] );
     }
 
-    function canInstantiateClassList( $groupID, $parentNode, $filterType = 'include', $fetchID, $asObject )
+    static public function canInstantiateClassList( $groupID, $parentNode, $filterType = 'include', $fetchID, $asObject )
     {
         $ClassGroupIDs = false;
 
@@ -591,25 +588,23 @@ class eZContentFunctionCollection
         }
         else
         {
-            //include_once( 'kernel/classes/ezcontentclass.php' );
             $classList = eZContentClass::canInstantiateClassList( $asObject, $filterType == 'include', $ClassGroupIDs, $fetchID );
         }
 
         return array( 'result' => $classList );
     }
 
-    function canInstantiateClasses( $parentNode )
+    static public function canInstantiateClasses( $parentNode )
     {
         if ( is_object( $parentNode ) )
         {
             $contentObject = $parentNode->attribute( 'object' );
             return array( 'result' => $contentObject->attribute( 'can_create' ) );
         }
-        //include_once( 'kernel/classes/ezcontentclass.php' );
         return array( 'result' => eZContentClass::canInstantiateClasses() );
     }
 
-    function contentobjectAttributes( $version, $languageCode )
+    static public function contentobjectAttributes( $version, $languageCode )
     {
         if ( $languageCode == '' )
         {
@@ -621,31 +616,25 @@ class eZContentFunctionCollection
         }
     }
 
-    function fetchBookmarks( $offset, $limit )
+    static public function fetchBookmarks( $offset, $limit )
     {
-        //include_once( 'kernel/classes/datatypes/ezuser/ezuser.php' );
         $user = eZUser::currentUser();
-        //include_once( 'kernel/classes/ezcontentbrowsebookmark.php' );
         return array( 'result' => eZContentBrowseBookmark::fetchListForUser( $user->id(), $offset, $limit ) );
     }
 
-    function fetchRecent()
+    static public function fetchRecent()
     {
         $user = eZUser::currentUser();
-        //include_once( 'kernel/classes/ezcontentbrowserecent.php' );
         return array( 'result' => eZContentBrowseRecent::fetchListForUser( $user->id() ) );
     }
 
-    function fetchSectionList()
+    static public function fetchSectionList()
     {
-        //include_once( 'kernel/classes/ezsection.php' );
         return array( 'result' => eZSection::fetchList() );
     }
 
-    function fetchTipafriendTopList( $offset, $limit, $start_time, $end_time, $duration, $ascending, $extended )
+    static public function fetchTipafriendTopList( $offset, $limit, $start_time, $end_time, $duration, $ascending, $extended )
     {
-        //include_once( 'kernel/classes/eztipafriendcounter.php' );
-
         $currentTime = time();
         $conds = array();
 
@@ -685,7 +674,6 @@ class eZContentFunctionCollection
                                                         array( 'node_id' ),
                                                         array( array( 'operation' => 'count( * )',
                                                                       'name' => 'count' ) ) );
-        //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
         if ( $extended )
         {
             foreach ( array_keys( $topList ) as $key )
@@ -714,11 +702,8 @@ class eZContentFunctionCollection
 
     }
 
-    function fetchMostViewedTopList( $classID, $sectionID, $offset, $limit )
+    static public function fetchMostViewedTopList( $classID, $sectionID, $offset, $limit )
     {
-        //include_once( 'kernel/classes/ezviewcounter.php' );
-        //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
-
         $topList = eZViewCounter::fetchTopList( $classID, $sectionID, $offset, $limit );
         $contentNodeList = array();
         foreach ( array_keys ( $topList ) as $key )
@@ -733,38 +718,33 @@ class eZContentFunctionCollection
         return array( 'result' => $contentNodeList );
     }
 
-    function fetchCollectedInfoCount( $objectAttributeID, $objectID, $value, $creatorID = false, $userIdentifier = false )
+    static public function fetchCollectedInfoCount( $objectAttributeID, $objectID, $value, $creatorID = false, $userIdentifier = false )
     {
-        //include_once( 'kernel/infocollector/ezinfocollectorfunctioncollection.php' );
         return eZInfocollectorFunctionCollection::fetchCollectedInfoCount( $objectAttributeID, $objectID, $value, $creatorID, $userIdentifier );
     }
 
-    function fetchCollectedInfoCountList( $objectAttributeID )
+    static public function fetchCollectedInfoCountList( $objectAttributeID )
     {
-        //include_once( 'kernel/infocollector/ezinfocollectorfunctioncollection.php' );
         return eZInfocollectorFunctionCollection::fetchCollectedInfoCountList( $objectAttributeID );
     }
 
-    function fetchCollectedInfoCollection( $collectionID, $contentObjectID )
+    static public function fetchCollectedInfoCollection( $collectionID, $contentObjectID )
     {
-        //include_once( 'kernel/infocollector/ezinfocollectorfunctioncollection.php' );
         return eZInfocollectorFunctionCollection::fetchCollectedInfoCollection( $collectionID, $contentObjectID );
     }
 
-    function fetchCollectionsList( $objectID = false, $creatorID = false, $userIdentifier = false, $limit = false, $offset = false, $sortBy = false )
+    static public function fetchCollectionsList( $objectID = false, $creatorID = false, $userIdentifier = false, $limit = false, $offset = false, $sortBy = false )
     {
-        //include_once( 'kernel/infocollector/ezinfocollectorfunctioncollection.php' );
-        return eZInfocollectorFunctionCollection::fetchCollectionsList( $objectID = false,
-                                                                        $creatorID = false,
-                                                                        $userIdentifier = false,
-                                                                        $limit = false,
-                                                                        $offset = false,
-                                                                        $sortBy = false );
+        return eZInfocollectorFunctionCollection::fetchCollectionsList( $objectID,
+                                                                        $creatorID,
+                                                                        $userIdentifier,
+                                                                        $limit,
+                                                                        $offset,
+                                                                        $sortBy );
      }
 
-    function fetchObjectByAttribute( $identifier )
+    static public function fetchObjectByAttribute( $identifier )
     {
-        //include_once( 'kernel/classes/ezcontentobjectattribute.php' );
         $contentObjectAttribute = eZContentObjectAttribute::fetchByIdentifier( $identifier );
         if ( $contentObjectAttribute === null )
         {
@@ -778,17 +758,16 @@ class eZContentFunctionCollection
         return $result;
     }
 
-    function fetchObjectCountByUserID( $classID, $userID )
+    static public function fetchObjectCountByUserID( $classID, $userID )
     {
-        //include_once( 'kernel/classes/ezcontentobject.php' );
         $objectCount = eZContentObject::fetchObjectCountByUserID( $classID, $userID );
         return array( 'result' => $objectCount );
     }
 
-    function fetchKeywordCount( $alphabet, 
-                                $classid, 
-                                $owner = false, 
-                                $parentNodeID = false, 
+    static public function fetchKeywordCount( $alphabet,
+                                $classid,
+                                $owner = false,
+                                $parentNodeID = false,
                                 $includeDuplicates = true,
                                 $strictMatching = false )
     {
@@ -802,13 +781,11 @@ class eZContentFunctionCollection
             $classIDArray = $classid;
         }
 
-        //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
         $showInvisibleNodesCond = eZContentObjectTreeNode::createShowInvisibleSQLString( true, false );
         $limitation = false;
         $limitationList = eZContentObjectTreeNode::getLimitationList( $limitation );
         $sqlPermissionChecking = eZContentObjectTreeNode::createPermissionCheckingSQL( $limitationList );
 
-        //include_once( 'lib/ezdb/classes/ezdb.php' );
         $db = eZDB::instance();
 
         $alphabet = $db->escapeString( $alphabet );
@@ -826,9 +803,9 @@ class eZContentFunctionCollection
         if ( !$includeDuplicates )
         {
           //will use SELECT COUNT( DISTINCT ezcontentobject.id ) to count object only once even if it has
-          //several keywords started with $alphabet. 
+          //several keywords started with $alphabet.
           //COUNT( DISTINCT fieldName ) is SQL92 compliant syntax.
-            $sqlToExcludeDuplicates = ' DISTINCT';  
+            $sqlToExcludeDuplicates = ' DISTINCT';
         }
         // composing sql for matching tag word, it could be strict equiality or LIKE clause dependent of $strictMatching parameter.
         $sqlMatching = "ezkeyword.keyword LIKE '$alphabet%'";
@@ -866,20 +843,20 @@ class eZContentFunctionCollection
     //
     //Returns an array( 'result' => array( 'keyword' => keyword, 'link_object' => node_id );
     //By default fetchKeyword gets a list of (not necessary unique) nodes and respective keyword strings
-    //Search keyword provided in $alphabet parameter. 
+    //Search keyword provided in $alphabet parameter.
     //By default keyword matching implemented by LIKE so all keywords that starts with $alphabet
     //will successfully match. This means that if some object have attached keywords:
     //'Skien', 'Skien forests', 'Skien comunity' than fetchKeyword('Skien') will return tree entries
     //for this object.
-    //Setting $includeDuplicates parameter to false makes fetchKeyword('Skien') to return just 
+    //Setting $includeDuplicates parameter to false makes fetchKeyword('Skien') to return just
     //one entry for such objects.
-    function fetchKeyword( $alphabet, 
-                           $classid, 
-                           $offset, 
-                           $limit, 
-                           $owner = false, 
-                           $sortBy = array(), 
-                           $parentNodeID = false, 
+    static public function fetchKeyword( $alphabet,
+                           $classid,
+                           $offset,
+                           $limit,
+                           $owner = false,
+                           $sortBy = array(),
+                           $parentNodeID = false,
                            $includeDuplicates = true,
                            $strictMatching = false )
     {
@@ -893,7 +870,6 @@ class eZContentFunctionCollection
             $classIDArray = $classid;
         }
 
-        //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
         $showInvisibleNodesCond = eZContentObjectTreeNode::createShowInvisibleSQLString( true, false );
         $limitation = false;
         $limitationList = eZContentObjectTreeNode::getLimitationList( $limitation );
@@ -906,20 +882,18 @@ class eZContentFunctionCollection
         $keywordNodeArray = array();
         $lastKeyword = '';
 
+        $db = eZDB::instance();
+
         //in SELECT clause below we will use a full keyword value
         //or just a part of ezkeyword.keyword matched to $alphabet respective to $includeDuplicates parameter.
-        //In the case $includeDuplicates = ture we need only a part 
+        //In the case $includeDuplicates = ture we need only a part
         //of ezkeyword.keyword to be fetched in field to allow DISTINCT to remove rows with the same node id's
         $sqlKeyword = 'ezkeyword.keyword';
         if ( !$includeDuplicates )
         {
-            //SUBSTRING( str FROM pos FOR len ) is a SQL92 compliant syntax.
-            $sqlKeyword = 'SUBSTRING(ezkeyword.keyword FROM 1 FOR '.strlen( $alphabet ).') AS keyword ';
+            $sqlKeyword = $db->subString('ezkeyword.keyword', 1, strlen( $alphabet ) ) . ' AS keyword ';
         }
 
-        //include_once( 'lib/ezdb/classes/ezdb.php' );
-        $db = eZDB::instance();
-
         $alphabet = $db->escapeString( $alphabet );
 
         $sortingInfo = array();
@@ -970,7 +944,7 @@ class eZContentFunctionCollection
         $sortingInfo['attributeWhereSQL'] .= " a1.version=ezcontentobject.current_version
                                              AND a1.contentobject_id=ezcontentobject.id AND";
 
-        //Adding DISTINCT to avoid duplicates, 
+        //Adding DISTINCT to avoid duplicates,
         //check if DISTINCT keyword was added before providing clauses for sorting.
         if ( !$includeDuplicates && substr( $sqlTarget, 0, 9) != 'DISTINCT ' )
         {
@@ -986,7 +960,7 @@ class eZContentFunctionCollection
             $sqlClassIDString = 'AND ezkeyword.class_id IN (' . $db->implodeWithTypeCast( ',', $classIDArray, 'int' ) . ')';
         }
 
-        // composing sql for matching tag word, it could be strict equiality or LIKE clause 
+        // composing sql for matching tag word, it could be strict equiality or LIKE clause
         // dependent of $strictMatching parameter.
         $sqlMatching = "ezkeyword.keyword LIKE '$alphabet%'";
         if ( $strictMatching )
@@ -1016,7 +990,6 @@ class eZContentFunctionCollection
 
         $keyWords = $db->arrayQuery( $query, $db_params );
 
-        //include_once( 'lib/ezi18n/classes/ezchartransform.php' );
         $trans = eZCharTransform::instance();
 
         foreach ( $keyWords as $keywordArray )
@@ -1043,7 +1016,7 @@ class eZContentFunctionCollection
         return array( 'result' => $keywordNodeArray );
     }
 
-    function fetchSameClassAttributeNodeList( $contentclassattributeID, $value, $datatype )
+    static public function fetchSameClassAttributeNodeList( $contentclassattributeID, $value, $datatype )
     {
         if ( $datatype == "int" )
              $type = "data_int";
@@ -1056,7 +1029,6 @@ class eZContentFunctionCollection
             eZDebug::writeError( "DatatypeString not supported in fetch same_classattribute_node, use int, float or text" );
             return false;
         }
-        //include_once( 'lib/ezdb/classes/ezdb.php' );
         $db = eZDB::instance();
         $contentclassattributeID =(int) $contentclassattributeID;
         $value = $db->escapeString( $value );
@@ -1082,7 +1054,7 @@ class eZContentFunctionCollection
         return array( 'result' => $resultNodeArray );
     }
 
-    function checkAccess( $access, $contentObject, $contentClassID, $parentContentClassID, $languageCode = false )
+    static public function checkAccess( $access, $contentObject, $contentClassID, $parentContentClassID, $languageCode = false )
     {
         if ( $contentObject instanceof eZContentObjectTreeNode )
         {
@@ -1090,7 +1062,6 @@ class eZContentFunctionCollection
         }
         if (  $contentClassID !== false and !is_numeric( $contentClassID ) )
         {
-            //include_once( 'kernel/classes/ezcontentclass.php' );
             $class = eZContentClass::fetchByIdentifier( $contentClassID );
             if ( !$class )
                 return array( 'error' => array( 'error_type' => 'kernel',
@@ -1105,20 +1076,18 @@ class eZContentFunctionCollection
     }
 
     // Fetches all navigation parts as an array
-    function fetchNavigationParts()
+    static public function fetchNavigationParts()
     {
-        //include_once( 'kernel/classes/eznavigationpart.php' );
         return array( 'result' => eZNavigationPart::fetchList() );
     }
 
     // Fetches one navigation parts by identifier
-    function fetchNavigationPart( $identifier )
+    static public function fetchNavigationPart( $identifier )
     {
-        //include_once( 'kernel/classes/eznavigationpart.php' );
         return array( 'result' => eZNavigationPart::fetchPartByIdentifier( $identifier ) );
     }
 
-    function contentobjectRelationTypeMask( $contentObjectRelationTypes = false )
+    static public function contentobjectRelationTypeMask( $contentObjectRelationTypes = false )
     {
         $relationTypeMask = 0;
         if ( is_array( $contentObjectRelationTypes ) )
@@ -1153,7 +1122,7 @@ class eZContentFunctionCollection
     }
 
     // Fetches related objects id grouped by relation types
-    function fetchRelatedObjectsID( $objectID, $attributeID, $allRelations)
+    static public function fetchRelatedObjectsID( $objectID, $attributeID, $allRelations)
     {
         if ( !is_array( $allRelations ) || $allRelations === array() )
         {
@@ -1185,7 +1154,7 @@ class eZContentFunctionCollection
     }
 
     // Fetches reverse related objects id grouped by relation types
-    function fetchReverseRelatedObjectsID( $objectID, $attributeID, $allRelations )
+    static public function fetchReverseRelatedObjectsID( $objectID, $attributeID, $allRelations )
     {
         if ( !is_array( $allRelations ) || $allRelations === array() )
         {
@@ -1217,7 +1186,7 @@ class eZContentFunctionCollection
     }
 
     // Fetches reverse related objects
-    function fetchRelatedObjects( $objectID, $attributeID, $allRelations, $groupByAttribute, $sortBy )
+    static public function fetchRelatedObjects( $objectID, $attributeID, $allRelations, $groupByAttribute, $sortBy, $limit = false, $offset = false, $asObject = true, $loadDataMap = false, $ignoreVisibility = null )
     {
         if ( !$objectID )
         {
@@ -1225,6 +1194,11 @@ class eZContentFunctionCollection
             return false;
         }
         $params = array();
+        $params['Limit'] = $limit;
+        $params['Offset'] = $offset;
+        $params['AsObject'] = $asObject;
+        $params['LoadDataMap'] = $loadDataMap;
+
         if ( $sortBy )
         {
             if ( is_array( $sortBy ) )
@@ -1236,6 +1210,12 @@ class eZContentFunctionCollection
                 eZDebug::writeError( "Function parameter 'SortBy' should be an array.", 'content/fetchRelatedObjects' );
             }
         }
+
+        if ( $ignoreVisibility !== null )
+        {
+            $params['IgnoreVisibility'] = $ignoreVisibility;
+        }
+
         if ( !$attributeID )
         {
             $attributeID = 0;
@@ -1259,7 +1239,6 @@ class eZContentFunctionCollection
 
         if ( $attributeID && !is_numeric( $attributeID ) && !is_bool( $attributeID ) )
         {
-            //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
             $attributeID = eZContentObjectTreeNode::classAttributeIDByIdentifier( $attributeID );
             if ( !$attributeID )
             {
@@ -1271,12 +1250,11 @@ class eZContentFunctionCollection
         $object = eZContentObject::fetch( $objectID );
         if ( $object === null )
             return false;
-        //include_once( 'kernel/classes/ezcontentobject.php' );
         return array( 'result' => $object->relatedContentObjectList( false, $objectID, $attributeID, $groupByAttribute, $params ) );
     }
 
         // Fetches count of reverse related objects
-    function fetchRelatedObjectsCount( $objectID, $attributeID, $allRelations )
+    static public function fetchRelatedObjectsCount( $objectID, $attributeID, $allRelations )
     {
         if ( !$objectID )
         {
@@ -1308,7 +1286,6 @@ class eZContentFunctionCollection
 
         if ( $attributeID && !is_numeric( $attributeID ) && !is_bool( $attributeID ) )
         {
-            //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
             $attributeID = eZContentObjectTreeNode::classAttributeIDByIdentifier( $attributeID );
             if ( !$attributeID )
             {
@@ -1320,13 +1297,17 @@ class eZContentFunctionCollection
         $object = eZContentObject::fetch( $objectID );
         if ( $object === null )
             return false;
-        //include_once( 'kernel/classes/ezcontentobject.php' );
         return array( 'result' => $object->relatedContentObjectCount( false, $attributeID, $params ) );
     }
 
-    function fetchReverseRelatedObjects( $objectID, $attributeID, $allRelations, $groupByAttribute, $sortBy, $ignoreVisibility )
+    static public function fetchReverseRelatedObjects( $objectID, $attributeID, $allRelations, $groupByAttribute, $sortBy, $ignoreVisibility,  $limit = false, $offset = false, $asObject = true, $loadDataMap = false  )
     {
         $params = array();
+        $params['Limit'] = $limit;
+        $params['Offset'] = $offset;
+        $params['AsObject'] = $asObject;
+        $params['LoadDataMap'] = $loadDataMap;
+
         if ( $sortBy )
         {
             if ( is_array( $sortBy ) )
@@ -1365,7 +1346,6 @@ class eZContentFunctionCollection
 
         if ( $attributeID && !is_numeric( $attributeID ) && !is_bool( $attributeID ) )
         {
-            //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
             $attributeID = eZContentObjectTreeNode::classAttributeIDByIdentifier( $attributeID );
             if ( !$attributeID )
             {
@@ -1373,12 +1353,11 @@ class eZContentFunctionCollection
                 return false;
             }
         }
-        //include_once( 'kernel/classes/ezcontentobject.php' );
         return array( 'result' => eZContentObject::fetch( $objectID )->reverseRelatedObjectList( false, $attributeID, $groupByAttribute, $params ) );
     }
 
     // Fetches count of reverse related objects
-    function fetchReverseRelatedObjectsCount( $objectID, $attributeID, $allRelations, $ignoreVisibility  )
+    static public function fetchReverseRelatedObjectsCount( $objectID, $attributeID, $allRelations, $ignoreVisibility  )
     {
         $params = array();
         if ( isset( $ignoreVisibility ) )
@@ -1409,7 +1388,6 @@ class eZContentFunctionCollection
 
         if ( $attributeID && !is_numeric( $attributeID ) && !is_bool( $attributeID ) )
         {
-            //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
             $attributeID = eZContentObjectTreeNode::classAttributeIDByIdentifier( $attributeID );
             if ( !$attributeID )
             {
@@ -1417,11 +1395,10 @@ class eZContentFunctionCollection
                 return false;
             }
         }
-        //include_once( 'kernel/classes/ezcontentobject.php' );
         return array( 'result' => eZContentObject::fetch( $objectID )->reverseRelatedObjectCount( false, $attributeID, $params ) );
     }
 
-    function fetchAvailableSortFieldList()
+    static public function fetchAvailableSortFieldList()
     {
         return array( 'result' => array( '6' => ezi18n( 'kernel/content', 'Class identifier' ),
                                          '7' => ezi18n( 'kernel/content', 'Class name' ),
@@ -1434,9 +1411,8 @@ class eZContentFunctionCollection
                                          '4' => ezi18n( 'kernel/content', 'Section' ) ) );
     }
 
-    function fetchCountryList( $filter, $value )
+    static public function fetchCountryList( $filter, $value )
     {
-        //include_once( 'kernel/classes/datatypes/ezcountry/ezcountrytype.php' );
         // Fetch country list
         if ( !$filter and !$value )
         {
@@ -1450,7 +1426,7 @@ class eZContentFunctionCollection
         return array( 'result' => $country );
     }
 
-    function fetchContentTreeMenuExpiry()
+    static public function fetchContentTreeMenuExpiry()
     {
         eZExpiryHandler::registerShutdownFunction();
 
