@@ -3,9 +3,9 @@
 // Created on: <17-Apr-2002 10:34:48 bf>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -24,21 +24,8 @@
 //
 //
 
-//include_once( 'kernel/classes/ezcontentclass.php' );
-//include_once( 'kernel/classes/ezcontentclassattribute.php' );
-
-//include_once( 'kernel/classes/ezcontentobject.php' );
-//include_once( 'kernel/classes/ezcontentobjectversion.php' );
-//include_once( 'kernel/classes/ezcontentobjectattribute.php' );
-//include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
-
-//include_once( "lib/ezdb/classes/ezdb.php" );
-//include_once( 'lib/ezutils/classes/ezhttptool.php' );
-
 require_once( 'kernel/common/template.php' );
 
-//include_once( 'kernel/classes/ezpreferences.php' );
-
 
 function checkNodeAssignments( $module, $class, $object, $version, $contentObjectAttributes, $editVersion, $editLanguage, $FromLanguage, &$validation )
 {
@@ -289,10 +276,6 @@ function storeNodeAssignments( $module, $class, $object, $version, $contentObjec
         $mainNodeID = $setPlacementNodeIDArray[$elementNumber];
     }
 
-    $nodesID = array();
-    if ( $http->hasPostVariable( 'NodesID' ) )
-        $nodesID = $http->postVariable( 'NodesID' );
-
     $nodeID = eZContentObjectTreeNode::findNode( $mainNodeID, $object->attribute('id') );
     eZDebugSetting::writeDebug( 'kernel-content-edit', $nodeID, 'nodeID' );
 //    $object->setAttribute( 'main_node_id', $nodeID );
@@ -779,7 +762,8 @@ function handleNodeTemplate( $module, $class, $object, $version, $contentObjectA
         else
         {
             $assignedNode->purge();
-            unset( $assignedNodeArray[$assignedNodeKey] );
+            if( isset( $assignedNodeArray[$assignedNodeKey] ) )
+                unset( $assignedNodeArray[$assignedNodeKey] );
         }
     }
     $db->commit();
