@@ -5,9 +5,9 @@
 // Created on: <25-Jun-2002 13:09:57 bf>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -31,16 +31,8 @@
 
 */
 
-//include_once( "lib/ezdb/classes/ezdb.php" );
-//include_once( "kernel/classes/ezcontentobject.php" );
-//include_once( "lib/ezlocale/classes/ezdatetime.php" );
-//include_once( "kernel/classes/ezcontentobject.php" );
-//include_once( 'kernel/classes/ezcontentlanguage.php' );
-
 class eZSearchEngine
 {
-    /*!
-     */
     function eZSearchEngine()
     {
         $generalFilter = array( 'subTreeTable' => '',
@@ -55,10 +47,22 @@ class eZSearchEngine
         $this->GeneralFilter = $generalFilter;
     }
 
+
+    static function needCommit()
+    {
+        //commits are NA
+        return false;
+    }
+
+    static function needRemoveWithUpdate()
+    {
+        return true;
+    }
+
     /*!
      Adds an object to the search database.
     */
-    function addObject( $contentObject, $uri )
+    function addObject( $contentObject, $commit )
     {
         $contentObjectID = $contentObject->attribute( 'id' );
         $currentVersion = $contentObject->currentVersion();
@@ -66,7 +70,6 @@ class eZSearchEngine
         if ( !$currentVersion )
         {
             $errCurrentVersion = $contentObject->attribute( 'current_version');
-            require_once( "lib/ezutils/classes/ezdebug.php" );
             eZDebug::writeError( "Failed to fetch \"current version\" ({$errCurrentVersion})" .
                                  " of content object (ID: {$contentObjectID})", 'eZSearchEngine' );
             return;
@@ -113,12 +116,17 @@ class eZSearchEngine
                     {
                         $integerValue = 0;
                     }
-                    $wordArray = split( " ", $text );
+                    $wordArray = explode( ' ', $text );
 
                     foreach ( $wordArray as $word )
                     {
                         if ( trim( $word ) != "" )
                         {
+                            // words stored in search index are limited to 150 characters
+                            if ( strlen( $word ) > 150 )
+                            {
+                                $word = substr( $word, 0, 150 );
+                            }
                             $indexArray[] = array( 'Word' => $word,
                                                    'ContentClassAttributeID' => $attribute->attribute( 'contentclassattribute_id' ),
                                                    'identifier' => $metaDataPart['id'],
@@ -171,7 +179,6 @@ class eZSearchEngine
         $db = eZDB::instance();
 
         // Initialize transformation system
-        //include_once( 'lib/ezi18n/classes/ezchartransform.php' );
         $trans = eZCharTransform::instance();
 
         $wordCount = count( $indexArrayOnlyWords );
@@ -291,7 +298,6 @@ class eZSearchEngine
         */
 
         // Initialize transformation system
-        //include_once( 'lib/ezi18n/classes/ezchartransform.php' );
         $trans = eZCharTransform::instance();
 
         $prevWordID = 0;
@@ -380,7 +386,7 @@ class eZSearchEngine
     /*!
      \static
     */
-    function removeObject( $contentObject )
+    function removeObject( $contentObject, $commit )
     {
         $db = eZDB::instance();
         $objectID = $contentObject->attribute( "id" );
@@ -765,10 +771,7 @@ class eZSearchEngine
                     foreach ( $nodeArray as $node )
                     {
                         $pathString = $node['path_string'];
-
-                        $subStringString = $db->subString( 'ezcontentobject_tree.path_string', 1, strlen( $pathString ) );
-
-                        $subTreeSQL .= " $subStringString = '$pathString' ";
+                        $subTreeSQL .= " ezcontentobject_tree.path_string like '$pathString%' ";
 
                         if ( $i < ( count( $nodeArray ) -1 ) )
                             $subTreeSQL .= " OR ";
@@ -848,7 +851,6 @@ class eZSearchEngine
             // Loop every word and insert result in temporary table
 
             // Determine whether we should search invisible nodes.
-            //include_once( 'kernel/classes/ezcontentobjecttreenode.php' );
             $showInvisibleNodesCond = eZContentObjectTreeNode::createShowInvisibleSQLString( !$ignoreVisibility );
 
             foreach ( $searchPartsArray as $searchPart )
@@ -897,7 +899,8 @@ class eZSearchEngine
                                          ezcontentobject.id = ezcontentobject_tree.contentobject_id and
                                          ezcontentobject_tree.node_id = ezcontentobject_tree.main_node_id
                                          $showInvisibleNodesCond
-                                         $sqlPermissionChecking[where]" );
+                                         $sqlPermissionChecking[where]",
+                                    eZDBInterface::SERVER_SLAVE );
                     }
                     else
                     {
@@ -929,7 +932,8 @@ class eZSearchEngine
                                           ezcontentobject.id = ezcontentobject_tree.contentobject_id and
                                           ezcontentobject_tree.node_id = ezcontentobject_tree.main_node_id
                                           $showInvisibleNodesCond
-                                          $sqlPermissionChecking[where]" );
+                                          $sqlPermissionChecking[where]",
+                                    eZDBInterface::SERVER_SLAVE );
                     }
                     $i++;
                 }
@@ -939,7 +943,7 @@ class eZSearchEngine
                 }
             }
 
-            if ( $searchPartsArray === null && $this->TempTablesCount == 0 )
+            if ( count( $searchPartsArray ) === 0 && $this->TempTablesCount == 0 )
             {
                  $table = $db->generateUniqueTempTableName( 'ezsearch_tmp_%', 0 );
                  $this->saveCreatedTempTableName( 0, $table );
@@ -963,7 +967,8 @@ class eZSearchEngine
                                           ezcontentobject.id = ezcontentobject_tree.contentobject_id and
                                           ezcontentobject_tree.node_id = ezcontentobject_tree.main_node_id
                                           $showInvisibleNodesCond
-                                          $sqlPermissionChecking[where]" );
+                                          $sqlPermissionChecking[where]",
+                             eZDBInterface::SERVER_SLAVE );
                  $this->TempTablesCount = 1;
                  $i = $this->TempTablesCount;
             }
@@ -1049,24 +1054,6 @@ class eZSearchEngine
                     $showInvisibleNodesCond
                     $sortWhereSQL
                     ORDER BY $orderByFieldsSQL";
-                if ( $tmpTableCount == 0 )
-                {
-                    $searchCountQuery = "SELECT count( DISTINCT ezcontentobject.id ) AS count
-                    FROM
-                       ezcontentobject,
-                       ezcontentclass,
-                       ezcontentobject_tree
-                       $versionNameTables
-                    WHERE
-                    $emptyWhere
-                    ezcontentobject.contentclass_id = ezcontentclass.id and
-                    ezcontentclass.version = '0' and
-                    ezcontentobject.id = ezcontentobject_tree.contentobject_id and
-                    ezcontentobject_tree.node_id = ezcontentobject_tree.main_node_id
-                    $versionNameJoins
-                    $showInvisibleNodesCond
-                    $sortWhereSQL";
-                }
             }
             else
             {
@@ -1087,30 +1074,29 @@ class eZSearchEngine
                     ezcontentobject_tree.node_id = ezcontentobject_tree.main_node_id
                     $versionNameJoins
                      ";
-                if ( $tmpTableCount == 0 )
-                {
-                    $searchCountQuery = "SELECT count( DISTINCT ezcontentobject.id ) AS count
-                    FROM
-                       ezcontentobject,
-                       ezcontentclass,
-                       ezcontentobject_tree
-                       $versionNameTables
-                    WHERE
-                    ezcontentobject.contentclass_id = ezcontentclass.id and
-                    ezcontentclass.version = '0' and
-                    ezcontentobject.id = ezcontentobject_tree.contentobject_id and
-                    ezcontentobject_tree.node_id = ezcontentobject_tree.main_node_id
-                    $versionNameJoins
-                     ";
-                }
             }
             // Count query
-            $where = "WHERE";
-            if ( $tmpTableCount == 1 )
-                $where = "";
-            if ( $tmpTableCount > 0 )
+            $languageCond = eZContentLanguage::languagesSQLFilter( 'ezcontentobject' );
+            if ( $tmpTableCount == 0 )
             {
-                $searchCountQuery = "SELECT count( * ) AS count FROM $tmpTablesFrom $where $tmpTablesWhere ";
+                $searchCountQuery = "SELECT count( DISTINCT ezcontentobject.id ) AS count
+                        FROM
+                           ezcontentobject,
+                           ezcontentobject_tree
+                        WHERE
+                        ezcontentobject.id = ezcontentobject_tree.contentobject_id and
+                        ezcontentobject_tree.node_id = ezcontentobject_tree.main_node_id
+                        AND $languageCond
+                        $showInvisibleNodesCond";
+            }
+            else
+            {
+                $searchCountQuery = "SELECT count( DISTINCT ezcontentobject.id ) AS count
+                        FROM $tmpTablesFrom $tmpTablesSeparator
+                             ezcontentobject
+                        WHERE $tmpTablesWhere $and
+                            $tmpTablesWhereExtra
+                            $languageCond";
             }
 
             $objectRes = array();
@@ -1119,9 +1105,9 @@ class eZSearchEngine
             if ( $nonExistingWordCount <= 0 )
             {
                 // execute search query
-                $objectResArray = $db->arrayQuery( $searchQuery, array( "limit" => $searchLimit, "offset" => $searchOffset ) );
+                $objectResArray = $db->arrayQuery( $searchQuery, array( "limit" => $searchLimit, "offset" => $searchOffset ), eZDBInterface::SERVER_SLAVE );
                 // execute search count query
-                $objectCountRes = $db->arrayQuery( $searchCountQuery );
+                $objectCountRes = $db->arrayQuery( $searchCountQuery, array(), eZDBInterface::SERVER_SLAVE );
                 $objectRes = eZContentObjectTreeNode::makeObjectsArray( $objectResArray );
                 $searchCount = $objectCountRes[0]['count'];
             }
@@ -1142,7 +1128,6 @@ class eZSearchEngine
                           "SearchCount" => 0,
                           "StopWordArray" => array() );
         }
-        ini_set(  "OCI_COMMIT_ON_SUCCESS", 1 );
     }
 
     /*!
@@ -1205,7 +1190,6 @@ class eZSearchEngine
                         } break;
                         case 'class_name':
                         {
-                            //include_once( 'kernel/classes/ezcontentobjectname.php' );
                             $classNameFilter = eZContentClassName::sqlFilter();
                             $sortingFields .= $classNameFilter['nameField'];
                             $attributeFromSQL .= ", $classNameFilter[from]";
@@ -1223,7 +1207,12 @@ class eZSearchEngine
                         {
                             $sortClassID = $sortBy[2];
                             // Look up datatype for sorting
-                            $sortDataType = eZContentObjectTreeNode::sortKeyByClassAttributeID( $sortClassID );
+                            if ( !is_numeric( $sortClassID ) )
+                            {
+                                $sortClassID = eZContentObjectTreeNode::classAttributeIDByIdentifier( $sortClassID );
+                            }
+
+                            $sortDataType = $sortClassID === false ? false : eZContentObjectTreeNode::sortKeyByClassAttributeID( $sortClassID );
 
                             $sortKey = false;
                             if ( $sortDataType == 'string' )
@@ -1343,7 +1332,7 @@ class eZSearchEngine
         $text = preg_replace("(\s+)", " ", $text );
 
         // Split text on whitespace
-        $wordArray = split( " ", $text );
+        $wordArray = explode( ' ', $text );
 
         $retArray = array();
         foreach ( $wordArray as $word )
@@ -1364,7 +1353,6 @@ class eZSearchEngine
     */
     function normalizeText( $text, $isMetaData = false )
     {
-        //include_once( 'lib/ezi18n/classes/ezchartransform.php' );
         $trans = eZCharTransform::instance();
         $text = $trans->transformByGroup( $text, 'search' );
 
@@ -1596,7 +1584,7 @@ class eZSearchEngine
         $wordIDArrays = $this->prepareWordIDArraysForPattern( $searchText );
         $wordIDArray = $wordIDArrays['wordIDArray'];
         $wordIDHash = $wordIDArrays['wordIDHash'];
-        $wildIDArray = $wordIDArrays['wildIDArray'];
+        $wildIDArray = array();
         $patternWordIDHash = $wordIDArrays['patternWordIDHash'];
 
         $searchWordArray = $this->splitString( $searchText );
@@ -1710,7 +1698,8 @@ class eZSearchEngine
                     ezcontentclass.version = '0' and
                     ezcontentobject.id = ezcontentobject_tree.contentobject_id and
                     ezcontentobject_tree.node_id = ezcontentobject_tree.main_node_id
-                    $sqlPermissionChecking[where]" );
+                    $sqlPermissionChecking[where]",
+                    eZDBInterface::SERVER_SLAVE );
         }
         else
         {
@@ -1740,7 +1729,8 @@ class eZSearchEngine
                     ezcontentclass.version = '0' and
                     ezcontentobject.id = ezcontentobject_tree.contentobject_id and
                     ezcontentobject_tree.node_id = ezcontentobject_tree.main_node_id
-                    $sqlPermissionChecking[where]" );
+                    $sqlPermissionChecking[where]",
+                    eZDBInterface::SERVER_SLAVE );
         }
 
         $tmpTableI = $this->getSavedTempTableName( $i );
@@ -1854,7 +1844,8 @@ class eZSearchEngine
                     ezcontentclass.version = '0' and
                     ezcontentobject.id = ezcontentobject_tree.contentobject_id and
                     ezcontentobject_tree.node_id = ezcontentobject_tree.main_node_id
-                    $sqlPermissionChecking[where]" );
+                    $sqlPermissionChecking[where]",
+                    eZDBInterface::SERVER_SLAVE );
                 }
                 else
                 {
@@ -1884,7 +1875,8 @@ class eZSearchEngine
                     ezcontentclass.version = '0' and
                     ezcontentobject.id = ezcontentobject_tree.contentobject_id and
                     ezcontentobject_tree.node_id = ezcontentobject_tree.main_node_id
-                    $sqlPermissionChecking[where]" );
+                    $sqlPermissionChecking[where]",
+                    eZDBInterface::SERVER_SLAVE );
                 }
                 $i++;
             }
@@ -2218,14 +2210,7 @@ class eZSearchEngine
             return false;
         }
 
-        if ( $this->UseOldCall )
-        {
-            return call_user_method_array( $methodName, $this, $parameterArray );
-        }
-        else
-        {
-            return $this->$methodName($parameterArray[0]);
-        }
+        return call_user_func_array( array( $this, $methodName ), $parameterArray );
     }
 
     /*!
@@ -2320,7 +2305,6 @@ class eZSearchEngine
     }
 
 
-    public $UseOldCall = false;
     public $TempTablesCount = 0;
     public $CreatedTempTablesNames = array();
 }
