@@ -5,9 +5,9 @@
 // Created on: <08-Nov-2002 11:00:54 kd>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -34,17 +34,20 @@ define( 'EZ_SETUP_TEST_FAILURE', 2 );
 function eZSetupTestTable()
 {
     return array( 'phpversion' => array( 'eZSetupTestPhpVersion' ),
+                  'variables_order' => array( 'eZSetupTestVariablesOrder' ),
                   'php_session' => array( 'eZSetupTestExtension' ),
                   'directory_permissions' => array( 'eZSetupTestDirectoryPermissions' ),
                   'settings_permission' => array( 'eZSetupTestFilePermissions' ),
-                  'autoload_permission' => array( 'eZSetupTestFilePermissions' ),
                   'database_extensions' => array( 'eZSetupTestExtension' ),
                   'database_all_extensions' => array( 'eZSetupTestExtension' ),
                   'php_magicquotes' => array( 'eZSetupCheckMagicQuotes' ),
                   'magic_quotes_runtime' => array( 'eZSetupCheckMagicQuotesRuntime' ),
                   'php_register_globals' => array( 'eZSetupCheckRegisterGlobals' ),
                   'mbstring_extension' => array( 'eZSetupMBStringExtension' ),
+                  'curl_extension' => array( 'eZSetupTestExtension' ),
                   'zlib_extension' => array( 'eZSetupTestExtension' ),
+                  'dom_extension' => array( 'eZSetupTestExtension' ),
+                  'iconv_extension' => array( 'eZSetupTestExtension' ),
                   'file_upload' => array( 'eZSetupTestFileUpload' ),
                   'open_basedir' => array( 'eZSetupTestOpenBasedir' ),
                   'safe_mode' => array( 'eZSetupTestSafeMode' ),
@@ -55,7 +58,9 @@ function eZSetupTestTable()
                   'memory_limit' => array( 'eZSetupTestMemLimit' ),
                   'execution_time' => array( 'eZSetupTestExecutionTime' ),
                   'allow_url_fopen' => array( 'eZSetupTestAllowURLFOpen' ),
-                  'accept_path_info' => array( 'eZSetupTestAcceptPathInfo' ) );
+                  'accept_path_info' => array( 'eZSetupTestAcceptPathInfo' ),
+                  'timezone' => array( 'eZSetupTestTimeZone' ),
+                  'ezcversion' => array( 'eZSetupTestComponentsVersion' ) );
 }
 
 function eZSetupConfigVariable( $type, $name )
@@ -86,7 +91,6 @@ function eZSetupRunTests( $testList, $client, &$givenPersistentList )
     $persistenceResults = array();
     $testResult = EZ_SETUP_TEST_SUCCESS;
     $successCount = 0;
-    //include_once( 'lib/ezutils/classes/ezhttptool.php' );
     $http = eZHTTPTool::instance();
     foreach ( $testList as $testItem )
     {
@@ -266,6 +270,40 @@ function eZSetupCheckMagicQuotes( $type )
                   'persistent_data' => array( 'result' => array( 'value' => $result ) ) );
 }
 
+/*!
+    Test if eZ Components version is greater than required version
+    This is currently done by checking existence of class and function
+    since ezc does not have an api to get version information atm.
+*/
+function eZSetupTestComponentsVersion( $type )
+{
+    $minVersion = eZSetupConfigVariable( $type, 'MinimumVersion' );
+    $testClass = eZSetupConfigVariable( $type, 'TestClass' );
+    $testFunction = eZSetupConfigVariable( $type, 'TestFunction' );
+    $result = true;
+    $ezcExists = true;
+
+    if ( $testClass && class_exists( $testClass ) )
+    {
+        if ( $testFunction && !is_callable( array( $testClass, $testFunction ) ) )
+        {
+            $result = false;
+        }
+    }
+    else if ( $testClass )
+    {
+        $result = false;
+        $ezcExists = false;
+    }
+
+    return array( 'result' => $result,
+                  'persistent_data' => array( 'result' => array( 'value' => $result ),
+                                              'required' => array( 'value' => $minVersion ) ),
+                  'needed_version' => $minVersion,
+                  'class_exists' => !$ezcExists );
+}
+
+
 /*!
     Test if PHP version is equal or greater than required version
 */
@@ -276,7 +314,7 @@ function eZSetupTestPhpVersion( $type )
 
     /*
      // Get the operating systems name
-    $operatingSystem = split( " ", php_uname() );
+    $operatingSystem = explode( ' ', php_uname() );
     $operatingSystem = strtolower( $operatingSystem[0] );
 
     // Find out if there is an os specific version needed
@@ -321,6 +359,19 @@ function eZSetupTestPhpVersion( $type )
                   'warning_version' => $warningVersion );
 }
 
+function eZSetupTestVariablesOrder( $type )
+{
+    $variablesOrder = ini_get( 'variables_order' );
+    $result = strpos( $variablesOrder, 'E' ) !== false;
+    return array(
+        'result' => $result,
+        'persistent_data' => array(
+            'result' => array( 'value' => $result ),
+            'found' => array( 'value' => $variablesOrder )
+         )
+    );
+}
+
 /*!
   Test if allowed to open URLs using fopen
 */
@@ -445,8 +496,6 @@ function eZSetupTestExtension( $type )
 
 function eZSetupTestDirectoryPermissions( $type )
 {
-    //include_once( 'lib/ezfile/classes/ezdir.php' );
-
     $dirList = eZSetupConfigVariableArray( $type, 'CheckList' );
 
     $ini = eZINI::instance();
@@ -478,7 +527,7 @@ function eZSetupTestDirectoryPermissions( $type )
                 $dirPath = './' . $dir;
             else
                 $dirPath = $rootDir . '/' . $dir;
-            $res = @mkdir( $dirPath, $dirPermOctal );
+            $res = eZDir::mkdir( $dirPath, $dirPermOctal );
             if ( $res )
             {
                 $resultElement['permission'] = $dirPermission;
@@ -522,8 +571,6 @@ function eZSetupTestDirectoryPermissions( $type )
 function eZSetupTestFilePermissions( $type )
 {
     $fileList = eZSetupConfigVariableArray( $type, 'CheckList' );
-    //include_once( 'lib/ezfile/classes/ezdir.php' );
-
     $ini = eZINI::instance();
     $dirPermission = $ini->variable( 'FileSettings', 'StorageDirPermissions' );
     $filePermission = $ini->variable( 'FileSettings', 'StorageFilePermissions' );
@@ -608,9 +655,6 @@ function eZSetupPrvPosixExtension()
 */
 function eZSetupCheckExecutable( $type )
 {
-    //include_once( 'lib/ezutils/classes/ezsys.php' );
-    //include_once( 'lib/ezfile/classes/ezdir.php' );
-    //include_once( 'lib/ezutils/classes/ezhttptool.php' );
     $http = eZHTTPTool::instance();
 
     $filesystemType = eZSys::filesystemType();
@@ -775,7 +819,6 @@ function eZSetupCheckGDVersion( $type )
 */
 function eZSetupMBStringExtension( $type )
 {
-    //include_once( "lib/ezi18n/classes/ezmbstringmapper.php" );
     $result = eZMBStringMapper::hasMBStringExtension();
     $charsetList = eZMBStringMapper::charsetList();
     return array( 'result' => $result,
@@ -869,6 +912,7 @@ function eZSetupTestOpenBasedir( $type )
     if ( $openBasedir != '' and
          $openBasedir != '.' )
     {
+        $returnData['result'] = false;
         $returnData['warnings'] = array( array( 'name' => 'open_basedir',
                                                 'text' => array( 'open_basedir is in use and can give problems running eZ Publish due to bugs in some PHP versions.',
                                                                  'It\'s recommended that it is turned off if you experience problems running eZ Publish.' ) ) );
@@ -957,7 +1001,6 @@ function eZSetupPrvtExtractExtraPaths( &$givenPersistentList )
  */
 function eZSetupPrvtAreDirAndFilesWritable( $dir )
 {
-    //include_once( 'lib/ezfile/classes/ezfile.php' );
     if ( !eZDir::isWriteable( $dir ) )
         return FALSE;
 
@@ -974,4 +1017,15 @@ function eZSetupPrvtAreDirAndFilesWritable( $dir )
    return TRUE;
 }
 
+function eZSetupTestTimeZone( $something )
+{
+    $result = true;
+    if ( date_default_timezone_get() == "UTC" )
+    {
+        $result = false;
+    }
+
+    return array( 'result' => $result );
+}
+
 ?>
