@@ -3,7 +3,7 @@ CREATE TABLE ezapprove_items (
   id int(11) NOT NULL auto_increment,
   workflow_process_id int(11) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -16,7 +16,7 @@ CREATE TABLE ezbasket (
   session_id varchar(255) NOT NULL default '',
   PRIMARY KEY  (id),
   KEY ezbasket_session_id (session_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -26,11 +26,76 @@ CREATE TABLE ezbinaryfile (
   contentobject_attribute_id int(11) NOT NULL default '0',
   download_count int(11) NOT NULL default '0',
   filename varchar(255) NOT NULL default '',
-  mime_type varchar(50) NOT NULL default '',
+  mime_type varchar(255) NOT NULL default '',
   original_filename varchar(255) NOT NULL default '',
   version int(11) NOT NULL default '0',
   PRIMARY KEY  (contentobject_attribute_id,version)
-);
+) ENGINE=InnoDB;
+
+
+
+
+
+CREATE TABLE ezcobj_state (
+  default_language_id int(11) NOT NULL default '0',
+  group_id int(11) NOT NULL default '0',
+  id int(11) NOT NULL auto_increment,
+  identifier varchar(45) NOT NULL default '',
+  language_mask int(11) NOT NULL default '0',
+  priority int(11) NOT NULL default '0',
+  PRIMARY KEY  (id),
+  UNIQUE KEY ezcobj_state_identifier (group_id,identifier),
+  KEY ezcobj_state_lmask (language_mask),
+  KEY ezcobj_state_priority (priority)
+) ENGINE=InnoDB;
+
+
+
+
+
+CREATE TABLE ezcobj_state_group (
+  default_language_id int(11) NOT NULL default '0',
+  id int(11) NOT NULL auto_increment,
+  identifier varchar(45) NOT NULL default '',
+  language_mask int(11) NOT NULL default '0',
+  PRIMARY KEY  (id),
+  UNIQUE KEY ezcobj_state_group_identifier (identifier),
+  KEY ezcobj_state_group_lmask (language_mask)
+) ENGINE=InnoDB;
+
+
+
+
+
+CREATE TABLE ezcobj_state_group_language (
+  contentobject_state_group_id int(11) NOT NULL default '0',
+  description longtext NOT NULL,
+  language_id int(11) NOT NULL default '0',
+  name varchar(45) NOT NULL default '',
+  PRIMARY KEY  (contentobject_state_group_id,language_id)
+) ENGINE=InnoDB;
+
+
+
+
+
+CREATE TABLE ezcobj_state_language (
+  contentobject_state_id int(11) NOT NULL default '0',
+  description longtext NOT NULL,
+  language_id int(11) NOT NULL default '0',
+  name varchar(45) NOT NULL default '',
+  PRIMARY KEY  (contentobject_state_id,language_id)
+) ENGINE=InnoDB;
+
+
+
+
+
+CREATE TABLE ezcobj_state_link (
+  contentobject_id int(11) NOT NULL default '0',
+  contentobject_state_id int(11) NOT NULL default '0',
+  PRIMARY KEY  (contentobject_id,contentobject_state_id)
+) ENGINE=InnoDB;
 
 
 
@@ -50,7 +115,7 @@ CREATE TABLE ezcollab_group (
   PRIMARY KEY  (id),
   KEY ezcollab_group_depth (depth),
   KEY ezcollab_group_path (path_string)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -73,7 +138,7 @@ CREATE TABLE ezcollab_item (
   status int(11) NOT NULL default '1',
   type_identifier varchar(40) NOT NULL default '',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -89,7 +154,7 @@ CREATE TABLE ezcollab_item_group_link (
   modified int(11) NOT NULL default '0',
   user_id int(11) NOT NULL default '0',
   PRIMARY KEY  (collaboration_id,group_id,user_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -104,7 +169,7 @@ CREATE TABLE ezcollab_item_message_link (
   modified int(11) NOT NULL default '0',
   participant_id int(11) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -121,7 +186,7 @@ CREATE TABLE ezcollab_item_participant_link (
   participant_role int(11) NOT NULL default '1',
   participant_type int(11) NOT NULL default '1',
   PRIMARY KEY  (collaboration_id,participant_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -134,7 +199,7 @@ CREATE TABLE ezcollab_item_status (
   last_read int(11) NOT NULL default '0',
   user_id int(11) NOT NULL default '0',
   PRIMARY KEY  (collaboration_id,user_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -145,7 +210,7 @@ CREATE TABLE ezcollab_notification_rule (
   id int(11) NOT NULL auto_increment,
   user_id varchar(255) NOT NULL default '',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -159,7 +224,7 @@ CREATE TABLE ezcollab_profile (
   modified int(11) NOT NULL default '0',
   user_id int(11) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -181,7 +246,7 @@ CREATE TABLE ezcollab_simple_message (
   message_type varchar(40) NOT NULL default '',
   modified int(11) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -192,8 +257,9 @@ CREATE TABLE ezcontent_language (
   id int(11) NOT NULL default '0',
   locale varchar(20) NOT NULL default '',
   name varchar(255) NOT NULL default '',
-  PRIMARY KEY  (id)
-);
+  PRIMARY KEY  (id),
+  KEY ezcontent_language_name (name)
+) ENGINE=InnoDB;
 
 
 
@@ -206,7 +272,7 @@ CREATE TABLE ezcontentbrowsebookmark (
   user_id int(11) NOT NULL default '0',
   PRIMARY KEY  (id),
   KEY ezcontentbrowsebookmark_user (user_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -220,7 +286,7 @@ CREATE TABLE ezcontentbrowserecent (
   user_id int(11) NOT NULL default '0',
   PRIMARY KEY  (id),
   KEY ezcontentbrowserecent_user (user_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -246,7 +312,7 @@ CREATE TABLE ezcontentclass (
   version int(11) NOT NULL default '0',
   PRIMARY KEY  (id,version),
   KEY ezcontentclass_version (version)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -279,7 +345,7 @@ CREATE TABLE ezcontentclass_attribute (
   version int(11) NOT NULL default '0',
   PRIMARY KEY  (id,version),
   KEY ezcontentclass_attr_ccid (contentclass_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -291,7 +357,7 @@ CREATE TABLE ezcontentclass_classgroup (
   group_id int(11) NOT NULL default '0',
   group_name varchar(255) default NULL,
   PRIMARY KEY  (contentclass_id,contentclass_version,group_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -304,7 +370,7 @@ CREATE TABLE ezcontentclass_name (
   language_locale varchar(20) NOT NULL default '',
   name varchar(255) NOT NULL default '',
   PRIMARY KEY  (contentclass_id,contentclass_version,language_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -318,7 +384,7 @@ CREATE TABLE ezcontentclassgroup (
   modifier_id int(11) NOT NULL default '0',
   name varchar(255) default NULL,
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -342,9 +408,11 @@ CREATE TABLE ezcontentobject (
   KEY ezcontentobject_classid (contentclass_id),
   KEY ezcontentobject_currentversion (current_version),
   KEY ezcontentobject_lmask (language_mask),
+  KEY ezcontentobject_owner (owner_id),
   KEY ezcontentobject_pub (published),
+  UNIQUE KEY ezcontentobject_remote_id (remote_id),
   KEY ezcontentobject_status (status)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -371,7 +439,7 @@ CREATE TABLE ezcontentobject_attribute (
   KEY ezcontentobject_attribute_language_code (language_code),
   KEY sort_key_int (sort_key_int),
   KEY sort_key_string (sort_key_string)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -388,7 +456,7 @@ CREATE TABLE ezcontentobject_link (
   PRIMARY KEY  (id),
   KEY ezco_link_from (from_contentobject_id,from_contentobject_version,contentclassattribute_id),
   KEY ezco_link_to_co_id (to_contentobject_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -406,7 +474,7 @@ CREATE TABLE ezcontentobject_name (
   KEY ezcontentobject_name_cov_id (content_version),
   KEY ezcontentobject_name_lang_id (language_id),
   KEY ezcontentobject_name_name (name)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -435,7 +503,7 @@ CREATE TABLE ezcontentobject_trash (
   KEY ezcobj_trash_p_node_id (parent_node_id),
   KEY ezcobj_trash_path (path_string),
   KEY ezcobj_trash_path_ident (path_identification_string(50))
-);
+) ENGINE=InnoDB;
 
 
 
@@ -465,7 +533,7 @@ CREATE TABLE ezcontentobject_tree (
   KEY ezcontentobject_tree_path (path_string),
   KEY ezcontentobject_tree_path_ident (path_identification_string(50)),
   KEY modified_subnode (modified_subnode)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -487,7 +555,7 @@ CREATE TABLE ezcontentobject_version (
   KEY ezcobj_version_creator_id (creator_id),
   KEY ezcobj_version_status (status),
   KEY idx_object_version_objver (contentobject_id,version)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -504,7 +572,7 @@ CREATE TABLE ezcurrencydata (
   symbol varchar(255) NOT NULL default '',
   PRIMARY KEY  (id),
   KEY ezcurrencydata_code (code)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -514,7 +582,7 @@ CREATE TABLE ezdiscountrule (
   id int(11) NOT NULL auto_increment,
   name varchar(255) NOT NULL default '',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -527,7 +595,7 @@ CREATE TABLE ezdiscountsubrule (
   limitation char(1) default NULL,
   name varchar(255) NOT NULL default '',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -538,7 +606,7 @@ CREATE TABLE ezdiscountsubrule_value (
   issection int(11) NOT NULL default '0',
   value int(11) NOT NULL default '0',
   PRIMARY KEY  (discountsubrule_id,value,issection)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -552,7 +620,7 @@ CREATE TABLE ezenumobjectvalue (
   enumvalue varchar(255) NOT NULL default '',
   PRIMARY KEY  (contentobject_attribute_id,contentobject_attribute_version,enumid),
   KEY ezenumobjectvalue_co_attr_id_co_attr_ver (contentobject_attribute_id,contentobject_attribute_version)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -567,7 +635,7 @@ CREATE TABLE ezenumvalue (
   placement int(11) NOT NULL default '0',
   PRIMARY KEY  (id,contentclass_attribute_id,contentclass_attribute_version),
   KEY ezenumvalue_co_cl_attr_id_co_class_att_ver (contentclass_attribute_id,contentclass_attribute_version)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -578,8 +646,9 @@ CREATE TABLE ezforgot_password (
   id int(11) NOT NULL auto_increment,
   time int(11) NOT NULL default '0',
   user_id int(11) NOT NULL default '0',
-  PRIMARY KEY  (id)
-);
+  PRIMARY KEY  (id),
+  KEY ezforgot_password_user (user_id)
+) ENGINE=InnoDB;
 
 
 
@@ -592,22 +661,9 @@ CREATE TABLE ezgeneral_digest_user_settings (
   id int(11) NOT NULL auto_increment,
   receive_digest int(11) NOT NULL default '0',
   time varchar(255) NOT NULL default '',
-  PRIMARY KEY  (id)
-);
-
-
-
-
-
-CREATE TABLE ezimage (
-  alternative_text varchar(255) NOT NULL default '',
-  contentobject_attribute_id int(11) NOT NULL default '0',
-  filename varchar(255) NOT NULL default '',
-  mime_type varchar(50) NOT NULL default '',
-  original_filename varchar(255) NOT NULL default '',
-  version int(11) NOT NULL default '0',
-  PRIMARY KEY  (contentobject_attribute_id,version)
-);
+  PRIMARY KEY  (id),
+  UNIQUE KEY ezgeneral_digest_user_settings_address (address)
+) ENGINE=InnoDB;
 
 
 
@@ -620,23 +676,7 @@ CREATE TABLE ezimagefile (
   PRIMARY KEY  (id),
   KEY ezimagefile_coid (contentobject_attribute_id),
   KEY ezimagefile_file (filepath(200))
-);
-
-
-
-
-
-CREATE TABLE ezimagevariation (
-  additional_path varchar(255) default NULL,
-  contentobject_attribute_id int(11) NOT NULL default '0',
-  filename varchar(255) NOT NULL default '',
-  height int(11) NOT NULL default '0',
-  requested_height int(11) NOT NULL default '0',
-  requested_width int(11) NOT NULL default '0',
-  version int(11) NOT NULL default '0',
-  width int(11) NOT NULL default '0',
-  PRIMARY KEY  (contentobject_attribute_id,version,requested_width,requested_height)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -650,7 +690,7 @@ CREATE TABLE ezinfocollection (
   modified int(11) default '0',
   user_identifier varchar(34) default NULL,
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -667,7 +707,7 @@ CREATE TABLE ezinfocollection_attribute (
   informationcollection_id int(11) NOT NULL default '0',
   PRIMARY KEY  (id),
   KEY ezinfocollection_attr_co_id (contentobject_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -678,7 +718,7 @@ CREATE TABLE ezisbn_group (
   group_number int(11) NOT NULL default '0',
   id int(11) NOT NULL auto_increment,
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -692,7 +732,7 @@ CREATE TABLE ezisbn_group_range (
   id int(11) NOT NULL auto_increment,
   to_number int(11) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -707,7 +747,7 @@ CREATE TABLE ezisbn_registrant_range (
   registrant_to varchar(32) NOT NULL default '',
   to_number int(11) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -720,7 +760,7 @@ CREATE TABLE ezkeyword (
   PRIMARY KEY  (id),
   KEY ezkeyword_keyword (keyword),
   KEY ezkeyword_keyword_id (keyword,id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -733,7 +773,7 @@ CREATE TABLE ezkeyword_attribute_link (
   PRIMARY KEY  (id),
   KEY ezkeyword_attr_link_keyword_id (keyword_id),
   KEY ezkeyword_attr_link_kid_oaid (keyword_id,objectattribute_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -754,7 +794,7 @@ CREATE TABLE ezmedia (
   version int(11) NOT NULL default '0',
   width int(11) default NULL,
   PRIMARY KEY  (contentobject_attribute_id,version)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -770,7 +810,7 @@ CREATE TABLE ezmessage (
   send_weekday varchar(50) NOT NULL default '',
   title varchar(255) NOT NULL default '',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -784,7 +824,7 @@ CREATE TABLE ezmodule_run (
   workflow_process_id int(11) default NULL,
   PRIMARY KEY  (id),
   UNIQUE KEY ezmodule_run_workflow_process_id_s (workflow_process_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -801,7 +841,7 @@ CREATE TABLE ezmultipricedata (
   KEY ezmultipricedata_coa_id (contentobject_attr_id),
   KEY ezmultipricedata_coa_version (contentobject_attr_version),
   KEY ezmultipricedata_currency_code (currency_code)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -825,7 +865,7 @@ CREATE TABLE eznode_assignment (
   KEY eznode_assignment_coid_cov (contentobject_id,contentobject_version),
   KEY eznode_assignment_is_main (is_main),
   KEY eznode_assignment_parent_node (parent_node)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -839,7 +879,7 @@ CREATE TABLE eznotificationcollection (
   id int(11) NOT NULL auto_increment,
   transport varchar(255) NOT NULL default '',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -852,7 +892,7 @@ CREATE TABLE eznotificationcollection_item (
   id int(11) NOT NULL auto_increment,
   send_date int(11) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -871,7 +911,7 @@ CREATE TABLE eznotificationevent (
   id int(11) NOT NULL auto_increment,
   status int(11) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -885,7 +925,7 @@ CREATE TABLE ezoperation_memento (
   memento_key varchar(32) NOT NULL default '',
   PRIMARY KEY  (id,memento_key),
   KEY ezoperation_memento_memento_key_main (memento_key,main)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -910,7 +950,7 @@ CREATE TABLE ezorder (
   PRIMARY KEY  (id),
   KEY ezorder_is_archived (is_archived),
   KEY ezorder_is_tmp (is_temporary)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -923,11 +963,11 @@ CREATE TABLE ezorder_item (
   order_id int(11) NOT NULL default '0',
   price float default NULL,
   type varchar(30) default NULL,
-  vat_value int(11) NOT NULL default '0',
+  vat_value float NOT NULL default '0',
   PRIMARY KEY  (id),
   KEY ezorder_item_order_id (order_id),
   KEY ezorder_item_type (type)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -942,7 +982,7 @@ CREATE TABLE ezorder_status (
   KEY ezorder_status_active (is_active),
   KEY ezorder_status_name (name),
   KEY ezorder_status_sid (status_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -958,7 +998,7 @@ CREATE TABLE ezorder_status_history (
   KEY ezorder_status_history_mod (modified),
   KEY ezorder_status_history_oid (order_id),
   KEY ezorder_status_history_sid (status_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -970,7 +1010,7 @@ CREATE TABLE ezpackage (
   name varchar(100) NOT NULL default '',
   version varchar(30) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -983,7 +1023,7 @@ CREATE TABLE ezpaymentobject (
   status int(11) NOT NULL default '0',
   workflowprocess_id int(11) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1007,7 +1047,7 @@ CREATE TABLE ezpdf_export (
   title varchar(255) default NULL,
   version int(11) NOT NULL default '0',
   PRIMARY KEY  (id,version)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1015,9 +1055,11 @@ CREATE TABLE ezpdf_export (
 
 CREATE TABLE ezpending_actions (
   action varchar(64) NOT NULL default '',
+  created int(11) default NULL,
   param longtext,
-  KEY ezpending_actions_action (action)
-);
+  KEY ezpending_actions_action (action),
+  KEY ezpending_actions_created (created)
+) ENGINE=InnoDB;
 
 
 
@@ -1029,7 +1071,7 @@ CREATE TABLE ezpolicy (
   module_name varchar(255) default NULL,
   role_id int(11) default NULL,
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1040,7 +1082,7 @@ CREATE TABLE ezpolicy_limitation (
   identifier varchar(255) NOT NULL default '',
   policy_id int(11) default NULL,
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1052,7 +1094,7 @@ CREATE TABLE ezpolicy_limitation_value (
   value varchar(255) default NULL,
   PRIMARY KEY  (id),
   KEY ezpolicy_limitation_value_val (value)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1066,7 +1108,7 @@ CREATE TABLE ezpreferences (
   PRIMARY KEY  (id),
   KEY ezpreferences_name (name),
   KEY ezpreferences_user_id_idx (user_id,name)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1076,7 +1118,7 @@ CREATE TABLE ezproductcategory (
   id int(11) NOT NULL auto_increment,
   name varchar(255) NOT NULL default '',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1087,7 +1129,7 @@ CREATE TABLE ezproductcollection (
   currency_code varchar(4) NOT NULL default '',
   id int(11) NOT NULL auto_increment,
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1106,7 +1148,7 @@ CREATE TABLE ezproductcollection_item (
   PRIMARY KEY  (id),
   KEY ezproductcollection_item_contentobject_id (contentobject_id),
   KEY ezproductcollection_item_productcollection_id (productcollection_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1122,7 +1164,7 @@ CREATE TABLE ezproductcollection_item_opt (
   value varchar(255) NOT NULL default '',
   PRIMARY KEY  (id),
   KEY ezproductcollection_item_opt_item_id (item_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1135,7 +1177,7 @@ CREATE TABLE ezrole (
   value char(1) default NULL,
   version int(11) default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1152,6 +1194,7 @@ CREATE TABLE ezrss_export (
   main_node_only int(11) NOT NULL default '1',
   modified int(11) default NULL,
   modifier_id int(11) default NULL,
+  node_id int(11) default NULL,
   number_of_objects int(11) NOT NULL default '0',
   rss_version varchar(255) default NULL,
   site_access varchar(255) default NULL,
@@ -1159,13 +1202,14 @@ CREATE TABLE ezrss_export (
   title varchar(255) default NULL,
   url varchar(255) default NULL,
   PRIMARY KEY  (id,status)
-);
+) ENGINE=InnoDB;
 
 
 
 
 
 CREATE TABLE ezrss_export_item (
+  category varchar(255) default NULL,
   class_id int(11) default NULL,
   description varchar(255) default NULL,
   id int(11) NOT NULL auto_increment,
@@ -1176,7 +1220,7 @@ CREATE TABLE ezrss_export_item (
   title varchar(255) default NULL,
   PRIMARY KEY  (id,status),
   KEY ezrss_export_rsseid (rssexport_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1200,7 +1244,7 @@ CREATE TABLE ezrss_import (
   status int(11) NOT NULL default '0',
   url longtext,
   PRIMARY KEY  (id,status)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1226,7 +1270,7 @@ CREATE TABLE ezsearch_object_word_link (
   KEY ezsearch_object_word_link_integer_value (integer_value),
   KEY ezsearch_object_word_link_object (contentobject_id),
   KEY ezsearch_object_word_link_word (word_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1239,7 +1283,7 @@ CREATE TABLE ezsearch_return_count (
   time int(11) NOT NULL default '0',
   PRIMARY KEY  (id),
   KEY ezsearch_return_cnt_ph_id_cnt (phrase_id,count)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1253,7 +1297,7 @@ CREATE TABLE ezsearch_search_phrase (
   PRIMARY KEY  (id),
   KEY ezsearch_search_phrase_count (phrase_count),
   UNIQUE KEY ezsearch_search_phrase_phrase (phrase)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1266,7 +1310,7 @@ CREATE TABLE ezsearch_word (
   PRIMARY KEY  (id),
   KEY ezsearch_word_obj_count (object_count),
   KEY ezsearch_word_word_i (word)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1278,7 +1322,7 @@ CREATE TABLE ezsection (
   name varchar(255) default NULL,
   navigation_part_identifier varchar(100) default 'ezcontentnavigationpart',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1288,11 +1332,12 @@ CREATE TABLE ezsession (
   data longtext NOT NULL,
   expiration_time int(11) NOT NULL default '0',
   session_key varchar(32) NOT NULL default '',
+  user_hash varchar(32) NOT NULL default '',
   user_id int(11) NOT NULL default '0',
   PRIMARY KEY  (session_key),
   KEY expiration_time (expiration_time),
   KEY ezsession_user_id (user_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1302,7 +1347,7 @@ CREATE TABLE ezsite_data (
   name varchar(60) NOT NULL default '',
   value longtext NOT NULL,
   PRIMARY KEY  (name)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1315,7 +1360,7 @@ CREATE TABLE ezsubtree_notification_rule (
   user_id int(11) NOT NULL default '0',
   PRIMARY KEY  (id),
   KEY ezsubtree_notification_rule_user_id (user_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1326,7 +1371,7 @@ CREATE TABLE eztipafriend_counter (
   node_id int(11) NOT NULL default '0',
   requested int(11) NOT NULL default '0',
   PRIMARY KEY  (node_id,requested)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1337,7 +1382,7 @@ CREATE TABLE eztipafriend_request (
   email_receiver varchar(100) NOT NULL default '',
   KEY eztipafriend_request_created (created),
   KEY eztipafriend_request_email_rec (email_receiver)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1353,7 +1398,7 @@ CREATE TABLE eztrigger (
   PRIMARY KEY  (id),
   UNIQUE KEY eztrigger_def_id (module_name(50),function_name(50),connect_type),
   KEY eztrigger_fetch (name(25),module_name(50),function_name(50))
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1369,7 +1414,7 @@ CREATE TABLE ezurl (
   url longtext,
   PRIMARY KEY  (id),
   KEY ezurl_url (url(255))
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1382,7 +1427,7 @@ CREATE TABLE ezurl_object_link (
   KEY ezurl_ol_coa_id (contentobject_attribute_id),
   KEY ezurl_ol_coa_version (contentobject_attribute_version),
   KEY ezurl_ol_url_id (url_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1404,7 +1449,7 @@ CREATE TABLE ezurlalias (
   KEY ezurlalias_source_md5 (source_md5),
   KEY ezurlalias_source_url (source_url(255)),
   KEY ezurlalias_wcard_fwd (is_wildcard,forward_to_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1413,6 +1458,7 @@ CREATE TABLE ezurlalias (
 CREATE TABLE ezurlalias_ml (
   action longtext NOT NULL,
   action_type varchar(32) NOT NULL default '',
+  alias_redirects int(11) NOT NULL default '1',
   id int(11) NOT NULL default '0',
   is_alias int(11) NOT NULL default '0',
   is_original int(11) NOT NULL default '0',
@@ -1432,7 +1478,16 @@ CREATE TABLE ezurlalias_ml (
   KEY ezurlalias_ml_par_txt (parent,text(32)),
   KEY ezurlalias_ml_text (text(32),id,link),
   KEY ezurlalias_ml_text_lang (text(32),lang_mask,parent)
-);
+) ENGINE=InnoDB;
+
+
+
+
+
+CREATE TABLE ezurlalias_ml_incr (
+  id int(11) NOT NULL auto_increment,
+  PRIMARY KEY  (id)
+) ENGINE=InnoDB;
 
 
 
@@ -1444,7 +1499,7 @@ CREATE TABLE ezurlwildcard (
   source_url longtext NOT NULL,
   type int(11) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1457,7 +1512,7 @@ CREATE TABLE ezuser (
   password_hash varchar(50) default NULL,
   password_hash_type int(11) NOT NULL default '1',
   PRIMARY KEY  (contentobject_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1469,7 +1524,7 @@ CREATE TABLE ezuser_accountkey (
   time int(11) NOT NULL default '0',
   user_id int(11) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1481,7 +1536,7 @@ CREATE TABLE ezuser_discountrule (
   id int(11) NOT NULL auto_increment,
   name varchar(255) NOT NULL default '',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1496,7 +1551,7 @@ CREATE TABLE ezuser_role (
   PRIMARY KEY  (id),
   KEY ezuser_role_contentobject_id (contentobject_id),
   KEY ezuser_role_role_id (role_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1507,7 +1562,7 @@ CREATE TABLE ezuser_setting (
   max_login int(11) default NULL,
   user_id int(11) NOT NULL default '0',
   PRIMARY KEY  (user_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1517,9 +1572,11 @@ CREATE TABLE ezuservisit (
   current_visit_timestamp int(11) NOT NULL default '0',
   failed_login_attempts int(11) NOT NULL default '0',
   last_visit_timestamp int(11) NOT NULL default '0',
+  login_count int(11) NOT NULL default '0',
   user_id int(11) NOT NULL default '0',
-  PRIMARY KEY  (user_id)
-);
+  PRIMARY KEY  (user_id),
+  KEY ezuservisit_co_visit_count (current_visit_timestamp,login_count)
+) ENGINE=InnoDB;
 
 
 
@@ -1530,7 +1587,7 @@ CREATE TABLE ezvatrule (
   id int(11) NOT NULL auto_increment,
   vat_type int(11) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1540,7 +1597,7 @@ CREATE TABLE ezvatrule_product_category (
   product_category_id int(11) NOT NULL default '0',
   vatrule_id int(11) NOT NULL default '0',
   PRIMARY KEY  (vatrule_id,product_category_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1551,7 +1608,7 @@ CREATE TABLE ezvattype (
   name varchar(255) NOT NULL default '',
   percentage float default NULL,
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1561,7 +1618,7 @@ CREATE TABLE ezview_counter (
   count int(11) NOT NULL default '0',
   node_id int(11) NOT NULL default '0',
   PRIMARY KEY  (node_id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1575,7 +1632,7 @@ CREATE TABLE ezwaituntildatevalue (
   workflow_event_version int(11) NOT NULL default '0',
   PRIMARY KEY  (id,workflow_event_id,workflow_event_version),
   KEY ezwaituntildateevalue_wf_ev_id_wf_ver (workflow_event_id,workflow_event_version)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1586,7 +1643,7 @@ CREATE TABLE ezwishlist (
   productcollection_id int(11) NOT NULL default '0',
   user_id int(11) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1603,7 +1660,7 @@ CREATE TABLE ezworkflow (
   version int(11) NOT NULL default '0',
   workflow_type_string varchar(50) NOT NULL default '',
   PRIMARY KEY  (id,version)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1616,7 +1673,7 @@ CREATE TABLE ezworkflow_assign (
   node_id int(11) NOT NULL default '0',
   workflow_id int(11) NOT NULL default '0',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1627,10 +1684,11 @@ CREATE TABLE ezworkflow_event (
   data_int2 int(11) default NULL,
   data_int3 int(11) default NULL,
   data_int4 int(11) default NULL,
-  data_text1 varchar(50) default NULL,
-  data_text2 varchar(50) default NULL,
-  data_text3 varchar(50) default NULL,
-  data_text4 varchar(50) default NULL,
+  data_text1 varchar(255) default NULL,
+  data_text2 varchar(255) default NULL,
+  data_text3 varchar(255) default NULL,
+  data_text4 varchar(255) default NULL,
+  data_text5 longtext,
   description varchar(50) NOT NULL default '',
   id int(11) NOT NULL auto_increment,
   placement int(11) NOT NULL default '0',
@@ -1638,7 +1696,7 @@ CREATE TABLE ezworkflow_event (
   workflow_id int(11) NOT NULL default '0',
   workflow_type_string varchar(50) NOT NULL default '',
   PRIMARY KEY  (id,version)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1652,7 +1710,7 @@ CREATE TABLE ezworkflow_group (
   modifier_id int(11) NOT NULL default '0',
   name varchar(255) NOT NULL default '',
   PRIMARY KEY  (id)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1664,7 +1722,7 @@ CREATE TABLE ezworkflow_group_link (
   workflow_id int(11) NOT NULL default '0',
   workflow_version int(11) NOT NULL default '0',
   PRIMARY KEY  (workflow_id,group_id,workflow_version)
-);
+) ENGINE=InnoDB;
 
 
 
@@ -1694,7 +1752,7 @@ CREATE TABLE ezworkflow_process (
   workflow_id int(11) NOT NULL default '0',
   PRIMARY KEY  (id),
   KEY ezworkflow_process_process_key (process_key)
-);
+) ENGINE=InnoDB;
 
 
 
