@@ -35,6 +35,32 @@ CREATE SEQUENCE ezbasket_s
 
 
 
+CREATE SEQUENCE ezcobj_state_s
+    START 1
+    INCREMENT 1
+    MAXVALUE 9223372036854775807
+    MINVALUE 1
+    CACHE 1;
+
+
+
+
+
+
+
+CREATE SEQUENCE ezcobj_state_group_s
+    START 1
+    INCREMENT 1
+    MAXVALUE 9223372036854775807
+    MINVALUE 1
+    CACHE 1;
+
+
+
+
+
+
+
 CREATE SEQUENCE ezcollab_group_s
     START 1
     INCREMENT 1
@@ -893,6 +919,19 @@ CREATE SEQUENCE ezurlalias_s
 
 
 
+CREATE SEQUENCE ezurlalias_ml_incr_s
+    START 1
+    INCREMENT 1
+    MAXVALUE 9223372036854775807
+    MINVALUE 1
+    CACHE 1;
+
+
+
+
+
+
+
 CREATE SEQUENCE ezurlwildcard_s
     START 1
     INCREMENT 1
@@ -1091,7 +1130,7 @@ CREATE TABLE ezbinaryfile (
     contentobject_attribute_id integer DEFAULT 0 NOT NULL,
     download_count integer DEFAULT 0 NOT NULL,
     filename character varying(255) DEFAULT ''::character varying NOT NULL,
-    mime_type character varying(50) DEFAULT ''::character varying NOT NULL,
+    mime_type character varying(255) DEFAULT ''::character varying NOT NULL,
     original_filename character varying(255) DEFAULT ''::character varying NOT NULL,
     "version" integer DEFAULT 0 NOT NULL
 );
@@ -1102,6 +1141,71 @@ CREATE TABLE ezbinaryfile (
 
 
 
+CREATE TABLE ezcobj_state (
+    default_language_id integer DEFAULT 0 NOT NULL,
+    group_id integer DEFAULT 0 NOT NULL,
+    id integer DEFAULT nextval('ezcobj_state_s'::text) NOT NULL,
+    identifier character varying(45) DEFAULT ''::character varying NOT NULL,
+    language_mask integer DEFAULT 0 NOT NULL,
+    priority integer DEFAULT 0 NOT NULL
+);
+
+
+
+
+
+
+
+CREATE TABLE ezcobj_state_group (
+    default_language_id integer DEFAULT 0 NOT NULL,
+    id integer DEFAULT nextval('ezcobj_state_group_s'::text) NOT NULL,
+    identifier character varying(45) DEFAULT ''::character varying NOT NULL,
+    language_mask integer DEFAULT 0 NOT NULL
+);
+
+
+
+
+
+
+
+CREATE TABLE ezcobj_state_group_language (
+    contentobject_state_group_id integer DEFAULT 0 NOT NULL,
+    description text NOT NULL,
+    language_id integer DEFAULT 0 NOT NULL,
+    name character varying(45) DEFAULT ''::character varying NOT NULL
+);
+
+
+
+
+
+
+
+CREATE TABLE ezcobj_state_language (
+    contentobject_state_id integer DEFAULT 0 NOT NULL,
+    description text NOT NULL,
+    language_id integer DEFAULT 0 NOT NULL,
+    name character varying(45) DEFAULT ''::character varying NOT NULL
+);
+
+
+
+
+
+
+
+CREATE TABLE ezcobj_state_link (
+    contentobject_id integer DEFAULT 0 NOT NULL,
+    contentobject_state_id integer DEFAULT 0 NOT NULL
+);
+
+
+
+
+
+
+
 CREATE TABLE ezcollab_group (
     created integer DEFAULT 0 NOT NULL,
     depth integer DEFAULT 0 NOT NULL,
@@ -1656,21 +1760,6 @@ CREATE TABLE ezgeneral_digest_user_settings (
 
 
 
-CREATE TABLE ezimage (
-    alternative_text character varying(255) DEFAULT ''::character varying NOT NULL,
-    contentobject_attribute_id integer DEFAULT 0 NOT NULL,
-    filename character varying(255) DEFAULT ''::character varying NOT NULL,
-    mime_type character varying(50) DEFAULT ''::character varying NOT NULL,
-    original_filename character varying(255) DEFAULT ''::character varying NOT NULL,
-    "version" integer DEFAULT 0 NOT NULL
-);
-
-
-
-
-
-
-
 CREATE TABLE ezimagefile (
     contentobject_attribute_id integer DEFAULT 0 NOT NULL,
     filepath text NOT NULL,
@@ -1683,23 +1772,6 @@ CREATE TABLE ezimagefile (
 
 
 
-CREATE TABLE ezimagevariation (
-    additional_path character varying(255),
-    contentobject_attribute_id integer DEFAULT 0 NOT NULL,
-    filename character varying(255) DEFAULT ''::character varying NOT NULL,
-    height integer DEFAULT 0 NOT NULL,
-    requested_height integer DEFAULT 0 NOT NULL,
-    requested_width integer DEFAULT 0 NOT NULL,
-    "version" integer DEFAULT 0 NOT NULL,
-    width integer DEFAULT 0 NOT NULL
-);
-
-
-
-
-
-
-
 CREATE TABLE ezinfocollection (
     contentobject_id integer DEFAULT 0 NOT NULL,
     created integer DEFAULT 0 NOT NULL,
@@ -1981,7 +2053,7 @@ CREATE TABLE ezorder_item (
     order_id integer DEFAULT 0 NOT NULL,
     price double precision,
     "type" character varying(30),
-    vat_value integer DEFAULT 0 NOT NULL
+    vat_value double precision DEFAULT 0::double precision NOT NULL
 );
 
 
@@ -2071,6 +2143,7 @@ CREATE TABLE ezpdf_export (
 
 CREATE TABLE ezpending_actions (
     "action" character varying(64) DEFAULT ''::character varying NOT NULL,
+    created integer,
     param text
 );
 
@@ -2212,6 +2285,7 @@ CREATE TABLE ezrss_export (
     main_node_only integer DEFAULT 1 NOT NULL,
     modified integer,
     modifier_id integer,
+    node_id integer,
     number_of_objects integer DEFAULT 0 NOT NULL,
     rss_version character varying(255),
     site_access character varying(255),
@@ -2227,6 +2301,7 @@ CREATE TABLE ezrss_export (
 
 
 CREATE TABLE ezrss_export_item (
+    category character varying(255),
     class_id integer,
     description character varying(255),
     id integer DEFAULT nextval('ezrss_export_item_s'::text) NOT NULL,
@@ -2345,6 +2420,7 @@ CREATE TABLE ezsession (
     data text NOT NULL,
     expiration_time integer DEFAULT 0 NOT NULL,
     session_key character varying(32) DEFAULT ''::character varying NOT NULL,
+    user_hash character varying(32) DEFAULT ''::character varying NOT NULL,
     user_id integer DEFAULT 0 NOT NULL
 );
 
@@ -2464,6 +2540,7 @@ CREATE TABLE ezurlalias (
 CREATE TABLE ezurlalias_ml (
     "action" text NOT NULL,
     action_type character varying(32) DEFAULT ''::character varying NOT NULL,
+    alias_redirects integer DEFAULT 1 NOT NULL,
     id integer DEFAULT 0 NOT NULL,
     is_alias integer DEFAULT 0 NOT NULL,
     is_original integer DEFAULT 0 NOT NULL,
@@ -2480,6 +2557,16 @@ CREATE TABLE ezurlalias_ml (
 
 
 
+CREATE TABLE ezurlalias_ml_incr (
+    id integer DEFAULT nextval('ezurlalias_ml_incr_s'::text) NOT NULL
+);
+
+
+
+
+
+
+
 CREATE TABLE ezurlwildcard (
     destination_url text NOT NULL,
     id integer DEFAULT nextval('ezurlwildcard_s'::text) NOT NULL,
@@ -2563,6 +2650,7 @@ CREATE TABLE ezuservisit (
     current_visit_timestamp integer DEFAULT 0 NOT NULL,
     failed_login_attempts integer DEFAULT 0 NOT NULL,
     last_visit_timestamp integer DEFAULT 0 NOT NULL,
+    login_count integer DEFAULT 0 NOT NULL,
     user_id integer DEFAULT 0 NOT NULL
 );
 
@@ -2681,10 +2769,11 @@ CREATE TABLE ezworkflow_event (
     data_int2 integer,
     data_int3 integer,
     data_int4 integer,
-    data_text1 character varying(50),
-    data_text2 character varying(50),
-    data_text3 character varying(50),
-    data_text4 character varying(50),
+    data_text1 character varying(255),
+    data_text2 character varying(255),
+    data_text3 character varying(255),
+    data_text4 character varying(255),
+    data_text5 text,
     description character varying(50) DEFAULT ''::character varying NOT NULL,
     id integer DEFAULT nextval('ezworkflow_event_s'::text) NOT NULL,
     placement integer DEFAULT 0 NOT NULL,
@@ -2765,6 +2854,46 @@ CREATE INDEX ezbasket_session_id ON ezbasket USING btree (session_id);
 
 
 
+CREATE UNIQUE INDEX ezcobj_state_identifier ON ezcobj_state USING btree (group_id, identifier);
+
+
+
+
+
+
+
+CREATE INDEX ezcobj_state_lmask ON ezcobj_state USING btree (language_mask);
+
+
+
+
+
+
+
+CREATE INDEX ezcobj_state_priority ON ezcobj_state USING btree (priority);
+
+
+
+
+
+
+
+CREATE UNIQUE INDEX ezcobj_state_group_identifier ON ezcobj_state_group USING btree (identifier);
+
+
+
+
+
+
+
+CREATE INDEX ezcobj_state_group_lmask ON ezcobj_state_group USING btree (language_mask);
+
+
+
+
+
+
+
 CREATE INDEX ezcollab_group_depth ON ezcollab_group USING btree (depth);
 
 
@@ -2781,6 +2910,14 @@ CREATE INDEX ezcollab_group_path ON ezcollab_group USING btree (path_string);
 
 
 
+CREATE INDEX ezcontent_language_name ON ezcontent_language USING btree (name);
+
+
+
+
+
+
+
 CREATE INDEX ezcontentbrowsebookmark_user ON ezcontentbrowsebookmark USING btree (user_id);
 
 
@@ -2837,6 +2974,14 @@ CREATE INDEX ezcontentobject_lmask ON ezcontentobject USING btree (language_mask
 
 
 
+CREATE INDEX ezcontentobject_owner ON ezcontentobject USING btree (owner_id);
+
+
+
+
+
+
+
 CREATE INDEX ezcontentobject_pub ON ezcontentobject USING btree (published);
 
 
@@ -2845,6 +2990,14 @@ CREATE INDEX ezcontentobject_pub ON ezcontentobject USING btree (published);
 
 
 
+CREATE UNIQUE INDEX ezcontentobject_remote_id ON ezcontentobject USING btree (remote_id);
+
+
+
+
+
+
+
 CREATE INDEX ezcontentobject_status ON ezcontentobject USING btree (status);
 
 
@@ -3093,6 +3246,22 @@ CREATE INDEX ezenumvalue_co_cl_attr_id_co_class_att_ver ON ezenumvalue USING btr
 
 
 
+CREATE INDEX ezforgot_password_user ON ezforgot_password USING btree (user_id);
+
+
+
+
+
+
+
+CREATE UNIQUE INDEX ezgeneral_digest_user_settings_address ON ezgeneral_digest_user_settings USING btree (address);
+
+
+
+
+
+
+
 CREATE INDEX ezimagefile_coid ON ezimagefile USING btree (contentobject_attribute_id);
 
 
@@ -3317,6 +3486,14 @@ CREATE INDEX ezpending_actions_action ON ezpending_actions USING btree ("action"
 
 
 
+CREATE INDEX ezpending_actions_created ON ezpending_actions USING btree (created);
+
+
+
+
+
+
+
 CREATE INDEX ezpolicy_limitation_value_val ON ezpolicy_limitation_value USING btree (value);
 
 
@@ -3685,6 +3862,14 @@ CREATE INDEX ezuser_role_role_id ON ezuser_role USING btree (role_id);
 
 
 
+CREATE INDEX ezuservisit_co_visit_count ON ezuservisit USING btree (current_visit_timestamp, login_count);
+
+
+
+
+
+
+
 CREATE INDEX ezwaituntildateevalue_wf_ev_id_wf_ver ON ezwaituntildatevalue USING btree (workflow_event_id, workflow_event_version);
 
 
@@ -3729,6 +3914,51 @@ ALTER TABLE ONLY ezbinaryfile
 
 
 
+ALTER TABLE ONLY ezcobj_state
+    ADD CONSTRAINT ezcobj_state_pkey PRIMARY KEY (id);
+
+
+
+
+
+
+
+ALTER TABLE ONLY ezcobj_state_group
+    ADD CONSTRAINT ezcobj_state_group_pkey PRIMARY KEY (id);
+
+
+
+
+
+
+
+ALTER TABLE ONLY ezcobj_state_group_language
+    ADD CONSTRAINT ezcobj_state_group_language_pkey PRIMARY KEY (contentobject_state_group_id, language_id);
+
+
+
+
+
+
+
+ALTER TABLE ONLY ezcobj_state_language
+    ADD CONSTRAINT ezcobj_state_language_pkey PRIMARY KEY (contentobject_state_id, language_id);
+
+
+
+
+
+
+
+ALTER TABLE ONLY ezcobj_state_link
+    ADD CONSTRAINT ezcobj_state_link_pkey PRIMARY KEY (contentobject_id, contentobject_state_id);
+
+
+
+
+
+
+
 ALTER TABLE ONLY ezcollab_group
     ADD CONSTRAINT ezcollab_group_pkey PRIMARY KEY (id);
 
@@ -4017,15 +4247,6 @@ ALTER TABLE ONLY ezgeneral_digest_user_settings
 
 
 
-ALTER TABLE ONLY ezimage
-    ADD CONSTRAINT ezimage_pkey PRIMARY KEY (contentobject_attribute_id, "version");
-
-
-
-
-
-
-
 ALTER TABLE ONLY ezimagefile
     ADD CONSTRAINT ezimagefile_pkey PRIMARY KEY (id);
 
@@ -4035,15 +4256,6 @@ ALTER TABLE ONLY ezimagefile
 
 
 
-ALTER TABLE ONLY ezimagevariation
-    ADD CONSTRAINT ezimagevariation_pkey PRIMARY KEY (contentobject_attribute_id, "version", requested_width, requested_height);
-
-
-
-
-
-
-
 ALTER TABLE ONLY ezinfocollection
     ADD CONSTRAINT ezinfocollection_pkey PRIMARY KEY (id);
 
@@ -4476,6 +4688,15 @@ ALTER TABLE ONLY ezurlalias_ml
 
 
 
+ALTER TABLE ONLY ezurlalias_ml_incr
+    ADD CONSTRAINT ezurlalias_ml_incr_pkey PRIMARY KEY (id);
+
+
+
+
+
+
+
 ALTER TABLE ONLY ezurlwildcard
     ADD CONSTRAINT ezurlwildcard_pkey PRIMARY KEY (id);
 
