@@ -7,9 +7,9 @@
 // Created on: <12-Feb-2002 15:54:17 bf>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -36,9 +36,6 @@
   \sa eZDB
 */
 
-require_once( "lib/ezutils/classes/ezdebug.php" );
-//include_once( "lib/ezutils/classes/ezini.php" );
-
 class eZDBInterface
 {
     const BINDING_NO = 0;
@@ -62,6 +59,9 @@ class eZDBInterface
 
     const ERROR_MISSING_EXTENSION = 1;
 
+    const SERVER_MASTER = 1;
+    const SERVER_SLAVE = 2;
+
     /*!
       Create a new eZDBInterface object and connects to the database backend.
     */
@@ -123,7 +123,6 @@ class eZDBInterface
         else
 */
         {
-            //include_once( "lib/ezi18n/classes/eztextcodec.php" );
             $tmpOutputTextCodec = eZTextCodec::instance( $charset, false, false );
             $tmpInputTextCodec = eZTextCodec::instance( false, $charset, false );
             unset( $this->OutputTextCodec );
@@ -299,7 +298,6 @@ class eZDBInterface
     {
         $type = $this->databaseName();
 
-        //include_once( 'lib/ezfile/classes/ezdir.php' );
         if ( $usePathType )
             $sqlFileName = eZDir::path( array( $path, $type, $sqlFile ) );
         else
@@ -344,13 +342,16 @@ class eZDBInterface
      \private
      Writes a debug notice with query information.
     */
-    function reportQuery( $class, $sql, $numRows, $timeTaken )
+    function reportQuery( $class, $sql, $numRows, $timeTaken, $asDebug = false )
     {
         $rowText = '';
         if ( $numRows !== false ) $rowText = "$numRows rows, ";
 
-        $backgroundClass = ($this->TransactionCounter > 0  ? "debugtransaction transactionlevel-$this->TransactionCounter" : "");
-        eZDebug::writeNotice( "$sql", "$class::query($rowText" . number_format( $timeTaken, 3 ) . " ms) query number per page:" . $this->NumQueries++, $backgroundClass );
+        $backgroundClass = ($this->TransactionCounter > 0  ? "debugtransaction transactionlevel-$this->TransactionCounter" : '');
+        if ( $asDebug )
+            eZDebug::writeDebug( "$sql", "$class::query($rowText" . number_format( $timeTaken, 3 ) . ' ms) query number per page:' . $this->NumQueries++, $backgroundClass );
+        else
+            eZDebug::writeNotice( "$sql", "$class::query($rowText" . number_format( $timeTaken, 3 ) . ' ms) query number per page:' . $this->NumQueries++, $backgroundClass );
     }
 
     /*!
@@ -603,7 +604,7 @@ class eZDBInterface
 
       \param $sql SQL query to execute.
     */
-    function query( $sql )
+    function query( $sql, $server = false )
     {
     }
 
@@ -616,13 +617,14 @@ class eZDBInterface
              - offset - The offset of the query.
              - limit - The limit of the query.
              - column - Limit returned row arrays to only contain this column.
+      \param $server Which server to execute the query on, either eZDBInterface::SERVER_MASTER or eZDBInterface::SERVER_SLAVE
 
       An example would be:
       \code
       $db->arrayQuery( 'SELECT * FROM eztable', array( 'limit' => 10, 'offset' => 5 ) );
       \endcode
     */
-    function arrayQuery( $sql, $params = array() )
+    function arrayQuery( $sql, $params = array(), $server = false )
     {
     }
 
@@ -978,7 +980,6 @@ class eZDBInterface
             $this->RecordError = $oldRecordError;
 
             // Stop execution immediately while allowing other systems (session etc.) to cleanup
-            require_once( 'lib/ezutils/classes/ezexecution.php' );
             eZExecution::cleanup();
             eZExecution::setCleanExit();
 
@@ -987,14 +988,11 @@ class eZDBInterface
 
             $ini = eZINI::instance();
             $adminEmail = $ini->variable( 'MailSettings', 'AdminEmail' );
-            //include_once( 'lib/ezutils/classes/ezsys.php' );
-            $site = eZSys::serverVariable( 'HTTP_HOST' );
-            $uri = eZSys::serverVariable( 'REQUEST_URI' );
-
-            $htmlErrors = ini_get( 'html_errors' ) != 0;
-
-            if ( $htmlErrors )
+            if ( !eZSys::isShellExecution() )
             {
+                $site = eZSys::serverVariable( 'HTTP_HOST' );
+                $uri = eZSys::serverVariable( 'REQUEST_URI' );
+
                 print( "<div class=\"fatal-error\" style=\"" );
                 print( 'margin: 0.5em 0 1em 0; ' .
                        'padding: 0.25em 1em 0.75em 1em;' .
@@ -1021,9 +1019,9 @@ class eZDBInterface
                 fputs( STDERR,"Fatal error: A database transaction in eZ Publish failed.\n" );
                 fputs( STDERR, "\n" );
                 fputs( STDERR, "The current execution was stopped to prevent further problems.\n" .
-                       "You should contact the System Administrator ($adminEmail) of this site with the information on this page.\n" .
+                       "You should contact the System Administrator ($adminEmail) of this site.\n" .
                        "The current transaction ID is $transID and has been logged.\n" .
-                       "Please include the transaction ID and the current URL when contacting the system administrator.\n" );
+                       "Please include the transaction ID and the name of the current script when contacting the system administrator.\n" );
                 fputs( STDERR, "\n" );
 
                 fputs( STDERR, eZDebug::printReport( false, false, true ) );
@@ -1075,7 +1073,7 @@ class eZDBInterface
      \pure
      \return existing ez publish tables in database
     */
-    function eZTableList()
+    function eZTableList( $server = self::SERVER_MASTER )
     {
     }
 
@@ -1203,29 +1201,37 @@ class eZDBInterface
     {
     }
 
+    /*!
+      \pure
+      Removes a database
+    */
+    function removeDatabase( $dbName )
+    {
+    }
+
     /*!
       Create a new temporary table
     */
-    function createTempTable( $createTableQuery = '' )
+    function createTempTable( $createTableQuery = '', $server = self::SERVER_SLAVE )
     {
-        $this->query( $createTableQuery );
+        $this->query( $createTableQuery, $server );
     }
 
     /*!
       Drop temporary table
     */
-    function dropTempTable( $dropTableQuery = '' )
+    function dropTempTable( $dropTableQuery = '', $server = self::SERVER_SLAVE )
     {
-        $this->query( $dropTableQuery );
+        $this->query( $dropTableQuery, $server );
     }
 
     /*!
       Drop temporary table list
     */
-    function dropTempTableList( $tableList )
+    function dropTempTableList( $tableList, $server = self::SERVER_SLAVE )
     {
         foreach( $tableList as $tableName )
-            $this->dropTempTable( "DROP TABLE $tableName" );
+            $this->dropTempTable( "DROP TABLE $tableName", $server );
     }
 
     /*!
@@ -1269,9 +1275,9 @@ class eZDBInterface
      If the pattern contains a (%) character then the character
      is replaced with a part providing uniqueness (e.g. random number).
     */
-    function generateUniqueTempTableName( $pattern, $randomizeIndex = false )
+    function generateUniqueTempTableName( $pattern, $randomizeIndex = false, $server = self::SERVER_SLAVE )
     {
-        $tableList = array_keys( $this->eZTableList() );
+        $tableList = array_keys( $this->eZTableList( $server ) );
         if ( $randomizeIndex === false )
         {
             $randomizeIndex = rand( 10, 1000 );
@@ -1317,11 +1323,13 @@ class eZDBInterface
      \param $columnName Column name of the database table the IN statement should be created for
      \param $not        Will generate a "NOT IN" ( if set to \c true ) statement instead of an "IN" ( if set to
                         \c false , default )
+     \param $unique
+     \param $type      The type to cast the array elements to
 
      \return A string with the correct IN statement like for example
              "columnName IN ( element1, element2 )"
      */
-    function generateSQLINStatement( $elements, $columnName = '', $not = false, $unique = true )
+    function generateSQLINStatement( $elements, $columnName = '', $not = false, $unique = true, $type = false )
     {
         $result    = '';
         $statement = $columnName . ' IN';
@@ -1329,17 +1337,23 @@ class eZDBInterface
         {
             $statement = $columnName . ' NOT IN';
         }
-        if ( is_array( $elements ) )
+
+        if ( !is_array( $elements ) )
         {
-            $result = $statement . ' ( ' . implode( ', ', $elements ) . ' )';
-        }
-        else
-        {
-            $result = $statement . ' ( ' . $elements . ' )';
+            $elements = array( $elements );
         }
+
+        $impString = $type ? $this->implodeWithTypeCast( ', ', $elements, $type ) : implode( ', ', $elements );
+        $result = $statement . ' ( ' . $impString . ' )';
+
         return $result;
     }
 
+    function supportsDefaultValuesInsertion()
+    {
+        return true;
+    }
+
     /// \protectedsection
     /// Contains the current server
     public $Server;
