@@ -7,9 +7,9 @@
 // Created on: <12-Feb-2002 15:54:17 bf>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -36,11 +36,6 @@
   eZMySQLDB is the MySQL implementation of eZDB.
   \sa eZDB
 */
-
-require_once( "lib/ezutils/classes/ezdebug.php" );
-//include_once( "lib/ezutils/classes/ezini.php" );
-//include_once( "lib/ezdb/classes/ezdbinterface.php" );
-
 class eZMySQLDB extends eZDBInterface
 {
     /*!
@@ -164,6 +159,7 @@ class eZMySQLDB extends eZDBInterface
         {
             eZDebug::writeError( "Connection error: Couldn't connect to database. Please try again later or inform the system administrator.\n$dbErrorText", "eZMySQLDB" );
             $this->IsConnected = false;
+            throw new eZDBNoConnectionException( $server );
         }
 
         if ( $this->IsConnected && $db != null )
@@ -180,7 +176,6 @@ class eZMySQLDB extends eZDBInterface
         if ( $charset !== null )
         {
             $originalCharset = $charset;
-            //include_once( 'lib/ezi18n/classes/ezcharsetinfo.php' );
             $charset = eZCharsetInfo::realCharsetCode( $charset );
             // Convert charset names into something MySQL will understand
             if ( isset( $this->CharsetMapping[ $charset ] ) )
@@ -198,7 +193,7 @@ class eZMySQLDB extends eZDBInterface
             {
                 $query = "SET NAMES '" . $charset . "'";
                 $status = mysql_query( $query, $connection );
-                $this->reportQuery( 'eZMySQLDB', $query, false, false );
+                $this->reportQuery( 'eZMySQLDB', $query, false, false, true );
                 if ( !$status )
                 {
                     $this->setError();
@@ -210,25 +205,16 @@ class eZMySQLDB extends eZDBInterface
         return $connection;
     }
 
-    /*!
-     \reimp
-    */
     function databaseName()
     {
         return 'mysql';
     }
 
-    /*!
-      \reimp
-    */
     function bindingType( )
     {
         return eZDBInterface::BINDING_NO;
     }
 
-    /*!
-      \reimp
-    */
     function bindVariable( $value, $fieldDef = false )
     {
         return $value;
@@ -260,8 +246,6 @@ class eZMySQLDB extends eZDBInterface
         if ( version_compare( $versionInfo['string'], '4.1.1' ) < 0 )
             return true;
 
-        //include_once( 'lib/ezi18n/classes/ezcharsetinfo.php' );
-
         if ( is_array( $charset ) )
         {
             foreach ( $charset as $charsetItem )
@@ -301,7 +285,6 @@ class eZMySQLDB extends eZDBInterface
                 if ( preg_match( '#DEFAULT CHARACTER SET ([a-zA-Z0-9_-]+)#', $createText, $matches ) )
                 {
                     $currentCharset = $matches[1];
-                    //include_once( 'lib/ezi18n/classes/ezcharsetinfo.php' );
                     $currentCharset = eZCharsetInfo::realCharsetCode( $currentCharset );
                     // Convert charset names into something MySQL will understand
 
@@ -327,32 +310,7 @@ class eZMySQLDB extends eZDBInterface
         return true;
     }
 
-    /*!
-     \reimp
-    */
-    function createTempTable( $createTableQuery = '' )
-    {
-        if ( $this->UseSlaveServer )
-        {
-            $matches = array();
-            if ( preg_match( "/create\s+temporary\s+table\s+([a-zA-Z0-9_-]+).*/i", $createTableQuery, $matches ) )
-            {
-                $this->TempTableList[] = $matches[1];
-            }
-            else
-            {
-                eZDebug::writeError( 'Could not extract temporary filename: ' . $createTableQuery,
-                                     'eZMySQLDB::createTempTable()' );
-            }
-        }
-        $this->query( $createTableQuery );
-    }
-
-
-    /*!
-     \reimp
-    */
-    function query( $sql )
+    function query( $sql, $server = false )
     {
         if ( $this->IsConnected )
         {
@@ -370,72 +328,17 @@ class eZMySQLDB extends eZDBInterface
             {
                 $this->startTimer();
             }
-            // Check if it's a write or read sql query
+
             $sql = trim( $sql );
 
-            $isWriteQuery = true;
-            if ( strncasecmp( $sql, 'select', 6 ) === 0 )
+            // Check if we need to use the master or slave server by default
+            if ( $server === false )
             {
-                $isWriteQuery = false;
+                $server = strncasecmp( $sql, 'select', 6 ) === 0 && $this->TransactionCounter == 0 ?
+                    eZDBInterface::SERVER_SLAVE : eZDBInterface::SERVER_MASTER;
             }
 
-            // Send temporary create queries to slave server
-            if ( preg_match( "/create\s+temporary/i", $sql ) )
-            {
-                $isWriteQuery = false;
-            }
-
-            if ( $isWriteQuery )
-            {
-                $connection = false;
-                // Check if write query is into temporary table.
-                if ( $this->UseSlaveServer && !empty( $this->TempTableList ) )
-                {
-                    $sqlMatch = false;
-                    $matches = array();
-                    // Check update sql for temporary tables
-                    if ( strncasecmp( $sql, 'update', 6 ) === 0 )
-                    {
-                        $queryParts = preg_match( "/(update[\s]*)(low_priority[\s*])?(ignore[\s*])?([\s\w,]*)([\s]set[\s].*)/",
-                                                  strtolower( $sql ),
-                                                  $matches );
-                        $sqlMatch = array_intersect( $this->TempTableList, explode( ",", $matches[4] ) );
-                    }
-                    // Check insert sql for temporary table
-                    else if ( strncasecmp( $sql, 'insert', 6 ) === 0 )
-                    {
-                        $queryParts = preg_match( "/(insert[\s*])(low_priority[\s*])?(delayed[\s*])?(high_priority[\s*])?(ignore[\s*])?(into[\s*])?([\w]*)(\(.*\))?([\s](
-set|values|select).*)?/",
-                                                  strtolower( $sql ),
-                                                  $matches );
-                        $sqlMatch = in_array( $matches[7], $this->TempTableList );
-                    }
-                    // Check delete sql for temporary tables
-                    else if ( strncasecmp( $sql, 'delete', 6 ) === 0 )
-                    {
-                        $queryParts = preg_match( "/(delete[\s]*)(low_priority[\s*])?(quick[\s*])?(ignore[\s*])?(from[\s*])?([\s\w,]*)([\s]where[\s].*)/",
-                                                  strtolower( $sql ),
-                                                  $matches );
-                        $sqlMatch = array_intersect( $this->TempTableList, explode( ",", $matches[6] ) );
-                    }
-
-                    // Check if it is write to temp table.
-                    if ( !empty( $sqlMatch ) )
-                    {
-                        eZDebug::writeNotice( 'Using slave connection for updating temporary table: ' . substr( $sql, 0, 100 ),
-                                              'eZMySQLDB::query()' );
-                        $connection = $this->DBConnection;
-                    }
-                }
-                if ( !$connection )
-                {
-                    $connection = $this->DBWriteConnection;
-                }
-            }
-            else
-            {
-                $connection = $this->DBConnection;
-            }
+            $connection = ( $server == eZDBInterface::SERVER_SLAVE ) ? $this->DBConnection : $this->DBWriteConnection;
 
             $analysisText = false;
             // If query analysis is enable we need to run the query
@@ -540,7 +443,7 @@ set|values|select).*)?/",
                     if ( $analysisText !== false )
                         $text = "EXPLAIN\n" . $text . "\n\nANALYSIS:\n" . $analysisText;
 
-                    $this->reportQuery( 'eZMySQLDB', $text, $num_rows, $this->timeTaken() );
+                    $this->reportQuery( ( $server == eZDBInterface::SERVER_MASTER ? 'on master : ' : '' ) . 'eZMySQLDB', $text, $num_rows, $this->timeTaken() );
                 }
             }
             eZDebug::accumulatorStop( 'mysql_query' );
@@ -570,10 +473,7 @@ set|values|select).*)?/",
 
     }
 
-    /*!
-     \reimp
-    */
-    function arrayQuery( $sql, $params = array() )
+    function arrayQuery( $sql, $params = array(), $server = false )
     {
         $retArray = array();
         if ( $this->IsConnected )
@@ -602,7 +502,7 @@ set|values|select).*)?/",
             {
                 $sql .= "\nLIMIT $offset, 18446744073709551615"; // 2^64-1
             }
-            $result = $this->query( $sql );
+            $result = $this->query( $sql, $server );
 
             if ( $result == false )
             {
@@ -690,25 +590,16 @@ set|values|select).*)?/",
         return 'cast( ' . $arg1 . ' | ' . $arg2 . ' AS SIGNED ) ';
     }
 
-    /*!
-     \reimp
-    */
     function supportedRelationTypeMask()
     {
         return eZDBInterface::RELATION_TABLE_BIT;
     }
 
-    /*!
-     \reimp
-    */
     function supportedRelationTypes()
     {
         return array( eZDBInterface::RELATION_TABLE );
     }
 
-    /*!
-     \reimp
-    */
     function relationCounts( $relationMask )
     {
         if ( $relationMask & eZDBInterface::RELATION_TABLE_BIT )
@@ -717,9 +608,6 @@ set|values|select).*)?/",
             return 0;
     }
 
-    /*!
-      \reimp
-    */
     function relationCount( $relationType = eZDBInterface::RELATION_TABLE )
     {
         if ( $relationType != eZDBInterface::RELATION_TABLE )
@@ -739,9 +627,6 @@ set|values|select).*)?/",
         return $count;
     }
 
-    /*!
-      \reimp
-    */
     function relationList( $relationType = eZDBInterface::RELATION_TABLE )
     {
         if ( $relationType != eZDBInterface::RELATION_TABLE )
@@ -766,16 +651,24 @@ set|values|select).*)?/",
         return $tables;
     }
 
-    /*!
-     \reimp
-    */
-    function eZTableList()
+    function eZTableList( $server = eZDBInterface::SERVER_MASTER )
     {
         $tables = array();
         if ( $this->IsConnected )
         {
-            $query = "SHOW TABLES FROM `" . $this->DB . "`";
-            $result = @mysql_query( $query, $this->DBConnection );
+            if ( $this->UseSlaveServer && $server == eZDBInterface::SERVER_SLAVE )
+            {
+                $connection = $this->DBConnection;
+                $db = $this->SlaveDB;
+            }
+            else
+            {
+                $connection = $this->DBWriteConnection;
+                $db = $this->DB;
+            }
+
+            $query = "SHOW TABLES FROM `" . $db . "`";
+            $result = @mysql_query( $query, $connection );
             $this->reportQuery( 'eZMySQLDB', $query, false, false );
             $count = mysql_num_rows( $result );
             for ( $i = 0; $i < $count; ++ $i )
@@ -792,17 +685,11 @@ set|values|select).*)?/",
         return $tables;
     }
 
-    /*!
-     \reimp
-    */
     function relationMatchRegexp( $relationType )
     {
         return "#^ez#";
     }
 
-    /*!
-      \reimp
-    */
     function removeRelation( $relationName, $relationType )
     {
         $relationTypeName = $this->relationName( $relationType );
@@ -820,9 +707,6 @@ set|values|select).*)?/",
         return false;
     }
 
-    /*!
-     \reimp
-    */
     function lock( $table )
     {
         if ( $this->IsConnected )
@@ -848,9 +732,6 @@ set|values|select).*)?/",
         }
     }
 
-    /*!
-     \reimp
-    */
     function unlock()
     {
         if ( $this->IsConnected )
@@ -860,7 +741,6 @@ set|values|select).*)?/",
     }
 
     /*!
-     \reimp
      The query to start the transaction.
     */
     function beginQuery()
@@ -869,7 +749,6 @@ set|values|select).*)?/",
     }
 
     /*!
-     \reimp
      The query to commit the transaction.
     */
     function commitQuery()
@@ -878,7 +757,6 @@ set|values|select).*)?/",
     }
 
     /*!
-     \reimp
      The query to cancel the transaction.
     */
     function rollbackQuery()
@@ -886,9 +764,6 @@ set|values|select).*)?/",
         return $this->query( "ROLLBACK" );
     }
 
-    /*!
-     \reimp
-    */
     function lastSerialID( $table = false, $column = false )
     {
         if ( $this->IsConnected )
@@ -900,17 +775,18 @@ set|values|select).*)?/",
             return false;
     }
 
-    /*!
-     \reimp
-    */
     function escapeString( $str )
     {
-        return mysql_real_escape_string( $str );
+        if ( $this->IsConnected )
+        {
+            return mysql_real_escape_string( $str, $this->DBConnection );
+        }
+        else
+        {
+            return mysql_escape_string( $str );
+        }
     }
 
-    /*!
-     \reimp
-    */
     function close()
     {
         if ( $this->IsConnected )
@@ -920,21 +796,24 @@ set|values|select).*)?/",
         }
     }
 
-    /*!
-     \reimp
-    */
     function createDatabase( $dbName )
     {
         if ( $this->DBConnection != false )
         {
-            mysql_create_db( $dbName, $this->DBConnection );
+            $this->query( "CREATE DATABASE $dbName" );
+            $this->setError();
+        }
+    }
+
+    function removeDatabase( $dbName )
+    {
+        if ( $this->DBConnection != false )
+        {
+            $this->query( "DROP DATABASE $dbName" );
             $this->setError();
         }
     }
 
-    /*!
-     \reimp
-    */
     function setError()
     {
         if ( $this->DBConnection )
@@ -949,9 +828,6 @@ set|values|select).*)?/",
         }
     }
 
-    /*!
-     \reimp
-    */
     function availableDatabases()
     {
         $databaseArray = mysql_list_dbs( $this->DBConnection );
@@ -985,9 +861,6 @@ set|values|select).*)?/",
         return $databases;
     }
 
-    /*!
-     \reimp
-    */
     function databaseServerVersion()
     {
         $versionInfo = mysql_get_server_info();
@@ -998,9 +871,6 @@ set|values|select).*)?/",
                       'values' => $versionArray );
     }
 
-    /*!
-     \reimp
-    */
     function databaseClientVersion()
     {
         $versionInfo = mysql_get_client_info();
@@ -1011,9 +881,6 @@ set|values|select).*)?/",
                       'values' => $versionArray );
     }
 
-    /*!
-     \reimp
-    */
     function isCharsetSupported( $charset )
     {
         if ( $charset == 'utf-8' )
@@ -1031,8 +898,19 @@ set|values|select).*)?/",
         }
     }
 
+    function supportsDefaultValuesInsertion()
+    {
+        return false;
+    }
+
+    function dropTempTable( $dropTableQuery = '', $server = self::SERVER_SLAVE )
+    {
+        $dropTableQuery = str_ireplace( 'DROP TABLE', 'DROP TEMPORARY TABLE', $dropTableQuery );
+        parent::dropTempTable( $dropTableQuery, $server );
+    }
+
     public $CharsetMapping;
-    var $TempTableList;
+    public $TempTableList;
 
     /// \privatesection
 }
