@@ -7,9 +7,9 @@
 // Created on: <12-Feb-2002 15:54:17 bf>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -37,10 +37,6 @@
   \sa eZDB
 */
 
-//require_once( "lib/ezutils/classes/ezdebug.php" );
-////include_once( "lib/ezutils/classes/ezini.php" );
-//include_once( "lib/ezdb/classes/ezdbinterface.php" );
-
 class eZMySQLiDB extends eZDBInterface
 {
     /*!
@@ -72,14 +68,15 @@ class eZMySQLiDB extends eZDBInterface
                                                               'number' => eZDBInterface::ERROR_MISSING_EXTENSION ),
                                             'text' => 'MySQLi extension was not found, the DB handler will not be initialized.' ) );
                 $this->IsConnected = false;
-                return;
             }
+            eZDebug::writeWarning( 'MySQLi extension was not found, the DB handler will not be initialized.', 'eZMySQLiDB' );
+            return;
         }
 
         /// Connect to master server
         if ( !is_object( $this->DBWriteConnection ) )
         {
-            $connection = $this->connect( $this->Server, $this->DB, $this->User, $this->Password, $this->SocketPath, $this->Charset );
+            $connection = $this->connect( $this->Server, $this->DB, $this->User, $this->Password, $this->SocketPath, $this->Charset, $this->Port );
             if ( $this->IsConnected )
             {
                 $this->DBWriteConnection = $connection;
@@ -91,7 +88,7 @@ class eZMySQLiDB extends eZDBInterface
         {
             if ( $this->UseSlaveServer === true )
             {
-                $connection = $this->connect( $this->SlaveServer, $this->SlaveDB, $this->SlaveUser, $this->SlavePassword, $this->SocketPath, $this->Charset );
+                $connection = $this->connect( $this->SlaveServer, $this->SlaveDB, $this->SlaveUser, $this->SlavePassword, $this->SocketPath, $this->Charset, $this->SlavePort );
             }
             else
             {
@@ -129,7 +126,7 @@ class eZMySQLiDB extends eZDBInterface
             eZDebug::writeWarning( 'mysqli does not support persistent connections', 'eZMySQLiDB::connect' );
         }
 
-        $connection = mysqli_connect( $server, $user, $password, null, $port, $socketPath );
+        $connection = mysqli_connect( $server, $user, $password, null, (int)$port, $socketPath );
 
         $dbErrorText = mysqli_connect_error();
         $maxAttempts = $this->connectRetryCount();
@@ -143,7 +140,7 @@ class eZMySQLiDB extends eZDBInterface
                 eZDebug::writeWarning( 'mysqli does not support persistent connections', 'eZMySQLiDB::connect' );
             }
 
-            $connection = mysqli_connect( $this->Server, $this->User, $this->Password, null, $this->Port, $this->SocketPath );
+            $connection = mysqli_connect( $this->Server, $this->User, $this->Password, null, (int)$this->Port, $this->SocketPath );
 
             $numAttempts++;
         }
@@ -155,6 +152,7 @@ class eZMySQLiDB extends eZDBInterface
         {
             eZDebug::writeError( "Connection error: Couldn't connect to database. Please try again later or inform the system administrator.\n$dbErrorText", "eZMySQLiDB" );
             $this->IsConnected = false;
+            throw new eZDBNoConnectionException( $server );
         }
 
         if ( $this->IsConnected && $db != null )
@@ -171,7 +169,6 @@ class eZMySQLiDB extends eZDBInterface
         if ( $charset !== null )
         {
             $originalCharset = $charset;
-            ////include_once( 'lib/ezi18n/classes/ezcharsetinfo.php' );
             $charset = eZCharsetInfo::realCharsetCode( $charset );
             // Convert charset names into something MySQL will understand
             if ( isset( $this->CharsetMapping[ $charset ] ) )
@@ -191,25 +188,16 @@ class eZMySQLiDB extends eZDBInterface
         return $connection;
     }
 
-    /*!
-     \reimp
-    */
     function databaseName()
     {
         return 'mysql';
     }
 
-    /*!
-      \reimp
-    */
     function bindingType( )
     {
         return eZDBInterface::BINDING_NO;
     }
 
-    /*!
-      \reimp
-    */
     function bindVariable( $value, $fieldDef = false )
     {
         return $value;
@@ -241,8 +229,6 @@ class eZMySQLiDB extends eZDBInterface
         if ( version_compare( $versionInfo['string'], '4.1.1' ) < 0 )
             return true;
 
-        ////include_once( 'lib/ezi18n/classes/ezcharsetinfo.php' );
-
         if ( is_array( $charset ) )
         {
             foreach ( $charset as $charsetItem )
@@ -282,7 +268,6 @@ class eZMySQLiDB extends eZDBInterface
                 if ( preg_match( '#DEFAULT CHARACTER SET ([a-zA-Z0-9_-]+)#', $createText, $matches ) )
                 {
                     $currentCharset = $matches[1];
-                    ////include_once( 'lib/ezi18n/classes/ezcharsetinfo.php' );
                     $currentCharset = eZCharsetInfo::realCharsetCode( $currentCharset );
                     // Convert charset names into something MySQL will understand
 
@@ -308,32 +293,7 @@ class eZMySQLiDB extends eZDBInterface
         return true;
     }
 
-    /**
-     * @reimp
-     */
-    public function createTempTable( $createTableQuery = '' )
-    {
-        if ( $this->UseSlaveServer )
-        {
-            $matches = array();
-            if ( preg_match( "/create\s+temporary\s+table\s+([a-zA-Z0-9_-]+).*/i", $createTableQuery, $matches ) )
-            {
-                $this->TempTableList[] = $matches[1];
-            }
-            else
-            {
-                eZDebug::writeError( 'Could not extract temporary filename: ' . $createTableQuery,
-                                     'eZMySQLDB::createTempTable()' );
-            }
-        }
-        $this->query( $createTableQuery );
-    }
-
-
-    /*!
-     \reimp
-    */
-    function query( $sql )
+    function query( $sql, $server = false )
     {
         if ( $this->IsConnected )
         {
@@ -351,72 +311,17 @@ class eZMySQLiDB extends eZDBInterface
             {
                 $this->startTimer();
             }
-            // Check if it's a write or read sql query
+
             $sql = trim( $sql );
 
-            $isWriteQuery = true;
-            if ( strncasecmp( $sql, 'select', 6 ) === 0 )
+            // Check if we need to use the master or slave server by default
+            if ( $server === false )
             {
-                $isWriteQuery = false;
+                $server = strncasecmp( $sql, 'select', 6 ) === 0 && $this->TransactionCounter == 0 ?
+                    eZDBInterface::SERVER_SLAVE : eZDBInterface::SERVER_MASTER;
             }
 
-            // Send temporary create queries to slave server
-            if ( preg_match( "/create\s+temporary/i", $sql ) )
-            {
-                $isWriteQuery = false;
-            }
-
-            if ( $isWriteQuery )
-            {
-                $connection = false;
-                // Check if write query is into temporary table.
-                if ( $this->UseSlaveServer && !empty( $this->TempTableList ) )
-                {
-                    $sqlMatch = false;
-                    $matches = array();
-                    // Check update sql for temporary tables
-                    if ( strncasecmp( $sql, 'update', 6 ) === 0 )
-                    {
-                        $queryParts = preg_match( "/(update[\s]*)(low_priority[\s*])?(ignore[\s*])?([\s\w,]*)([\s]set[\s].*)/",
-                                                  strtolower( $sql ),
-                                                  $matches );
-                        $sqlMatch = array_intersect( $this->TempTableList, explode( ",", $matches[4] ) );
-                    }
-                    // Check insert sql for temporary table
-                    else if ( strncasecmp( $sql, 'insert', 6 ) === 0 )
-                    {
-                        $queryParts = preg_match( "/(insert[\s*])(low_priority[\s*])?(delayed[\s*])?(high_priority[\s*])?(ignore[\s*])?(into[\s*])?([\w]*)(\(.*\))?([\s](
-set|values|select).*)?/",
-                                                  strtolower( $sql ),
-                                                  $matches );
-                        $sqlMatch = in_array( $matches[7], $this->TempTableList );
-                    }
-                    // Check delete sql for temporary tables
-                    else if ( strncasecmp( $sql, 'delete', 6 ) === 0 )
-                    {
-                        $queryParts = preg_match( "/(delete[\s]*)(low_priority[\s*])?(quick[\s*])?(ignore[\s*])?(from[\s*])?([\s\w,]*)([\s]where[\s].*)/",
-                                                  strtolower( $sql ),
-                                                  $matches );
-                        $sqlMatch = array_intersect( $this->TempTableList, explode( ",", $matches[6] ) );
-                    }
-
-                    // Check if it is write to temp table.
-                    if ( !empty( $sqlMatch ) )
-                    {
-                        eZDebug::writeNotice( 'Using slave connection for updating temporary table: ' . substr( $sql, 0, 100 ),
-                                              'eZMySQLDB::query()' );
-                        $connection = $this->DBConnection;
-                    }
-                }
-                if ( !$connection )
-                {
-                    $connection = $this->DBWriteConnection;
-                }
-            }
-            else
-            {
-                $connection = $this->DBConnection;
-            }
+            $connection = ( $server == eZDBInterface::SERVER_SLAVE ) ? $this->DBConnection : $this->DBWriteConnection;
 
             $analysisText = false;
             // If query analysis is enable we need to run the query
@@ -521,7 +426,7 @@ set|values|select).*)?/",
                     if ( $analysisText !== false )
                         $text = "EXPLAIN\n" . $text . "\n\nANALYSIS:\n" . $analysisText;
 
-                    $this->reportQuery( 'eZMySQLiDB', $text, $num_rows, $this->timeTaken() );
+                    $this->reportQuery( ( $server == eZDBInterface::SERVER_MASTER ? 'on master : ' : '' ) . 'eZMySQLiDB', $text, $num_rows, $this->timeTaken() );
                 }
             }
             eZDebug::accumulatorStop( 'mysqli_query' );
@@ -551,10 +456,7 @@ set|values|select).*)?/",
 
     }
 
-    /*!
-     \reimp
-    */
-    function arrayQuery( $sql, $params = array() )
+    function arrayQuery( $sql, $params = array(), $server = false )
     {
         $retArray = array();
         if ( $this->IsConnected )
@@ -583,7 +485,7 @@ set|values|select).*)?/",
             {
                 $sql .= "\nLIMIT $offset, 18446744073709551615"; // 2^64-1
             }
-            $result = $this->query( $sql );
+            $result = $this->query( $sql, $server );
 
             if ( $result == false )
             {
@@ -661,25 +563,26 @@ set|values|select).*)?/",
         return " MD5( $str ) ";
     }
 
-    /*!
-     \reimp
-    */
+    function bitAnd( $arg1, $arg2 )
+    {
+        return 'cast(' . $arg1 . ' & ' . $arg2 . ' AS SIGNED ) ';
+    }
+
+    function bitOr( $arg1, $arg2 )
+    {
+        return 'cast( ' . $arg1 . ' | ' . $arg2 . ' AS SIGNED ) ';
+    }
+
     function supportedRelationTypeMask()
     {
         return eZDBInterface::RELATION_TABLE_BIT;
     }
 
-    /*!
-     \reimp
-    */
     function supportedRelationTypes()
     {
         return array( eZDBInterface::RELATION_TABLE );
     }
 
-    /*!
-     \reimp
-    */
     function relationCounts( $relationMask )
     {
         if ( $relationMask & eZDBInterface::RELATION_TABLE_BIT )
@@ -688,9 +591,6 @@ set|values|select).*)?/",
             return 0;
     }
 
-    /*!
-      \reimp
-    */
     function relationCount( $relationType = eZDBInterface::RELATION_TABLE )
     {
         if ( $relationType != eZDBInterface::RELATION_TABLE )
@@ -708,9 +608,6 @@ set|values|select).*)?/",
         return $count;
     }
 
-    /*!
-      \reimp
-    */
     function relationList( $relationType = eZDBInterface::RELATION_TABLE )
     {
         if ( $relationType != eZDBInterface::RELATION_TABLE )
@@ -731,15 +628,23 @@ set|values|select).*)?/",
         return $tables;
     }
 
-    /*!
-     \reimp
-    */
-    function eZTableList()
+    function eZTableList( $server = eZDBInterface::SERVER_MASTER )
     {
         $tables = array();
         if ( $this->IsConnected )
         {
-            $result = mysqli_query( $this->DBConnection, 'SHOW TABLES from `' . $this->DB .'`' );
+            if ( $this->UseSlaveServer && $server == eZDBInterface::SERVER_SLAVE )
+            {
+                $connection = $this->DBConnection;
+                $db = $this->SlaveDB;
+            }
+            else
+            {
+                $connection = $this->DBWriteConnection;
+                $db = $this->DB;
+            }
+
+            $result = mysqli_query( $connection, 'SHOW TABLES from `' . $db .'`' );
             while( $row = mysqli_fetch_row( $result ) )
             {
                 $tableName = $row[0];
@@ -753,17 +658,11 @@ set|values|select).*)?/",
         return $tables;
     }
 
-    /*!
-     \reimp
-    */
     function relationMatchRegexp( $relationType )
     {
         return "#^ez#";
     }
 
-    /*!
-      \reimp
-    */
     function removeRelation( $relationName, $relationType )
     {
         $relationTypeName = $this->relationName( $relationType );
@@ -781,9 +680,6 @@ set|values|select).*)?/",
         return false;
     }
 
-    /*!
-     \reimp
-    */
     function lock( $table )
     {
         if ( $this->IsConnected )
@@ -809,9 +705,6 @@ set|values|select).*)?/",
         }
     }
 
-    /*!
-     \reimp
-    */
     function unlock()
     {
         if ( $this->IsConnected )
@@ -821,7 +714,6 @@ set|values|select).*)?/",
     }
 
     /*!
-     \reimp
      The query to start the transaction.
     */
     function beginQuery()
@@ -830,7 +722,6 @@ set|values|select).*)?/",
     }
 
     /*!
-     \reimp
      The query to commit the transaction.
     */
     function commitQuery()
@@ -839,7 +730,6 @@ set|values|select).*)?/",
     }
 
     /*!
-     \reimp
      The query to cancel the transaction.
     */
     function rollbackQuery()
@@ -847,9 +737,6 @@ set|values|select).*)?/",
         return $this->query( "ROLLBACK" );
     }
 
-    /*!
-     \reimp
-    */
     function lastSerialID( $table = false, $column = false )
     {
         if ( $this->IsConnected )
@@ -861,9 +748,6 @@ set|values|select).*)?/",
             return false;
     }
 
-    /*!
-     \reimp
-    */
     function escapeString( $str )
     {
         if ( is_object( $this->DBConnection ) )
@@ -877,9 +761,6 @@ set|values|select).*)?/",
         }
     }
 
-    /*!
-     \reimp
-    */
     function close()
     {
         if ( $this->IsConnected )
@@ -889,9 +770,6 @@ set|values|select).*)?/",
         }
     }
 
-    /*!
-     \reimp
-    */
     function createDatabase( $dbName )
     {
         if ( $this->DBConnection != false )
@@ -901,9 +779,6 @@ set|values|select).*)?/",
         }
     }
 
-    /*!
-     \reimp
-    */
     function setError()
     {
         if ( is_object( $this->DBConnection ) )
@@ -918,9 +793,6 @@ set|values|select).*)?/",
         }
     }
 
-    /*!
-     \reimp
-    */
     function availableDatabases()
     {
         $databaseArray = mysqli_query( $this->DBConnection, 'SHOW DATABASES' );
@@ -950,9 +822,6 @@ set|values|select).*)?/",
         return $databases;
     }
 
-    /*!
-     \reimp
-    */
     function databaseServerVersion()
     {
         if ( is_object( $this->DBConnection ) )
@@ -968,9 +837,6 @@ set|values|select).*)?/",
         return false;
     }
 
-    /*!
-     \reimp
-    */
     function databaseClientVersion()
     {
         $versionInfo = mysqli_get_client_info();
@@ -981,14 +847,22 @@ set|values|select).*)?/",
                       'values' => $versionArray );
     }
 
-    /*!
-     \reimp
-    */
     function isCharsetSupported( $charset )
     {
         return true;
     }
 
+    function supportsDefaultValuesInsertion()
+    {
+        return false;
+    }
+
+    function dropTempTable( $dropTableQuery = '', $server = self::SERVER_SLAVE )
+    {
+        $dropTableQuery = str_ireplace( 'DROP TABLE', 'DROP TEMPORARY TABLE', $dropTableQuery );
+        parent::dropTempTable( $dropTableQuery, $server );
+    }
+
     public $CharsetMapping;
     protected $TempTableList;
 
