@@ -3,9 +3,9 @@
 // Created on: <09-Feb-2004 09:06:24 dr>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -31,8 +31,6 @@
 
 */
 
-//include_once( 'lib/ezdbschema/classes/ezdbschemainterface.php' );
-
 class eZPgsqlSchema extends eZDBSchemaInterface
 {
     const SHOW_TABLES_QUERY = '
@@ -87,7 +85,6 @@ class eZPgsqlSchema extends eZDBSchemaInterface
         ORDER BY a.attnum';
 
     /*!
-     \reimp
      Constructor
 
      \param db instance
@@ -97,9 +94,6 @@ class eZPgsqlSchema extends eZDBSchemaInterface
         $this->eZDBSchemaInterface( $db );
     }
 
-    /*!
-     \reimp
-    */
     function schema( $params = array() )
     {
         $params = array_merge( array( 'meta_data' => false,
@@ -269,7 +263,7 @@ class eZPgsqlSchema extends eZDBSchemaInterface
             $fields = array();
             $kn = $row['relname'];
 
-            $column_id_array = split( ' ', $row['indkey'] );
+            $column_id_array = explode( ' ', $row['indkey'] );
             if ( $row['indisprimary'] == 't' )
             {
                 // If the name of the key matches our primary key naming standard
@@ -734,9 +728,6 @@ class eZPgsqlSchema extends eZDBSchemaInterface
         return $sql;
     }
 
-    /*!
-     \reimp
-    */
     function generateTableSchema( $table, $table_def, $params )
     {
         $arrays = $this->generateTableArrays( $table, $table_def, $params, true );
@@ -746,9 +737,6 @@ class eZPgsqlSchema extends eZDBSchemaInterface
                  join( "\n\n", $arrays['constraints'] ) . "\n" );
     }
 
-    /*!
-     \reimp
-    */
     function generateTableSQLList( $table, $table_def, $params, $separateTypes )
     {
         $arrays = $this->generateTableArrays( $table, $table_def, $params, false );
@@ -828,7 +816,6 @@ class eZPgsqlSchema extends eZDBSchemaInterface
 
 
     /*!
-     \reimp
 
      This calls eZDBSchemaInterface::generateTableInsertSQLList() and adds a setval SQL if
      the table has auto increments.
@@ -850,9 +837,6 @@ class eZPgsqlSchema extends eZDBSchemaInterface
         return $sqlList;
     }
 
-    /*!
-      \reimp
-    */
     function generateSchemaFile( $schema, $params = array() )
     {
         $sql = '';
@@ -915,9 +899,6 @@ class eZPgsqlSchema extends eZDBSchemaInterface
         return "DROP TABLE $table;\n";
     }
 
-    /*!
-     \reimp
-    */
     function escapeSQLString( $value )
     {
         $value = str_replace( "'", "\'", $value );
@@ -925,17 +906,11 @@ class eZPgsqlSchema extends eZDBSchemaInterface
         return $value;
     }
 
-    /*!
-     \reimp
-    */
     function schemaType()
     {
         return 'postgresql';
     }
 
-    /*!
-     \reimp
-    */
     function schemaName()
     {
         return 'PostgreSQL';
