@@ -5,9 +5,9 @@
 // <creation-tag>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezdifftextengine.php
+/*! \file
   eZDiffTextEngine class
 */
 
@@ -39,9 +39,6 @@
   for the different available DiffEngine.
 */
 
-//include_once( 'lib/ezdiff/classes/ezdiffengine.php' );
-//include_once( 'lib/ezdiff/classes/ezdiffmatrix.php' );
-
 class eZDiffTextEngine extends eZDiffEngine
 {
     function eZDiffTextEngine()
@@ -54,8 +51,6 @@ class eZDiffTextEngine extends eZDiffEngine
     */
     function createDifferenceObject( $fromData, $toData )
     {
-        //include_once( 'lib/ezdiff/classes/eztextdiff.php' );
-
         $pattern = array( '/[ ][ ]+/',
                           '/ \n( \n)+/',
                           '/^ /m',
@@ -68,8 +63,8 @@ class eZDiffTextEngine extends eZDiffEngine
         $old = preg_replace( $pattern, $replace, $fromData );
         $new = preg_replace( $pattern, $replace, $toData );
 
-        $oldArray = split( "\r\n", $old );
-        $newArray = split( "\r\n", $new );
+        $oldArray = explode( "\r\n", $old );
+        $newArray = explode( "\r\n", $new );
 
         $oldSums = array();
         foreach( $oldArray as $paragraph )
