@@ -3,9 +3,9 @@
 // Definition of eZCodePage class
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -31,10 +31,6 @@
 
 */
 
-require_once( "lib/ezutils/classes/ezdebug.php" );
-//include_once( "lib/ezi18n/classes/ezutf8codec.php" );
-//include_once( "lib/ezi18n/classes/ezcharsetinfo.php" );
-
 class eZCodePage
 {
     const CACHE_CODE_DATE = 1028204478;
@@ -368,6 +364,9 @@ class eZCodePage
     function cacheFileName( $charset_code )
     {
         $permissionArray = eZCodePage::permissionSetting();
+
+        if ( $permissionArray === false )
+            return false;
         $charset_code = eZCharsetInfo::realCharsetCode( $charset_code );
         $cache_dir = $permissionArray['var_directory'] . "/codepages/";
         $cache_filename = md5( $charset_code );
@@ -408,95 +407,81 @@ class eZCodePage
     */
     function storeCacheObject( $filename, $permissionArray )
     {
-        //
-        $cache_dir = $permissionArray['var_directory'] . "/codepages/";
+        $dir = dirname( $filename );
+        $file = basename( $filename );
+        $php = new eZPHPCreator( $dir, $file );
 
-//         eZDebug::writeDebug("storeCacheObject is called... filname is: $filename ","");
+        $php->addVariable( "umap", array() );
+        $php->addVariable( "utf8map", array() );
+        $php->addVariable( "cmap", array() );
+        $php->addVariable( "utf8cmap", array() );
 
-        $str = "\$umap = array();\n\$utf8map = array();\n\$cmap = array();\n\$utf8cmap = array();\n";
         reset( $this->UnicodeMap );
         while ( ( $key = key( $this->UnicodeMap ) ) !== null )
         {
             $item = $this->UnicodeMap[$key];
-            $str .= "\$umap[$key] = $item;\n";
+            $php->addVariable( "umap[$key]", $item );
             next( $this->UnicodeMap );
         }
+
         reset( $this->UTF8Map );
         while ( ( $key = key( $this->UTF8Map ) ) !== null )
         {
             $item = $this->UTF8Map[$key];
-            $val = str_replace( array( "\\", "'" ),
-                                array( "\\\\", "\\'" ),
-                                $item );
-            $str .= "\$utf8map[$key] = '$val';\n";
+            if ( $item == 0 )
+            {
+                $php->addCodePiece( "\$utf8map[0] = chr(0);\n" );
+            }
+            else
+            {
+                $val = str_replace( array( "\\", "'" ),
+                                    array( "\\\\", "\\'" ),
+                                    $item );
+                $php->addVariable( "utf8map[$key]", $val );
+            }
             next( $this->UTF8Map );
         }
+
         reset( $this->CodeMap );
         while ( ( $key = key( $this->CodeMap ) ) !== null )
         {
             $item = $this->CodeMap[$key];
-            $str .= "\$cmap[$key] = $item;\n";
+            $php->addVariable( "cmap[$key]", $item );
             next( $this->CodeMap );
         }
+
         reset( $this->UTF8CodeMap );
         while ( ( $key = key( $this->UTF8CodeMap ) ) !== null )
         {
             $item = $this->UTF8CodeMap[$key];
             if ( $item == 0 )
             {
-                $str .= "\$utf8cmap[chr(0)] = 0;\n";
+                $php->addVariable( "utf8cmap[chr(0)]", 0 );
             }
             else
             {
                 $val = str_replace( array( "\\", "'" ),
                                     array( "\\\\", "\\'" ),
                                     $key );
-                $str .= "\$utf8cmap['$val'] = $item;\n";
+                $php->addVariable( "utf8cmap['$val']", $item );
             }
             next( $this->UTF8CodeMap );
         }
+
         reset( $this->ReadExtraMap );
         while ( ( $key = key( $this->ReadExtraMap ) ) !== null )
         {
             $item = $this->ReadExtraMap[$key];
-            $str .= "\$read_extra[$key] = $item;\n";
+            $php->addVariable( "read_extra[$key]", $item );
             next( $this->ReadExtraMap );
         }
 
-        $str = "<?" . "php
-$str
-\$eZCodePageCacheCodeDate = " . self::CACHE_CODE_DATE . ";
-\$min_char = " . $this->MinCharValue . ";
-\$max_char = " . $this->MaxCharValue . ";
-?" . ">";
+        $php->addVariable( "eZCodePageCacheCodeDate", self::CACHE_CODE_DATE );
+        $php->addVariable( "min_char", $this->MinCharValue );
+        $php->addVariable( "max_char", $this->MaxCharValue );
+        $php->store( true );
 
-        if ( !file_exists( $cache_dir ) )
-        {
-//             eZDebug::writeDebug( "Cache dir doesn't exist, attempting to create it with perm.:".$permissionArray['dir_permission'], "");
-
-            // Store the old umask and set a new one.
-            $oldPermissionSetting = umask( 0 );
-
-            //include_once( 'lib/ezfile/classes/ezdir.php' );
-            if ( ! eZDir::mkdir( $cache_dir, $permissionArray['dir_permission'], true ) )
-                eZDebug::writeError( "Couldn't create cache directory $cache_dir, perhaps wrong permissions", "eZCodePage" );
-
-            // Restore the old umask.
-            umask( $oldPermissionSetting );
-
-        }
-        $fd = @fopen( $filename, "w+" );
-        if ( ! $fd )
-        {
-            eZDebug::writeError( "Couldn't write cache file $filename, perhaps wrong permissions or leading directories not created", "eZCodePage" );
-        }
-        else
-        {
-            fwrite( $fd, $str );
-            fclose( $fd );
-        }
-
-        if ( file_exists( $filename) )
+        if ( file_exists( $filename ) )
         {
             // Store the old umask and set a new one.
             $oldPermissionSetting = umask( 0 );
@@ -510,11 +495,12 @@ $str
     }
 
 
-   /*!
-    */
     function cacheFilepath()
     {
         $permissionArray = eZCodePage::permissionSetting();
+
+        if ( $permissionArray === false )
+            return false;
         $cache_dir = $permissionArray['var_directory'] . "/codepages/";
         $cache_filename = md5( $this->CharsetCode );
         $cache = $cache_dir . $cache_filename . ".php";
@@ -537,10 +523,17 @@ $str
         $file = "share/codepages/" . $this->CharsetCode;
 //         eZDebug::writeDebug( "ezcodepage::load was called for $file..." );
 
-        $permissionArray = eZCodePage::permissionSetting();
-        $cache_dir = $permissionArray['var_directory'] . "/codepages/";
-        $cache_filename = md5( $this->CharsetCode );
-        $cache = $cache_dir . $cache_filename . ".php";
+        $permissionArray = self::permissionSetting();
+        if ( $permissionArray !== false )
+        {
+            $cache_dir = $permissionArray['var_directory'] . "/codepages/";
+            $cache_filename = md5( $this->CharsetCode );
+            $cache = $cache_dir . $cache_filename . ".php";
+        }
+        else
+        {
+            $cache = false;
+        }
 
         if ( !file_exists( $file ) )
         {
@@ -556,7 +549,7 @@ $str
                  $siteBasics['no-cache-adviced'] )
                 $use_cache = false;
         }
-        if ( file_exists( $cache ) and $use_cache )
+        if ( $cache && file_exists( $cache ) and $use_cache )
         {
             $cache_m = filemtime( $cache );
             if ( $file_m <= $cache_m )
@@ -657,9 +650,6 @@ $str
 
         if ( $use_cache )
         {
-            // Grab the permission setting(s).
-            $permissionArray = $this->permissionSetting();
-
             // If there is no setting; do nothing:
             if ( $permissionArray === false )
             {
@@ -742,7 +732,7 @@ $str
      Gets the permission setting for codepage files & returns it.
      If the permission setting doesnt exists: returns false.
     */
-    function permissionSetting()
+    static function permissionSetting()
     {
 //         eZDebug::writeDebug( "permissionSetting was called..." );
 
@@ -761,7 +751,7 @@ $str
 
      Sets the permission setting for codepagefiles.
     */
-    function setPermissionSetting( $permissionArray )
+    static function setPermissionSetting( $permissionArray )
     {
 //         eZDebug::writeDebug( "setPermissionSetting was called..." );
 
@@ -785,7 +775,7 @@ $str
         }
 
         // Grab the permission setting for codepage cache files.
-        $permissionArray = eZCodePage::permissionSetting();
+        $permissionArray = self::permissionSetting();
 
         // If we were unable to extract the permission setting:
         if ( $permissionArray === false )
