@@ -5,9 +5,9 @@
 // Created on: <16-Oct-2003 14:22:43 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezimagegdhandler.php
+/*! \file
 */
 
 /*!
@@ -41,8 +41,6 @@
   - height - The height
 */
 
-//include_once( 'lib/ezimage/classes/ezimagehandler.php' );
-
 class eZImageGDHandler extends eZImageHandler
 {
     /*!
@@ -732,7 +730,6 @@ class eZImageGDHandler extends eZImageHandler
             $iniFilename = 'image.ini';
 
         $handler = false;
-        //include_once( 'lib/ezutils/classes/ezini.php' );
         $ini = eZINI::instance( $iniFilename );
         if ( !$ini )
         {
@@ -778,25 +775,4 @@ class eZImageGDHandler extends eZImageHandler
     public $PostParameters;
 }
 
-class eZImageGDFactory extends eZImageFactory
-{
-    /*!
-     Initializes the factory with the name \c 'shell'
-    */
-    function eZImageGDFactory()
-    {
-        $this->eZImageFactory( 'gd' );
-    }
-
-    /*!
-     \reimp
-     Creates eZImageGDHandler objects and returns them.
-    */
-    static function produceFromINI( $iniGroup, $iniFilename = false )
-    {
-        $convertHandler = eZImageGDHandler::createFromINI( $iniGroup, $iniFilename );
-        return $convertHandler;
-    }
-}
-
 ?>
