@@ -5,9 +5,9 @@
 // Created on: <16-Oct-2003 13:58:34 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezimagehandler.php
+/*! \file
 */
 
 /*!
@@ -82,7 +82,6 @@ class eZImageHandler
     }
 
     /*!
-     \virtual
      \return whether this handler can be used or not.
 
      Implementors of image handlers should implement this to return true if
@@ -96,7 +95,6 @@ class eZImageHandler
     }
 
     /*!
-     \virtual
      \return the tag for the MIME type named \a $mimeName.
      This is a helper function for some shell based handlers, it will create a
      proper name from the MIME type \a $mimeData.
@@ -185,7 +183,6 @@ class eZImageHandler
     }
 
     /*!
-     \virtual
      Rewrites the URL in \a $originalMimeData to become a url for \a $destinationMimeData.
      The type of rewrite is determined by \a $rewriteType which can be one of:
      - self::KEEP_SUFFIX - Does nothing to the url
@@ -237,7 +234,6 @@ class eZImageHandler
     }
 
     /*!
-     \virtual
      \return an array with MIME type names that the handler supports as input.
              MIME type names can also be specified with wildcards, for instance
              image/* to say that all image types are supported.
@@ -249,7 +245,6 @@ class eZImageHandler
     }
 
     /*!
-     \virtual
      \return an array with MIME type names that the handler supports as output.
              MIME type names can also be specified with wildcards, for instance
              image/* to say that all image types are supported.
@@ -361,7 +356,6 @@ class eZImageHandler
     }
 
     /*!
-     \virtual
      Figures out the output MIME type for the \a $currentMimeData. It goes trough
      all conversion rules for this handler and returns a MIME structure for the
      possible output. The returned structure also contains the correct url for the output.
