@@ -5,9 +5,9 @@
 // Created on: <03-Oct-2002 15:05:09 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezimageinterface.php
+/*! \file
 */
 
 /*! \defgroup eZImageObject Image object and layer handling */
@@ -189,7 +189,7 @@ class eZImageInterface
      This makes sure that image resources are cleaned up after use.
      \return a reference for the image which can be used in unregisterImage later on. Returns false if resource can't be registered.
     */
-    function registerImage( $image )
+    static function registerImage( $image )
     {
         if ( !is_resource( $image ) or get_resource_type( $image ) != 'gd' )
             return false;
@@ -207,7 +207,7 @@ class eZImageInterface
     /*!
      Tries to unregister the image with reference \a $imageRef
     */
-    function unregisterImage( $imageRef )
+    static function unregisterImage( $imageRef )
     {
         $createdImageArray =& $GLOBALS['eZImageCreatedArray'];
         if ( !is_array( $createdImageArray ) )
@@ -220,7 +220,7 @@ class eZImageInterface
     /*!
      Cleans up all registered images.
     */
-    function cleanupRegisteredImages()
+    static function cleanupRegisteredImages()
     {
         $createdImageArray =& $GLOBALS['eZImageCreatedArray'];
         if ( !is_array( $createdImageArray ) )
@@ -401,7 +401,6 @@ class eZImageInterface
         if ( $this->StoredFile == '' )
             return true;
         $fileArray = array( $this->StoredPath, $this->StoredFile );
-        //include_once( 'lib/ezfile/classes/ezdir.php' );
         $filePath = eZDir::path( $fileArray );
         $imageinfo = getimagesize( $filePath );
         if ( $imageinfo )
@@ -436,12 +435,9 @@ class eZImageInterface
         {
             case 'png':
             {
-                //include_once( 'lib/ezfile/classes/ezdir.php' );
                 if ( !file_exists( $filePath ) )
                 {
-                    $ini = eZINI::instance();
-                    $perm = $ini->variable( 'FileSettings', 'StorageDirPermissions' );
-                    eZDir::mkdir( $filePath, octdec( $perm ), true );
+                    eZDir::mkdir( $filePath, false, true );
                 }
                 $fileFullPath = eZDir::path( array( $filePath, $fileName ) );
                 ImagePNG( $imageObject, $fileFullPath );
@@ -453,12 +449,9 @@ class eZImageInterface
 
             case 'jpg':
             {
-                //include_once( 'lib/ezfile/classes/ezdir.php' );
                 if ( !file_exists( $filePath ) )
                 {
-                    $ini = eZINI::instance();
-                    $perm = $ini->variable( 'FileSettings', 'StorageDirPermissions' );
-                    eZDir::mkdir( $filePath, octdec( $perm ), true );
+                    eZDir::mkdir( $filePath, false, true );
                 }
                 ImageJPEG( $imageObject, eZDir::path( array( $filePath, $fileName ) ) );
                 $this->StoredPath = $filePath;
@@ -479,7 +472,7 @@ class eZImageInterface
      \static
      \return true if GD2 is installed.
     */
-    function hasGD2()
+    static function hasGD2()
     {
         $imageINI = eZINI::instance( 'image.ini' );
         return $imageINI->variable( 'GDSettings', 'HasGD2' ) == 'true';
@@ -500,7 +493,7 @@ class eZImageInterface
      \private
      Creates an image with size \a $width and \a $height using GD and returns it.
     */
-    function createImage( $width, $height, &$useTruecolor )
+    static function createImage( $width, $height, &$useTruecolor )
     {
         if ( $useTruecolor === null )
         {
@@ -548,7 +541,7 @@ class eZImageInterface
     */
     function __clone()
     {
-        $this->cloneImage( $this->imageObject(), $this->width(), $this>height(),
+        $this->cloneImage( $this->imageObject(), $this->width(), $this->height(),
                            $this->isTruecolor() );
     }
 
