@@ -3,9 +3,9 @@
 // Created on: <26-Aug-2003 15:15:32 kk>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -24,14 +24,9 @@
 //
 //
 
-/*! \file eztemplateautoload.php
+/*! \file
 */
 
-//include_once( 'lib/ezpdf/classes/class.ezpdftable.php' );
-//include_once( 'lib/ezpdf/classes/class.pdf.php' );
-
-////include_once( 'lib/ezutils/classes/eztexttool.php' );
-
 /*!
   \defgroup eZPDF PDF generator library
 */
@@ -77,6 +72,8 @@ class eZPDF
     */
     function modify( $tpl, $operatorName, $operatorParameters, $rootNamespace, $currentNamespace, &$operatorValue, $namedParameters )
     {
+        $config = eZINI::instance( 'pdf.ini' );
+
         switch ( $namedParameters['operation'] )
         {
             case 'toc':
@@ -134,23 +131,26 @@ class eZPDF
                 {
                     $tableSettings = $tpl->elementValue( $operatorParameters[2], $rootNamespace, $currentNamespace );
 
-                    foreach( array_keys( $tableSettings ) as $key )
+                    if ( is_array( $tableSettings ) )
                     {
-                        switch( $key )
+                        foreach( array_keys( $tableSettings ) as $key )
                         {
-                            case 'headerCMYK':
-                            case 'cellCMYK':
-                            case 'textCMYK':
-                            case 'titleCellCMYK':
-                            case 'titleTextCMYK':
+                            switch( $key )
                             {
-                                $operatorValue .= ':' . $key . ':' . implode( ',', $tableSettings[$key] );
-                            } break;
+                                case 'headerCMYK':
+                                case 'cellCMYK':
+                                case 'textCMYK':
+                                case 'titleCellCMYK':
+                                case 'titleTextCMYK':
+                                {
+                                    $operatorValue .= ':' . $key . ':' . implode( ',', $tableSettings[$key] );
+                                } break;
 
-                            default:
-                            {
-                                $operatorValue .= ':' . $key . ':' . $tableSettings[$key];
-                            } break;
+                                default:
+                                {
+                                    $operatorValue .= ':' . $key . ':' . $tableSettings[$key];
+                                } break;
+                            }
                         }
                     }
                 }
@@ -159,9 +159,18 @@ class eZPDF
 
                 $rows = $tpl->elementValue( $operatorParameters[1], $rootNamespace, $currentNamespace );
 
-                $operatorValue .= urlencode( str_replace( array( ' ', "\t", "\r\n", "\n" ),
+                $rows = str_replace( array( ' ', "\t", "\r\n", "\n" ),
                                                           '',
-                                                          $rows ) );
+                                                          $rows );
+                $httpCharset = eZTextCodec::internalCharset();
+                $outputCharset = $config->hasVariable( 'PDFGeneral', 'OutputCharset' )
+                                 ? $config->variable( 'PDFGeneral', 'OutputCharset' )
+                                 : 'iso-8859-1';
+                $codec = eZTextCodec::instance( $httpCharset, $outputCharset );
+                // Convert current text to $outputCharset (by default iso-8859-1)
+                $rows = $codec->convertString( $rows );
+
+                $operatorValue .= urlencode( $rows );
 
                 $operatorValue .= '</ezGroup:callTable><C:callNewLine>';
 
@@ -283,14 +292,10 @@ class eZPDF
 
             case 'close':
             {
-                //include_once( 'lib/ezfile/classes/ezdir.php' );
                 $filename = $tpl->elementValue( $operatorParameters[1], $rootNamespace, $currentNamespace );
 
                 eZDir::mkdir( eZDir::dirpath( $filename ), false, true );
 
-                // VS-DBFILE
-
-                require_once( 'kernel/classes/ezclusterfilehandler.php' );
                 $file = eZClusterFileHandler::instance( $filename );
                 $file->storeContents( $this->PDF->ezOutput(), 'viewcache', 'pdf' );
 
@@ -307,8 +312,6 @@ class eZPDF
             /* usage : execute/add text to pdf file, pdf(execute,<text>) */
             case 'execute':
             {
-                $config = eZINI::instance( 'pdf.ini' );
-
                 $text = $tpl->elementValue( $operatorParameters[1], $rootNamespace, $currentNamespace );
 
                 if ( count ( $operatorParameters ) > 2 )
@@ -326,7 +329,6 @@ class eZPDF
                 }
 
                 $text = str_replace( array( ' ', "\n", "\t" ), '', $text );
-                //include_once( 'lib/ezi18n/classes/eztextcodec.php' );
                 $httpCharset = eZTextCodec::internalCharset();
                 $outputCharset = $config->hasVariable( 'PDFGeneral', 'OutputCharset' )
                                  ? $config->variable( 'PDFGeneral', 'OutputCharset' )
@@ -406,6 +408,13 @@ class eZPDF
 
                 if ( isset( $frameDesc['block_code'] ) )
                 {
+                    $httpCharset = eZTextCodec::internalCharset();
+                    $outputCharset = $config->hasVariable( 'PDFGeneral', 'OutputCharset' )
+                                 ? $config->variable( 'PDFGeneral', 'OutputCharset' )
+                                 : 'iso-8859-1';
+                    $codec = eZTextCodec::instance( $httpCharset, $outputCharset );
+                    // Convert current text to $outputCharset (by default iso-8859-1)
+                    $frameDesc['block_code'] = $codec->convertString( $frameDesc['block_code'] );
                     $operatorValue .= urlencode( $frameDesc['block_code'] );
                 }
 
@@ -474,6 +483,13 @@ class eZPDF
 
                 if ( isset( $frameDesc['text'] ) )
                 {
+                    $httpCharset = eZTextCodec::internalCharset();
+                    $outputCharset = $config->hasVariable( 'PDFGeneral', 'OutputCharset' )
+                                 ? $config->variable( 'PDFGeneral', 'OutputCharset' )
+                                 : 'iso-8859-1';
+                    $codec = eZTextCodec::instance( $httpCharset, $outputCharset );
+                    // Convert current text to $outputCharset (by default iso-8859-1)
+                    $frameDesc['text'] = $codec->convertString( $frameDesc['text'] );
                     $operatorValue .= urlencode( $frameDesc['text'] );
                 }
 
@@ -615,6 +631,13 @@ class eZPDF
                 $text = str_replace( array( ' ', "\t", "\r\n", "\n" ),
                                      '',
                                      $text );
+                $httpCharset = eZTextCodec::internalCharset();
+                $outputCharset = $config->hasVariable( 'PDFGeneral', 'OutputCharset' )
+                             ? $config->variable( 'PDFGeneral', 'OutputCharset' )
+                             : 'iso-8859-1';
+                $codec = eZTextCodec::instance( $httpCharset, $outputCharset );
+                // Convert current text to $outputCharset (by default iso-8859-1)
+                $text = $codec->convertString( $text );
 
                 $operatorValue .= '>'. urlencode( $text ) .'</ezGroup:callFrontpage>';
 
@@ -628,7 +651,6 @@ class eZPDF
             */
             case 'set_margin':
             {
-                //include_once( 'lib/ezutils/classes/ezmath.php' );
                 $operatorValue = '<C:callSetMargin';
                 $options = $tpl->elementValue( $operatorParameters[1], $rootNamespace, $currentNamespace );
 
@@ -650,6 +672,13 @@ class eZPDF
                 $text = $tpl->elementValue( $operatorParameters[1], $rootNamespace, $currentNamespace );
 
                 $text = str_replace( array( ' ', "\n", "\t" ), '', $text );
+                $httpCharset = eZTextCodec::internalCharset();
+                $outputCharset = $config->hasVariable( 'PDFGeneral', 'OutputCharset' )
+                             ? $config->variable( 'PDFGeneral', 'OutputCharset' )
+                             : 'iso-8859-1';
+                $codec = eZTextCodec::instance( $httpCharset, $outputCharset );
+                // Convert current text to $outputCharset (by default iso-8859-1)
+                $text = $codec->convertString( $text );
 
                 $operatorValue = '<C:callKeyword:'. rawurlencode( $text ) .'>';
             } break;
@@ -728,7 +757,6 @@ class eZPDF
 
             case 'filled_circle':
             {
-                //include_once( 'lib/ezutils/classes/ezmath.php' );
                 $operatorValue = '';
                 $options = $tpl->elementValue( $operatorParameters[1], $rootNamespace, $currentNamespace );
 
@@ -775,7 +803,6 @@ class eZPDF
 
             case 'rectangle':
             {
-                //include_once( 'lib/ezutils/classes/ezmath.php' );
                 $operatorValue = '';
                 $options = $tpl->elementValue( $operatorParameters[1], $rootNamespace, $currentNamespace );
 
@@ -828,7 +855,6 @@ class eZPDF
                                                     'cmykBottom', array( <c>, <m>, <y>, <k> ) ) ) */
             case 'filled_rectangle':
             {
-                //include_once( 'lib/ezutils/classes/ezmath.php' );
                 $operatorValue = '';
                 $options = $tpl->elementValue( $operatorParameters[1], $rootNamespace, $currentNamespace );
 
@@ -969,6 +995,14 @@ class eZPDF
                     }
                 }
 
+                $httpCharset = eZTextCodec::internalCharset();
+                $outputCharset = $config->hasVariable( 'PDFGeneral', 'OutputCharset' )
+                             ? $config->variable( 'PDFGeneral', 'OutputCharset' )
+                             : 'iso-8859-1';
+                $codec = eZTextCodec::instance( $httpCharset, $outputCharset );
+                // Convert current text to $outputCharset (by default iso-8859-1)
+                $parameters['text'] = $codec->convertString( $parameters['text'] );
+
                 $operatorValue .= '>';
                 $operatorValue .= urlencode( $parameters['text'] );
                 $operatorValue .= '</ezGroup:callTextBox>';
@@ -1020,6 +1054,14 @@ class eZPDF
                             }
                         }
 
+                        $httpCharset = eZTextCodec::internalCharset();
+                        $outputCharset = $config->hasVariable( 'PDFGeneral', 'OutputCharset' )
+                                     ? $config->variable( 'PDFGeneral', 'OutputCharset' )
+                                     : 'iso-8859-1';
+                        $codec = eZTextCodec::instance( $httpCharset, $outputCharset );
+                        // Convert current text to $outputCharset (by default iso-8859-1)
+                        $text = $codec->convertString( $text );
+
                         $operatorValue .= '>' . urlencode( $text ) . '</ezGroup::callTextFrame>';
 
                     }
