@@ -5,9 +5,9 @@
 // Created on: <01-Mar-2002 13:49:57 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file eztemplate.php
+/*! \file
  Template system manager.
 */
 
@@ -217,16 +217,6 @@ Denne koster {1.4|l10n(currency)}<br>
 \endcode
 */
 
-require_once( "lib/ezutils/classes/ezdebug.php" );
-
-//include_once( "lib/eztemplate/classes/eztemplatefileresource.php" );
-
-//include_once( "lib/eztemplate/classes/eztemplateroot.php" );
-//include_once( "lib/eztemplate/classes/eztemplatetextelement.php" );
-//include_once( "lib/eztemplate/classes/eztemplatevariableelement.php" );
-//include_once( "lib/eztemplate/classes/eztemplateoperatorelement.php" );
-//include_once( "lib/eztemplate/classes/eztemplatefunctionelement.php" );
-
 class eZTemplate
 {
     const RESOURCE_FETCH = 1;
@@ -361,7 +351,9 @@ class eZTemplate
              $this->MaxLevel = $ini->variable( 'ControlSettings', 'MaxLevel' );
         require_once('kernel/common/i18n.php');
         $this->MaxLevelWarning = ezi18n( 'lib/template',
-                                         'The maximum nesting level of 40 has been reached. The execution is stopped to avoid infinite recursion.' );
+                                         'The maximum nesting level of %max has been reached. The execution is stopped to avoid infinite recursion.',
+                                         '',
+                                         array( '%max' => $this->MaxLevel ) );
         eZDebug::createAccumulatorGroup( 'template_total', 'Template Total' );
 
         $this->TemplatesUsageStatistics = array();
@@ -718,7 +710,6 @@ class eZTemplate
 
     function parse( $sourceText, &$rootElement, $rootNamespace, &$resourceData )
     {
-        //include_once( 'lib/eztemplate/classes/eztemplatemultipassparser.php' );
         $parser = eZTemplateMultiPassParser::instance();
         $parser->parse( $this, $sourceText, $rootElement, $rootNamespace, $resourceData );
     }
@@ -1532,7 +1523,7 @@ class eZTemplate
     }
 
     /*!
-     Removes the template variable $var. If the variable does not exists an error is output.
+     Removes the template variable $var. If the variable does not exist an error is output.
     */
     function unsetVariable( $var, $namespace = "" )
     {
@@ -1678,16 +1669,12 @@ class eZTemplate
         return null;
     }
 
-    /*!
-    */
     function appendElement( &$text, $item, $nspace, $name )
     {
         $this->appendElementText( $textElements, $item, $nspace, $name );
         $text .= implode( '', $textElements );
     }
 
-    /*!
-    */
     function appendElementText( &$textElements, $item, $nspace, $name )
     {
         if ( !is_array( $textElements ) )
@@ -1714,7 +1701,6 @@ class eZTemplate
                         $templateURI =& $templateData['uri'];
                         $templateVariableName =& $templateData['template_variable_name'];
                         $templateText = '';
-                        //include_once( 'lib/eztemplate/classes/eztemplateincludefunction.php' );
                         $this->setVariableRef( $templateVariableName, $item, $name );
                         eZTemplateIncludeFunction::handleInclude( $textElements, $templateURI, $this, $nspace, $name );
                         $hasTemplateData = true;
@@ -1722,7 +1708,7 @@ class eZTemplate
                 }
             }
             if ( !$hasTemplateData )
-                $textElements[] = 'Object(' . get_class( $item ) . ')';
+                $textElements[] = method_exists( $item, '__toString' ) ? (string)$item : 'Object(' . get_class( $item ) . ')';
         }
         else
             $textElements[] = "$item";
@@ -1743,7 +1729,6 @@ class eZTemplate
         if ( eZTemplate::isXHTMLCodeIncluded() )
             $preText .= "<p class=\"small\">$path</p><br/>\n";
         $postText = "\n<!-- STOP: including template: $path ($uri) -->\n";
-        //include_once( 'lib/eztemplate/classes/eztemplatenodetool.php' );
         $root[1] = array_merge( array( eZTemplateNodeTool::createTextNode( $preText ) ), $root[1] );
         $root[1][] = eZTemplateNodeTool::createTextNode( $postText );
     }
@@ -1763,8 +1748,6 @@ class eZTemplate
         $this->registerFunctionsInternal( $functionObject );
     }
 
-    /*!
-    */
     function registerAutoloadFunctions( $functionDefinition )
     {
         if ( ( ( isset( $functionDefinition['function'] ) or
@@ -1781,7 +1764,7 @@ class eZTemplate
                     $this->error( 'registerFunctions', "Cannot register function definition, missing function names function '$functionNamesFunction'" );
                     return;
                 }
-                $functionNames = $operatorNamesFunction();
+                $functionNames = $functionNamesFunction();
             }
             else
                 $functionNames = $functionDefinition['function_names'];
@@ -1891,8 +1874,6 @@ class eZTemplate
         unset( $this->Literals[$func_name] );
     }
 
-    /*!
-    */
     function registerAutoloadOperators( $operatorDefinition )
     {
         if ( ( ( isset( $operatorDefinition['function'] ) or
@@ -1963,8 +1944,6 @@ class eZTemplate
         $this->registerOperatorsInternal( $operatorObject );
     }
 
-    /*!
-    */
     function registerOperatorsInternal( $operatorObject, $debug = false )
     {
         if ( !is_object( $operatorObject ) or
@@ -2358,7 +2337,6 @@ class eZTemplate
     */
     function ini()
     {
-        //include_once( "lib/ezutils/classes/ezini.php" );
         return eZINI::instance( "template.ini" );
     }
 
