@@ -5,9 +5,9 @@
 // Created on: <05-Mar-2002 12:52:10 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -42,8 +42,6 @@
 
 */
 
-//include_once( "lib/eztemplate/classes/eztemplate.php" );
-
 class eZTemplateArrayOperator
 {
     /*!
@@ -299,9 +297,6 @@ class eZTemplateArrayOperator
                                                     'element-transformation-func' => 'arrayTrans' ) );
     }
 
-    /*!
-     \reimp
-    */
     function arrayTrans( $operatorName, &$node, $tpl, &$resourceData,
                          $element, $lastElement, $elementList, $elementTree, &$parameters )
     {
@@ -1051,9 +1046,6 @@ class eZTemplateArrayOperator
         }
     }
 
-    /*!
-     \reimp
-    */
     function compareTrans( $operatorName, &$node, $tpl, &$resourceData,
                            $element, $lastElement, $elementList, $elementTree, &$parameters )
     {
@@ -1102,7 +1094,7 @@ class eZTemplateArrayOperator
                 {
                     if ( $isString )
                     {
-                        $result = ( strpos ( $inParam, $compareParams[0] ) === ( strlen( $inParam ) - strlen ( $compareParams[0] ) ) );
+                        $result = ( strrpos( $inParam, $compareParams[0] ) === ( strlen( $inParam ) - strlen ( $compareParams[0] ) ) );
                     }
                     else if ( $isArray )
                     {
@@ -1126,7 +1118,7 @@ class eZTemplateArrayOperator
 
                 if ( $isString )
                 {
-                    $code = '%output% = ( strpos( ' . $inParamCode . ', ' . $compareParamsCode[0] . ' ) === ( strlen( ' . $inParamCode . ' ) - strlen( ' . $compareParamsCode[0] . ' ) ) );';
+                    $code = '%output% = ( strrpos( ' . $inParamCode . ', ' . $compareParamsCode[0] . ' ) === ( strlen( ' . $inParamCode . ' ) - strlen( ' . $compareParamsCode[0] . ' ) ) );';
                 }
                 else if ( $isArray )
                 {
@@ -1150,7 +1142,7 @@ class eZTemplateArrayOperator
                     $code = '%tmp4% = ' . $inParamCode . ';' . "\n" .
                          'if ( is_string( %tmp4% ) )' . "\n" .
                          '{' . "\n" .
-                         '  %output% = ( strpos( %tmp4%, ' . $compareParamsCode[0] . ' ) === ( strlen( %tmp4% ) - strlen( ' . $compareParamsCode[0] . ' ) ) );' . "\n" .
+                         '  %output% = ( strrpos( %tmp4%, ' . $compareParamsCode[0] . ' ) === ( strlen( %tmp4% ) - strlen( ' . $compareParamsCode[0] . ' ) ) );' . "\n" .
                          '}' . "\n" .
                          'else if( is_array( %tmp4% ) )' . "\n" .
                          '{' . "\n" .
@@ -1245,9 +1237,6 @@ class eZTemplateArrayOperator
         }
     }
 
-    /*!
-     \reimp
-    */
     function extractTrans( $operatorName, &$node, $tpl, &$resourceData,
                            $element, $lastElement, $elementList, $elementTree, &$parameters )
     {
@@ -1351,9 +1340,6 @@ class eZTemplateArrayOperator
         return array( eZTemplateNodeTool::createCodePieceElement( $code, $values ) );
     }
 
-    /*!
-     \reimp
-    */
     function mergeTrans( $operatorName, &$node, $tpl, &$resourceData,
                          $element, $lastElement, $elementList, $elementTree, &$parameters )
     {
@@ -1712,7 +1698,7 @@ class eZTemplateArrayOperator
                 {
                     $tmpArray   = array();
                     if ( $operatorValue === null ) {
-                        $tmpArray[] = array(); // set to empty array in case of 
+                        $tmpArray[] = array(); // set to empty array in case of
                     } else {
                         $tmpArray[] = $operatorValue;
                     }
@@ -2029,7 +2015,7 @@ class eZTemplateArrayOperator
                 // Check if string ends with specified sequence:
                 case $this->EndsWithName:
                 {
-                    if ( strpos( $operatorValue, $namedParameters['match'] ) === ( strlen( $operatorValue ) - strlen ($namedParameters['match'] ) ) )
+                    if ( strrpos( $operatorValue, $namedParameters['match'] ) === ( strlen( $operatorValue ) - strlen ($namedParameters['match'] ) ) )
                     {
                         $operatorValue = true;
                     }
