@@ -5,9 +5,9 @@
 // Created on: <05-Mar-2002 12:52:10 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -38,13 +38,6 @@
   If fontDir() is an empty string the font will be looked for in the system.
 */
 
-//include_once( "lib/eztemplate/classes/eztemplate.php" );
-//include_once( "lib/ezimage/classes/ezimageobject.php" );
-//include_once( "lib/ezimage/classes/ezimagelayer.php" );
-//include_once( "lib/ezimage/classes/ezimagetextlayer.php" );
-//include_once( 'lib/ezimage/classes/ezimagefont.php' );
-//include_once( "lib/ezutils/classes/ezini.php" );
-
 class eZTemplateImageOperator
 {
     /*!
@@ -58,7 +51,6 @@ class eZTemplateImageOperator
                                   $imageName,
                                   $imagefileName );
 
-        //include_once( "lib/ezutils/classes/ezsys.php" );
         $ini = eZINI::instance( 'texttoimage.ini' );
         $fontDirs = $ini->variable( "PathSettings", "FontDir" );
         $this->FontDir = array();
@@ -253,7 +245,7 @@ class eZTemplateImageOperator
             }
             else
             {
-                $layer =& $this->loadImage( $this->CacheDir, 'imagetext', $md5Text, $alternativeText, $this->StoreAs );
+                $layer = $this->loadImage( $this->CacheDir, 'imagetext', $md5Text, $alternativeText, $this->StoreAs );
             }
             $layer->setAlternativeText( $alternativeText );
             $inputValue = $layer;
@@ -294,7 +286,7 @@ class eZTemplateImageOperator
                 $file = $matches[2];
             }
 
-            $layer =& eZImageLayer::createForFile( $file, $dir );
+            $layer = eZImageLayer::createForFile( $file, $dir );
             $alternativeText = $file;
             if ( preg_match( "#(.+)\.([^.]+)$#", $file, $matches ) )
                 $alternativeText = $matches[1];
@@ -631,10 +623,12 @@ class eZTemplateImageOperator
         $file = "$name.$imageType";
         $splitMD5Path = eZDir::getPathFromFilename( $md5Text );
         $filePath = eZDir::path( array( $dirs, $base, $splitMD5Path, $md5Text, $file ) );
-        return file_exists( $filePath );
+
+        $fileHandler = eZClusterFileHandler::instance( $filePath );
+        return $fileHandler->exists();
     }
 
-    function storeImage( &$image, $dirs, $base, $md5Text, $alternativeText, $imageType )
+    function storeImage( $image, $dirs, $base, $md5Text, $alternativeText, $imageType )
     {
         $name = preg_replace( array( "#[^a-zA-Z0-9_-]+#",
                                      "#__+#",
@@ -646,16 +640,15 @@ class eZTemplateImageOperator
         $file = "$name.$imageType";
         $splitMD5Path = eZDir::getPathFromFilename( $md5Text );
         $dirPath = eZDir::path( array( $dirs, $base, $splitMD5Path, $md5Text ) );
-        if ( !file_exists( $dirPath ) )
-        {
-            $ini = eZINI::instance();
-            $mod = $ini->variable( 'FileSettings', 'StorageDirPermissions' );
-            eZDir::mkdir( $dirPath, octdec( $mod ), true );
-        }
         $image->store( $file, $dirPath, $imageType );
+
+        $fileHandler = eZClusterFileHandler::instance();
+        $filePath = eZDir::path( array( $dirPath, $file ) );
+        $mimeData = eZMimeType::findByURL( $filePath, true );
+        $fileHandler->fileStore( $filePath, 'texttoimage', false, $mimeData['name'] );
     }
 
-    function setLoadImage( &$image, $dirs, $base, $md5Text, $alternativeText, $imageType )
+    function setLoadImage( $image, $dirs, $base, $md5Text, $alternativeText, $imageType )
     {
         $name = preg_replace( array( "#[^a-zA-Z0-9_-]+#",
                                      "#__+#",
@@ -668,12 +661,18 @@ class eZTemplateImageOperator
         $splitMD5Path = eZDir::getPathFromFilename( $md5Text );
         $dirPath = eZDir::path( array( $dirs, $base, $splitMD5Path, $md5Text ) );
         $filePath = eZDir::path( array( $dirPath, $file ) );
-        if ( !file_exists( $filePath ) )
+        $fileHandler = eZClusterFileHandler::instance( $filePath );
+        if ( !$fileHandler->exists() )
+        {
             return null;
+        }
+
+        // we use a local cache of the file, because the eZImage library only works on files on the file system
+        $fileHandler->fetch( true );
         $image->setStoredFile( $file, $dirPath, $imageType );
     }
 
-    function &loadImage( $dirs, $base, $md5Text, $alternativeText, $imageType )
+    function loadImage( $dirs, $base, $md5Text, $alternativeText, $imageType )
     {
         $name = preg_replace( array( "#[^a-zA-Z0-9_-]+#",
                                      "#__+#",
@@ -686,14 +685,19 @@ class eZTemplateImageOperator
         $splitMD5Path = eZDir::getPathFromFilename( $md5Text );
         $dirPath = eZDir::path( array( $dirs, $base, $splitMD5Path, $md5Text ) );
         $filePath = eZDir::path( array( $dirPath, $file ) );
-        if ( !file_exists( $filePath ) )
-            $layer = null;
-        else
-            $layer = eZImageLayer::createForFile( $file, $dirPath, $this->StoreAs );
-        return $layer;
+
+        $fileHandler = eZClusterFileHandler::instance( $filePath );
+        if ( !$fileHandler->exists() )
+        {
+            return null;
+        }
+
+        // we use a local cache of the file, because the eZImage library only works on files on the file system
+        $fileHandler->fetch( true );
+        return eZImageLayer::createForFile( $file, $dirPath, $this->StoreAs );
     }
 
-    function readImageParameters( $tpl, &$image, $operatorParameters, $rootNamespace, $currentNamespace, &$md5Input, &$alternativeText,
+    function readImageParameters( $tpl, $image, $operatorParameters, $rootNamespace, $currentNamespace, &$md5Input, &$alternativeText,
                                   $placement )
     {
         $imageAlternativeText = false;
@@ -709,7 +713,7 @@ class eZTemplateImageOperator
             }
             else if ( is_array( $operatorParameter ) )
             {
-                $imageLayer =& $operatorParameter[0];
+                $imageLayer = $operatorParameter[0];
                 $imageParameterSource = $operatorParameter[1];
                 if ( isset( $imageParameterSource['transparency'] ) )
                     $imageParameters['transparency'] = $imageParameterSource['transparency'];
@@ -793,7 +797,7 @@ class eZTemplateImageOperator
                 }
             }
             else
-                $imageLayer =& $operatorParameter;
+                $imageLayer = $operatorParameter;
             if ( $imageLayer !== null and
                  $image->appendLayer( $imageLayer, $imageParameters ) )
             {
