@@ -5,9 +5,9 @@
 // Created on: <01-Mar-2002 13:49:40 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -44,9 +44,6 @@
 \endcode
 */
 
-//include_once( "lib/ezlocale/classes/ezlocale.php" );
-//include_once( 'lib/ezlocale/classes/ezdatetime.php' );
-
 class eZTemplateLocaleOperator
 {
     /*!
@@ -302,7 +299,6 @@ class eZTemplateLocaleOperator
         $newElements = array();
         $paramCount = count( $parameters );
 
-        $code = '%output% = mktime( ';
         if ( $operatorName == 'makedate' )
         {
             $arguments = array ( 0, 0, 0 );
@@ -316,7 +312,8 @@ class eZTemplateLocaleOperator
             $values[] = $parameters[$i];
             $arguments[] = '%' . ($i + 1) . '%';
         }
-        $code .= implode( ', ', $arguments ) . " );\n";
+
+        $code = count( $arguments ) == 0 ? "%output% = time();\n" : "%output% = mktime( " . implode( ', ', $arguments ) . " );\n";
         $newElements[] = eZTemplateNodeTool::createCodePieceElement( $code, $values );
         return $newElements;
     }
@@ -440,7 +437,8 @@ class eZTemplateLocaleOperator
                     }
                 }
             }
-            $operatorValue = call_user_func_array( 'mktime', $parameters );
+
+            $operatorValue = count( $parameters ) == 0 ? time() : call_user_func_array( 'mktime', $parameters );
         }
         else if ( $operatorName == $this->MakeDateName )
         {
