@@ -5,9 +5,9 @@
 // Created on: <05-Mar-2002 13:55:25 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -230,6 +230,10 @@ class eZTemplateSetFunction
                 if ( $functionName == $this->LetName or $functionName == $this->DefaultName )
                 {
                     $childNodes = eZTemplateNodeTool::extractFunctionNodeChildren( $node );
+                    if ( !is_array( $childNodes ) )
+                    {
+                        $childNodes = array();
+                    }
                 }
                 else
                 {
