@@ -5,9 +5,9 @@
 // Created on: <05-Aug-2003 13:00:00 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file cli.php
+/*! \file
 */
 
 /*!
@@ -48,10 +48,6 @@ $cli->output( "This is a text string" );
 
 */
 
-//include_once( 'lib/ezutils/classes/ezini.php' );
-require_once( 'lib/ezutils/classes/ezdebug.php' );
-//include_once( 'lib/ezutils/classes/ezdebugsetting.php' );
-
 class eZCLI
 {
     const TERMINAL_ENDOFLINE_STRING = "\n";
@@ -313,7 +309,7 @@ class eZCLI
      \static
      \returns an ANSI sequence which will store the current position.
     */
-    function storePosition()
+    static function storePosition()
     {
         return "\033[s";
     }
@@ -322,13 +318,12 @@ class eZCLI
      \static
      \returns an ANSI sequence which will restore the current position.
     */
-    function restorePosition()
+    static function restorePosition()
     {
         return "\033[u";
     }
 
     /*!
-     \static
      \return an ANSI sequence which will tell the console go to the specified column.
     */
     function gotoColumn( $column )
@@ -445,7 +440,7 @@ class eZCLI
         return !$this->IsQuiet;
     }
 
-    function parseOptionString( $configString, &$optionConfig )
+    static function parseOptionString( $configString, &$optionConfig )
     {
         $len = strlen( $configString );
         $i = 0;
@@ -712,7 +707,7 @@ class eZCLI
     /*!
      \return \c true if instance of eZCLI already exists otherwise \c false.
     */
-    function hasInstance()
+    static function hasInstance()
     {
         return isset( $GLOBALS['eZCLIInstance'] ) && $GLOBALS['eZCLIInstance'] instanceof eZCLI;
     }
