@@ -5,9 +5,9 @@
 // Created on: <12-Feb-2002 11:00:54 bf>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -45,7 +45,6 @@
   PHP error messages can also be shown using setHandleType().
 
   \code
-  require_once( "lib/ezutils/classes/ezdebug.php" );
 
   // write a temporary debug message
   eZDebug::writeDebug( "Test" );
@@ -72,8 +71,6 @@
   \endcode
 */
 
-//include_once( "lib/ezutils/classes/ezsys.php" );
-
 class eZDebug
 {
     const LEVEL_NOTICE = 1;
@@ -281,7 +278,7 @@ class eZDebug
         {
             case self::HANDLE_FROM_PHP:
             {
-                set_error_handler( "eZDebugErrorHandler" );
+                set_error_handler( array( $instance, 'recursionProtectErrorHandler' ) );
             } break;
 
             case self::HANDLE_TO_PHP:
@@ -318,6 +315,22 @@ class eZDebug
         return $old_types;
     }
 
+    public function recursionProtectErrorHandler( $errno, $errstr, $errfile, $errline )
+    {
+        if ( $this->recursionFlag )
+        {
+            print( "Fatal debug error: A recursion in debug error handler was detected, aborting debug message.<br/>" );
+            $this->recursionFlag = false;
+            return;
+        }
+
+        $this->recursionFlag = true;
+
+        $result = $this->errorHandler( $errno, $errstr, $errfile, $errline );
+        $this->recursionFlag = false;
+        return $result;
+    }
+
     /*!
      Handles PHP errors, creates notice, warning and error messages for
      the various PHP error types.
@@ -329,55 +342,71 @@ class eZDebug
         if ( !eZDebug::isDebugEnabled() )
             return;
         $str = "$errstr in $errfile on line $errline";
-        if ( empty( $GLOBALS["eZDebugPHPErrorNames"] ) )
+        if ( empty( $GLOBALS['eZDebugPHPErrorNames'] ) )
         {
-            $GLOBALS["eZDebugPHPErrorNames"] =
-                array( E_ERROR => "E_ERROR",
-                       E_PARSE => "E_PARSE",
-                       E_CORE_ERROR => "E_CORE_ERROR",
-                       E_COMPILE_ERROR => "E_COMPILE_ERROR",
-                       E_USER_ERROR => "E_USER_ERROR",
-                       E_WARNING => "E_WARNING",
-                       E_CORE_WARNING => "E_CORE_WARNING",
-                       E_COMPILE_WARNING => "E_COMPILE_WARNING",
-                       E_USER_WARNING => "E_USER_WARNING",
-                       E_NOTICE => "E_NOTICE",
-                       E_USER_NOTICE => "E_USER_NOTICE",
-                       E_STRICT => "E_STRICT" );
+            $GLOBALS['eZDebugPHPErrorNames'] =
+                array( E_ERROR => 'E_ERROR',
+                       E_PARSE => 'E_PARSE',
+                       E_CORE_ERROR => 'E_CORE_ERROR',
+                       E_COMPILE_ERROR => 'E_COMPILE_ERROR',
+                       E_USER_ERROR => 'E_USER_ERROR',
+                       E_WARNING => 'E_WARNING',
+                       E_CORE_WARNING => 'E_CORE_WARNING',
+                       E_COMPILE_WARNING => 'E_COMPILE_WARNING',
+                       E_USER_WARNING => 'E_USER_WARNING',
+                       E_NOTICE => 'E_NOTICE',
+                       E_USER_NOTICE => 'E_USER_NOTICE',
+                       E_STRICT => 'E_STRICT' );
+            // Since PHP 5.2
+            if ( defined('E_RECOVERABLE_ERROR') )
+                $GLOBALS['eZDebugPHPErrorNames'][E_RECOVERABLE_ERROR] = 'E_RECOVERABLE_ERROR';
+            // Since PHP 5.3
+            if ( defined('E_DEPRECATED') )
+                $GLOBALS['eZDebugPHPErrorNames'][E_DEPRECATED] = 'E_DEPRECATED';
+            if ( defined('E_USER_DEPRECATED') )
+                $GLOBALS['eZDebugPHPErrorNames'][E_USER_DEPRECATED] = 'E_USER_DEPRECATED';
+            
         }
-        $errname = "unknown";
-        if ( isset( $GLOBALS["eZDebugPHPErrorNames"][$errno] ) )
+        $errname = "Unknown error code ($errno)";
+        if ( isset( $GLOBALS['eZDebugPHPErrorNames'][$errno] ) )
         {
-            $errname = $GLOBALS["eZDebugPHPErrorNames"][$errno];
+            $errname = $GLOBALS['eZDebugPHPErrorNames'][$errno];
         }
-        switch ( $errno )
+        switch ( $errname )
         {
-            case E_ERROR:
-            case E_PARSE:
-            case E_CORE_ERROR:
-            case E_COMPILE_ERROR:
-            case E_USER_ERROR:
+            case 'E_ERROR':
+            case 'E_PARSE':
+            case 'E_CORE_ERROR':
+            case 'E_COMPILE_ERROR':
+            case 'E_USER_ERROR':
+            case 'E_RECOVERABLE_ERROR':
             {
-                $this->writeError( $str, "PHP" );
+                $this->writeError( $str, 'PHP: ' . $errname );
             } break;
 
-            case E_WARNING:
-            case E_CORE_WARNING:
-            case E_COMPILE_WARNING:
-            case E_USER_WARNING:
-            case E_NOTICE:
+            case 'E_WARNING':
+            case 'E_CORE_WARNING':
+            case 'E_COMPILE_WARNING':
+            case 'E_USER_WARNING':
+            case 'E_DEPRECATED':
+            case 'E_USER_DEPRECATED':
             {
-                $this->writeWarning( $str, "PHP" );
+                $this->writeWarning( $str, 'PHP: ' . $errname );
             } break;
 
-            case E_USER_NOTICE:
+            case 'E_NOTICE':
+            case 'E_USER_NOTICE':
             {
-                $this->writeNotice( $str, "PHP" );
+                $this->writeNotice( $str, 'PHP: ' . $errname );
             } break;
 
-            case E_STRICT:
+            case 'E_STRICT':
             {
-                return $this->writeStrict( $str, "PHP" );
+                return $this->writeStrict( $str, 'PHP: ' . $errname );
+            } break;
+            default:
+            {
+                 $this->writeError( $str, 'PHP: ' . $errname );
             } break;
         }
     }
@@ -644,8 +673,6 @@ class eZDebug
         $this->MessageOutput = $output;
     }
 
-    /*!
-    */
     function setStoreLog( $store )
     {
         $this->StoreLog = $store;
@@ -828,7 +855,6 @@ class eZDebug
                 else
                 {
                     $newLogRotateName = $fileName . '.' . ($i + 1);
-                    //include_once( 'lib/ezfile/classes/ezfile.php' );
                     eZFile::rename( $logRotateName, $newLogRotateName );
 //                     print( "@rename( $logRotateName, $newLogRotateName )<br/>" );
                 }
@@ -837,7 +863,6 @@ class eZDebug
         if ( @file_exists( $fileName ) )
         {
             $newLogRotateName = $fileName . '.' . 1;
-            //include_once( 'lib/ezfile/classes/ezfile.php' );
             eZFile::rename( $fileName, $newLogRotateName );
 //             print( "@rename( $fileName, $newLogRotateName )<br/>" );
             return true;
@@ -862,8 +887,7 @@ class eZDebug
         $fileName = $logDir . $logName;
         if ( !file_exists( $logDir ) )
         {
-            //include_once( 'lib/ezfile/classes/ezdir.php' );
-            eZDir::mkdir( $logDir, 0775, true );
+            eZDir::mkdir( $logDir, false, true );
         }
         $oldumask = @umask( 0 );
         $fileExisted = @file_exists( $fileName );
@@ -884,7 +908,11 @@ class eZDebug
             @fwrite( $logFile, $notice );
             @fclose( $logFile );
             if ( !$fileExisted )
-                @chmod( $fileName, 0664 );
+            {
+                $ini = eZINI::instance();
+                $permissions = octdec( $ini->variable( 'FileSettings', 'LogFilePermissions' ) );
+                @chmod( $fileName, $permissions );
+            }
             @umask( $oldumask );
         }
         else
@@ -1073,61 +1101,19 @@ class eZDebug
             $GLOBALS['eZDebugLogOnly'] = ( $settings['log-only'] == 'enabled' );
         }
 
-        $notDebugByIP = true;
-        $debugEnabled = $settings['debug-enabled'];
-        if ( $settings['debug-enabled'] and
-             $settings['debug-by-ip'] )
+        $GLOBALS['eZDebugAllowedByIP'] = $settings['debug-by-ip'] ? self::isAllowedByCurrentIP( $settings['debug-ip-list'] ) : true;
+
+        // updateSettings is meant to be called before the user session is started
+        // so we do not take debug-by-user into account yet, but store the debug-user-list in $GLOBALS
+        // so it can be used in the final check, done by checkDebugByUser()
+        if ( isset( $settings['debug-by-user'] ) && $settings['debug-by-user'] )
         {
-            $ipAddress = eZSys::serverVariable( 'REMOTE_ADDR', true );
-            if ( $ipAddress )
-            {
-                $debugEnabled = false;
-                foreach( $settings['debug-ip-list'] as $itemToMatch )
-                {
-                    if ( preg_match("/^(([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+))(\/([0-9]+)$|$)/", $itemToMatch, $matches ) )
-                    {
-                        if ( $matches[6] )
-                        {
-                            if ( eZDebug::isIPInNet( $ipAddress, $matches[1], $matches[7]))
-                            {
-                                $debugEnabled = true;
-                                $notDebugByIP = false;
-                                break;
-                            }
-                        }
-                        else
-                        {
-                            if ( $matches[1] == $ipAddress )
-                            {
-                                $debugEnabled = true;
-                                $notDebugByIP = false;
-                                break;
-                            }
-                        }
-                    }
-                }
-            }
-            else
-            {
-                $debugEnabled = (
-                    in_array( 'commandline', $settings['debug-ip-list'] ) &&
-                    ( php_sapi_name() == 'cli' )
-                );
-            }
-        }
-        if ( $settings['debug-enabled'] and
-             isset( $settings['debug-by-user'] ) and
-             $settings['debug-by-user'] and
-             $notDebugByIP )
-        {
-            $debugUserIDList = $settings['debug-user-list'] ? $settings['debug-user-list'] : array();
-            $GLOBALS['eZDebugUserIDList'] = $debugUserIDList;
-            // We enable the debug temporarily.
-            // In checkDebugByUser() will be last(final) check for debug by user id.
-            $debugEnabled = true;
+            $GLOBALS['eZDebugUserIDList'] = $settings['debug-user-list'] ? $settings['debug-user-list'] : array();
         }
 
-        $GLOBALS['eZDebugEnabled'] = $debugEnabled;
+        $GLOBALS['eZDebugAllowed'] = $GLOBALS['eZDebugAllowedByIP'];
+        $GLOBALS['eZDebugEnabled'] = $settings['debug-enabled'] && $GLOBALS['eZDebugAllowedByIP'];
+
         eZDebug::setHandleType( $oldHandleType );
     }
 
@@ -1135,28 +1121,44 @@ class eZDebug
       \static
       Final checking for debug by user id.
       Checks if we should enable debug.
+
+      Returns false if debug-by-user is not active, was already checked before
+      or if there is no current user. Returns true otherwise.
     */
     static function checkDebugByUser()
     {
-        $debugUserIDList = isset( $GLOBALS['eZDebugUserIDList'] ) ? $GLOBALS['eZDebugUserIDList'] : false;
-
-        if ( $debugUserIDList === false )
-            return false;
-
-        if ( count( $debugUserIDList ) == 0 )
+        if ( !isset( $GLOBALS['eZDebugUserIDList'] ) ||
+             !is_array( $GLOBALS['eZDebugUserIDList'] ) )
         {
-            // We should set previous value.
-            return $GLOBALS['eZDebugEnabled'] = false;
+            return false;
         }
+        else
+        {
+            $currentUserID = eZUser::currentUserID();
 
-        // if ( //include_once( "kernel/classes/datatypes/ezuser/ezuser.php" ) )
-        $currentUserID = eZUser::currentUserID();
+            if ( !$currentUserID )
+            {
+                return false;
+            }
+            else
+            {
+                $GLOBALS['eZDebugAllowedByUser'] = in_array( $currentUserID, $GLOBALS['eZDebugUserIDList'] );
 
-        $GLOBALS['eZDebugEnabled'] = $currentUserID ?
-            in_array( $currentUserID, $debugUserIDList ) :
-            $GLOBALS['eZDebugEnabled'];
+                if ( $GLOBALS['eZDebugAllowed'] )
+                {
+                    $GLOBALS['eZDebugAllowed'] = $GLOBALS['eZDebugAllowedByUser'];
+                }
 
-        unset( $GLOBALS['eZDebugUserIDList'] );
+                if ( $GLOBALS['eZDebugEnabled'] )
+                {
+                    $GLOBALS['eZDebugEnabled'] = $GLOBALS['eZDebugAllowedByUser'];
+                }
+
+                unset( $GLOBALS['eZDebugUserIDList'] );
+
+                return true;
+            }
+        }
     }
 
     /*!
@@ -1175,6 +1177,8 @@ class eZDebug
         if ( $newWindow == true )
         {
             $debugFilePath = eZDir::path( array( eZSys::varDirectory(), 'cache', 'debug.html' ) );
+            $debugFileURL = $debugFilePath;
+            eZURI::transformURI( $debugFileURL, true );
             print( "
 <SCRIPT LANGUAGE='JavaScript'>
 <!-- hide this script from old browsers
@@ -1186,7 +1190,7 @@ function showDebug()
     if  (navigator.appName == \"Microsoft Internet Explorer\")
     {
         //Microsoft Internet Explorer
-        debugWindow = window.open( '/$debugFilePath', 'ezdebug', 'width=500,height=550,status,scrollbars,resizable,screenX=0,screenY=20,left=20,top=40');
+        debugWindow = window.open( '$debugFileURL', 'ezdebug', 'width=500,height=550,status,scrollbars,resizable,screenX=0,screenY=20,left=20,top=40');
         debugWindow.document.close();
         debugWindow.location.reload();
     }
@@ -1194,14 +1198,14 @@ function showDebug()
     {
         //Opera
         debugWindow = window.open( '', 'ezdebug', 'width=500,height=550,status,scrollbars,resizable,screenX=0,screenY=20,left=20,top=40');
-        debugWindow.location.href=\"/$debugFilePath\";
-        debugWindow.navigate(\"/$debugFilePath\");
+        debugWindow.location.href=\"$debugFileURL\";
+        debugWindow.navigate(\"$debugFileURL\");
     }
     else
     {
         //Mozilla, Firefox, etc.
         debugWindow = window.open( '', 'ezdebug', 'width=500,height=550,status,scrollbars,resizable,screenX=0,screenY=20,left=20,top=40');
-        debugWindow.document.location.href=\"/$debugFilePath\";
+        debugWindow.document.location.href=\"$debugFileURL\";
     };
 }
 
@@ -1234,7 +1238,7 @@ showDebug();
     static function timeToFloat( $mtime )
     {
         $tTime = explode( " ", $mtime );
-        ereg( "0\.([0-9]+)", "" . $tTime[0], $t1 );
+        preg_match( "#0\.([0-9]+)#", "" . $tTime[0], $t1 );
         $time = $tTime[1] . "." . $t1[1];
         return $time;
     }
@@ -1316,7 +1320,7 @@ showDebug();
 
         if ( $recursive )
         {
-            if ( isset( $this->TimeAccumulatorList[$key]['recursive_counter'] ) )
+            if ( isset( $debug->TimeAccumulatorList[$key]['recursive_counter'] ) )
             {
                 $debug->TimeAccumulatorList[$key]['recursive_counter']++;
                 return;
@@ -1339,7 +1343,7 @@ showDebug();
         $key = $key === false ? 'Default Debug-Accumulator' : $key;
         if ( ! array_key_exists( $key, $debug->TimeAccumulatorList ) )
         {
-            eZDebug::writeWarning( 'Accumulator $key does not exists, run eZDebug::accumulatorStart first', 'eZDebug::accumulatorStop' );
+            eZDebug::writeWarning( "Accumulator '$key' does not exist, run eZDebug::accumulatorStart first", 'eZDebug::accumulatorStop' );
             return;
         }
         $accumulator = $debug->TimeAccumulatorList[$key];
@@ -1368,7 +1372,9 @@ showDebug();
     function printReportInternal( $as_html = true, $returnReport = true, $allowedDebugLevels = false,
                                   $useAccumulators = true, $useTiming = true, $useIncludedFiles = false )
     {
-        $styles = array( 'warning' => false,
+        $styles = array( 'strict' => false,
+                         'strict-end' => false,
+                         'warning' => false,
                          'warning-end' => false,
                          'error' => false,
                          'error-end' => false,
@@ -1398,7 +1404,7 @@ showDebug();
 
         if ( $as_html )
         {
-            echo "<div id=\"debug\"><table style='border: 1px dashed black;' bgcolor=\"#fefefe\" summary='Layout table for eZ Publish debug output'>";
+            echo "<div id=\"debug\"><table style='border: 1px dashed black; background-color: #fefefe;' summary='Layout table for eZ Publish debug output'>";
             echo "<tr><th><h1>eZ debug</h1></th></tr>";
 
             echo "<tr><td>";
@@ -1499,7 +1505,7 @@ td.timingpoint2
             echo "</table>";
 
             echo "<h2>Timing points:</h2>";
-            echo "<table style='border: 1px dashed black;' cellspacing='0' summary='Tabel of timingpoint stats.'><tr><th>Checkpoint</th><th>Elapsed</th><th>Rel. Elapsed</th><th>Memory</th><th>Rel. Memory</th></tr>";
+            echo "<table id='timingpoints' style='border: 1px dashed black;' cellspacing='0' summary='Tabel of timingpoint stats.'><tr><th>Checkpoint</th><th>Elapsed</th><th>Rel. Elapsed</th><th>Memory</th><th>Rel. Memory</th></tr>";
         }
         $startTime = false;
         $elapsed = 0.00;
@@ -1514,25 +1520,31 @@ td.timingpoint2
                     $nextPoint = $this->TimePoints[$i + 1];
                 $time = $point["Time"];
                 $nextTime = false;
-                if ( $nextPoint !== false )
-                    $nextTime = $nextPoint["Time"];
                 if ( $startTime === false )
                     $startTime = $time;
                 $elapsed = $time - $startTime;
-                $relElapsed = $nextTime - $time;
 
                 $memory = $point["MemoryUsage"];
-                $nextMemory = 0;
-                // Calculate relative memory usage
+                // Calculate relative time and memory usage
                 if ( $nextPoint !== false )
                 {
+                    $nextTime = $nextPoint["Time"];
+                    $relElapsed = $nextTime - $time;
+                    $relElapsed = number_format( $relElapsed, $this->TimingAccuracy ) . " sec";
+
                     $nextMemory = $nextPoint["MemoryUsage"];
                     $relMemory = $nextMemory - $memory;
+                    $relMemory = number_format( $relMemory / 1024, $this->TimingAccuracy ) . " KB";
+                }
+                else
+                {
+                    $relElapsed = $as_html ? '&nbsp;' : '';
+                    $relMemory = $as_html ? '&nbsp;' : '';
                 }
 
-                // Convert memeory usage to human readable
-                $memory = number_format( $memory / 1024, $this->TimingAccuracy ) . "KB";
-                $relMemory = number_format( $relMemory / 1024, $this->TimingAccuracy ) . "KB";
+                // Convert memory usage to human readable
+                $memory = number_format( $memory / 1024, $this->TimingAccuracy ) . " KB";
+                $elapsed = number_format( $elapsed, $this->TimingAccuracy ) . " sec";
 
                 if ( $i % 2 == 0 )
                     $class = "timingpoint1";
@@ -1541,16 +1553,13 @@ td.timingpoint2
 
                 if ( $as_html )
                 {
-                    echo "<tr><td class='$class'>" . $point["Description"] . "</td><td class='$class'>" .
-    number_format( ( $elapsed ), $this->TimingAccuracy ) . " sec</td><td class='$class'>".
-    ( empty( $nextPoint ) ? "&nbsp;" : number_format( ( $relElapsed ), $this->TimingAccuracy ) . " sec" ) . "</td>"
-    . "<td class='$class'>" . $memory . "</td><td class='$class'>". $relMemory . "</td></tr>";
+                    echo "<tr><td class='$class'>" . $point["Description"] . "</td>
+                          <td class='$class' align='right'>$elapsed</td><td class='$class' align='right'>$relElapsed</td>
+                          <td class='$class' align='right'>$memory</td><td class='$class' align='right'>$relMemory</td></tr>";
                 }
                 else
                 {
-                    echo $point["Description"] . ' ' .
-    number_format( ( $elapsed ), $this->TimingAccuracy ) . " sec".
-    ( empty( $nextPoint ) ? "" : number_format( ( $relElapsed ), $this->TimingAccuracy ) . " sec" ) . "\n";
+                    echo $point["Description"] . ' ' . $elapsed . $relElapsed . "\n";
                 }
             }
 
@@ -1576,15 +1585,20 @@ td.timingpoint2
                 else
                     echo "No timing points defined\n";
             }
-            if ( function_exists('xdebug_peak_memory_usage') )
+
+            if ( function_exists( 'memory_get_peak_usage' ) )
             {
-                $peakMemory = xdebug_peak_memory_usage();
+                $peakMemory = memory_get_peak_usage();
                 if ( $as_html )
+                {
                     echo "<tr><td><b>Peak memory usage:</b></td><td><b>" .
-                        number_format( $peakMemory / 1024, $this->TimingAccuracy ) . "KB</b></td></tr>";
+                        number_format( $peakMemory / 1024, $this->TimingAccuracy ) . " KB</b></td></tr>";
+                }
                 else
+                {
                     echo "Peak memory usage: " .
-                        number_format( $peakMemory / 1024, $this->TimingAccuracy ) . "KB\n";
+                        number_format( $peakMemory / 1024, $this->TimingAccuracy ) . " KB\n";
+                }
             }
         }
         if ( $as_html )
@@ -1626,7 +1640,7 @@ td.timingpoint2
         if ( $as_html )
         {
             echo "<h2>Time accumulators:</h2>";
-            echo "<table style='border: 1px dashed black;' cellspacing='0' summary='Table with detailed list of time accumulators'><tr><th>&nbsp;Accumulator</th><th>&nbsp;Elapsed</th><th>&nbsp;Percent</th><th>&nbsp;Count</th><th>&nbsp;Average</th></tr>";
+            echo "<table id='timeaccumulators' style='border: 1px dashed black;' cellspacing='0' summary='Table with detailed list of time accumulators'><tr><th>&nbsp;Accumulator</th><th>&nbsp;Elapsed</th><th>&nbsp;Percent</th><th>&nbsp;Count</th><th>&nbsp;Average</th></tr>";
             $i = 0;
         }
 
@@ -1829,6 +1843,51 @@ td.timingpoint2
         }
     }
 
+    /*!
+     If debugging is allowed, given the limitations of the DebugByIP and DebugByUser settings.
+    */
+    function isDebugAllowed()
+    {
+
+    }
+
+    /*!
+     If debugging is allowed for the current IP address.
+    */
+    private static function isAllowedByCurrentIP( $allowedIpList )
+    {
+        $ipAddress = eZSys::serverVariable( 'REMOTE_ADDR', true );
+        if ( $ipAddress )
+        {
+            foreach( $allowedIpList as $itemToMatch )
+            {
+                if ( preg_match("/^(([0-9]+)\.([0-9]+)\.([0-9]+)\.([0-9]+))(\/([0-9]+)$|$)/", $itemToMatch, $matches ) )
+                {
+                    if ( $matches[6] )
+                    {
+                        if ( self::isIPInNet( $ipAddress, $matches[1], $matches[7] ) )
+                        {
+                            return true;
+                        }
+                    }
+                    else
+                    {
+                        if ( $matches[1] == $ipAddress )
+                        {
+                            return true;
+                        }
+                    }
+                }
+            }
+
+            return false;
+        }
+        else
+        {
+            return eZSys::isShellExecution() && in_array( 'commandline', $allowedIpList );
+        }
+    }
+
     /// \privatesection
     /// String array containing the debug information
     public $DebugStrings = array();
@@ -1854,10 +1913,10 @@ td.timingpoint2
     /// An array of logfiles used by the debug class with each key being the debug level
     public $LogFiles;
 
-    /// How many places behing . should be displayed when showing times
+    /// How many places behind . should be displayed when showing times
     public $TimingAccuracy = 4;
 
-    /// How many places behing . should be displayed when showing percentages
+    /// How many places behind . should be displayed when showing percentages
     public $PercentAccuracy = 4;
 
     /// Whether to use external CSS or output own CSS. True if external is to be used.
@@ -1886,28 +1945,8 @@ td.timingpoint2
 
     /// A list of debug reports that appears at the top of debug output
     public $topReportsList;
+
+    private $recursionFlag = false;
 }
 
-/*!
-  Helper function for eZDebug, called whenever a PHP error occurs.
-  The error is then handled by the eZDebug class.
-*/
-
-function eZDebugErrorHandler( $errno, $errstr, $errfile, $errline )
-{
-    if ( $GLOBALS['eZDebugRecursionFlag'] )
-    {
-        print( "Fatal debug error: A recursion in debug error handler was detected, aborting debug message.<br/>" );
-        $GLOBALS['eZDebugRecursionFlag'] = false;
-        return;
-    }
-
-    $GLOBALS['eZDebugRecursionFlag'] = true;
-    $debug = eZDebug::instance();
-    $result = $debug->errorHandler( $errno, $errstr, $errfile, $errline );
-    $GLOBALS['eZDebugRecursionFlag'] = false;
-    return $result;
-}
-$GLOBALS['eZDebugRecursionFlag'] = false;
-
 ?>
