@@ -5,9 +5,9 @@
 // Created on: <18-Apr-2002 14:05:21 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -38,10 +38,6 @@
 
 */
 
-require_once( "lib/ezutils/classes/ezdebug.php" );
-require_once( "lib/ezutils/classes/ezsession.php" );
-//include_once( "lib/ezutils/classes/ezsys.php" );
-
 class eZHTTPTool
 {
     /*!
@@ -68,17 +64,21 @@ class eZHTTPTool
     }
 
     /*!
-     \return a reference to the HTTP post variable $var, or null if it does not exist.
+     \return the HTTP post variable $var, or $fallbackValue if the post variable does not exist , or null if $fallbackValue is omitted.
      \sa variable
     */
-    function postVariable( $var )
+   function postVariable( $var, $fallbackValue = null )
     {
-        $ret = null;
+        $ret = $fallbackValue;
         if ( isset( $_POST[$var] ) )
+        {
             $ret = $_POST[$var];
-        else
+        }
+        else if ( $ret === null )
+        {
             eZDebug::writeWarning( "Undefined post variable: $var",
                                    "eZHTTPTool" );
+        }
         return $ret;
     }
 
@@ -101,17 +101,21 @@ class eZHTTPTool
     }
 
     /*!
-     \return a reference to the HTTP get variable $var, or null if it does not exist.
+     \return the HTTP get variable $var, or $fallbackValue if the get variable does not exist, or null if $fallbackValue is omitted.
      \sa variable
     */
-    function getVariable( $var )
+    function getVariable( $var, $fallbackValue = null )
     {
-        $ret = null;
+        $ret = $fallbackValue;
         if ( isset( $_GET[$var] ) )
+        {
             $ret = $_GET[$var];
-        else
+        }
+        else if ( $ret === null )
+        {
             eZDebug::writeWarning( "Undefined get variable: $var",
                                    "eZHTTPTool" );
+        }
         return $ret;
     }
 
@@ -142,10 +146,10 @@ class eZHTTPTool
     }
 
     /*!
-     \return a reference to the HTTP post/get variable $var, or null if it does not exist.
+     \return the HTTP post/get variable $var, or $fallbackValue if the post/get variable does not exist , or null if $fallbackValue is omitted.
      \sa postVariable
     */
-    function variable( $var )
+    function variable( $var, $fallbackValue = null )
     {
         if ( isset( $_POST[$var] ) )
         {
@@ -155,7 +159,12 @@ class eZHTTPTool
         {
             return $_GET[$var];
         }
-        $ret = false;
+        $ret = $fallbackValue;
+        if ( $ret === null )
+        {
+            eZDebug::writeWarning( "Undefined post/get variable: $var",
+                                   "eZHTTPTool" );
+        }
         return $ret;
     }
 
@@ -202,7 +211,7 @@ class eZHTTPTool
         {
             $GLOBALS["eZHTTPToolInstance"] = new eZHTTPTool();
             $GLOBALS["eZHTTPToolInstance"]->createPostVarsFromImageButtons();
-            eZSessionStart();
+            eZSession::start();
         }
 
         return $GLOBALS["eZHTTPToolInstance"];
@@ -213,18 +222,18 @@ class eZHTTPTool
 
      Sends a http request to the specified host. Using https:// requires PHP 4.3.0, and compiled in OpenSSL support.
 
-     \param http/https address, only path to send request to eZ Publish.
+     \param uri http/https address, only path to send request to eZ Publish.
             examples: http://ez.no, https://secure.ez.no, ssl://secure.ez.no, content/view/full/2
-     \param port, default 80
-     \param post parameters array (optional), if no post parameters are present, a get request will be send.
-     \param user agent, default will be eZ Publish
-     \param passtrough, will send result directly to client, default false
+     \param port which port to connect to, default 80
+     \param postParameters post parameters array (optional), if no post parameters are present, a get request will be send.
+     \param userAgent user agent, default will be eZ Publish
+     \param passthrough will send result directly to client, default false
 
      \return result if http request, or return false if an error occurs.
              If pipetrough, program will end here.
 
     */
-    static function sendHTTPRequest( $uri, $port = 80, $postParameters = false, $userAgent = 'eZ Publish', $passtrough = true )
+    static function sendHTTPRequest( $uri, $port = 80, $postParameters = false, $userAgent = 'eZ Publish', $passthrough = true )
     {
         preg_match( "/^((http[s]?:\/\/)([a-zA-Z0-9_.]+))?([\/]?[~]?(\.?[^.]+[~]?)*)/i", $uri, $matches );
         $protocol = $matches[2];
@@ -358,7 +367,6 @@ class eZHTTPTool
             header( 'Content-Location: ' . $uri );
 
             fpassthru( $fp );
-            require_once( 'lib/ezutils/classes/ezexecution.php' );
             eZExecution::cleanExit();
         }
         else
@@ -423,8 +431,8 @@ class eZHTTPTool
         {
             return $_SERVER['PHP_AUTH_USER'];
         }
-        elseif ( substr( php_sapi_name(), 0, 3 ) == 'cgi' and 
-                 array_key_exists( $AUTHKey, $_SERVER ) and 
+        elseif ( substr( php_sapi_name(), 0, 3 ) == 'cgi' and
+                 array_key_exists( $AUTHKey, $_SERVER ) and
                  preg_match('/Basic\s+(.*)$/i', $_SERVER[$AUTHKey], $matches ) )
         {
             list( $name, $password ) = explode( ':', base64_decode( $matches[1] ) );
@@ -448,8 +456,8 @@ class eZHTTPTool
         {
             return $_SERVER['PHP_AUTH_PW'];
         }
-        elseif ( substr( php_sapi_name(), 0, 3 ) == 'cgi' and 
-                 array_key_exists( $AUTHKey, $_SERVER ) and 
+        elseif ( substr( php_sapi_name(), 0, 3 ) == 'cgi' and
+                 array_key_exists( $AUTHKey, $_SERVER ) and
                  preg_match('/Basic\s+(.*)$/i', $_SERVER[$AUTHKey], $matches ) )
         {
             list( $name, $password ) = explode( ':', base64_decode( $matches[1] ) );
@@ -736,7 +744,7 @@ class eZHTTPTool
      \param $justCheckURL if true, we should check url only not downloading data.
      \return data from \p $url, false if invalid URL
     */
-    static function getDataByURL( $url, $justCheckURL = false )
+    static function getDataByURL( $url, $justCheckURL = false, $userAgent = false )
     {
         // First try CURL
         if ( extension_loaded( 'curl' ) )
@@ -749,6 +757,11 @@ class eZHTTPTool
                 curl_setopt( $ch, CURLOPT_NOBODY, 1 );
             }
 
+            if ( $userAgent )
+            {
+                curl_setopt( $ch, CURLOPT_USERAGENT, $userAgent );
+            }
+
             $ini = eZINI::instance();
             $proxy = $ini->hasVariable( 'ProxySettings', 'ProxyServer' ) ? $ini->variable( 'ProxySettings', 'ProxyServer' ) : false;
             // If we should use proxy
@@ -782,6 +795,12 @@ class eZHTTPTool
 
             return $data;
         }
+
+        if ( $userAgent )
+        {
+            ini_set( 'user_agent', $userAgent );
+        }
+
         // Open and read url
         $fid = fopen( $url, 'r' );
         if ( $fid === false )
