@@ -5,9 +5,9 @@
 // Created on: <15-Aug-2002 12:44:57 sp>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezmimetype.php
+/*! \file
 */
 
 /*!
@@ -62,6 +62,16 @@ class eZMimeType
         $this->PrefixList = array();
         $this->MIMEList = array();
 
+        $ini = eZINI::instance( 'mime.ini' );
+        $this->QuickMIMETypes = array();
+        foreach ( $ini->groups() as $extension => $blockValues )
+        {
+            foreach ( $blockValues['Types'] as $type )
+            {
+                $this->QuickMIMETypes[] = array( $extension, $type );
+            }
+        }
+
         foreach ( $this->QuickMIMETypes as $quickMIMEType )
         {
             $mimeEntry =& $this->MIMEList[$quickMIMEType[1]];
@@ -427,206 +437,6 @@ class eZMimeType
         );
 
     /// A list of suffixes and their MIME types, this is used to quickly initialize the system.
-    /// Should be removed to a .ini file or other external file
-    public $QuickMIMETypes = array(
-        array( 'ezpkg', 'application/x-ezpublish-package' ),
-        array( 'ez', 'application/andrew-inset' ),
-        array( 'hqx', 'application/mac-binhex40' ),
-        array( 'cpt', 'application/mac-compactpro' ),
-        array( 'doc', 'application/msword' ),
-        array( 'bin', 'application/octet-stream' ),
-        array( 'dms', 'application/octet-stream' ),
-        array( 'lha', 'application/octet-stream' ),
-        array( 'lzh', 'application/octet-stream' ),
-        array( 'exe', 'application/octet-stream' ),
-        array( 'class', 'application/octet-stream' ),
-        array( 'oda', 'application/oda' ),
-        array( 'pdf', 'application/pdf' ),
-        array( 'ps', 'application/postscript' ),
-        array( 'eps', 'application/postscript' ),
-        array( 'ai', 'application/postscript' ),
-        array( 'rtf', 'application/rtf' ),
-        array( 'sgml', 'application/sgml' ),
-        array( 'ppt', 'application/vnd.ms-powerpoint' ),
-        array( 'xls', 'application/vnd.ms-excel' ),
-        array( 'slc', 'application/vnd.wap.slc' ),
-        array( 'sic', 'application/vnd.wap.sic' ),
-        array( 'wmlc', 'application/vnd.wap.wmlc' ),
-        array( 'wmlsc', 'application/vnd.wap.wmlscriptc' ),
-        array( 'bcpio', 'application/x-bcpio' ),
-        array( 'bz2', 'application/x-bzip2' ),
-        array( 'vcd', 'application/x-cdlink' ),
-        array( 'pgn', 'application/x-chess-pgn' ),
-        array( 'cpio', 'application/x-cpio' ),
-        array( 'csh', 'application/x-csh' ),
-        array( 'dcr', 'application/x-director' ),
-        array( 'dir', 'application/x-director' ),
-        array( 'dxr', 'application/x-director' ),
-        array( 'dvi', 'application/x-dvi' ),
-        array( 'spl', 'application/x-futuresplash' ),
-        array( 'gtar', 'application/x-gtar' ),
-        array( 'gz', 'application/x-gzip' ),
-        array( 'tgz', 'application/x-gzip' ),
-        array( 'hdf', 'application/x-hdf' ),
-        array( 'js', 'application/x-javascript' ),
-        array( 'kwd', 'application/x-kword' ),
-        array( 'kwt', 'application/x-kword' ),
-        array( 'ksp', 'application/x-kspread' ),
-        array( 'kpr', 'application/x-kpresenter' ),
-        array( 'kpt', 'application/x-kpresenter' ),
-        array( 'chrt', 'application/x-kchart' ),
-        array( 'kil', 'application/x-killustrator' ),
-        array( 'skp', 'application/x-koan' ),
-        array( 'skd', 'application/x-koan' ),
-        array( 'skt', 'application/x-koan' ),
-        array( 'skm', 'application/x-koan' ),
-        array( 'latex', 'application/x-latex' ),
-        array( 'nc', 'application/x-netcdf' ),
-        array( 'cdf', 'application/x-netcdf' ),
-        array( 'rpm', 'application/x-rpm' ),
-        array( 'sh', 'application/x-sh' ),
-        array( 'shar', 'application/x-shar' ),
-        array( 'swf', 'application/x-shockwave-flash' ),
-        array( 'sit', 'application/x-stuffit' ),
-        array( 'sv4cpio', 'application/x-sv4cpio' ),
-        array( 'sv4crc', 'application/x-sv4crc' ),
-        array( 'tar', 'application/x-tar' ),
-        array( 'tcl', 'application/x-tcl' ),
-        array( 'tex', 'application/x-tex' ),
-        array( 'texinfo', 'application/x-texinfo' ),
-        array( 'texi', 'application/x-texinfo' ),
-        array( 't', 'application/x-troff' ),
-        array( 'tr', 'application/x-troff' ),
-        array( 'roff', 'application/x-troff' ),
-        array( 'man', 'application/x-troff-man' ),
-        array( 'me', 'application/x-troff-me' ),
-        array( 'ms', 'application/x-troff-ms' ),
-        array( 'ustar', 'application/x-ustar' ),
-        array( 'src', 'application/x-wais-source' ),
-        array( 'zip', 'application/zip' ),
-        array( 'mid', 'audio/midi' ),
-        array( 'midi', 'audio/midi' ),
-        array( 'kar', 'audio/midi' ),
-        array( 'mpga', 'audio/mpeg' ),
-        array( 'mp2', 'audio/mpeg' ),
-        array( 'mp3', 'audio/mpeg' ),
-        array( 'ra', 'audio/x-realaudio' ),
-        array( 'pdb', 'chemical/x-pdb' ),
-        array( 'xyz', 'chemical/x-pdb' ),
-        array( 'gif', 'image/gif' ),
-        array( 'ief', 'image/ief' ),
-        array( 'jpg', 'image/jpeg' ),
-        array( 'jpeg', 'image/jpeg' ),
-        array( 'jpe', 'image/jpeg' ),
-        array( 'png', 'image/png' ),
-        array( 'tif', 'image/tiff' ),
-        array( 'tiff', 'image/tiff' ),
-        array( 'pcx', 'image/x-pcx' ),
-
-        // XML media types as defined in RFC 3023
-        array( 'xml', 'text/xml' ),
-        array( 'svg', 'image/svg+xml' ),
-        array( 'svgz', 'image/svg+xml' ),
-        array( 'ent', 'application/xml-external-parsed-entity' ),
-        array( 'dtd', 'application/xml-dtd' ),
-        array( 'mod', 'application/xml-dtd' ),
-        array( 'xsl', 'application/xslt+xml' ),
-        array( 'xslt', 'application/xslt+xml' ),
-        array( 'rdf', 'application/rdf+xml' ),
-        array( 'mml', 'application/mathml+xml' ),
-
-        array( 'wbmp', 'image/vnd.wap.wbmp' ),
-        array( 'ras', 'image/x-cmu-raster' ),
-        array( 'pnm', 'image/x-portable-anymap' ),
-        array( 'pbm', 'image/x-portable-bitmap' ),
-        array( 'pgm', 'image/x-portable-graymap' ),
-        array( 'ppm', 'image/x-portable-pixmap' ),
-        array( 'rgb', 'image/x-rgb' ),
-        array( 'xbm', 'image/x-xbitmap' ),
-        array( 'xpm', 'image/x-xpixmap' ),
-        array( 'xwd', 'image/x-xwindowdump' ),
-        array( 'bmp', 'image/bmp' ),
-        array( 'pict', 'image/x-pict' ),
-        array( 'pct', 'image/x-pict' ),
-        array( 'tga', 'image/tga' ),
-        array( 'xcf', 'image/x-xcf-gimp' ),
-        array( 'psd', 'application/x-photoshop' ),
-        array( 'igs', 'model/iges' ),
-        array( 'iges', 'model/iges' ),
-        array( 'msh', 'model/mesh' ),
-        array( 'mesh', 'model/mesh' ),
-        array( 'silo', 'model/mesh' ),
-        array( 'wrl', 'model/vrml' ),
-        array( 'vrml', 'model/vrml' ),
-        array( 'css', 'text/css' ),
-        array( 'txt', 'text/plain' ),
-        array( 'asc', 'text/plain' ),
-        array( 'rtx', 'text/richtext' ),
-        array( 'rtf', 'text/rtf' ),
-        array( 'sgml', 'text/sgml' ),
-        array( 'sgm', 'text/sgml' ),
-        array( 'tsv', 'text/tab-separated-values' ),
-        array( 'sl', 'text/vnd.wap.sl' ),
-        array( 'si', 'text/vnd.wap.si' ),
-        array( 'wml', 'text/vnd.wap.wml' ),
-        array( 'wmls', 'text/vnd.wap.wmlscript' ),
-        array( 'etx', 'text/x-setext' ),
-        array( 'mpeg', 'video/mpeg' ),
-        array( 'mpg', 'video/mpeg' ),
-        array( 'mpe', 'video/mpeg' ),
-        array( 'mov', 'video/quicktime' ),
-        array( 'qt', 'video/quicktime' ),
-        array( 'avi', 'video/x-msvideo' ),
-        array( 'movie', 'video/x-sgi-movie' ),
-        array( 'ice', 'x-conference/x-cooltalk' ),
-        array( 'rmm', 'audio/x-pn-realaudio' ),
-        array( 'ram', 'audio/x-pn-realaudio' ),
-        array( 'ra', 'audio/vnd.rn-realaudio' ),
-        array( 'smi', 'application/smil' ),
-        array( 'smil', 'application/smil' ),
-        array( 'rt', 'text/vnd.rn-realtext' ),
-        array( 'rv', 'video/vnd.rn-realvideo' ),
-        array( 'rf', 'image/vnd.rn-realflash' ),
-        array( 'swf', 'image/vnd.rn-realflash' ),
-        array( 'rf', 'application/x-shockwave-flash2-preview' ),
-        array( 'swf', 'application/x-shockwave-flash2-preview' ),
-        array( 'flv', 'video/x-flv' ),
-        array( 'sdp', 'application/sdp' ),
-        array( 'sdp', 'application/x-sdp' ),
-        array( 'rm', 'application/vnd.rn-realmedia' ),
-        array( 'rp', 'image/vnd.rn-realpix' ),
-        array( 'wav', 'audio/wav' ),
-        array( 'wav', 'audio/x-wav' ),
-        array( 'wav', 'audio/x-pn-wav' ),
-        array( 'wav', 'audio/x-pn-windows-acm' ),
-        array( 'au', 'audio/basic' ),
-        array( 'au', 'audio/x-pn-au' ),
-        array( 'aiff', 'audio/aiff' ),
-        array( 'af', 'audio/aiff' ),
-        array( 'aiff', 'audio/x-aiff' ),
-        array( 'af', 'audio/x-aiff' ),
-        array( 'aiff', 'audio/x-pn-aiff' ),
-        array( 'af', 'audio/x-pn-aiff' ),
-        array( 'html', 'text/html' ),
-        array( 'htm', 'text/html' ),
-        array( 'sxw', 'application/vnd.sun.xml.writer' ),
-        array( 'sxc', 'application/vnd.sun.xml.calc' ),
-        array( 'sxi', 'application/vnd.sun.xml.impress' ),
-        array( 'odt', 'application/vnd.oasis.opendocument.text' ),
-        array( 'ods', 'application/vnd.oasis.opendocument.spreadsheet' ),
-        array( 'odp', 'application/vnd.oasis.opendocument.presentation' ),
-        array( 'odg', 'application/vnd.oasis.opendocument.graphics' ),
-        array( 'odc', 'application/vnd.oasis.opendocument.chart' ),
-        array( 'odf', 'application/vnd.oasis.opendocument.formula' ),
-        array( 'odb', 'application/vnd.oasis.opendocument.database' ),
-        array( 'odi', 'application/vnd.oasis.opendocument.image' ),
-        array( 'odm', 'application/vnd.oasis.opendocument.text-master' ),
-        array( 'ott', 'application/vnd.oasis.opendocument.text-template' ),
-        array( 'ots', 'application/vnd.oasis.opendocument.spreadsheet-template' ),
-        array( 'otp', 'application/vnd.oasis.opendocument.presentation-template' ),
-        array( 'otg', 'application/vnd.oasis.opendocument.graphics-template' ),
-        array( 'asf', 'video/x-ms-asf' ),
-        array( 'wmv', 'video/x-ms-wmv' )
-        );
+    public $QuickMIMETypes = array();
 }
 ?>
