@@ -5,9 +5,9 @@
 // Created on: <17-Apr-2002 11:11:39 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -33,8 +33,6 @@
 
 */
 
-require_once( "lib/ezutils/classes/ezdebug.php" );
-
 class eZModule
 {
     const STATUS_IDLE = 0;
@@ -47,9 +45,9 @@ class eZModule
     const HOOK_STATUS_CANCEL_RUN = 1;
     const HOOK_STATUS_FAILED = 2;
 
-    function eZModule( $path, $file, $moduleName )
+    function eZModule( $path, $file, $moduleName, $checkFileExistence = true )
     {
-        $this->initialize( $path, $file, $moduleName );
+        $this->initialize( $path, $file, $moduleName, $checkFileExistence);
     }
 
     /*!
@@ -59,9 +57,9 @@ class eZModule
      of that file, it will then assume that some variables were set
      which defines the module and it's view/functions.
     */
-    function initialize( $path, $file, $moduleName )
+    function initialize( $path, $file, $moduleName, $checkFileExistence = true )
     {
-        if ( file_exists( $file ) )
+        if ( $checkFileExistence === false || file_exists( $file ) )
         {
             unset( $FunctionList );
             unset( $Module );
@@ -307,7 +305,7 @@ class eZModule
             $errorType = 'kernel';
         }
         $errorModule = eZModule::errorModule();
-        $module = eZModule::findModule( $errorModule['module'] );
+        $module = eZModule::findModule( $errorModule['module'], $this );
 
         if ( $module === null )
         {
@@ -500,7 +498,6 @@ class eZModule
             return $viewData['params'];
         }
         return null;
-        return $retValue;
     }
 
     /*!
@@ -679,7 +676,6 @@ class eZModule
             $view = eZModule::currentView();
         if ( isset( $this->ViewActions[$view] ) )
             return $this->ViewActions[$view];
-        //include_once( "lib/ezutils/classes/ezhttptool.php" );
         $http = eZHTTPTool::instance();
         if ( isset( $this->Functions[$view]['default_action'] ) )
         {
@@ -757,7 +753,6 @@ class eZModule
         if ( isset( $this->ViewActionParameters[$view][$parameterName] ) )
             return $this->ViewActionParameters[$view][$parameterName];
         $currentAction = $this->currentAction( $view );
-        //include_once( "lib/ezutils/classes/ezhttptool.php" );
         $http = eZHTTPTool::instance();
         if ( isset( $this->Functions[$view]['post_action_parameters'][$currentAction] ) )
         {
@@ -799,7 +794,6 @@ class eZModule
         if ( isset( $this->ViewActionParameters[$view][$parameterName] ) )
             return true;
         $currentAction = $this->currentAction( $view );
-        //include_once( "lib/ezutils/classes/ezhttptool.php" );
         $http = eZHTTPTool::instance();
         if ( isset( $this->Functions[$view]['post_action_parameters'][$currentAction] ) )
         {
@@ -933,7 +927,7 @@ class eZModule
                             }
                             else if ( $expandParameters )
                             {
-                                $retVal = call_user_method_array( $functionName, $object, array_merge( array( $this ), $parameters ) );
+                                $retVal = call_user_func_array( array( $object, $functionName ), array_merge( array( $this ), $parameters ) );
                             }
                             else
                             {
@@ -1051,7 +1045,7 @@ class eZModule
                                defined parameters.
      \return null if function could not be run or no return value was found.
     */
-    function run( $functionName, $parameters, $overrideParameters = false, $userParameters = false )
+    function run( $functionName, $parameters = array(), $overrideParameters = false, $userParameters = false )
     {
         if ( count( $this->Functions ) > 0 and
              !isset( $this->Functions[$functionName] ) )
@@ -1185,7 +1179,6 @@ class eZModule
         $params["FunctionName"] = $functionName;
         $params["Parameters"] = $parameters;
         $params_as_var = isset( $this->Module["variable_params"] ) ? $this->Module["variable_params"] : false;
-        //include_once( "lib/ezutils/classes/ezprocess.php" );
         $this->ExitStatus = eZModule::STATUS_OK;
 //        eZDebug::writeNotice( $params, 'module parameters1' );
 
@@ -1288,8 +1281,6 @@ class eZModule
     */
     static function activeModuleRepositories( $useExtensions = true )
     {
-        //include_once( 'lib/ezutils/classes/ezini.php' );
-        //include_once( 'lib/ezutils/classes/ezextension.php' );
         $moduleINI = eZINI::instance( 'module.ini' );
         $moduleRepositories = $moduleINI->variable( 'ModuleSettings', 'ModuleRepositories' );
 
@@ -1304,7 +1295,13 @@ class eZModule
             {
                 $extPath = $extensionDirectory . '/' . $extensionRepository;
                 $modulePath = $extPath . '/modules';
-                if ( file_exists( $modulePath ) )
+                if ( !in_array( $extensionRepository, $activeExtensions ) )
+                {
+                    eZDebug::writeWarning( "Extension '$extensionRepository' was reported to have modules but has not yet been activated.\n" .
+                                           "Check the setting ModuleSettings/ExtensionRepositories in module.ini for your extensions\n" .
+                                           "or make sure it is activated in the setting ExtensionSettings/ActiveExtensions in site.ini." );
+                }
+                else if ( file_exists( $modulePath ) )
                 {
                     $globalExtensionRepositories[] = $modulePath;
                 }
@@ -1314,12 +1311,6 @@ class eZModule
                                            "Check the setting ModuleSettings/ExtensionRepositories in module.ini for your extensions.\n" .
                                            "You should probably remove this extension from the list." );
                 }
-                else if ( !in_array( $extensionRepository, $activeExtensions ) )
-                {
-                    eZDebug::writeWarning( "Extension '$extensionRepository' was reported to have modules but has not yet been activated.\n" .
-                                           "Check the setting ModuleSettings/ExtensionRepositories in module.ini for your extensions\n" .
-                                           "or make sure it is activated in the setting ExtensionSettings/ActiveExtensions in site.ini." );
-                }
                 else
                 {
                     eZDebug::writeWarning( "Extension '$extensionRepository' does not have the subdirectory 'modules' allthough it reported it had modules.\n" .
@@ -1375,23 +1366,28 @@ class eZModule
      additional path.
      \param $moduleName The name of the module to find
      \param $pathList Is either an array with path strings or a single path string
+     \param $showError If true an error will be shown if the module it not found.
     */
-    static function exists( $moduleName, $pathList = null )
+    static function exists( $moduleName, $pathList = null, $showError = false )
     {
-        return eZModule::findModule( $moduleName, $pathList );
+        $module = null;
+        return eZModule::findModule( $moduleName, $module, $pathList, $showError );
     }
 
     /*!
      \static
-     Tries to locate the module named \a $moduleName and returns the eZModule object.
+     Tries to locate the module named \a $moduleName, sets the \a $module parameter with the eZModule object
+     and returns the eZModule object. If \a $module is already a module object its contents are overwritten.
      Returns \c null if no module can be found.
 
      It uses the globalPathList() to search for modules, use \a $pathList to add
      additional path.
      \param $moduleName The name of the module to find
+     \param $module
      \param $pathList Is either an array with path strings or a single path string
+     \param $showError If true an error will be shown if the module it not found.
     */
-    static function findModule( $moduleName, $pathList = null )
+    static function findModule( $moduleName, $module = null, $pathList = null, $showError = false )
     {
         if ( $pathList === null )
             $pathList = array();
@@ -1410,8 +1406,10 @@ class eZModule
             $file = "$dir/module.php";
             if ( file_exists( $file ) )
             {
-                $module = new eZModule( $path, $file, $moduleName );
-                $module->initialize( $path, $file, $moduleName );
+                if ( $module === null )
+                    $module = new eZModule( $path, $file, $moduleName, false );
+                else
+                    $module->initialize( $path, $file, $moduleName, false );
                 return $module;
             }
             else if ( !file_exists( $dir ) )
@@ -1439,7 +1437,8 @@ class eZModule
             if ( count( $triedDirList ) > 0 )
                 $msg.= "\nThese directories were tried but none of them exists:\n" . implode( ", ", $triedDirList );
         }
-        eZDebug::writeWarning( $msg );
+        if ( $showError )
+            eZDebug::writeWarning( $msg );
 
         return null;
     }
