@@ -5,9 +5,9 @@
 // Created on: <06-Oct-2002 16:27:36 amos>
 //
 // SOFTWARE NAME: eZ Publish
-// SOFTWARE RELEASE: 4.0.0
-// BUILD VERSION: 20988
-// COPYRIGHT NOTICE: Copyright (C) 1999-2007 eZ Systems AS
+// SOFTWARE RELEASE: 4.1.3
+// BUILD VERSION: 23650
+// COPYRIGHT NOTICE: Copyright (C) 1999-2009 eZ Systems AS
 // SOFTWARE LICENSE: GNU General Public License v2.0
 // NOTICE: >
 //   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@
 //
 //
 
-/*! \file ezmoduleoperationinfo.php
+/*! \file
 */
 
 /*!
@@ -35,11 +35,6 @@
 
 */
 
-//include_once( 'lib/ezutils/classes/ezmodule.php' );
-require_once( 'lib/ezutils/classes/ezdebug.php' );
-//include_once( 'lib/ezutils/classes/ezoperationmemento.php' );
-//include_once( 'kernel/classes/eztrigger.php' );
-
 class eZModuleOperationInfo
 {
     const ERROR_NO_CLASS = 5;
@@ -59,7 +54,6 @@ class eZModuleOperationInfo
         $this->ModuleName = $moduleName;
         $this->IsValid = false;
         $this->OperationList = array();
-        $this->UseOldCall = false;
         $this->Memento = null;
         $this->UseTriggers = $useTriggers;
     }
@@ -168,6 +162,10 @@ class eZModuleOperationInfo
             if ( isset( $operationDefinition['keys'] ) )
                 $operationKeys = $operationDefinition['keys'];
             $operationParameterDefinitions = $operationDefinition['parameters'];
+
+            $db = eZDB::instance();
+            $db->begin();
+
             $this->storeOperationMemento( $operationKeys, $operationParameterDefinitions, $operationParameters, $bodyCallCount, $operationName );
 
             $runOperation = true;
@@ -261,6 +259,8 @@ class eZModuleOperationInfo
             }
             */
             $this->Memento = null;
+
+            $db->commit();
         }
         else
         {
@@ -734,7 +734,7 @@ class eZModuleOperationInfo
             }
         }
 
-        return $this->callClassMethod( $methodName, $classObject, $parameterArray );
+        return call_user_func_array( array( $classObject, $methodName ), $parameterArray );
     }
 
     function objectForClass( $className )
@@ -751,12 +751,12 @@ class eZModuleOperationInfo
         return $GLOBALS['eZModuleOperationClassObjectList'][$className] = new $className();
     }
 
+    /*!
+     \deprecated use call_user_func_array() instead
+    */
     function callClassMethod( $methodName, $classObject, $parameterArray )
     {
-        if ( $this->UseOldCall )
-            return call_user_method_array( $methodName, $classObject, $parameterArray );
-        else
-            return call_user_func_array( array( $classObject, $methodName ), $parameterArray );
+        return call_user_func_array( array( $classObject, $methodName ), $parameterArray );
     }
 
 
@@ -764,7 +764,6 @@ class eZModuleOperationInfo
     public $ModuleName;
     public $FunctionList;
     public $IsValid;
-    public $UseOldCall;
     public $UseTriggers = false;
 }
 
